%%
%% This is file `xsenc.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% ucs.dtx  (with options: `xsenc.def')
%% 
%% Copyright 2001 Dominique Unruh  <unruh@ut.ee>
%% Copyright 2013 Wolfgang Jeltsch <wolfgang@cs.ioc.ee>
%% Copyright 2022 David Carlisle https://github.com/LaTeX-Package-Repositories/ucs
%% 
%% This program is provided under the terms of the LaTeX Project Public License with some
%% modifications. See the file LICENSE for information.
%% 
\NeedsTeXFormat{LaTeX2e}[1998/12/01]%
\ProvidesFile{xsenc.def}[Experimental XS]%
\DeclareFontEncoding{XS}{}{}%
\DeclareFontSubstitution{\LastDeclaredEncoding}{cmr}{m}{n}%
\DeclareTextSymbol\CYRII\LastDeclaredEncoding{"41}%
\DeclareTextSymbol\cyrii\LastDeclaredEncoding{"61}%
\DeclareTextSymbol\CYRJE\LastDeclaredEncoding{"42}%
\DeclareTextSymbol\cyrje\LastDeclaredEncoding{"62}%
\DeclareTextSymbol\CYRDZE\LastDeclaredEncoding{"43}%
\DeclareTextSymbol\cyrdze\LastDeclaredEncoding{"63}%
\DeclareTextSymbol\CYRYAT\LastDeclaredEncoding{"44}%
\DeclareTextSymbol\cyryat\LastDeclaredEncoding{"64}%
\DeclareTextSymbol\CYRBYUS\LastDeclaredEncoding{"45}%
\DeclareTextSymbol\cyrbyus\LastDeclaredEncoding{"65}%
\DeclareTextSymbol\CYRIZH\LastDeclaredEncoding{"46}%
\DeclareTextSymbol\cyrizh\LastDeclaredEncoding{"66}%
\DeclareTextSymbol\CYRYI\LastDeclaredEncoding{"47}%
\DeclareTextSymbol\cyryi\LastDeclaredEncoding{"67}%
\DeclareTextSymbol\CYRNG\LastDeclaredEncoding{"48}%
\DeclareTextSymbol\cyrng\LastDeclaredEncoding{"68}%
\DeclareTextSymbol\CYRIE\LastDeclaredEncoding{"49}%
\DeclareTextSymbol\cyrie\LastDeclaredEncoding{"69}%
\DeclareTextSymbol\CYRAZ\LastDeclaredEncoding{"4A}%
\DeclareTextSymbol\cyraz\LastDeclaredEncoding{"6A}%
\DeclareTextSymbol\CYRIAZ\LastDeclaredEncoding{"4B}%
\DeclareTextSymbol\cyriaz\LastDeclaredEncoding{"6B}%
\DeclareTextSymbol\CYRLYUS\LastDeclaredEncoding{"4C}%
\DeclareTextSymbol\cyrlyus\LastDeclaredEncoding{"6C}%
\DeclareTextSymbol\CYRIOTLYUS\LastDeclaredEncoding{"4D}%
\DeclareTextSymbol\cyriotlyus\LastDeclaredEncoding{"6D}%
\DeclareTextSymbol\CYRGERV\LastDeclaredEncoding{"4E}%
\DeclareTextSymbol\cyrgerv\LastDeclaredEncoding{"6E}%
\DeclareTextSymbol\CYRZEMLA\LastDeclaredEncoding{"50}%
\DeclareTextSymbol\cyrzemla\LastDeclaredEncoding{"70}%
\DeclareTextSymbol\CYRKSI\LastDeclaredEncoding{"51}%
\DeclareTextSymbol\cyrksi\LastDeclaredEncoding{"71}%
\DeclareTextSymbol\CYRVARIZHE\LastDeclaredEncoding{"52}%
\DeclareTextSymbol\cyrvarizhe\LastDeclaredEncoding{"72}%
\DeclareTextSymbol\CYRIZHE\LastDeclaredEncoding{"53}%
\DeclareTextSymbol\cyrizhe\LastDeclaredEncoding{"73}%
\DeclareTextSymbol\CYROMGA\LastDeclaredEncoding{"54}%
\DeclareTextSymbol\cyromga\LastDeclaredEncoding{"74}%
\DeclareTextSymbol\CYROMRND\LastDeclaredEncoding{"55}%
\DeclareTextSymbol\cyromrnd\LastDeclaredEncoding{"75}%
\DeclareTextSymbol\CYROT\LastDeclaredEncoding{"56}%
\DeclareTextSymbol\cyrot\LastDeclaredEncoding{"76}%
\DeclareTextSymbol\CYROMTLO\LastDeclaredEncoding{"57}%
\DeclareTextSymbol\cyromtlo\LastDeclaredEncoding{"77}%
\DeclareTextSymbol\CYRFITA\LastDeclaredEncoding{"58}%
\DeclareTextSymbol\cyrfita\LastDeclaredEncoding{"78}%
\DeclareTextSymbol\CYRKOPPA\LastDeclaredEncoding{"59}%
\DeclareTextSymbol\cyrkoppa\LastDeclaredEncoding{"79}%
\DeclareTextSymbol\CYRUK\LastDeclaredEncoding{"5A}%
\DeclareTextSymbol\cyruk\LastDeclaredEncoding{"7A}%
\DeclareTextSymbol\CYRCHERV\LastDeclaredEncoding{"80}%
\DeclareTextSymbol\cyrcherv\LastDeclaredEncoding{"A0}%
\DeclareTextSymbol\CYRPSI\LastDeclaredEncoding{"81}%
\DeclareTextSymbol\cyrpsi\LastDeclaredEncoding{"A1}%
\DeclareTextSymbol\CYRSHTA\LastDeclaredEncoding{"82}%
\DeclareTextSymbol\cyrshta\LastDeclaredEncoding{"A2}%
\DeclareTextSymbol\CYRIOTBYUS\LastDeclaredEncoding{"83}%
\DeclareTextSymbol\cyriotbyus\LastDeclaredEncoding{"A3}%
\DeclareTextSymbol\CYRIOTEST\LastDeclaredEncoding{"84}%
\DeclareTextSymbol\cyriotest\LastDeclaredEncoding{"A4}%
\DeclareTextSymbol\CYRNARROWE\LastDeclaredEncoding{"85}%
\DeclareTextSymbol\cyrnarrowe\LastDeclaredEncoding{"A5}%
\DeclareTextSymbol\CYRZELO\LastDeclaredEncoding{"86}%
\DeclareTextSymbol\cyrzelo\LastDeclaredEncoding{"A6}%
\DeclareTextSymbol\CYRVARUK\LastDeclaredEncoding{"87}%
\DeclareTextSymbol\cyrvaruk\LastDeclaredEncoding{"A7}%
\DeclareTextSymbol\CYRVIA\LastDeclaredEncoding{"88}%
\DeclareTextSymbol\cyrvia\LastDeclaredEncoding{"A8}%
\DeclareTextSymbol\CYRVLYUS\LastDeclaredEncoding{"89}%
\DeclareTextSymbol\cyrvlyus\LastDeclaredEncoding{"A9}%
\DeclareTextSymbol\CYRIZHDGR\LastDeclaredEncoding{"8A}%
\DeclareTextSymbol\cyrizhdgr\LastDeclaredEncoding{"AA}%
\DeclareTextSymbol\CYRIZHUML\LastDeclaredEncoding{"8B}%
\DeclareTextSymbol\cyrizhuml\LastDeclaredEncoding{"AB}%
\DeclareTextSymbol\CYROLG\LastDeclaredEncoding{"8C}%
\DeclareTextSymbol\cyrolg\LastDeclaredEncoding{"AC}%
\DeclareTextSymbol\CYROERY\LastDeclaredEncoding{"8D}%
\DeclareTextSymbol\cyroery\LastDeclaredEncoding{"AD}%
\DeclareTextSymbol\CYROHSN\LastDeclaredEncoding{"8E}%
\DeclareTextSymbol\cyrohsn\LastDeclaredEncoding{"AE}%
\DeclareTextSymbol\CYROOCDOT\LastDeclaredEncoding{"8F}%
\DeclareTextSymbol\cyroocdot\LastDeclaredEncoding{"AF}%
\DeclareTextSymbol\CYROOCDDOT\LastDeclaredEncoding{"90}%
\DeclareTextSymbol\cyroocddot\LastDeclaredEncoding{"B0}%
\DeclareTextSymbol\CYRVIZH\LastDeclaredEncoding{"91}%
\DeclareTextSymbol\cyrvizh\LastDeclaredEncoding{"B1}%
\DeclareTextSymbol\CYRPPETER\LastDeclaredEncoding{"92}%
\DeclareTextSymbol\cyrppeter\LastDeclaredEncoding{"B2}%
\DeclareTextSymbol\CYRTPETER\LastDeclaredEncoding{"93}%
\DeclareTextSymbol\cyrtpeter\LastDeclaredEncoding{"B3}%
\DeclareTextSymbol\CYRZELOM\LastDeclaredEncoding{"94}%
\DeclareTextSymbol\cyrzelom\LastDeclaredEncoding{"B4}%
\DeclareTextAccent\F\LastDeclaredEncoding{"00}%
\DeclareTextAccent\C\LastDeclaredEncoding{"01}%
\DeclareTextAccent\U\LastDeclaredEncoding{"02}%
\DeclareTextSymbol\cyrdash\LastDeclaredEncoding{"16}%
\DeclareTextAccent\CYRtitlo\LastDeclaredEncoding{"05}%
\DeclareTextAccent\CYRpalatal\LastDeclaredEncoding{"06}%
\DeclareTextAccent\CYRpaerok\LastDeclaredEncoding{"07}%
\DeclareTextAccent\CYRkamora\LastDeclaredEncoding{"17}%
\DeclareTextAccent\CYRpsili\LastDeclaredEncoding{"1B}%
\DeclareTextAccent\CYRdasia\LastDeclaredEncoding{"1C}%
\DeclareTextAccent\CYRzvat\LastDeclaredEncoding{"1D}%
\DeclareTextAccent\CYRpneuac\LastDeclaredEncoding{"1E}%
\DeclareTextAccent\CYRpneugrav\LastDeclaredEncoding{"1F}%
\DeclareTextAccent\CYRthousands\LastDeclaredEncoding{"9E}%
\DeclareTextAccent\CYRaccte\LastDeclaredEncoding{"08}%
\DeclareTextAccent\CYRtma\LastDeclaredEncoding{"09}%
\DeclareTextAccent\CYRlegion\LastDeclaredEncoding{"0A}%
\DeclareTextAccent\CYRleodr\LastDeclaredEncoding{"0B}%
\DeclareTextAccent\CYRvran\LastDeclaredEncoding{"0C}%
\DeclareTextAccent\CYRkoloda\LastDeclaredEncoding{"0E}%
\DeclareTextAccent\CYRtmatem\LastDeclaredEncoding{"0F}%
\DeclareTextAccent\CYRvzvat\LastDeclaredEncoding{"10}%
\DeclareTextAccent\CYRvdasia\LastDeclaredEncoding{"11}%
\DeclareTextAccent\CYRvpsili\LastDeclaredEncoding{"12}%
\DeclareTextAccent\CYRvpneuac\LastDeclaredEncoding{"13}%
\DeclareTextAccent\CYRvpneugrav\LastDeclaredEncoding{"14}%
\DeclareTextSymbol\CYRNASH\LastDeclaredEncoding{"4F}%
\DeclareTextSymbol\cyrnash\LastDeclaredEncoding{"6F}%
