%%
%% This is file `pctexwin.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% drivers.dtx  (with options: `pctexwin,nops')
%% 
%% drivers.dtx Copyright (C) 1994      David Carlisle Sebastian Rahtz
%%             Copyright (C) 1995 1996 1997 1998 1999 David Carlisle
%%             Copyright (C) 2000-2025 LaTeX Project
%% The LaTeX Project and any individual authors listed elsewhere
%% in this file.
%%
%% This file is part of the Standard LaTeX `Graphics Bundle'.
%% It may be distributed under the terms of the LaTeX Project Public
%% License, as described in lppl.txt in the base LaTeX distribution.
%% Either version 1.3 or, at your option, any later version.
%%
\ProvidesFile{pctexwin.def}
        [2016/06/17 v3.0m Driver-dependent file (DPC,SPQR)]
\def\Ginclude@eps#1{%
\message{<#1>}%
   \ifGin@clip
     \typeout{no clipping support in pctexwin}%
   \fi
   \Gin@req@width.03515\Gin@req@width
   \Gin@req@height.03515\Gin@req@height
   \special{eps:#1\space x=\strip@pt\Gin@req@width cm,
                         y=\strip@pt\Gin@req@height cm}}
\def\Ginclude@ps#1{%
\message{<#1>}%
  \ifGin@clip
    \typeout{no clipping support in pctexwin}%
  \fi
  \hbox{\kern-\Gin@llx bp\raise-\Gin@lly bp\hbox{\special{ps:#1}}}%
  \typeout{^^J%
---------------------------------------------------------^^J%
.ps graphics without bounding box information cannot be^^J%
scaled.  If the file actually contains the information,^^J%
please rename the file to .eps file extension.^^J%
---------------------------------------------------------^^J%
}}
\def\Ginclude@bmp#1{%
\message{<#1>}%
   \ifGin@clip
     \typeout{no clipping support in pctexwin}%
   \fi
   \Gin@req@width.03515\Gin@req@width
   \Gin@req@height.03515\Gin@req@height
   \special{bmp:#1\space x=\strip@pt\Gin@req@width cm,
                         y=\strip@pt\Gin@req@height cm}}
\def\Ginclude@wmf#1{%
\message{<#1>}%
   \ifGin@clip
     \typeout{no clipping support in pctexwin}%
   \fi
   \Gin@req@width.03515\Gin@req@width
   \Gin@req@height.03515\Gin@req@height
   \special{wmf:#1\space x=\strip@pt\Gin@req@width cm,
                         y=\strip@pt\Gin@req@height cm}}
\def\Gin@extensions{.eps,.ps,.wmf,.bmp}
\@namedef{Gin@rule@.bmp}#1{{bmp}{}{#1}}
\@namedef{Gin@rule@.wmf}#1{{wmf}{}{#1}}
\@namedef{Gin@rule@.ps}#1{{ps}{.ps}{#1}}
\@namedef{Gin@rule@.eps}#1{{eps}{.eps}{#1}}
\def\Gin@PS@raw#1{}
\def\Gin@PS@restored#1{}
\def\Gin@PS@literal@header#1{}
\def\Gin@PS@file@header#1{}
\endinput
%%
%% End of file `pctexwin.def'.
