%%
%% This is file `x-cp852.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% inputenx.dtx  (with options: `cp852')
%% 
%% This is a generated file.
%% 
%% Project: inputenx
%% Version: 2019/11/29 v1.12
%% 
%% Copyright (C)
%%   2006-2011 Heiko Oberdiek
%%   2016-2019 Oberdiek Package Support Group
%% 
%% This work may be distributed and/or modified under the
%% conditions of the LaTeX Project Public License, either
%% version 1.3c of this license or (at your option) any later
%% version. This version of this license is in
%%    https://www.latex-project.org/lppl/lppl-1-3c.txt
%% and the latest version of this license is in
%%    https://www.latex-project.org/lppl.txt
%% and version 1.3 or later is part of all distributions of
%% LaTeX version 2005/12/01 or later.
%% 
%% This work has the LPPL maintenance status "maintained".
%% 
%% The Current Maintainers of this work are
%% Heiko Oberdiek and the Oberdiek Package Support Group
%% https://github.com/ho-tex/inputenx/issues
%% 
%% 
%% This work consists of the main source file inputenx.dtx
%% and the derived files
%%    inputenx.sty, inputenx.pdf, inputenx.ins, inputenx.drv, ix-alias.def,
%%    ix-math.def, ix-name.def, ix-slot.def, ix-uc.def,
%%    ix-utf8enc.dfu, x-ascii.def, x-verbatim.def, x-atarist.def,
%%    x-iso-8859-1.def, x-iso-8859-2.def, x-iso-8859-3.def,
%%    x-iso-8859-4.def, x-iso-8859-5.def, x-iso-8859-8.def,
%%    x-iso-8859-9.def, x-iso-8859-10.def, x-iso-8859-13.def,
%%    x-iso-8859-14.def, x-iso-8859-15.def, x-iso-8859-16.def,
%%    x-cp437.def, x-cp850.def, x-cp852.def, x-cp855.def,
%%    x-cp858.def, x-cp865.def, x-cp866.def, x-cp1250.def,
%%    x-cp1251.def, x-cp1252.def, x-cp1255.def, x-cp1257.def,
%%    x-dec-mcs.def, x-koi8-r.def, x-mac-centeuro.def,
%%    x-mac-cyrillic.def, x-mac-roman.def, x-nextstep.def,
%%    inputenx-licrcmds.txt, inputenx-utf8enc.txt.
%% 
\ProvidesFile{x-cp852.def}%
  [2019/11/29 v1.12 Input encoding cp852 (inputenx)]%
\edef\RestoreAtCatcode{\catcode64=\the\catcode64\relax}
\makeatletter
\ProvideTextCommandDefault{\textacutedbl}{%
  \H{}%
}
\ProvideTextCommandDefault{\textasciiacute}{%
  \@tabacckludge'{}%
}
\ProvideTextCommandDefault{\textasciibreve}{%
  \u{}%
}
\ProvideTextCommandDefault{\textasciicaron}{%
  \v{}%
}
\ProvideTextCommandDefault{\textasciidieresis}{%
  \"{}%
}
\ProvideTextCommandDefault{\textblacksquare}{%
  \vrule \@width .3em \@height .4em \@depth -.1em\relax
}
\ProvideTextCommandDefault{\textcurrency}{%
  \TextSymbolUnavailable\textcurrency
}
\ProvideTextCommandDefault{\textdegree}{%
  \ensuremath{{^\circ}}%
}
\ProvideTextCommandDefault{\textdiv}{%
  \TextSymbolUnavailable\textdiv
}
\ProvideTextCommandDefault{\textlnot}{%
  \ensuremath\lnot
}
\ProvideTextCommandDefault{\texttimes}{%
  \ensuremath\times
}
\DeclareInputText{128}{\c C}
\DeclareInputText{129}{\"u}
\DeclareInputText{130}{\@tabacckludge'e}
\DeclareInputText{131}{\^a}
\DeclareInputText{132}{\"a}
\DeclareInputText{133}{\r u}
\DeclareInputText{134}{\@tabacckludge'c}
\DeclareInputText{135}{\c c}
\DeclareInputText{136}{\l}
\DeclareInputText{137}{\"e}
\DeclareInputText{138}{\H O}
\DeclareInputText{139}{\H o}
\DeclareInputText{140}{\^\i}
\DeclareInputText{141}{\@tabacckludge'Z}
\DeclareInputText{142}{\"A}
\DeclareInputText{143}{\@tabacckludge'C}
\DeclareInputText{144}{\@tabacckludge'E}
\DeclareInputText{145}{\@tabacckludge'L}
\DeclareInputText{146}{\@tabacckludge'l}
\DeclareInputText{147}{\^o}
\DeclareInputText{148}{\"o}
\DeclareInputText{149}{\v L}
\DeclareInputText{150}{\v l}
\DeclareInputText{151}{\@tabacckludge'S}
\DeclareInputText{152}{\@tabacckludge's}
\DeclareInputText{153}{\"O}
\DeclareInputText{154}{\"U}
\DeclareInputText{155}{\v T}
\DeclareInputText{156}{\v t}
\DeclareInputText{157}{\L}
\DeclareInputText{158}{\texttimes}
\DeclareInputText{159}{\v c}
\DeclareInputText{160}{\@tabacckludge'a}
\DeclareInputText{161}{\@tabacckludge'\i}
\DeclareInputText{162}{\@tabacckludge'o}
\DeclareInputText{163}{\@tabacckludge'u}
\DeclareInputText{164}{\k A}
\DeclareInputText{165}{\k a}
\DeclareInputText{166}{\v Z}
\DeclareInputText{167}{\v z}
\DeclareInputText{168}{\k E}
\DeclareInputText{169}{\k e}
\DeclareInputText{170}{\textlnot}
\DeclareInputText{171}{\@tabacckludge'z}
\DeclareInputText{172}{\v C}
\DeclareInputText{173}{\c s}
\DeclareInputText{174}{\guillemotleft}
\DeclareInputText{175}{\guillemotright}
\DeclareInputText{176}{\textltshade}
\DeclareInputText{177}{\textshade}
\DeclareInputText{178}{\textdkshade}
\DeclareInputText{179}{\textSFxi}
\DeclareInputText{180}{\textSFix}
\DeclareInputText{181}{\@tabacckludge'A}
\DeclareInputText{182}{\^A}
\DeclareInputText{183}{\v E}
\DeclareInputText{184}{\c S}
\DeclareInputText{185}{\textSFxxiii}
\DeclareInputText{186}{\textSFxxiv}
\DeclareInputText{187}{\textSFxxv}
\DeclareInputText{188}{\textSFxxvi}
\DeclareInputText{189}{\.Z}
\DeclareInputText{190}{\.z}
\DeclareInputText{191}{\textSFiii}
\DeclareInputText{192}{\textSFii}
\DeclareInputText{193}{\textSFvii}
\DeclareInputText{194}{\textSFvi}
\DeclareInputText{195}{\textSFviii}
\DeclareInputText{196}{\textSFx}
\DeclareInputText{197}{\textSFv}
\DeclareInputText{198}{\u A}
\DeclareInputText{199}{\u a}
\DeclareInputText{200}{\textSFxxxviii}
\DeclareInputText{201}{\textSFxxxix}
\DeclareInputText{202}{\textSFxl}
\DeclareInputText{203}{\textSFxli}
\DeclareInputText{204}{\textSFxlii}
\DeclareInputText{205}{\textSFxliii}
\DeclareInputText{206}{\textSFxliv}
\DeclareInputText{207}{\textcurrency}
\DeclareInputText{208}{\dj}
\DeclareInputText{209}{\DJ}
\DeclareInputText{210}{\v D}
\DeclareInputText{211}{\"E}
\DeclareInputText{212}{\v d}
\DeclareInputText{213}{\v N}
\DeclareInputText{214}{\@tabacckludge'I}
\DeclareInputText{215}{\^I}
\DeclareInputText{216}{\v e}
\DeclareInputText{217}{\textSFiv}
\DeclareInputText{218}{\textSFi}
\DeclareInputText{219}{\textblock}
\DeclareInputText{220}{\textdnblock}
\DeclareInputText{221}{\c T}
\DeclareInputText{222}{\r U}
\DeclareInputText{223}{\textupblock}
\DeclareInputText{224}{\@tabacckludge'O}
\DeclareInputText{225}{\ss}
\DeclareInputText{226}{\^O}
\DeclareInputText{227}{\@tabacckludge'N}
\DeclareInputText{228}{\@tabacckludge'n}
\DeclareInputText{229}{\v n}
\DeclareInputText{230}{\v S}
\DeclareInputText{231}{\v s}
\DeclareInputText{232}{\@tabacckludge'R}
\DeclareInputText{233}{\@tabacckludge'U}
\DeclareInputText{234}{\@tabacckludge'r}
\DeclareInputText{235}{\H U}
\DeclareInputText{236}{\@tabacckludge'y}
\DeclareInputText{237}{\@tabacckludge'Y}
\DeclareInputText{238}{\c t}
\DeclareInputText{239}{\textasciiacute}
\DeclareInputText{240}{\-}
\DeclareInputText{241}{\textacutedbl}
\DeclareInputText{242}{\k{}}
\DeclareInputText{243}{\textasciicaron}
\DeclareInputText{244}{\textasciibreve}
\DeclareInputText{245}{\textsection}
\DeclareInputText{246}{\textdiv}
\DeclareInputText{247}{\c\ }
\DeclareInputText{248}{\textdegree}
\DeclareInputText{249}{\textasciidieresis}
\DeclareInputText{250}{\.{}}
\DeclareInputText{251}{\H u}
\DeclareInputText{252}{\v R}
\DeclareInputText{253}{\v r}
\DeclareInputText{254}{\textblacksquare}
\DeclareInputText{255}{\nobreakspace}
\RestoreAtCatcode
\endinput
%%
%% End of file `x-cp852.def'.
