%%
%% This is file `fc-brazilian.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% fmtcount.dtx  (with options: `fc-brazilian.def')
%% 
%%  fmtcount.dtx
%%  Copyright 2025 Nicola Talbot (inactive), Vincent Belaïche and Erik Nijenhuis
%% 
%%  This work may be distributed and/or modified under the
%%  conditions of the LaTeX Project Public License, either version 1.3
%%  of this license or (at your option) any later version.
%%  The latest version of this license is in
%%    http://www.latex-project.org/lppl.txt
%%  and version 1.3 or later is part of all distributions of LaTeX
%%  version 2005/12/01 or later.
%% 
%%  This work has the LPPL maintenance status `maintained'.
%% 
%%  The Current Maintainer of this work is Nicola Talbot (inactive), Vincent Belaïche and Erik Nijenhuis.
%% 
%%  This work consists of the files fmtcount.dtx and fmtcount.ins and the derived files fc-american.def, fc-brazilian.def, fc-british.def, fc-dutch.def, fc-english.def, fc-francais.def, fc-french.def, fc-frenchb.def, fc-german.def, fc-germanb.def, fc-italian.def, fc-ngerman.def, fc-ngermanb.def, fc-portuges.def, fc-portuguese.def, fc-spanish.def, fc-UKenglish.def, fc-USenglish.def, fcnumparser.sty, fcprefix.sty, fmtcount.sty.
%% 
\ProvidesFCLanguage{brazilian}[2017/12/26]%
\FCloadlang{portuges}%
\global\let\@ordinalMbrazilian=\@ordinalMportuges
\global\let\@ordinalFbrazilian=\@ordinalFportuges
\global\let\@ordinalNbrazilian=\@ordinalNportuges
\global\let\@ordinalstringFbrazilian\@ordinalstringFportuges
\global\let\@ordinalstringMbrazilian\@ordinalstringMportuges
\global\let\@ordinalstringNbrazilian\@ordinalstringMportuges
\global\let\@OrdinalstringMbrazilian\@OrdinalstringMportuges
\global\let\@OrdinalstringFbrazilian\@OrdinalstringFportuges
\global\let\@OrdinalstringNbrazilian\@OrdinalstringMportuges
\newcommand*\@@teenstringbrazilian[1]{%
  \ifcase#1\relax
    dez%
    \or onze%
    \or doze%
    \or treze%
    \or quatorze%
    \or quinze%
    \or dezesseis%
    \or dezessete%
    \or dezoito%
    \or dezenove%
  \fi
}%
\global\let\@@teenstringbrazilian\@@teenstringbrazilian
\newcommand*\@@Teenstringbrazilian[1]{%
  \ifcase#1\relax
    Dez%
    \or Onze%
    \or Doze%
    \or Treze%
    \or Quatorze%
    \or Quinze%
    \or Dezesseis%
    \or Dezessete%
    \or Dezoito%
    \or Dezenove%
  \fi
}%
\global\let\@@Teenstringbrazilian\@@Teenstringbrazilian
\newcommand*{\@numberstringMbrazilian}[2]{%
  \let\@unitstring=\@@unitstringportuges
  \let\@teenstring=\@@teenstringbrazilian
  \let\@tenstring=\@@tenstringportuges
  \let\@hundredstring=\@@hundredstringportuges
  \def\@hundred{cem}\def\@thousand{mil}%
  \def\@andname{e}%
  \@@numberstringportuges{#1}{#2}%
}%
\global\let\@numberstringMbrazilian\@numberstringMbrazilian
\newcommand*{\@numberstringFbrazilian}[2]{%
  \let\@unitstring=\@@unitstringFportuges
  \let\@teenstring=\@@teenstringbrazilian
  \let\@tenstring=\@@tenstringportuges
  \let\@hundredstring=\@@hundredstringFportuges
  \def\@hundred{cem}\def\@thousand{mil}%
  \def\@andname{e}%
  \@@numberstringportuges{#1}{#2}%
}%
\global\let\@numberstringFbrazilian\@numberstringFbrazilian
\global\let\@numberstringNbrazilian\@numberstringMbrazilian
\newcommand*{\@NumberstringMbrazilian}[2]{%
  \let\@unitstring=\@@unitstringportuges
  \let\@teenstring=\@@Teenstringbrazilian
  \let\@tenstring=\@@Tenstringportuges
  \let\@hundredstring=\@@hundredstringportuges
  \def\@hundred{Cem}\def\@thousand{Mil}%
  \def\@andname{e}%
  \@@numberstringportuges{#1}{#2}%
}%
\global\let\@NumberstringMbrazilian\@NumberstringMbrazilian
\newcommand*{\@NumberstringFbrazilian}[2]{%
  \let\@unitstring=\@@UnitstringFportuges
  \let\@teenstring=\@@Teenstringbrazilian
  \let\@tenstring=\@@Tenstringportuges
  \let\@hundredstring=\@@HundredstringFportuges
  \def\@hundred{Cem}\def\@thousand{Mil}%
  \def\@andname{e}%
  \@@numberstringportuges{#1}{#2}%
}%
\global\let\@NumberstringFbrazilian\@NumberstringFbrazilian
\global\let\@NumberstringNbrazilian\@NumberstringMbrazilian
\endinput
%%
%% End of file `fc-brazilian.def'.
