%!TEX encoding = UTF-8 Unicode
%
% 
\ProvidesFile{europasscv_it.def}[europasscv Italian definitions]
% Personal information
\def\ecv@infosectionkey{\ecv@utf{Informazioni personali}}
\def\ecv@namekey{\ecv@utf{Nome e cognome}}
\def\ecv@addresskey{\ecv@utf{Indirizzo}}
\def\ecv@telkey{\ecv@utf{Telefono}}
\def\ecv@mobilekey{\ecv@utf{Cellulare}}
\def\ecv@faxkey{\ecv@utf{Fax}}
\def\ecv@emailkey{\ecv@utf{E-mail}}
\def\ecv@nationalitykey{\ecv@utf{Nazionalit\`a}}
\def\ecv@birthkey{\ecv@utf{Data di nascita}}
\def\ecv@genderkey{\ecv@utf{Sesso}}
% Footer
\def\ecv@pagekey{\ecv@utf{Pagina}}
\def\ecv@cvofkey{\ecv@utf{Curriculum vit\ae\ di}}
% Language table
\def\ecv@mothertonguekey{\ecv@utf{Lingua madre}}
\def\ecv@otherlanguageskey{\ecv@utf{Altre lingue}}
\def\ecv@assesskey{\ecv@utf{Autovalutazione}}
\def\ecv@levelkey{\ecv@utf{Livello europeo}}
\def\ecv@understandkey{\ecv@utf{Comprensione}}
\def\ecv@speakkey{\ecv@utf{Parlato}}
\def\ecv@writekey{\ecv@utf{Produzione scritta}}
\def\ecv@listenkey{\ecv@utf{Ascolto}}
\def\ecv@readkey{\ecv@utf{Lettura}}
\def\ecv@interactkey{\ecv@utf{Interazione}}
\def\ecv@productkey{\ecv@utf{Produzione orale}}
\def\ecv@langshortdesckey{\ecv@utf{Livelli: A1 e A2: Utente base -- B1 e B2: Utente autonomo -- C1 e C2: Utente avanzato}}
\def\ecv@langfooterkey{\ecv@utf{Quadro Comune Europeo di Riferimento delle Lingue}}
\def\ecv@langlinkkey{\ecv@utf{https://europass.cedefop.europa.eu/it/resources/european-language-levels-cefr}}
\def\ecv@cefbasickey{\ecv@utf{Utente elementare}}
\def\ecv@cefindepkey{\ecv@utf{Utente autonomo}}
\def\ecv@cefprofkey{\ecv@utf{Utente avanzato}}
\def\ecv@europeanunionkey{\ecv@utf{Unione Europea}}
% Digital competences self-assessment grid
\def\ecv@digitalcompetenceskey{\ecv@utf{Competenze digitali}}
\def\ecv@informationprocessingkey{\ecv@utf{Elaborazione delle informazioni}}
\def\ecv@communicationkey{\ecv@utf{Comunicazione}}
\def\ecv@contentcreationkey{\ecv@utf{Creazione di contenuti}}
\def\ecv@safetykey{\ecv@utf{Sicurezza}}
\def\ecv@problensolvingkey{\ecv@utf{Risoluzione di problemi}}
\def\ecv@digcompfooterkey{\ecv@utf{Competenze digitali - Scheda per l'autovalutazione}}
\def\ecv@digcomplinkkey{\ecv@utf{https://europass.cedefop.europa.eu/it/resources/digital-competences}}
\def\ecv@dcbasickey{\ecv@utf{Utente base}}
\def\ecv@dcindepkey{\ecv@utf{Utente autonomo}}
\def\ecv@dcprofkey{\ecv@utf{Utente avanzato}}

% Width of language columns
\def\ecv@langcola{0.15}
\def\ecv@langcolb{0.15}
\def\ecv@langcolc{0.2}
\def\ecv@langcold{0.2}
\def\ecv@langcole{0.3}

