%%
%% This is file `ix-math.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% inputenx.dtx  (with options: `math')
%% 
%% This is a generated file.
%% 
%% Project: inputenx
%% Version: 2019/11/29 v1.12
%% 
%% Copyright (C)
%%   2006-2011 Heiko Oberdiek
%%   2016-2019 Oberdiek Package Support Group
%% 
%% This work may be distributed and/or modified under the
%% conditions of the LaTeX Project Public License, either
%% version 1.3c of this license or (at your option) any later
%% version. This version of this license is in
%%    https://www.latex-project.org/lppl/lppl-1-3c.txt
%% and the latest version of this license is in
%%    https://www.latex-project.org/lppl.txt
%% and version 1.3 or later is part of all distributions of
%% LaTeX version 2005/12/01 or later.
%% 
%% This work has the LPPL maintenance status "maintained".
%% 
%% The Current Maintainers of this work are
%% Heiko Oberdiek and the Oberdiek Package Support Group
%% https://github.com/ho-tex/inputenx/issues
%% 
%% 
%% This work consists of the main source file inputenx.dtx
%% and the derived files
%%    inputenx.sty, inputenx.pdf, inputenx.ins, inputenx.drv, ix-alias.def,
%%    ix-math.def, ix-name.def, ix-slot.def, ix-uc.def,
%%    ix-utf8enc.dfu, x-ascii.def, x-verbatim.def, x-atarist.def,
%%    x-iso-8859-1.def, x-iso-8859-2.def, x-iso-8859-3.def,
%%    x-iso-8859-4.def, x-iso-8859-5.def, x-iso-8859-8.def,
%%    x-iso-8859-9.def, x-iso-8859-10.def, x-iso-8859-13.def,
%%    x-iso-8859-14.def, x-iso-8859-15.def, x-iso-8859-16.def,
%%    x-cp437.def, x-cp850.def, x-cp852.def, x-cp855.def,
%%    x-cp858.def, x-cp865.def, x-cp866.def, x-cp1250.def,
%%    x-cp1251.def, x-cp1252.def, x-cp1255.def, x-cp1257.def,
%%    x-dec-mcs.def, x-koi8-r.def, x-mac-centeuro.def,
%%    x-mac-cyrillic.def, x-mac-roman.def, x-nextstep.def,
%%    inputenx-licrcmds.txt, inputenx-utf8enc.txt.
%% 
\ProvidesFile{ix-math.def}%
  [2019/11/29 v1.12 Math list (inputenx)]%
\edef\RestoreAtCatcode{\catcode64=\the\catcode64\relax}
\makeatletter
\DeclareMathMeaning{\ss}{\beta}
\DeclareMathMeaning{\textalpha}{\alpha}
\DeclareMathMeaning{\textapproxequal}{\aprox}
\DeclareMathMeaning{\textbardbl}{\Vert}% = \|
\DeclareMathMeaning{\textbeta}{\beta}
\DeclareMathMeaning{\textbullet}{\bullet}
\DeclareMathMeaning{\textcap}{\cap}
\DeclareMathMeaning{\textcontourintegral}{\oint}
\DeclareMathMeaning{\textcopyright}{{\nfss@text{\textcopyright}}}
\DeclareMathMeaning{\textcup}{\cup}
\DeclareMathMeaning{\textdagger}{\dagger}
\DeclareMathMeaning{\textdaggerdbl}{\ddagger}
\DeclareMathMeaning{\textdegree}{{^\circ}}
\DeclareMathMeaning{\textdelta}{\delta}
\DeclareMathMeaning{\textdollar}{\mathdollar}
\DeclareMathMeaning{\textepsilon}{\varepsilon}
\DeclareMathMeaning{\textequivalence}{\equiv}
\DeclareMathMeaning{\textbraceleft}{\lbrace}
\DeclareMathMeaning{\textbraceright}{\rbrace}
\DeclareMathMeaning{\textdiv}{\div}
\DeclareMathMeaning{\textdownarrow}{\downarrow}
\DeclareMathMeaning{\textelement}{\in}
\DeclareMathMeaning{\textellipsis}{\mathellipsis}
\DeclareMathMeaning{\textGamma}{\Gamma}
\DeclareMathMeaning{\textgreaterequal}{\geq}
\DeclareMathMeaning{\textincrement}{\Delta}
\DeclareMathMeaning{\textinfinity}{\infty}
\DeclareMathMeaning{\textintegral}{\int}
\DeclareMathMeaning{\textintersection}{\cap}
\DeclareMathMeaning{\textlangle}{\langle}
\DeclareMathMeaning{\textleftarrow}{\leftarrow}
\DeclareMathMeaning{\textlessequal}{\leq}
\DeclareMathMeaning{\textlnot}{\lnot}
\DeclareMathMeaning{\textlogicalnot}{\lnot}
\DeclareMathMeaning{\textlozenge}{\diamond}
\DeclareMathMeaning{\textmu}{\mu}
\DeclareMathMeaning{\textnotequal}{\neq}
\DeclareMathMeaning{\textnsuperior}{^n}
\DeclareMathMeaning{\textohm}{\Omega}
\DeclareMathMeaning{\textOmega}{\Omega}
\DeclareMathMeaning{\textonehalf}{\frac12}
\DeclareMathMeaning{\textonequarter}{\frac14}
\DeclareMathMeaning{\textonesuperior}{^1}
\DeclareMathMeaning{\textopenbullet}{\circ}
\DeclareMathMeaning{\textparagraph}{\mathparagraph}
\DeclareMathMeaning{\textpartial}{\partial}
\DeclareMathMeaning{\textPhi}{\Phi}
\DeclareMathMeaning{\textphi}{\phi}
\DeclareMathMeaning{\textpi}{\pi}
\DeclareMathMeaning{\textproduct}{\prod}
\DeclareMathMeaning{\textrangle}{\rangle}
\DeclareMathMeaning{\textrevlogicalnot}{{\nfss@text{\textrevlogicalnot}}}
\DeclareMathMeaning{\textrightarrow}{\rightarrow}
\DeclareMathMeaning{\textsection}{\mathsection}
\DeclareMathMeaning{\textSigma}{\Sigma}
\DeclareMathMeaning{\textsigma}{\sigma}
\DeclareMathMeaning{\textsterling}{\mathsterling}
\DeclareMathMeaning{\textsummation}{\sum}
\DeclareMathMeaning{\textsurd}{\surd}
\DeclareMathMeaning{\texttau}{\tau}
\DeclareMathMeaning{\textTheta}{\Theta}
\DeclareMathMeaning{\textthreequarters}{\frac34}
\DeclareMathMeaning{\textthreesuperior}{^3}
\DeclareMathMeaning{\texttwosuperior}{^2}
\DeclareMathMeaning{\textuparrow}{\uparrow}
\RestoreAtCatcode
\endinput
%%
%% End of file `ix-math.def'.
