%!TEX encoding = UTF-8 Unicode
%
% Translation completed on 01/03/2020
\ProvidesFile{ecvit.def}[europecv Italian definitions]
% Personal information
\def\ecv@infosectionkey{\ecv@utf{Informazioni personali}}
\def\ecv@datekey{\ecv@utf{Aggiornato al }}
\def\ecv@namekey{\ecv@utf{Nome~/ Cognome}}
\def\ecv@addresskey{\ecv@utf{Indirizzo}}
\def\ecv@telkey{\ecv@utf{Telefono}}
\def\ecv@mobilekey{\ecv@utf{Mobile}}
\def\ecv@officekey{\ecv@utf{Ufficio}}
\def\ecv@faxkey{\ecv@utf{Fax}}
\def\ecv@emailkey{\ecv@utf{Email}}
\def\ecv@professionalkey{\ecv@utf{Email Professionale}}
\def\ecv@skypekey{\ecv@utf{Skype}}
\def\ecv@matrixriotkey{\ecv@utf{Matrix/Riot}}
\def\ecv@youtubekey{\ecv@utf{YouTube}}
\def\ecv@peckey{\ecv@utf{PEC}}
\def\ecv@nationalitykey{\ecv@utf{Nazionalit\`a}}
\def\ecv@birthkey{\ecv@utf{Data di nascita}}
\def\ecv@homepagekey{\ecv@utf{Sito web}}
\def\ecv@genderkey{\ecv@utf{Sesso}}
% Footer
\def\ecv@pagekey{\ecv@utf{Pagina}}
\def\ecv@cvofkey{\ecv@utf{Curriculum vit\ae\ di}}
% Language table
\def\ecv@mothertonguekey{\ecv@utf{Madrelingua}}
\def\ecv@assesskey{\ecv@utf{Autovalutazione}}
\def\ecv@levelkey{\ecv@utf{Livello europeo}}
\def\ecv@understandkey{\ecv@utf{Comprensione}}
\def\ecv@speakkey{\ecv@utf{Parlato}}
\def\ecv@writekey{\ecv@utf{Scritto}}
\def\ecv@listenkey{\ecv@utf{Ascolto}}
\def\ecv@readkey{\ecv@utf{Lettura}}
\def\ecv@interactkey{\ecv@utf{Interazione}}
\def\ecv@productkey{\ecv@utf{Produzione orale}}
\def\ecv@langfooterkey{\ecv@utf{Quadro comune europeo di riferimento per le lingue \ecv@upshape{(}ERL\ecv@upshape{)}}}
\def\ecv@cefbasickey{\ecv@utf{Livello elementare}}
\def\ecv@cefindepkey{\ecv@utf{Livello intermedio}}
\def\ecv@cefprofkey{\ecv@utf{Livello avanzato}}



\renewcommand*{\ecvbranding}{\\[5pt]\ecv@utf{\Large\textbf{E\ecv@kern u\ecv@kern
r\ecv@kern o\ecv@kern p\ecv@kern a\ecv@kern s\ecv@kern s}}}
\renewcommand*{\ecvtitle}{\ecv@utf{%
\Large\textbf{C\ecv@kern u\ecv@kern r\ecv@kern r\ecv@kern
i\ecv@kern c\ecv@kern u\ecv@kern l\ecv@kern u\ecv@kern m \ecv@kern V\ecv@kern
i\ecv@kern t\ecv@kern a\ecv@kern e}}\ecvbranding}
