%%% Unicode to TeX mapping, file uni-204.def, U+CC00..U+CCFF, autogenerated by makeunidef.pl
\ifx\ProvidesFile\undefined\else
\ProvidesFile{uni-204.def}[2022/08/07 UCS: Unicode data U+CC00..U+CCFF]%
\fi
\gdef\u@cjk@hangul#1#2#3#4{{\fontencoding{C61}\def\CJK@plane{#1#2}\selectfont\char"#3#4\relax}}%
\uc@dclc{52236}{cjkhangul}{\u@cjk@hangul136B}%
\uc@dclc{52237}{cjkhangul}{\u@cjk@hangul136C}%
\uc@dclc{52240}{cjkhangul}{\u@cjk@hangul136D}%
\uc@dclc{52244}{cjkhangul}{\u@cjk@hangul136E}%
\uc@dclc{52252}{cjkhangul}{\u@cjk@hangul136F}%
\uc@dclc{52253}{cjkhangul}{\u@cjk@hangul1370}%
\uc@dclc{52257}{cjkhangul}{\u@cjk@hangul1371}%
\uc@dclc{52258}{cjkhangul}{\u@cjk@hangul1372}%
\uc@dclc{52263}{cjkhangul}{\u@cjk@hangul1373}%
\uc@dclc{52264}{cjkhangul}{\u@cjk@hangul1374}%
\uc@dclc{52265}{cjkhangul}{\u@cjk@hangul1375}%
\uc@dclc{52268}{cjkhangul}{\u@cjk@hangul1376}%
\uc@dclc{52270}{cjkhangul}{\u@cjk@hangul1377}%
\uc@dclc{52272}{cjkhangul}{\u@cjk@hangul1378}%
\uc@dclc{52280}{cjkhangul}{\u@cjk@hangul1379}%
\uc@dclc{52281}{cjkhangul}{\u@cjk@hangul137A}%
\uc@dclc{52283}{cjkhangul}{\u@cjk@hangul137B}%
\uc@dclc{52284}{cjkhangul}{\u@cjk@hangul137C}%
\uc@dclc{52285}{cjkhangul}{\u@cjk@hangul137D}%
\uc@dclc{52286}{cjkhangul}{\u@cjk@hangul137E}%
\uc@dclc{52292}{cjkhangul}{\u@cjk@hangul137F}%
\uc@dclc{52293}{cjkhangul}{\u@cjk@hangul1380}%
\uc@dclc{52296}{cjkhangul}{\u@cjk@hangul1381}%
\uc@dclc{52300}{cjkhangul}{\u@cjk@hangul1382}%
\uc@dclc{52308}{cjkhangul}{\u@cjk@hangul1383}%
\uc@dclc{52309}{cjkhangul}{\u@cjk@hangul1384}%
\uc@dclc{52311}{cjkhangul}{\u@cjk@hangul1385}%
\uc@dclc{52312}{cjkhangul}{\u@cjk@hangul1386}%
\uc@dclc{52313}{cjkhangul}{\u@cjk@hangul1387}%
\uc@dclc{52320}{cjkhangul}{\u@cjk@hangul1388}%
\uc@dclc{52324}{cjkhangul}{\u@cjk@hangul1389}%
\uc@dclc{52326}{cjkhangul}{\u@cjk@hangul138A}%
\uc@dclc{52328}{cjkhangul}{\u@cjk@hangul138B}%
\uc@dclc{52336}{cjkhangul}{\u@cjk@hangul138C}%
\uc@dclc{52341}{cjkhangul}{\u@cjk@hangul138D}%
\uc@dclc{52376}{cjkhangul}{\u@cjk@hangul138E}%
\uc@dclc{52377}{cjkhangul}{\u@cjk@hangul138F}%
\uc@dclc{52380}{cjkhangul}{\u@cjk@hangul1390}%
\uc@dclc{52384}{cjkhangul}{\u@cjk@hangul1391}%
\uc@dclc{52392}{cjkhangul}{\u@cjk@hangul1392}%
\uc@dclc{52393}{cjkhangul}{\u@cjk@hangul1393}%
\uc@dclc{52395}{cjkhangul}{\u@cjk@hangul1394}%
\uc@dclc{52396}{cjkhangul}{\u@cjk@hangul1395}%
\uc@dclc{52397}{cjkhangul}{\u@cjk@hangul1396}%
\uc@dclc{52404}{cjkhangul}{\u@cjk@hangul1397}%
\uc@dclc{52405}{cjkhangul}{\u@cjk@hangul1398}%
\uc@dclc{52408}{cjkhangul}{\u@cjk@hangul1399}%
\uc@dclc{52412}{cjkhangul}{\u@cjk@hangul139A}%
\uc@dclc{52420}{cjkhangul}{\u@cjk@hangul139B}%
\uc@dclc{52421}{cjkhangul}{\u@cjk@hangul139C}%
\uc@dclc{52423}{cjkhangul}{\u@cjk@hangul139D}%
\uc@dclc{52425}{cjkhangul}{\u@cjk@hangul139E}%
\uc@dclc{52432}{cjkhangul}{\u@cjk@hangul139F}%
\uc@dclc{52436}{cjkhangul}{\u@cjk@hangul13A0}%
\uc@dclc{52452}{cjkhangul}{\u@cjk@hangul13A1}%
\uc@dclc{52460}{cjkhangul}{\u@cjk@hangul13A2}%
\uc@dclc{52464}{cjkhangul}{\u@cjk@hangul13A3}%
%%% Local Variables: 
%%% mode: latex
%%% coding: utf-8
%%% End: 
