%%% Unicode to TeX mapping, file uni-186.def, U+BA00..U+BAFF, autogenerated by makeunidef.pl
\ifx\ProvidesFile\undefined\else
\ProvidesFile{uni-186.def}[2022/08/07 UCS: Unicode data U+BA00..U+BAFF]%
\fi
\gdef\u@cjk@hangul#1#2#3#4{{\fontencoding{C61}\def\CJK@plane{#1#2}\selectfont\char"#3#4\relax}}%
\uc@dclc{47616}{cjkhangul}{\u@cjk@hangul09A0}%
\uc@dclc{47617}{cjkhangul}{\u@cjk@hangul09A1}%
\uc@dclc{47624}{cjkhangul}{\u@cjk@hangul09A2}%
\uc@dclc{47637}{cjkhangul}{\u@cjk@hangul09A3}%
\uc@dclc{47672}{cjkhangul}{\u@cjk@hangul09A4}%
\uc@dclc{47673}{cjkhangul}{\u@cjk@hangul09A5}%
\uc@dclc{47676}{cjkhangul}{\u@cjk@hangul09A6}%
\uc@dclc{47680}{cjkhangul}{\u@cjk@hangul09A7}%
\uc@dclc{47682}{cjkhangul}{\u@cjk@hangul09A8}%
\uc@dclc{47688}{cjkhangul}{\u@cjk@hangul09A9}%
\uc@dclc{47689}{cjkhangul}{\u@cjk@hangul09AA}%
\uc@dclc{47691}{cjkhangul}{\u@cjk@hangul09AB}%
\uc@dclc{47693}{cjkhangul}{\u@cjk@hangul09AC}%
\uc@dclc{47694}{cjkhangul}{\u@cjk@hangul09AD}%
\uc@dclc{47699}{cjkhangul}{\u@cjk@hangul09AE}%
\uc@dclc{47700}{cjkhangul}{\u@cjk@hangul09AF}%
\uc@dclc{47701}{cjkhangul}{\u@cjk@hangul09B0}%
\uc@dclc{47704}{cjkhangul}{\u@cjk@hangul09B1}%
\uc@dclc{47708}{cjkhangul}{\u@cjk@hangul09B2}%
\uc@dclc{47716}{cjkhangul}{\u@cjk@hangul09B3}%
\uc@dclc{47717}{cjkhangul}{\u@cjk@hangul09B4}%
\uc@dclc{47719}{cjkhangul}{\u@cjk@hangul09B5}%
\uc@dclc{47720}{cjkhangul}{\u@cjk@hangul09B6}%
\uc@dclc{47721}{cjkhangul}{\u@cjk@hangul09B7}%
\uc@dclc{47728}{cjkhangul}{\u@cjk@hangul09B8}%
\uc@dclc{47729}{cjkhangul}{\u@cjk@hangul09B9}%
\uc@dclc{47732}{cjkhangul}{\u@cjk@hangul09BA}%
\uc@dclc{47736}{cjkhangul}{\u@cjk@hangul09BB}%
\uc@dclc{47747}{cjkhangul}{\u@cjk@hangul09BC}%
\uc@dclc{47748}{cjkhangul}{\u@cjk@hangul09BD}%
\uc@dclc{47749}{cjkhangul}{\u@cjk@hangul09BE}%
\uc@dclc{47751}{cjkhangul}{\u@cjk@hangul09BF}%
\uc@dclc{47756}{cjkhangul}{\u@cjk@hangul09C0}%
\uc@dclc{47784}{cjkhangul}{\u@cjk@hangul09C1}%
\uc@dclc{47785}{cjkhangul}{\u@cjk@hangul09C2}%
\uc@dclc{47787}{cjkhangul}{\u@cjk@hangul09C3}%
\uc@dclc{47788}{cjkhangul}{\u@cjk@hangul09C4}%
\uc@dclc{47792}{cjkhangul}{\u@cjk@hangul09C5}%
\uc@dclc{47794}{cjkhangul}{\u@cjk@hangul09C6}%
\uc@dclc{47800}{cjkhangul}{\u@cjk@hangul09C7}%
\uc@dclc{47801}{cjkhangul}{\u@cjk@hangul09C8}%
\uc@dclc{47803}{cjkhangul}{\u@cjk@hangul09C9}%
\uc@dclc{47805}{cjkhangul}{\u@cjk@hangul09CA}%
\uc@dclc{47812}{cjkhangul}{\u@cjk@hangul09CB}%
\uc@dclc{47816}{cjkhangul}{\u@cjk@hangul09CC}%
\uc@dclc{47832}{cjkhangul}{\u@cjk@hangul09CD}%
\uc@dclc{47833}{cjkhangul}{\u@cjk@hangul09CE}%
\uc@dclc{47868}{cjkhangul}{\u@cjk@hangul09CF}%
%%% Local Variables: 
%%% mode: latex
%%% coding: utf-8
%%% End: 
