%%
%% This is file `fc-british.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% fmtcount.dtx  (with options: `fc-british.def')
%% 
%%  fmtcount.dtx
%%  Copyright 2025 Nicola Talbot (inactive), Vincent Belaïche and Erik Nijenhuis
%% 
%%  This work may be distributed and/or modified under the
%%  conditions of the LaTeX Project Public License, either version 1.3
%%  of this license or (at your option) any later version.
%%  The latest version of this license is in
%%    http://www.latex-project.org/lppl.txt
%%  and version 1.3 or later is part of all distributions of LaTeX
%%  version 2005/12/01 or later.
%% 
%%  This work has the LPPL maintenance status `maintained'.
%% 
%%  The Current Maintainer of this work is Nicola Talbot (inactive), Vincent Belaïche and Erik Nijenhuis.
%% 
%%  This work consists of the files fmtcount.dtx and fmtcount.ins and the derived files fc-american.def, fc-brazilian.def, fc-british.def, fc-dutch.def, fc-english.def, fc-francais.def, fc-french.def, fc-frenchb.def, fc-german.def, fc-germanb.def, fc-italian.def, fc-ngerman.def, fc-ngermanb.def, fc-portuges.def, fc-portuguese.def, fc-spanish.def, fc-UKenglish.def, fc-USenglish.def, fcnumparser.sty, fcprefix.sty, fmtcount.sty.
%% 
\ProvidesFCLanguage{british}[2013/08/17]%
\FCloadlang{english}%
\global\let\@ordinalMbritish\@ordinalMenglish
\global\let\@ordinalFbritish\@ordinalMenglish
\global\let\@ordinalNbritish\@ordinalMenglish
\global\let\@numberstringMbritish\@numberstringMenglish
\global\let\@numberstringFbritish\@numberstringMenglish
\global\let\@numberstringNbritish\@numberstringMenglish
\global\let\@NumberstringMbritish\@NumberstringMenglish
\global\let\@NumberstringFbritish\@NumberstringMenglish
\global\let\@NumberstringNbritish\@NumberstringMenglish
\global\let\@ordinalstringMbritish\@ordinalstringMenglish
\global\let\@ordinalstringFbritish\@ordinalstringMenglish
\global\let\@ordinalstringNbritish\@ordinalstringMenglish
\global\let\@OrdinalstringMbritish\@OrdinalstringMenglish
\global\let\@OrdinalstringFbritish\@OrdinalstringMenglish
\global\let\@OrdinalstringNbritish\@OrdinalstringMenglish
\endinput
%%
%% End of file `fc-british.def'.
