%%
%% This is file `tagpdf-ns-pdf.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% tagpdf-data.dtx  (with options: `ns-pdf')
%% 
%% Copyright (C) 2019-2024 Ulrike Fischer
%% 
%% It may be distributed and/or modified under the conditions of
%% the LaTeX Project Public License (LPPL), either version 1.3c of
%% this license or (at your option) any later version.  The latest
%% version of this license is in the file:
%% 
%%    https://www.latex-project.org/lppl.txt
%% 
%% This file is part of the "tagpdf bundle" (The Work in LPPL)
%% and all files in that bundle must be distributed together.
%% 
%% File: tagpdf-data.dtx
%% \ProvidesExplFile {tagpdf-ns-pdf.def} {2025-03-05} {0.99o}
%%  {pdf}   {http://iso.org/pdf/ssn}{}
StructTreeRoot,StructTreeRoot,pdf,D,
Document,Document,pdf,D,
Part,Part,pdf,G,
Sect,Sect,pdf,G,
Div,Div,pdf,G,
Caption,Caption,pdf,GB,
NonStruct,NonStruct,pdf,G,
H,H,pdf,B,
H1,H1,pdf,B,
H2,H2,pdf,B,
H3,H3,pdf,B,
H4,H4,pdf,B,
H5,H5,pdf,B,
H6,H6,pdf,B,
P,P,pdf,B,
L,L,pdf,BI,
LI,LI,pdf,L,
Lbl,Lbl,pdf,I,
LBody,LBody,pdf,L,
Table,Table,pdf,B,
TR,TR,pdf,T,
TH,TH,pdf,T,
TD,TD,pdf,T,
THead,THead,pdf,T,
TBody,TBody,pdf,T,
TFoot,TFoot,pdf,T,
Span,Span,pdf,I,
Link,Link,pdf,GBI,
Annot,Annot,pdf,GBI,
Figure,Figure,pdf,GBI,
Formula,Formula,pdf,GBI,
Form,Form,pdf,GBI,
Ruby,Ruby,pdf,I,
RB,RB,pdf,I,
RT,RT,pdf,I,
Warichu,Warichu,pdf,I,
WT,WT,pdf,I,
WP,WP,pdf,I,
Artifact,NonStruct,pdf,GBI,
Art,Art,pdf,,G,  % only pdf, types unclear, needs correction later
BlockQuote,BlockQuote,pdf,G, %or GB?
TOC,TOC,pdf,G,
TOCI,TOCI,pdf,G,
Index,Index,pdf,G,
Private,Private,pdf,G,
Quote,Quote,pdf,I,
Note,Note,pdf,GBI, % I in reference, but
Reference,Reference,pdf,B, %
BibEntry,BibEntry,pdf,B, %
Code,Code,pdf,I, %
DocumentFragment,Art,pdf,D, %from pdf2
Aside,Note,pdf,G,
H7,H6,pdf,B,
H8,H6,pdf,B,
H9,H6,pdf,B,
H10,H6,pdf,B,
Title,P,pdf,GB,
FENote,Note,pdf,GBI,
Sub,Span,pdf,I,
Em,Span,pdf,I,
Strong,Span,pdf,I,
%% 
%%
%% End of file `tagpdf-ns-pdf.def'.
