%%
%% This is file `fc-germanb.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% fmtcount.dtx  (with options: `fc-germanb.def')
%% 
%%  fmtcount.dtx
%%  Copyright 2025 Nicola Talbot (inactive), Vincent Belaïche and Erik Nijenhuis
%% 
%%  This work may be distributed and/or modified under the
%%  conditions of the LaTeX Project Public License, either version 1.3
%%  of this license or (at your option) any later version.
%%  The latest version of this license is in
%%    http://www.latex-project.org/lppl.txt
%%  and version 1.3 or later is part of all distributions of LaTeX
%%  version 2005/12/01 or later.
%% 
%%  This work has the LPPL maintenance status `maintained'.
%% 
%%  The Current Maintainer of this work is Nicola Talbot (inactive), Vincent Belaïche and Erik Nijenhuis.
%% 
%%  This work consists of the files fmtcount.dtx and fmtcount.ins and the derived files fc-american.def, fc-brazilian.def, fc-british.def, fc-dutch.def, fc-english.def, fc-francais.def, fc-french.def, fc-frenchb.def, fc-german.def, fc-germanb.def, fc-italian.def, fc-ngerman.def, fc-ngermanb.def, fc-portuges.def, fc-portuguese.def, fc-spanish.def, fc-UKenglish.def, fc-USenglish.def, fcnumparser.sty, fcprefix.sty, fmtcount.sty.
%% 
\ProvidesFCLanguage{germanb}[2013/08/17]%
\FCloadlang{german}%
\global\let\@ordinalMgermanb=\@ordinalMgerman
\global\let\@ordinalFgermanb=\@ordinalFgerman
\global\let\@ordinalNgermanb=\@ordinalNgerman
\global\let\@numberstringMgermanb=\@numberstringMgerman
\global\let\@numberstringFgermanb=\@numberstringFgerman
\global\let\@numberstringNgermanb=\@numberstringNgerman
\global\let\@NumberstringMgermanb=\@NumberstringMgerman
\global\let\@NumberstringFgermanb=\@NumberstringFgerman
\global\let\@NumberstringNgermanb=\@NumberstringNgerman
\global\let\@ordinalstringMgermanb=\@ordinalstringMgerman
\global\let\@ordinalstringFgermanb=\@ordinalstringFgerman
\global\let\@ordinalstringNgermanb=\@ordinalstringNgerman
\global\let\@OrdinalstringMgermanb=\@OrdinalstringMgerman
\global\let\@OrdinalstringFgermanb=\@OrdinalstringFgerman
\global\let\@OrdinalstringNgermanb=\@OrdinalstringNgerman
\endinput
%%
%% End of file `fc-germanb.def'.
