%%% Unicode to TeX mapping, file uni-480.def, U+1E000..U+1E0FF, autogenerated by makeunidef.pl
\ifx\ProvidesFile\undefined\else
\ProvidesFile{uni-480.def}[2022/08/07 UCS: Unicode data U+1E000..U+1E0FF]%
\fi
\uc@dclc{122928}{autogenerated}{\unicodesuper{\unichar{1072}}}%
\uc@dclc{122929}{autogenerated}{\unicodesuper{\unichar{1073}}}%
\uc@dclc{122930}{autogenerated}{\unicodesuper{\unichar{1074}}}%
\uc@dclc{122931}{autogenerated}{\unicodesuper{\unichar{1075}}}%
\uc@dclc{122932}{autogenerated}{\unicodesuper{\unichar{1076}}}%
\uc@dclc{122933}{autogenerated}{\unicodesuper{\unichar{1077}}}%
\uc@dclc{122934}{autogenerated}{\unicodesuper{\unichar{1078}}}%
\uc@dclc{122935}{autogenerated}{\unicodesuper{\unichar{1079}}}%
\uc@dclc{122936}{autogenerated}{\unicodesuper{\unichar{1080}}}%
\uc@dclc{122937}{autogenerated}{\unicodesuper{\unichar{1082}}}%
\uc@dclc{122938}{autogenerated}{\unicodesuper{\unichar{1083}}}%
\uc@dclc{122939}{autogenerated}{\unicodesuper{\unichar{1084}}}%
\uc@dclc{122940}{autogenerated}{\unicodesuper{\unichar{1086}}}%
\uc@dclc{122941}{autogenerated}{\unicodesuper{\unichar{1087}}}%
\uc@dclc{122942}{autogenerated}{\unicodesuper{\unichar{1088}}}%
\uc@dclc{122943}{autogenerated}{\unicodesuper{\unichar{1089}}}%
\uc@dclc{122944}{autogenerated}{\unicodesuper{\unichar{1090}}}%
\uc@dclc{122945}{autogenerated}{\unicodesuper{\unichar{1091}}}%
\uc@dclc{122946}{autogenerated}{\unicodesuper{\unichar{1092}}}%
\uc@dclc{122947}{autogenerated}{\unicodesuper{\unichar{1093}}}%
\uc@dclc{122948}{autogenerated}{\unicodesuper{\unichar{1094}}}%
\uc@dclc{122949}{autogenerated}{\unicodesuper{\unichar{1095}}}%
\uc@dclc{122950}{autogenerated}{\unicodesuper{\unichar{1096}}}%
\uc@dclc{122951}{autogenerated}{\unicodesuper{\unichar{1099}}}%
\uc@dclc{122952}{autogenerated}{\unicodesuper{\unichar{1101}}}%
\uc@dclc{122953}{autogenerated}{\unicodesuper{\unichar{1102}}}%
\uc@dclc{122955}{autogenerated}{\unicodesuper{\unichar{1241}}}%
\uc@dclc{122956}{autogenerated}{\unicodesuper{\unichar{1110}}}%
\uc@dclc{122957}{autogenerated}{\unicodesuper{\unichar{1112}}}%
\uc@dclc{122958}{autogenerated}{\unicodesuper{\unichar{1257}}}%
\uc@dclc{122959}{autogenerated}{\unicodesuper{\unichar{1199}}}%
\uc@dclc{122961}{autogenerated}{\unicodesub{\unichar{1072}}}%
\uc@dclc{122962}{autogenerated}{\unicodesub{\unichar{1073}}}%
\uc@dclc{122963}{autogenerated}{\unicodesub{\unichar{1074}}}%
\uc@dclc{122964}{autogenerated}{\unicodesub{\unichar{1075}}}%
\uc@dclc{122965}{autogenerated}{\unicodesub{\unichar{1076}}}%
\uc@dclc{122966}{autogenerated}{\unicodesub{\unichar{1077}}}%
\uc@dclc{122967}{autogenerated}{\unicodesub{\unichar{1078}}}%
\uc@dclc{122968}{autogenerated}{\unicodesub{\unichar{1079}}}%
\uc@dclc{122969}{autogenerated}{\unicodesub{\unichar{1080}}}%
\uc@dclc{122970}{autogenerated}{\unicodesub{\unichar{1082}}}%
\uc@dclc{122971}{autogenerated}{\unicodesub{\unichar{1083}}}%
\uc@dclc{122972}{autogenerated}{\unicodesub{\unichar{1086}}}%
\uc@dclc{122973}{autogenerated}{\unicodesub{\unichar{1087}}}%
\uc@dclc{122974}{autogenerated}{\unicodesub{\unichar{1089}}}%
\uc@dclc{122975}{autogenerated}{\unicodesub{\unichar{1091}}}%
\uc@dclc{122976}{autogenerated}{\unicodesub{\unichar{1092}}}%
\uc@dclc{122977}{autogenerated}{\unicodesub{\unichar{1093}}}%
\uc@dclc{122978}{autogenerated}{\unicodesub{\unichar{1094}}}%
\uc@dclc{122979}{autogenerated}{\unicodesub{\unichar{1095}}}%
\uc@dclc{122980}{autogenerated}{\unicodesub{\unichar{1096}}}%
\uc@dclc{122981}{autogenerated}{\unicodesub{\unichar{1098}}}%
\uc@dclc{122982}{autogenerated}{\unicodesub{\unichar{1099}}}%
\uc@dclc{122983}{autogenerated}{\unicodesub{\unichar{1169}}}%
\uc@dclc{122984}{autogenerated}{\unicodesub{\unichar{1110}}}%
\uc@dclc{122985}{autogenerated}{\unicodesub{\unichar{1109}}}%
\uc@dclc{122986}{autogenerated}{\unicodesub{\unichar{1119}}}%
\uc@dclc{122987}{autogenerated}{\unicodesuper{\unichar{1195}}}%
\uc@dclc{122989}{autogenerated}{\unicodesuper{\unichar{1201}}}%
%%% Local Variables: 
%%% mode: latex
%%% coding: utf-8
%%% End: 
