%%% Unicode to TeX mapping, file uni-191.def, U+BF00..U+BFFF, autogenerated by makeunidef.pl
\ifx\ProvidesFile\undefined\else
\ProvidesFile{uni-191.def}[2022/08/07 UCS: Unicode data U+BF00..U+BFFF]%
\fi
\gdef\u@cjk@hangul#1#2#3#4{{\fontencoding{C61}\def\CJK@plane{#1#2}\selectfont\char"#3#4\relax}}%
\uc@dclc{48897}{cjkhangul}{\u@cjk@hangul10AA}%
\uc@dclc{48904}{cjkhangul}{\u@cjk@hangul10AB}%
\uc@dclc{48905}{cjkhangul}{\u@cjk@hangul10AC}%
\uc@dclc{48920}{cjkhangul}{\u@cjk@hangul10AD}%
\uc@dclc{48921}{cjkhangul}{\u@cjk@hangul10AE}%
\uc@dclc{48923}{cjkhangul}{\u@cjk@hangul10AF}%
\uc@dclc{48924}{cjkhangul}{\u@cjk@hangul10B0}%
\uc@dclc{48925}{cjkhangul}{\u@cjk@hangul10B1}%
\uc@dclc{48960}{cjkhangul}{\u@cjk@hangul10B2}%
\uc@dclc{48961}{cjkhangul}{\u@cjk@hangul10B3}%
\uc@dclc{48964}{cjkhangul}{\u@cjk@hangul10B4}%
\uc@dclc{48968}{cjkhangul}{\u@cjk@hangul10B5}%
\uc@dclc{48976}{cjkhangul}{\u@cjk@hangul10B6}%
\uc@dclc{48977}{cjkhangul}{\u@cjk@hangul10B7}%
\uc@dclc{48981}{cjkhangul}{\u@cjk@hangul10B8}%
\uc@dclc{49044}{cjkhangul}{\u@cjk@hangul10B9}%
\uc@dclc{49072}{cjkhangul}{\u@cjk@hangul10BA}%
\uc@dclc{49093}{cjkhangul}{\u@cjk@hangul10BB}%
\uc@dclc{49100}{cjkhangul}{\u@cjk@hangul10BC}%
\uc@dclc{49101}{cjkhangul}{\u@cjk@hangul10BD}%
\uc@dclc{49104}{cjkhangul}{\u@cjk@hangul10BE}%
\uc@dclc{49108}{cjkhangul}{\u@cjk@hangul10BF}%
\uc@dclc{49116}{cjkhangul}{\u@cjk@hangul10C0}%
\uc@dclc{49119}{cjkhangul}{\u@cjk@hangul10C1}%
\uc@dclc{49121}{cjkhangul}{\u@cjk@hangul10C2}%
%%% Local Variables: 
%%% mode: latex
%%% coding: utf-8
%%% End: 
