%%
%% This is file `latin4.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% inputenc.dtx  (with options: `latin4')
%% 
%% This is a generated file.
%% 
%% The source is maintained by the LaTeX Project team and bug
%% reports for it can be opened at https://latex-project.org/bugs.html
%% (but please observe conditions on bug reports sent to that address!)
%% 
%% 
%% Copyright (C) 1993-2025
%% The LaTeX Project and any individual authors listed elsewhere
%% in this file.
%% 
%% This file was generated from file(s) of the LaTeX base system.
%% --------------------------------------------------------------
%% 
%% It may be distributed and/or modified under the
%% conditions of the LaTeX Project Public License, either version 1.3c
%% of this license or (at your option) any later version.
%% The latest version of this license is in
%%    https://www.latex-project.org/lppl.txt
%% and version 1.3c or later is part of all distributions of LaTeX
%% version 2008 or later.
%% 
%% This file has the LPPL maintenance status "maintained".
%% 
%% This file may only be distributed together with a copy of the LaTeX
%% base system. You may however distribute the LaTeX base system without
%% such generated files.
%% 
%% The list of all files belonging to the LaTeX base distribution is
%% given in the file `manifest.txt'. See also `legal.txt' for additional
%% information.
%% 
%% The list of derived (unpacked) files belonging to the distribution
%% and covered by LPPL is defined by the unpacking scripts (with
%% extension .ins) which are part of the distribution.

 \ProvidesFile{latin4.def}
   [2024/02/08 v1.3d Input encoding file]
\ProvideTextCommandDefault{\textdegree}{\ensuremath{{^\circ}}}
\ProvideTextCommandDefault{\textcurrency}
   {\TextSymbolUnavailable\textcurrency}
\ProvideTextCommandDefault{\textkra}
  {\TextSymbolUnavailable\textkra}
\ProvideTextCommandDefault{\textTstroke}
  {\TextSymbolUnavailable\textTstroke}
\ProvideTextCommandDefault{\texttstroke}
  {\TextSymbolUnavailable\texttstroke}
\DeclareInputText{160}{\nobreakspace}
\DeclareInputText{161}{\k A}
\DeclareInputText{162}{\textkra}%% Greenlandic Inuit
\DeclareInputText{163}{\c R}
\DeclareInputText{164}{\textcurrency}
\DeclareInputText{165}{\~I}
\DeclareInputText{166}{\c L}
\DeclareInputText{167}{\S}
\DeclareInputText{168}{\"{}}
\DeclareInputText{169}{\v S}
\DeclareInputText{170}{\@tabacckludge=E}
\DeclareInputText{171}{\c G}
\DeclareInputText{172}{\textTstroke}%% Northern Sami
\DeclareInputText{173}{\-}
\DeclareInputText{174}{\v Z}
\DeclareInputText{175}{\@tabacckludge={}}
\DeclareInputText{176}{\textdegree}
\DeclareInputText{177}{\k a}
\DeclareInputText{178}{\k\ }
\DeclareInputText{179}{\c r}
\DeclareInputText{180}{\@tabacckludge'{}}
\DeclareInputText{181}{\~\i}
\DeclareInputText{182}{\c l}
\DeclareInputText{183}{\v{}}
\DeclareInputText{184}{\c\ }
\DeclareInputText{185}{\v s}
\DeclareInputText{186}{\@tabacckludge=e}
\DeclareInputText{187}{\c g}
\DeclareInputText{188}{\texttstroke}%% Northern Sami
\DeclareInputText{189}{\NG}
\DeclareInputText{190}{\v z}
\DeclareInputText{191}{\ng}
\DeclareInputText{192}{\@tabacckludge=A}
\DeclareInputText{193}{\@tabacckludge'A}
\DeclareInputText{194}{\^A}
\DeclareInputText{195}{\~A}
\DeclareInputText{196}{\"A}
\DeclareInputText{197}{\r A}
\DeclareInputText{198}{\AE}
\DeclareInputText{199}{\k I}
\DeclareInputText{200}{\v C}
\DeclareInputText{201}{\@tabacckludge'E}
\DeclareInputText{202}{\k E}
\DeclareInputText{203}{\"E}
\DeclareInputText{204}{\.{E}}
\DeclareInputText{205}{\@tabacckludge'I}
\DeclareInputText{206}{\^I}
\DeclareInputText{207}{\@tabacckludge=I}
\DeclareInputText{208}{\DJ}
\DeclareInputText{209}{\c N}
\DeclareInputText{210}{\@tabacckludge=O}
\DeclareInputText{211}{\c K}
\DeclareInputText{212}{\^O}
\DeclareInputText{213}{\~O}
\DeclareInputText{214}{\"O}
\DeclareInputMath{215}{\times}
\DeclareInputText{216}{\O}
\DeclareInputText{217}{\k U}
\DeclareInputText{218}{\@tabacckludge'U}
\DeclareInputText{219}{\^U}
\DeclareInputText{220}{\"U}
\DeclareInputText{221}{\~U}
\DeclareInputText{222}{\@tabacckludge=U}
\DeclareInputText{223}{\ss}
\DeclareInputText{224}{\@tabacckludge=a}
\DeclareInputText{225}{\@tabacckludge'a}
\DeclareInputText{226}{\^a}
\DeclareInputText{227}{\~a}
\DeclareInputText{228}{\"a}
\DeclareInputText{229}{\r a}
\DeclareInputText{230}{\ae}
\DeclareInputText{231}{\k i}
\DeclareInputText{232}{\v c}
\DeclareInputText{233}{\@tabacckludge'e}
\DeclareInputText{234}{\k e}
\DeclareInputText{235}{\"e}
\DeclareInputText{236}{\.{e}}
\DeclareInputText{237}{\@tabacckludge'\i}
\DeclareInputText{238}{\^\i}
\DeclareInputText{239}{\@tabacckludge=\i}
\DeclareInputText{240}{\dj}
\DeclareInputText{241}{\c n}
\DeclareInputText{242}{\@tabacckludge=o}
\DeclareInputText{243}{\c k}
\DeclareInputText{244}{\^o}
\DeclareInputText{245}{\~o}
\DeclareInputText{246}{\"o}
\DeclareInputMath{247}{\div}
\DeclareInputText{248}{\o}
\DeclareInputText{249}{\k u}
\DeclareInputText{250}{\@tabacckludge'u}
\DeclareInputText{251}{\^u}
\DeclareInputText{252}{\"u}
\DeclareInputText{253}{\~u}
\DeclareInputText{254}{\@tabacckludge=u}
\DeclareInputText{255}{\.{}}
\endinput
%%
%% End of file `latin4.def'.
