%%% Unicode to TeX mapping, file uni-190.def, U+BE00..U+BEFF, autogenerated by makeunidef.pl
\ifx\ProvidesFile\undefined\else
\ProvidesFile{uni-190.def}[2022/08/07 UCS: Unicode data U+BE00..U+BEFF]%
\fi
\gdef\u@cjk@hangul#1#2#3#4{{\fontencoding{C61}\def\CJK@plane{#1#2}\selectfont\char"#3#4\relax}}%
\uc@dclc{48640}{cjkhangul}{\u@cjk@hangul1074}%
\uc@dclc{48643}{cjkhangul}{\u@cjk@hangul1075}%
\uc@dclc{48645}{cjkhangul}{\u@cjk@hangul1076}%
\uc@dclc{48652}{cjkhangul}{\u@cjk@hangul1077}%
\uc@dclc{48653}{cjkhangul}{\u@cjk@hangul1078}%
\uc@dclc{48656}{cjkhangul}{\u@cjk@hangul1079}%
\uc@dclc{48660}{cjkhangul}{\u@cjk@hangul107A}%
\uc@dclc{48668}{cjkhangul}{\u@cjk@hangul107B}%
\uc@dclc{48669}{cjkhangul}{\u@cjk@hangul107C}%
\uc@dclc{48671}{cjkhangul}{\u@cjk@hangul107D}%
\uc@dclc{48708}{cjkhangul}{\u@cjk@hangul107E}%
\uc@dclc{48709}{cjkhangul}{\u@cjk@hangul107F}%
\uc@dclc{48712}{cjkhangul}{\u@cjk@hangul1080}%
\uc@dclc{48716}{cjkhangul}{\u@cjk@hangul1081}%
\uc@dclc{48718}{cjkhangul}{\u@cjk@hangul1082}%
\uc@dclc{48724}{cjkhangul}{\u@cjk@hangul1083}%
\uc@dclc{48725}{cjkhangul}{\u@cjk@hangul1084}%
\uc@dclc{48727}{cjkhangul}{\u@cjk@hangul1085}%
\uc@dclc{48729}{cjkhangul}{\u@cjk@hangul1086}%
\uc@dclc{48730}{cjkhangul}{\u@cjk@hangul1087}%
\uc@dclc{48731}{cjkhangul}{\u@cjk@hangul1088}%
\uc@dclc{48736}{cjkhangul}{\u@cjk@hangul1089}%
\uc@dclc{48737}{cjkhangul}{\u@cjk@hangul108A}%
\uc@dclc{48740}{cjkhangul}{\u@cjk@hangul108B}%
\uc@dclc{48744}{cjkhangul}{\u@cjk@hangul108C}%
\uc@dclc{48746}{cjkhangul}{\u@cjk@hangul108D}%
\uc@dclc{48752}{cjkhangul}{\u@cjk@hangul108E}%
\uc@dclc{48753}{cjkhangul}{\u@cjk@hangul108F}%
\uc@dclc{48755}{cjkhangul}{\u@cjk@hangul1090}%
\uc@dclc{48756}{cjkhangul}{\u@cjk@hangul1091}%
\uc@dclc{48757}{cjkhangul}{\u@cjk@hangul1092}%
\uc@dclc{48763}{cjkhangul}{\u@cjk@hangul1093}%
\uc@dclc{48764}{cjkhangul}{\u@cjk@hangul1094}%
\uc@dclc{48765}{cjkhangul}{\u@cjk@hangul1095}%
\uc@dclc{48768}{cjkhangul}{\u@cjk@hangul1096}%
\uc@dclc{48772}{cjkhangul}{\u@cjk@hangul1097}%
\uc@dclc{48780}{cjkhangul}{\u@cjk@hangul1098}%
\uc@dclc{48781}{cjkhangul}{\u@cjk@hangul1099}%
\uc@dclc{48783}{cjkhangul}{\u@cjk@hangul109A}%
\uc@dclc{48784}{cjkhangul}{\u@cjk@hangul109B}%
\uc@dclc{48785}{cjkhangul}{\u@cjk@hangul109C}%
\uc@dclc{48792}{cjkhangul}{\u@cjk@hangul109D}%
\uc@dclc{48793}{cjkhangul}{\u@cjk@hangul109E}%
\uc@dclc{48808}{cjkhangul}{\u@cjk@hangul109F}%
\uc@dclc{48848}{cjkhangul}{\u@cjk@hangul10A0}%
\uc@dclc{48849}{cjkhangul}{\u@cjk@hangul10A1}%
\uc@dclc{48852}{cjkhangul}{\u@cjk@hangul10A2}%
\uc@dclc{48855}{cjkhangul}{\u@cjk@hangul10A3}%
\uc@dclc{48856}{cjkhangul}{\u@cjk@hangul10A4}%
\uc@dclc{48864}{cjkhangul}{\u@cjk@hangul10A5}%
\uc@dclc{48867}{cjkhangul}{\u@cjk@hangul10A6}%
\uc@dclc{48868}{cjkhangul}{\u@cjk@hangul10A7}%
\uc@dclc{48869}{cjkhangul}{\u@cjk@hangul10A8}%
\uc@dclc{48876}{cjkhangul}{\u@cjk@hangul10A9}%
%%% Local Variables: 
%%% mode: latex
%%% coding: utf-8
%%% End: 
