%%% Unicode to TeX mapping, file uni-12.def, U+0C00..U+0CFF, autogenerated by makeunidef.pl
\ifx\ProvidesFile\undefined\else
\ProvidesFile{uni-12.def}[2022/08/07 UCS: Unicode data U+0C00..U+0CFF]%
\fi
\global\let\uc@combining@prechar\@ne
\gdef\uc@telugu@prechar#1{%
  \ifnum#1<"C01 \texttelugustop\let\uc@prechar\undefined\fi
  \ifnum#1>"C6F \texttelugustop\let\uc@prechar\undefined\fi}%
\DeclareRobustCommand\uc@telugu[1]{%
  \ifx\uc@prechar\undefined
    \texttelugustart
    \let\uc@prechar\uc@telugu@prechar
  \else\ifx\uc@telugu@prechar\uc@prechar\else
    \PackageError{ucs}{\protect\uc@prechar\space already
      defined.}{Something is already using the \protect\uc@prechar
      mechanism. Telugu characters wont combine properly.}%
  \fi\fi
  #1}%
% make \uc@telugu global
\def\uc@temp@a#1{\global\let#1#1}%
\uc@temp@a\uc@telugu
\expandafter\uc@temp@a\csname uc@telugu \endcsname
%
\gdef\uc@@kill@telugu#1#2\uc@telugu#3#4\@nil{%
  \ifx\@nil#3\@nil\expandafter\@firstoftwo\else\expandafter\@secondoftwo\fi
  {#1{#2}}{#1{#3}}}%
\gdef\uc@kill@telugu#1#2{%
  \uc@@kill@telugu#1#2\uc@telugu{}\@nil}%
\uc@dclc{3073}{default}{\uc@cmb\uc@telugu{\uc@kill@telugu\texttelugucandrabindu{#1}}}%
\uc@dclc{3074}{default}{\uc@cmb\uc@telugu{\uc@kill@telugu\textteluguanusvara{#1}}}%
\uc@dclc{3075}{default}{\uc@cmb\uc@telugu{\uc@kill@telugu\textteluguvisarga{#1}}}%
\uc@dclc{3077}{default}{\uc@telugu{\texttelugua}}%
\uc@dclc{3078}{default}{\uc@telugu{\textteluguaa}}%
\uc@dclc{3079}{default}{\uc@telugu{\texttelugui}}%
\uc@dclc{3080}{default}{\uc@telugu{\textteluguii}}%
\uc@dclc{3081}{default}{\uc@telugu{\textteluguu}}%
\uc@dclc{3082}{default}{\uc@telugu{\textteluguuu}}%
\uc@dclc{3083}{default}{\uc@telugu{\textteluguvocalicr}}%
\uc@dclc{3084}{default}{\uc@telugu{\textteluguvocalicl}}%
\uc@dclc{3086}{default}{\uc@telugu{\texttelugue}}%
\uc@dclc{3087}{default}{\uc@telugu{\textteluguee}}%
\uc@dclc{3088}{default}{\uc@telugu{\textteluguai}}%
\uc@dclc{3090}{default}{\uc@telugu{\textteluguo}}%
\uc@dclc{3091}{default}{\uc@telugu{\textteluguoo}}%
\uc@dclc{3092}{default}{\uc@telugu{\textteluguau}}%
\uc@dclc{3093}{default}{\uc@telugu{\textteluguka}}%
\uc@dclc{3094}{default}{\uc@telugu{\texttelugukha}}%
\uc@dclc{3095}{default}{\uc@telugu{\textteluguga}}%
\uc@dclc{3096}{default}{\uc@telugu{\texttelugugha}}%
\uc@dclc{3097}{default}{\uc@telugu{\texttelugunga}}%
\uc@dclc{3098}{default}{\uc@telugu{\textteluguca}}%
\uc@dclc{3099}{default}{\uc@telugu{\texttelugucha}}%
\uc@dclc{3100}{default}{\uc@telugu{\textteluguja}}%
\uc@dclc{3101}{default}{\uc@telugu{\texttelugujha}}%
\uc@dclc{3102}{default}{\uc@telugu{\texttelugunya}}%
\uc@dclc{3103}{default}{\uc@telugu{\texttelugutta}}%
\uc@dclc{3104}{default}{\uc@telugu{\textteluguttha}}%
\uc@dclc{3105}{default}{\uc@telugu{\texttelugudda}}%
\uc@dclc{3106}{default}{\uc@telugu{\textteluguddha}}%
\uc@dclc{3107}{default}{\uc@telugu{\texttelugunna}}%
\uc@dclc{3108}{default}{\uc@telugu{\textteluguta}}%
\uc@dclc{3109}{default}{\uc@telugu{\texttelugutha}}%
\uc@dclc{3110}{default}{\uc@telugu{\textteluguda}}%
\uc@dclc{3111}{default}{\uc@telugu{\texttelugudha}}%
\uc@dclc{3112}{default}{\uc@telugu{\textteluguna}}%
\uc@dclc{3114}{default}{\uc@telugu{\texttelugupa}}%
\uc@dclc{3115}{default}{\uc@telugu{\texttelugupha}}%
\uc@dclc{3116}{default}{\uc@telugu{\textteluguba}}%
\uc@dclc{3117}{default}{\uc@telugu{\texttelugubha}}%
\uc@dclc{3118}{default}{\uc@telugu{\textteluguma}}%
\uc@dclc{3119}{default}{\uc@telugu{\textteluguya}}%
\uc@dclc{3120}{default}{\uc@telugu{\texttelugura}}%
\uc@dclc{3121}{default}{\uc@telugu{\texttelugurra}}%
\uc@dclc{3122}{default}{\uc@telugu{\texttelugula}}%
\uc@dclc{3123}{default}{\uc@telugu{\texttelugulla}}%
\uc@dclc{3125}{default}{\uc@telugu{\textteluguva}}%
\uc@dclc{3126}{default}{\uc@telugu{\texttelugusha}}%
\uc@dclc{3127}{default}{\uc@telugu{\texttelugussa}}%
\uc@dclc{3128}{default}{\uc@telugu{\texttelugusa}}%
\uc@dclc{3129}{default}{\uc@telugu{\textteluguha}}%
\uc@dclc{3134}{default}{\uc@cmb\uc@telugu{\uc@kill@telugu\textteluguvowelaa{#1}}}%
\uc@dclc{3135}{default}{\uc@cmb\uc@telugu{\uc@kill@telugu\textteluguvoweli{#1}}}%
\uc@dclc{3136}{default}{\uc@cmb\uc@telugu{\uc@kill@telugu\textteluguvowelii{#1}}}%
\uc@dclc{3137}{default}{\uc@cmb\uc@telugu{\uc@kill@telugu\textteluguvowelu{#1}}}%
\uc@dclc{3138}{default}{\uc@cmb\uc@telugu{\uc@kill@telugu\textteluguvoweluu{#1}}}%
\uc@dclc{3139}{default}{\uc@cmb\uc@telugu{\uc@kill@telugu\textteluguvowelvocalicr{#1}}}%
\uc@dclc{3140}{default}{\uc@cmb\uc@telugu{\uc@kill@telugu\textteluguvowelvocalicrr{#1}}}%
\uc@dclc{3142}{default}{\uc@cmb\uc@telugu{\uc@kill@telugu\textteluguvowele{#1}}}%
\uc@dclc{3143}{default}{\uc@cmb\uc@telugu{\uc@kill@telugu\textteluguvowelee{#1}}}%
\uc@dclc{3144}{default}{\uc@cmb\uc@telugu{\uc@kill@telugu\textteluguvowelai{#1}}}%
\uc@dclc{3146}{default}{\uc@cmb\uc@telugu{\uc@kill@telugu\textteluguvowelo{#1}}}%
\uc@dclc{3147}{default}{\uc@cmb\uc@telugu{\uc@kill@telugu\textteluguvoweloo{#1}}}%
\uc@dclc{3148}{default}{\uc@cmb\uc@telugu{\uc@kill@telugu\textteluguvowelau{#1}}}%
\uc@dclc{3149}{default}{\uc@cmb\uc@telugu{\uc@kill@telugu\textteluguvirama{#1}}}%
\uc@dclc{3157}{default}{\uc@cmb\uc@telugu{\uc@kill@telugu\texttelugulengthmark{#1}}}%
\uc@dclc{3158}{default}{\uc@cmb\uc@telugu{\uc@kill@telugu\textteluguailengthmark{#1}}}%
\uc@dclc{3168}{default}{\uc@telugu{\textteluguvocalicrr}}%
\uc@dclc{3169}{default}{\uc@telugu{\textteluguvocalicll}}%
\uc@dclc{3174}{default}{\uc@telugu{\textteluguzero}}%
\uc@dclc{3175}{default}{\uc@telugu{\textteluguone}}%
\uc@dclc{3176}{default}{\uc@telugu{\texttelugutwo}}%
\uc@dclc{3177}{default}{\uc@telugu{\textteluguthree}}%
\uc@dclc{3178}{default}{\uc@telugu{\texttelugufour}}%
\uc@dclc{3179}{default}{\uc@telugu{\texttelugufive}}%
\uc@dclc{3180}{default}{\uc@telugu{\texttelugusix}}%
\uc@dclc{3181}{default}{\uc@telugu{\textteluguseven}}%
\uc@dclc{3182}{default}{\uc@telugu{\texttelugueight}}%
\uc@dclc{3183}{default}{\uc@telugu{\texttelugunine}}%
%%% Local Variables: 
%%% mode: latex
%%% coding: utf-8
%%% End: 
