%%% Unicode to TeX mapping, file uni-761.def, U+2F900..U+2F9FF, autogenerated by makeunidef.pl
\ifx\ProvidesFile\undefined\else
\ProvidesFile{uni-761.def}[2022/08/07 UCS: Unicode data U+2F900..U+2F9FF]%
\fi
\uc@dclc{194816}{autogenerated}{\unichar{27966}}%
\uc@dclc{194817}{autogenerated}{\unichar{28023}}%
\uc@dclc{194818}{autogenerated}{\unichar{27969}}%
\uc@dclc{194819}{autogenerated}{\unichar{28009}}%
\uc@dclc{194820}{autogenerated}{\unichar{28024}}%
\uc@dclc{194821}{autogenerated}{\unichar{28037}}%
\uc@dclc{194823}{autogenerated}{\unichar{27956}}%
\uc@dclc{194824}{autogenerated}{\unichar{28207}}%
\uc@dclc{194825}{autogenerated}{\unichar{28270}}%
\uc@dclc{194827}{autogenerated}{\unichar{28363}}%
\uc@dclc{194828}{autogenerated}{\unichar{28359}}%
\uc@dclc{194830}{autogenerated}{\unichar{28153}}%
\uc@dclc{194831}{autogenerated}{\unichar{28526}}%
\uc@dclc{194834}{autogenerated}{\unichar{28614}}%
\uc@dclc{194835}{autogenerated}{\unichar{28729}}%
\uc@dclc{194836}{autogenerated}{\unichar{28702}}%
\uc@dclc{194837}{autogenerated}{\unichar{28699}}%
\uc@dclc{194839}{autogenerated}{\unichar{28746}}%
\uc@dclc{194840}{autogenerated}{\unichar{28797}}%
\uc@dclc{194842}{autogenerated}{\unichar{28845}}%
\uc@dclc{194844}{autogenerated}{\unichar{28997}}%
\uc@dclc{194846}{autogenerated}{\unichar{29084}}%
\uc@dclc{194848}{autogenerated}{\unichar{29224}}%
\uc@dclc{194849}{autogenerated}{\unichar{29237}}%
\uc@dclc{194852}{autogenerated}{\unichar{29312}}%
\uc@dclc{194853}{autogenerated}{\unichar{29333}}%
\uc@dclc{194856}{autogenerated}{\unichar{29562}}%
\uc@dclc{194857}{autogenerated}{\unichar{29579}}%
\uc@dclc{194859}{autogenerated}{\unichar{29605}}%
\uc@dclc{194863}{autogenerated}{\unichar{29788}}%
\uc@dclc{194864}{autogenerated}{\unichar{29809}}%
\uc@dclc{194865}{autogenerated}{\unichar{29829}}%
\uc@dclc{194866}{autogenerated}{\unichar{29898}}%
\uc@dclc{194870}{autogenerated}{\unichar{30014}}%
\uc@dclc{194872}{autogenerated}{\unichar{30064}}%
\uc@dclc{194874}{autogenerated}{\unichar{30224}}%
\uc@dclc{194880}{autogenerated}{\unichar{30452}}%
\uc@dclc{194885}{autogenerated}{\unichar{30494}}%
\uc@dclc{194886}{autogenerated}{\unichar{30495}}%
\uc@dclc{194887}{autogenerated}{\unichar{30495}}%
\uc@dclc{194888}{autogenerated}{\unichar{30538}}%
\uc@dclc{194890}{autogenerated}{\unichar{30603}}%
\uc@dclc{194894}{autogenerated}{\unichar{30798}}%
\uc@dclc{194895}{autogenerated}{\unichar{30860}}%
\uc@dclc{194896}{autogenerated}{\unichar{30924}}%
\uc@dclc{194899}{autogenerated}{\unichar{31062}}%
\uc@dclc{194902}{autogenerated}{\unichar{31119}}%
\uc@dclc{194903}{autogenerated}{\unichar{31211}}%
\uc@dclc{194905}{autogenerated}{\unichar{31296}}%
\uc@dclc{194906}{autogenerated}{\unichar{31306}}%
\uc@dclc{194907}{autogenerated}{\unichar{31311}}%
\uc@dclc{194911}{autogenerated}{\unichar{31470}}%
\uc@dclc{194914}{autogenerated}{\unichar{31686}}%
\uc@dclc{194915}{autogenerated}{\unichar{31689}}%
\uc@dclc{194918}{autogenerated}{\unichar{31954}}%
\uc@dclc{194920}{autogenerated}{\unichar{31976}}%
\uc@dclc{194922}{autogenerated}{\unichar{32000}}%
\uc@dclc{194924}{autogenerated}{\unichar{32099}}%
\uc@dclc{194926}{autogenerated}{\unichar{32199}}%
\uc@dclc{194928}{autogenerated}{\unichar{32325}}%
\uc@dclc{194934}{autogenerated}{\unichar{32634}}%
\uc@dclc{194936}{autogenerated}{\unichar{32661}}%
\uc@dclc{194938}{autogenerated}{\unichar{32773}}%
\uc@dclc{194943}{autogenerated}{\unichar{32880}}%
\uc@dclc{194946}{autogenerated}{\unichar{32946}}%
\uc@dclc{194949}{autogenerated}{\unichar{33086}}%
\uc@dclc{194950}{autogenerated}{\unichar{23221}}%
\uc@dclc{194955}{autogenerated}{\unichar{33281}}%
\uc@dclc{194956}{autogenerated}{\unichar{33284}}%
\uc@dclc{194957}{autogenerated}{\unichar{36766}}%
\uc@dclc{194959}{autogenerated}{\unichar{33425}}%
\uc@dclc{194960}{autogenerated}{\unichar{33419}}%
\uc@dclc{194961}{autogenerated}{\unichar{33437}}%
\uc@dclc{194962}{autogenerated}{\unichar{21171}}%
\uc@dclc{194963}{autogenerated}{\unichar{33457}}%
\uc@dclc{194964}{autogenerated}{\unichar{33459}}%
\uc@dclc{194965}{autogenerated}{\unichar{33469}}%
\uc@dclc{194966}{autogenerated}{\unichar{33510}}%
\uc@dclc{194968}{autogenerated}{\unichar{33509}}%
\uc@dclc{194970}{autogenerated}{\unichar{33635}}%
\uc@dclc{194972}{autogenerated}{\unichar{33571}}%
\uc@dclc{194973}{autogenerated}{\unichar{33725}}%
\uc@dclc{194974}{autogenerated}{\unichar{33767}}%
\uc@dclc{194975}{autogenerated}{\unichar{33879}}%
\uc@dclc{194976}{autogenerated}{\unichar{33619}}%
\uc@dclc{194977}{autogenerated}{\unichar{33738}}%
\uc@dclc{194978}{autogenerated}{\unichar{33740}}%
\uc@dclc{194979}{autogenerated}{\unichar{33756}}%
\uc@dclc{194984}{autogenerated}{\unichar{34033}}%
\uc@dclc{194985}{autogenerated}{\unichar{34035}}%
\uc@dclc{194986}{autogenerated}{\unichar{34070}}%
\uc@dclc{194988}{autogenerated}{\unichar{34148}}%
\uc@dclc{194995}{autogenerated}{\unichar{34384}}%
\uc@dclc{194996}{autogenerated}{\unichar{34396}}%
\uc@dclc{194997}{autogenerated}{\unichar{34407}}%
\uc@dclc{194998}{autogenerated}{\unichar{34409}}%
\uc@dclc{194999}{autogenerated}{\unichar{34473}}%
\uc@dclc{195001}{autogenerated}{\unichar{34574}}%
\uc@dclc{195002}{autogenerated}{\unichar{34530}}%
\uc@dclc{195003}{autogenerated}{\unichar{34681}}%
\uc@dclc{195004}{autogenerated}{\unichar{34600}}%
\uc@dclc{195005}{autogenerated}{\unichar{34667}}%
\uc@dclc{195008}{autogenerated}{\unichar{34785}}%
\uc@dclc{195009}{autogenerated}{\unichar{34817}}%
\uc@dclc{195012}{autogenerated}{\unichar{34915}}%
\uc@dclc{195014}{autogenerated}{\unichar{35031}}%
\uc@dclc{195015}{autogenerated}{\unichar{35038}}%
\uc@dclc{195017}{autogenerated}{\unichar{35066}}%
\uc@dclc{195023}{autogenerated}{\unichar{35488}}%
\uc@dclc{195024}{autogenerated}{\unichar{35565}}%
\uc@dclc{195025}{autogenerated}{\unichar{35722}}%
\uc@dclc{195026}{autogenerated}{\unichar{35925}}%
\uc@dclc{195028}{autogenerated}{\unichar{36011}}%
\uc@dclc{195029}{autogenerated}{\unichar{36033}}%
\uc@dclc{195030}{autogenerated}{\unichar{36123}}%
\uc@dclc{195031}{autogenerated}{\unichar{36215}}%
\uc@dclc{195034}{autogenerated}{\unichar{36299}}%
\uc@dclc{195035}{autogenerated}{\unichar{36284}}%
\uc@dclc{195036}{autogenerated}{\unichar{36336}}%
\uc@dclc{195038}{autogenerated}{\unichar{36564}}%
\uc@dclc{195039}{autogenerated}{\unichar{36664}}%
\uc@dclc{195042}{autogenerated}{\unichar{37012}}%
\uc@dclc{195043}{autogenerated}{\unichar{37105}}%
\uc@dclc{195044}{autogenerated}{\unichar{37137}}%
\uc@dclc{195046}{autogenerated}{\unichar{37147}}%
\uc@dclc{195047}{autogenerated}{\unichar{37432}}%
\uc@dclc{195048}{autogenerated}{\unichar{37591}}%
\uc@dclc{195049}{autogenerated}{\unichar{37592}}%
\uc@dclc{195050}{autogenerated}{\unichar{37500}}%
\uc@dclc{195051}{autogenerated}{\unichar{37881}}%
\uc@dclc{195052}{autogenerated}{\unichar{37909}}%
\uc@dclc{195054}{autogenerated}{\unichar{38283}}%
\uc@dclc{195056}{autogenerated}{\unichar{38327}}%
\uc@dclc{195059}{autogenerated}{\unichar{38595}}%
\uc@dclc{195060}{autogenerated}{\unichar{23986}}%
\uc@dclc{195061}{autogenerated}{\unichar{38691}}%
%%% Local Variables: 
%%% mode: latex
%%% coding: utf-8
%%% End: 
