%%% Unicode to TeX mapping, file uni-36.def, U+2400..U+24FF, autogenerated by makeunidef.pl
\ifx\ProvidesFile\undefined\else
\ProvidesFile{uni-36.def}[2022/08/07 UCS: Unicode data U+2400..U+24FF]%
\fi
\uc@dclc{9251}{default}{\textvisiblespace}%
\uc@dclc{9312}{postscript}{\ding{"AC}}%
\uc@dclc{9313}{postscript}{\ding{"AD}}%
\uc@dclc{9314}{postscript}{\ding{"AE}}%
\uc@dclc{9315}{postscript}{\ding{"AF}}%
\uc@dclc{9316}{postscript}{\ding{"B0}}%
\uc@dclc{9317}{postscript}{\ding{"B1}}%
\uc@dclc{9318}{postscript}{\ding{"B2}}%
\uc@dclc{9319}{postscript}{\ding{"B3}}%
\uc@dclc{9320}{postscript}{\ding{"B4}}%
\uc@dclc{9321}{postscript}{\ding{"B5}}%
\uc@dclc{9322}{autogenerated}{\unicodecircle{\unichar{49}\unichar{49}}}%
\uc@dclc{9323}{autogenerated}{\unicodecircle{\unichar{49}\unichar{50}}}%
\uc@dclc{9324}{autogenerated}{\unicodecircle{\unichar{49}\unichar{51}}}%
\uc@dclc{9325}{autogenerated}{\unicodecircle{\unichar{49}\unichar{52}}}%
\uc@dclc{9326}{autogenerated}{\unicodecircle{\unichar{49}\unichar{53}}}%
\uc@dclc{9327}{autogenerated}{\unicodecircle{\unichar{49}\unichar{54}}}%
\uc@dclc{9328}{autogenerated}{\unicodecircle{\unichar{49}\unichar{55}}}%
\uc@dclc{9329}{autogenerated}{\unicodecircle{\unichar{49}\unichar{56}}}%
\uc@dclc{9330}{autogenerated}{\unicodecircle{\unichar{49}\unichar{57}}}%
\uc@dclc{9331}{autogenerated}{\unicodecircle{\unichar{50}\unichar{48}}}%
\uc@dclc{9332}{autogenerated}{\unichar{40}\unichar{49}\unichar{41}}%
\uc@dclc{9333}{autogenerated}{\unichar{40}\unichar{50}\unichar{41}}%
\uc@dclc{9334}{autogenerated}{\unichar{40}\unichar{51}\unichar{41}}%
\uc@dclc{9335}{autogenerated}{\unichar{40}\unichar{52}\unichar{41}}%
\uc@dclc{9336}{autogenerated}{\unichar{40}\unichar{53}\unichar{41}}%
\uc@dclc{9337}{autogenerated}{\unichar{40}\unichar{54}\unichar{41}}%
\uc@dclc{9338}{autogenerated}{\unichar{40}\unichar{55}\unichar{41}}%
\uc@dclc{9339}{autogenerated}{\unichar{40}\unichar{56}\unichar{41}}%
\uc@dclc{9340}{autogenerated}{\unichar{40}\unichar{57}\unichar{41}}%
\uc@dclc{9341}{autogenerated}{\unichar{40}\unichar{49}\unichar{48}\unichar{41}}%
\uc@dclc{9342}{autogenerated}{\unichar{40}\unichar{49}\unichar{49}\unichar{41}}%
\uc@dclc{9343}{autogenerated}{\unichar{40}\unichar{49}\unichar{50}\unichar{41}}%
\uc@dclc{9344}{autogenerated}{\unichar{40}\unichar{49}\unichar{51}\unichar{41}}%
\uc@dclc{9345}{autogenerated}{\unichar{40}\unichar{49}\unichar{52}\unichar{41}}%
\uc@dclc{9346}{autogenerated}{\unichar{40}\unichar{49}\unichar{53}\unichar{41}}%
\uc@dclc{9347}{autogenerated}{\unichar{40}\unichar{49}\unichar{54}\unichar{41}}%
\uc@dclc{9348}{autogenerated}{\unichar{40}\unichar{49}\unichar{55}\unichar{41}}%
\uc@dclc{9349}{autogenerated}{\unichar{40}\unichar{49}\unichar{56}\unichar{41}}%
\uc@dclc{9350}{autogenerated}{\unichar{40}\unichar{49}\unichar{57}\unichar{41}}%
\uc@dclc{9351}{autogenerated}{\unichar{40}\unichar{50}\unichar{48}\unichar{41}}%
\uc@dclc{9352}{autogenerated}{\unichar{49}\unichar{46}}%
\uc@dclc{9353}{autogenerated}{\unichar{50}\unichar{46}}%
\uc@dclc{9354}{autogenerated}{\unichar{51}\unichar{46}}%
\uc@dclc{9355}{autogenerated}{\unichar{52}\unichar{46}}%
\uc@dclc{9356}{autogenerated}{\unichar{53}\unichar{46}}%
\uc@dclc{9357}{autogenerated}{\unichar{54}\unichar{46}}%
\uc@dclc{9358}{autogenerated}{\unichar{55}\unichar{46}}%
\uc@dclc{9359}{autogenerated}{\unichar{56}\unichar{46}}%
\uc@dclc{9360}{autogenerated}{\unichar{57}\unichar{46}}%
\uc@dclc{9361}{autogenerated}{\unichar{49}\unichar{48}\unichar{46}}%
\uc@dclc{9362}{autogenerated}{\unichar{49}\unichar{49}\unichar{46}}%
\uc@dclc{9363}{autogenerated}{\unichar{49}\unichar{50}\unichar{46}}%
\uc@dclc{9364}{autogenerated}{\unichar{49}\unichar{51}\unichar{46}}%
\uc@dclc{9365}{autogenerated}{\unichar{49}\unichar{52}\unichar{46}}%
\uc@dclc{9366}{autogenerated}{\unichar{49}\unichar{53}\unichar{46}}%
\uc@dclc{9367}{autogenerated}{\unichar{49}\unichar{54}\unichar{46}}%
\uc@dclc{9368}{autogenerated}{\unichar{49}\unichar{55}\unichar{46}}%
\uc@dclc{9369}{autogenerated}{\unichar{49}\unichar{56}\unichar{46}}%
\uc@dclc{9370}{autogenerated}{\unichar{49}\unichar{57}\unichar{46}}%
\uc@dclc{9371}{autogenerated}{\unichar{50}\unichar{48}\unichar{46}}%
\uc@dclc{9372}{autogenerated}{\unichar{40}\unichar{97}\unichar{41}}%
\uc@dclc{9373}{autogenerated}{\unichar{40}\unichar{98}\unichar{41}}%
\uc@dclc{9374}{autogenerated}{\unichar{40}\unichar{99}\unichar{41}}%
\uc@dclc{9375}{autogenerated}{\unichar{40}\unichar{100}\unichar{41}}%
\uc@dclc{9376}{autogenerated}{\unichar{40}\unichar{101}\unichar{41}}%
\uc@dclc{9377}{autogenerated}{\unichar{40}\unichar{102}\unichar{41}}%
\uc@dclc{9378}{autogenerated}{\unichar{40}\unichar{103}\unichar{41}}%
\uc@dclc{9379}{autogenerated}{\unichar{40}\unichar{104}\unichar{41}}%
\uc@dclc{9380}{autogenerated}{\unichar{40}\unichar{105}\unichar{41}}%
\uc@dclc{9381}{autogenerated}{\unichar{40}\unichar{106}\unichar{41}}%
\uc@dclc{9382}{autogenerated}{\unichar{40}\unichar{107}\unichar{41}}%
\uc@dclc{9383}{autogenerated}{\unichar{40}\unichar{108}\unichar{41}}%
\uc@dclc{9384}{autogenerated}{\unichar{40}\unichar{109}\unichar{41}}%
\uc@dclc{9385}{autogenerated}{\unichar{40}\unichar{110}\unichar{41}}%
\uc@dclc{9386}{autogenerated}{\unichar{40}\unichar{111}\unichar{41}}%
\uc@dclc{9387}{autogenerated}{\unichar{40}\unichar{112}\unichar{41}}%
\uc@dclc{9388}{autogenerated}{\unichar{40}\unichar{113}\unichar{41}}%
\uc@dclc{9389}{autogenerated}{\unichar{40}\unichar{114}\unichar{41}}%
\uc@dclc{9390}{autogenerated}{\unichar{40}\unichar{115}\unichar{41}}%
\uc@dclc{9391}{autogenerated}{\unichar{40}\unichar{116}\unichar{41}}%
\uc@dclc{9392}{autogenerated}{\unichar{40}\unichar{117}\unichar{41}}%
\uc@dclc{9393}{autogenerated}{\unichar{40}\unichar{118}\unichar{41}}%
\uc@dclc{9394}{autogenerated}{\unichar{40}\unichar{119}\unichar{41}}%
\uc@dclc{9395}{autogenerated}{\unichar{40}\unichar{120}\unichar{41}}%
\uc@dclc{9396}{autogenerated}{\unichar{40}\unichar{121}\unichar{41}}%
\uc@dclc{9397}{autogenerated}{\unichar{40}\unichar{122}\unichar{41}}%
\uc@dclc{9398}{autogenerated}{\unicodecircle{\unichar{65}}}%
\uc@dclc{9399}{autogenerated}{\unicodecircle{\unichar{66}}}%
\uc@dclc{9400}{autogenerated}{\unicodecircle{\unichar{67}}}%
\uc@dclc{9401}{autogenerated}{\unicodecircle{\unichar{68}}}%
\uc@dclc{9402}{autogenerated}{\unicodecircle{\unichar{69}}}%
\uc@dclc{9403}{autogenerated}{\unicodecircle{\unichar{70}}}%
\uc@dclc{9404}{autogenerated}{\unicodecircle{\unichar{71}}}%
\uc@dclc{9405}{autogenerated}{\unicodecircle{\unichar{72}}}%
\uc@dclc{9406}{autogenerated}{\unicodecircle{\unichar{73}}}%
\uc@dclc{9407}{autogenerated}{\unicodecircle{\unichar{74}}}%
\uc@dclc{9408}{autogenerated}{\unicodecircle{\unichar{75}}}%
\uc@dclc{9409}{autogenerated}{\unicodecircle{\unichar{76}}}%
\uc@dclc{9410}{autogenerated}{\unicodecircle{\unichar{77}}}%
\uc@dclc{9411}{autogenerated}{\unicodecircle{\unichar{78}}}%
\uc@dclc{9412}{autogenerated}{\unicodecircle{\unichar{79}}}%
\uc@dclc{9413}{autogenerated}{\unicodecircle{\unichar{80}}}%
\uc@dclc{9414}{autogenerated}{\unicodecircle{\unichar{81}}}%
\uc@dclc{9415}{autogenerated}{\unicodecircle{\unichar{82}}}%
\uc@dclc{9416}{autogenerated}{\unicodecircle{\unichar{83}}}%
\uc@dclc{9417}{autogenerated}{\unicodecircle{\unichar{84}}}%
\uc@dclc{9418}{autogenerated}{\unicodecircle{\unichar{85}}}%
\uc@dclc{9419}{autogenerated}{\unicodecircle{\unichar{86}}}%
\uc@dclc{9420}{autogenerated}{\unicodecircle{\unichar{87}}}%
\uc@dclc{9421}{autogenerated}{\unicodecircle{\unichar{88}}}%
\uc@dclc{9422}{autogenerated}{\unicodecircle{\unichar{89}}}%
\uc@dclc{9423}{autogenerated}{\unicodecircle{\unichar{90}}}%
\uc@dclc{9424}{autogenerated}{\unicodecircle{\unichar{97}}}%
\uc@dclc{9425}{autogenerated}{\unicodecircle{\unichar{98}}}%
\uc@dclc{9426}{autogenerated}{\unicodecircle{\unichar{99}}}%
\uc@dclc{9427}{autogenerated}{\unicodecircle{\unichar{100}}}%
\uc@dclc{9428}{autogenerated}{\unicodecircle{\unichar{101}}}%
\uc@dclc{9429}{autogenerated}{\unicodecircle{\unichar{102}}}%
\uc@dclc{9430}{autogenerated}{\unicodecircle{\unichar{103}}}%
\uc@dclc{9431}{autogenerated}{\unicodecircle{\unichar{104}}}%
\uc@dclc{9432}{autogenerated}{\unicodecircle{\unichar{105}}}%
\uc@dclc{9433}{autogenerated}{\unicodecircle{\unichar{106}}}%
\uc@dclc{9434}{autogenerated}{\unicodecircle{\unichar{107}}}%
\uc@dclc{9435}{autogenerated}{\unicodecircle{\unichar{108}}}%
\uc@dclc{9436}{autogenerated}{\unicodecircle{\unichar{109}}}%
\uc@dclc{9437}{autogenerated}{\unicodecircle{\unichar{110}}}%
\uc@dclc{9438}{autogenerated}{\unicodecircle{\unichar{111}}}%
\uc@dclc{9439}{autogenerated}{\unicodecircle{\unichar{112}}}%
\uc@dclc{9440}{autogenerated}{\unicodecircle{\unichar{113}}}%
\uc@dclc{9441}{autogenerated}{\unicodecircle{\unichar{114}}}%
\uc@dclc{9442}{autogenerated}{\unicodecircle{\unichar{115}}}%
\uc@dclc{9443}{autogenerated}{\unicodecircle{\unichar{116}}}%
\uc@dclc{9444}{autogenerated}{\unicodecircle{\unichar{117}}}%
\uc@dclc{9445}{autogenerated}{\unicodecircle{\unichar{118}}}%
\uc@dclc{9446}{autogenerated}{\unicodecircle{\unichar{119}}}%
\uc@dclc{9447}{autogenerated}{\unicodecircle{\unichar{120}}}%
\uc@dclc{9448}{autogenerated}{\unicodecircle{\unichar{121}}}%
\uc@dclc{9449}{autogenerated}{\unicodecircle{\unichar{122}}}%
\uc@dclc{9450}{autogenerated}{\unicodecircle{\unichar{48}}}%
%%% Local Variables: 
%%% mode: latex
%%% coding: utf-8
%%% End: 
