%%% Unicode to TeX mapping, file uni-185.def, U+B900..U+B9FF, autogenerated by makeunidef.pl
\ifx\ProvidesFile\undefined\else
\ProvidesFile{uni-185.def}[2022/08/07 UCS: Unicode data U+B900..U+B9FF]%
\fi
\gdef\u@cjk@hangul#1#2#3#4{{\fontencoding{C61}\def\CJK@plane{#1#2}\selectfont\char"#3#4\relax}}%
\uc@dclc{47364}{cjkhangul}{\u@cjk@hangul0962}%
\uc@dclc{47384}{cjkhangul}{\u@cjk@hangul0963}%
\uc@dclc{47392}{cjkhangul}{\u@cjk@hangul0964}%
\uc@dclc{47420}{cjkhangul}{\u@cjk@hangul0965}%
\uc@dclc{47421}{cjkhangul}{\u@cjk@hangul0966}%
\uc@dclc{47424}{cjkhangul}{\u@cjk@hangul0967}%
\uc@dclc{47428}{cjkhangul}{\u@cjk@hangul0968}%
\uc@dclc{47436}{cjkhangul}{\u@cjk@hangul0969}%
\uc@dclc{47439}{cjkhangul}{\u@cjk@hangul096A}%
\uc@dclc{47441}{cjkhangul}{\u@cjk@hangul096B}%
\uc@dclc{47448}{cjkhangul}{\u@cjk@hangul096C}%
\uc@dclc{47449}{cjkhangul}{\u@cjk@hangul096D}%
\uc@dclc{47452}{cjkhangul}{\u@cjk@hangul096E}%
\uc@dclc{47456}{cjkhangul}{\u@cjk@hangul096F}%
\uc@dclc{47464}{cjkhangul}{\u@cjk@hangul0970}%
\uc@dclc{47465}{cjkhangul}{\u@cjk@hangul0971}%
\uc@dclc{47467}{cjkhangul}{\u@cjk@hangul0972}%
\uc@dclc{47469}{cjkhangul}{\u@cjk@hangul0973}%
\uc@dclc{47476}{cjkhangul}{\u@cjk@hangul0974}%
\uc@dclc{47477}{cjkhangul}{\u@cjk@hangul0975}%
\uc@dclc{47480}{cjkhangul}{\u@cjk@hangul0976}%
\uc@dclc{47484}{cjkhangul}{\u@cjk@hangul0977}%
\uc@dclc{47492}{cjkhangul}{\u@cjk@hangul0978}%
\uc@dclc{47493}{cjkhangul}{\u@cjk@hangul0979}%
\uc@dclc{47495}{cjkhangul}{\u@cjk@hangul097A}%
\uc@dclc{47497}{cjkhangul}{\u@cjk@hangul097B}%
\uc@dclc{47498}{cjkhangul}{\u@cjk@hangul097C}%
\uc@dclc{47501}{cjkhangul}{\u@cjk@hangul097D}%
\uc@dclc{47502}{cjkhangul}{\u@cjk@hangul097E}%
\uc@dclc{47532}{cjkhangul}{\u@cjk@hangul097F}%
\uc@dclc{47533}{cjkhangul}{\u@cjk@hangul0980}%
\uc@dclc{47536}{cjkhangul}{\u@cjk@hangul0981}%
\uc@dclc{47540}{cjkhangul}{\u@cjk@hangul0982}%
\uc@dclc{47548}{cjkhangul}{\u@cjk@hangul0983}%
\uc@dclc{47549}{cjkhangul}{\u@cjk@hangul0984}%
\uc@dclc{47551}{cjkhangul}{\u@cjk@hangul0985}%
\uc@dclc{47553}{cjkhangul}{\u@cjk@hangul0986}%
\uc@dclc{47560}{cjkhangul}{\u@cjk@hangul0987}%
\uc@dclc{47561}{cjkhangul}{\u@cjk@hangul0988}%
\uc@dclc{47564}{cjkhangul}{\u@cjk@hangul0989}%
\uc@dclc{47566}{cjkhangul}{\u@cjk@hangul098A}%
\uc@dclc{47567}{cjkhangul}{\u@cjk@hangul098B}%
\uc@dclc{47568}{cjkhangul}{\u@cjk@hangul098C}%
\uc@dclc{47569}{cjkhangul}{\u@cjk@hangul098D}%
\uc@dclc{47570}{cjkhangul}{\u@cjk@hangul098E}%
\uc@dclc{47576}{cjkhangul}{\u@cjk@hangul098F}%
\uc@dclc{47577}{cjkhangul}{\u@cjk@hangul0990}%
\uc@dclc{47579}{cjkhangul}{\u@cjk@hangul0991}%
\uc@dclc{47581}{cjkhangul}{\u@cjk@hangul0992}%
\uc@dclc{47582}{cjkhangul}{\u@cjk@hangul0993}%
\uc@dclc{47585}{cjkhangul}{\u@cjk@hangul0994}%
\uc@dclc{47587}{cjkhangul}{\u@cjk@hangul0995}%
\uc@dclc{47588}{cjkhangul}{\u@cjk@hangul0996}%
\uc@dclc{47589}{cjkhangul}{\u@cjk@hangul0997}%
\uc@dclc{47592}{cjkhangul}{\u@cjk@hangul0998}%
\uc@dclc{47596}{cjkhangul}{\u@cjk@hangul0999}%
\uc@dclc{47604}{cjkhangul}{\u@cjk@hangul099A}%
\uc@dclc{47605}{cjkhangul}{\u@cjk@hangul099B}%
\uc@dclc{47607}{cjkhangul}{\u@cjk@hangul099C}%
\uc@dclc{47608}{cjkhangul}{\u@cjk@hangul099D}%
\uc@dclc{47609}{cjkhangul}{\u@cjk@hangul099E}%
\uc@dclc{47610}{cjkhangul}{\u@cjk@hangul099F}%
%%% Local Variables: 
%%% mode: latex
%%% coding: utf-8
%%% End: 
