%%
%% This is file `tagpdf-ns-latex.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% tagpdf-data.dtx  (with options: `ns-latex')
%% 
%% Copyright (C) 2019-2024 Ulrike Fischer
%% 
%% It may be distributed and/or modified under the conditions of
%% the LaTeX Project Public License (LPPL), either version 1.3c of
%% this license or (at your option) any later version.  The latest
%% version of this license is in the file:
%% 
%%    https://www.latex-project.org/lppl.txt
%% 
%% This file is part of the "tagpdf bundle" (The Work in LPPL)
%% and all files in that bundle must be distributed together.
%% 
%% File: tagpdf-data.dtx
%% \ProvidesExplFile {tagpdf-ns-latex.def} {2025-03-05} {0.99o}
%% {latex} {https://www.latex-project.org/ns/dflt}{}
title,        Title,    pdf2,
part,         Title,    pdf2,
section,      H1,       pdf2,
subsection,   H2,       pdf2,
subsubsection,H3,       pdf2,
paragraph,    H4,       pdf2,
subparagraph, H5,       pdf2,
list,         L,        pdf2,
itemize,      L,        pdf2,
enumerate,    L,        pdf2,
description,  L,        pdf2,
quote,        BlockQuote,pdf,
quotation,    BlockQuote,pdf,
verbatim,     Div,      pdf2,
item,         LI,       pdf2,
itemlabel,    Lbl,      pdf2,
itembody,     LBody,    pdf2,
footnote,     FENote,   pdf2,
footnotemark, Lbl,      pdf2,
footnotelabel,Lbl,      pdf2,
text-unit,    Part,     pdf2,
text,         P,        pdf2,
%% 
%%
%% End of file `tagpdf-ns-latex.def'.
