%%% Unicode to TeX mapping, file uni-44.def, U+2C00..U+2CFF, autogenerated by makeunidef.pl
\ifx\ProvidesFile\undefined\else
\ProvidesFile{uni-44.def}[2022/08/07 UCS: Unicode data U+2C00..U+2CFF]%
\fi
\uc@dclc{11388}{autogenerated}{\unicodesub{\unichar{106}}}%
\uc@dclc{11389}{autogenerated}{\unicodesuper{\unichar{86}}}%
%%% Local Variables: 
%%% mode: latex
%%% coding: utf-8
%%% End: 
