%%
%% This is file `emtex.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% drivers.dtx  (with options: `emtex,dosrules,nops')
%% 
%% drivers.dtx Copyright (C) 1994      David Carlisle Sebastian Rahtz
%%             Copyright (C) 1995 1996 1997 1998 1999 David Carlisle
%%             Copyright (C) 2000-2025 LaTeX Project
%% The LaTeX Project and any individual authors listed elsewhere
%% in this file.
%%
%% This file is part of the Standard LaTeX `Graphics Bundle'.
%% It may be distributed under the terms of the LaTeX Project Public
%% License, as described in lppl.txt in the base LaTeX distribution.
%% Either version 1.3 or, at your option, any later version.
%%
\ProvidesFile{emtex.def}
        [2016/06/17 v3.0m Driver-dependent file (DPC,SPQR)]
\def\Ginclude@bmp#1{%
  \raise\Gin@req@height\hbox{\special{em:graph #1}}%
\typeout{WARNING: emtex does not permit graphics to be scaled}%
}
\def\Gin@PS@raw#1{}
\def\Gin@PS@restored#1{}
\def\Gin@PS@literal@header#1{}
\def\Gin@PS@file@header#1{}
\def\Gin@extensions{.eps,.ps,.pcx,.bmp}
\@namedef{Gin@rule@.pcx}#1{{bmp}{}{#1}}
\@namedef{Gin@rule@.bmp}#1{{bmp}{}{#1}}
\@namedef{Gin@rule@.msp}#1{{bmp}{}{#1}}
\endinput
%%
%% End of file `emtex.def'.
