%%
%% This is file `next.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% inputenc.dtx  (with options: `next')
%% 
%% This is a generated file.
%% 
%% The source is maintained by the LaTeX Project team and bug
%% reports for it can be opened at https://latex-project.org/bugs.html
%% (but please observe conditions on bug reports sent to that address!)
%% 
%% 
%% Copyright (C) 1993-2025
%% The LaTeX Project and any individual authors listed elsewhere
%% in this file.
%% 
%% This file was generated from file(s) of the LaTeX base system.
%% --------------------------------------------------------------
%% 
%% It may be distributed and/or modified under the
%% conditions of the LaTeX Project Public License, either version 1.3c
%% of this license or (at your option) any later version.
%% The latest version of this license is in
%%    https://www.latex-project.org/lppl.txt
%% and version 1.3c or later is part of all distributions of LaTeX
%% version 2008 or later.
%% 
%% This file has the LPPL maintenance status "maintained".
%% 
%% This file may only be distributed together with a copy of the LaTeX
%% base system. You may however distribute the LaTeX base system without
%% such generated files.
%% 
%% The list of all files belonging to the LaTeX base distribution is
%% given in the file `manifest.txt'. See also `legal.txt' for additional
%% information.
%% 
%% The list of derived (unpacked) files belonging to the distribution
%% and covered by LPPL is defined by the unpacking scripts (with
%% extension .ins) which are part of the distribution.

  \ProvidesFile{next.def}
   [2024/02/08 v1.3d Input encoding file]
\ProvideTextCommandDefault{\textdegree}{\ensuremath{{^\circ}}}
\ProvideTextCommandDefault{\textonehalf}{\ensuremath{\frac12}}
\ProvideTextCommandDefault{\textonequarter}{\ensuremath{\frac14}}
\ProvideTextCommandDefault{\textthreequarters}{\ensuremath{\frac34}}
\ProvideTextCommandDefault{\textflorin}{\textit{f}}
\ProvideTextCommandDefault{\textcent}
   {\TextSymbolUnavailable\textcent}
\ProvideTextCommandDefault{\textyen}
   {\TextSymbolUnavailable\textyen}
\ProvideTextCommandDefault{\textcurrency}
   {\TextSymbolUnavailable\textcurrency}
\ProvideTextCommandDefault{\textperthousand}
   {\TextSymbolUnavailable\textperthousand}
\providecommand{\mathonesuperior}{{^1}}
\providecommand{\maththreesuperior}{{^3}}
\providecommand{\mathtwosuperior}{{^2}}
\DeclareInputText{128}{\nobreakspace}
\DeclareInputText{129}{\@tabacckludge`A}
\DeclareInputText{130}{\@tabacckludge'A}
\DeclareInputText{131}{\^A}
\DeclareInputText{132}{\~A}
\DeclareInputText{133}{\"A}
\DeclareInputText{134}{\r A}
\DeclareInputText{135}{\c C}
\DeclareInputText{136}{\@tabacckludge`E}
\DeclareInputText{137}{\@tabacckludge'E}
\DeclareInputText{138}{\^E}
\DeclareInputText{139}{\"E}
\DeclareInputText{140}{\@tabacckludge`I}
\DeclareInputText{141}{\@tabacckludge'I}
\DeclareInputText{142}{\^I}
\DeclareInputText{143}{\"I}
\DeclareInputText{144}{\DH}
\DeclareInputText{145}{\~N}
\DeclareInputText{146}{\@tabacckludge`O}
\DeclareInputText{147}{\@tabacckludge'O}
\DeclareInputText{148}{\^O}
\DeclareInputText{149}{\~O}
\DeclareInputText{150}{\"O}
\DeclareInputText{151}{\@tabacckludge`U}
\DeclareInputText{152}{\@tabacckludge'U}
\DeclareInputText{153}{\^U}
\DeclareInputText{154}{\"U}
\DeclareInputText{155}{\@tabacckludge'Y}
\DeclareInputText{156}{\TH}
\DeclareInputMath{157}{\mu}
\DeclareInputMath{158}{\times}
\DeclareInputMath{159}{\div}
\DeclareInputText{160}{\copyright}
\DeclareInputText{161}{\textexclamdown}
\DeclareInputText{162}{\textcent}
\DeclareInputText{163}{\pounds}
\DeclareInputMath{164}{/}
\DeclareInputText{165}{\textyen}
\DeclareInputText{166}{\textflorin}
\DeclareInputText{167}{\S}
\DeclareInputText{168}{\textcurrency}
\DeclareInputText{169}{\textquoteright}
\DeclareInputText{170}{\textquotedblleft}
\DeclareInputText{171}{\guillemetleft}
\DeclareInputText{172}{\guilsinglleft}
\DeclareInputText{173}{\guilsinglright}
\DeclareInputText{174}{fi}
\DeclareInputText{175}{fl}
\DeclareInputText{176}{\textregistered}
\DeclareInputText{177}{\textendash}
\DeclareInputText{178}{\dag}
\DeclareInputText{179}{\ddag}
\DeclareInputText{180}{\textperiodcentered}
\DeclareInputText{181}{\textbrokenbar}
\DeclareInputText{182}{\P}
\DeclareInputText{183}{\textbullet}
\DeclareInputText{184}{\quotesinglbase}
\DeclareInputText{185}{\quotedblbase}
\DeclareInputText{186}{\textquotedblright}
\DeclareInputText{187}{\guillemetright}
\DeclareInputText{188}{\dots}
\DeclareInputText{189}{\textperthousand}
\DeclareInputMath{190}{\lnot}
\DeclareInputText{191}{\textquestiondown}
\DeclareInputMath{192}{\mathonesuperior}
\DeclareInputText{193}{\@tabacckludge`{}}
\DeclareInputText{194}{\@tabacckludge'{}}
\DeclareInputText{195}{\^{}}
\DeclareInputText{196}{\~{}}
\DeclareInputText{197}{\@tabacckludge={}}
\DeclareInputText{198}{\u{}}
\DeclareInputText{199}{\.{}}
\DeclareInputText{200}{\"{}}
\DeclareInputMath{201}{\mathtwosuperior}
\DeclareInputText{202}{\r{}}
\DeclareInputText{203}{\c\ }
\DeclareInputMath{204}{\maththreesuperior}
\DeclareInputText{205}{\H{}}
\DeclareInputText{206}{\k\ }
\DeclareInputText{207}{\v{}}
\DeclareInputText{208}{\textemdash}
\DeclareInputMath{209}{\pm}
\DeclareInputText{210}{\textonequarter}
\DeclareInputText{211}{\textonehalf}
\DeclareInputText{212}{\textthreequarters}
\DeclareInputText{213}{\@tabacckludge`a}
\DeclareInputText{214}{\@tabacckludge'a}
\DeclareInputText{215}{\^a}
\DeclareInputText{216}{\~a}
\DeclareInputText{217}{\"a}
\DeclareInputText{218}{\r a}
\DeclareInputText{219}{\c c}
\DeclareInputText{220}{\@tabacckludge`e}
\DeclareInputText{221}{\@tabacckludge'e}
\DeclareInputText{222}{\^e}
\DeclareInputText{223}{\"e}
\DeclareInputText{224}{\@tabacckludge`\i}
\DeclareInputText{225}{\AE}
\DeclareInputText{226}{\@tabacckludge'\i}
\DeclareInputText{227}{\textordfeminine}
\DeclareInputText{228}{\^\i}
\DeclareInputText{229}{\"\i}
\DeclareInputText{230}{\dh}
\DeclareInputText{231}{\~n}
\DeclareInputText{232}{\L}
\DeclareInputText{233}{\O}
\DeclareInputText{234}{\OE}
\DeclareInputText{235}{\textordmasculine}
\DeclareInputText{236}{\@tabacckludge`o}
\DeclareInputText{237}{\@tabacckludge'o}
\DeclareInputText{238}{\^o}
\DeclareInputText{239}{\~o}
\DeclareInputText{240}{\"o}
\DeclareInputText{241}{\ae}
\DeclareInputText{242}{\@tabacckludge`u}
\DeclareInputText{243}{\@tabacckludge'u}
\DeclareInputText{244}{\^u}
\DeclareInputText{245}{\i}
\DeclareInputText{246}{\"u}
\DeclareInputText{247}{\@tabacckludge'y}
\DeclareInputText{248}{\l}
\DeclareInputText{249}{\o}
\DeclareInputText{250}{\oe}
\DeclareInputText{251}{\ss}
\DeclareInputText{252}{\th}
\DeclareInputText{253}{\"y}
\endinput
%%
%% End of file `next.def'.
