%%
%% This is file `tagpdf-ns-pdf2.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% tagpdf-data.dtx  (with options: `ns-pdf2')
%% 
%% Copyright (C) 2019-2024 Ulrike Fischer
%% 
%% It may be distributed and/or modified under the conditions of
%% the LaTeX Project Public License (LPPL), either version 1.3c of
%% this license or (at your option) any later version.  The latest
%% version of this license is in the file:
%% 
%%    https://www.latex-project.org/lppl.txt
%% 
%% This file is part of the "tagpdf bundle" (The Work in LPPL)
%% and all files in that bundle must be distributed together.
%% 
%% File: tagpdf-data.dtx
%% \ProvidesExplFile {tagpdf-ns-pdf2.def} {2025-03-05} {0.99o}
%%  {pdf2}  {http://iso.org/pdf2/ssn}{}
StructTreeRoot,StructTreeRoot,pdf2,D,
Document,Document,pdf2,D,
Part,Part,pdf2,G,
Sect,Sect,pdf2,G,
Div,Div,pdf2,G,
Caption,Caption,pdf2,GB,
NonStruct,NonStruct,pdf2,G,
H,H,pdf2,B,
H1,H1,pdf2,B,
H2,H2,pdf2,B,
H3,H3,pdf2,B,
H4,H4,pdf2,B,
H5,H5,pdf2,B,
H6,H6,pdf2,B,
P,P,pdf2,B,
L,L,pdf2,BI,
LI,LI,pdf2,L,
Lbl,Lbl,pdf2,I,
LBody,LBody,pdf2,L,
Table,Table,pdf2,B,
TR,TR,pdf2,T,
TH,TH,pdf2,T,
TD,TD,pdf2,T,
THead,THead,pdf2,T,
TBody,TBody,pdf2,T,
TFoot,TFoot,pdf2,T,
Span,Span,pdf2,I,
Link,Link,pdf2,GBI,
Annot,Annot,pdf2,GBI,
Figure,Figure,pdf2,GBI,
Formula,Formula,pdf2,GBI,
Form,Form,pdf2,GBI,
Ruby,Ruby,pdf2,I,
RB,RB,pdf2,I,
RT,RT,pdf2,I,
Warichu,Warichu,pdf2,I,
WT,WT,pdf2,I,
WP,WP,pdf2,I,
Artifact,Artifact,pdf2,GBI,
DocumentFragment,DocumentFragment,pdf2,D, %rest only pdf2
Aside,Aside,pdf2,G,
H7,H7,pdf2,B,
H8,H8,pdf2,B,
H9,H9,pdf2,B,
H10,H10,pdf2,B,
Title,Title,pdf2,GB,
FENote,FENote,pdf2,GBI,
Sub,Sub,pdf2,I,
Em,Em,pdf2,I,
Strong,Strong,pdf2,I,
%% 
%%
%% End of file `tagpdf-ns-pdf2.def'.
