%%
%% This is file `lklenc.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% ucs.dtx  (with options: `lklenc.def')
%% 
%% Copyright 2001 Dominique Unruh  <unruh@ut.ee>
%% Copyright 2013 Wolfgang Jeltsch <wolfgang@cs.ioc.ee>
%% Copyright 2022 David Carlisle https://github.com/LaTeX-Package-Repositories/ucs
%% 
%% This program is provided under the terms of the LaTeX Project Public License with some
%% modifications. See the file LICENSE for information.
%% 
\ProvidesFile{lklenc.def}[2001/10/17 Okuda (Klingon) Font Encoding LKL]
\DeclareFontEncoding{LKL}{}{}
\DeclareFontSubstitution{LKL}{kli}{m}{n}
\DeclareTextSymbol{\klingona}{LKL}{`\a}
\DeclareTextSymbol{\klingonb}{LKL}{`\b}
\DeclareTextSymbol{\klingonch}{LKL}{`\C}
\DeclareTextSymbol{\klingonD}{LKL}{`\D}
\DeclareTextSymbol{\klingone}{LKL}{`\e}
\DeclareTextSymbol{\klingongh}{LKL}{`\G}
\DeclareTextSymbol{\klingonH}{LKL}{`\H}
\DeclareTextSymbol{\klingonI}{LKL}{`\I}
\DeclareTextSymbol{\klingonj}{LKL}{`\j}
\DeclareTextSymbol{\klingonl}{LKL}{`\l}
\DeclareTextSymbol{\klingonm}{LKL}{`\m}
\DeclareTextSymbol{\klingonn}{LKL}{`\n}
\DeclareTextSymbol{\klingonng}{LKL}{`\N}
\DeclareTextSymbol{\klingono}{LKL}{`\o}
\DeclareTextSymbol{\klingonp}{LKL}{`\p}
\DeclareTextSymbol{\klingonq}{LKL}{`\q}
\DeclareTextSymbol{\klingonQ}{LKL}{`\Q}
\DeclareTextSymbol{\klingonr}{LKL}{`\r}
\DeclareTextSymbol{\klingonS}{LKL}{`\S}
\DeclareTextSymbol{\klingont}{LKL}{`\t}
\DeclareTextSymbol{\klingontlh}{LKL}{`\T}
\DeclareTextSymbol{\klingonu}{LKL}{`\u}
\DeclareTextSymbol{\klingonv}{LKL}{`\v}
\DeclareTextSymbol{\klingonw}{LKL}{`\w}
\DeclareTextSymbol{\klingony}{LKL}{`\y}
\DeclareTextSymbol{\klingonglotstop}{LKL}{`\'}
\DeclareTextSymbol{\klingonzero}{LKL}{`\0}
\DeclareTextSymbol{\klingonone}{LKL}{`\1}
\DeclareTextSymbol{\klingontwo}{LKL}{`\2}
\DeclareTextSymbol{\klingonthree}{LKL}{`\3}
\DeclareTextSymbol{\klingonfour}{LKL}{`\4}
\DeclareTextSymbol{\klingonfive}{LKL}{`\5}
\DeclareTextSymbol{\klingonsix}{LKL}{`\6}
\DeclareTextSymbol{\klingonseven}{LKL}{`\7}
\DeclareTextSymbol{\klingoneight}{LKL}{`\8}
\DeclareTextSymbol{\klingonnine}{LKL}{`\9}
