\NewDocumentCommand{\tutodoc@trans@date}{mmm}{#3/#2/#1}
\NewDocumentCommand{\tutodoc@trans@in@EN}{m}{#1 en anglais}
\NewDocumentCommand{\tutodoc@trans@this@gives}{m}{Ceci donne #1}
\NewDocumentCommand{\tutodoc@trans@latex@show@start}{}{Début du rendu réel}
\NewDocumentCommand{\tutodoc@trans@latex@show@end}{}{Fin du rendu réel}
\NewDocumentCommand{\tutodoc@trans@exa@title}{}{Exemple}
\NewDocumentCommand{\tutodoc@trans@rem@title}{}{Remarque}
\NewDocumentCommand{\tutodoc@trans@note@title}{}{Note}
\NewDocumentCommand{\tutodoc@trans@tip@title}{}{Astuce}
\NewDocumentCommand{\tutodoc@trans@imp@title}{}{Important}
\NewDocumentCommand{\tutodoc@trans@caut@title}{}{Mise en garde}
\NewDocumentCommand{\tutodoc@trans@warn@title}{}{Avertissement}
\NewDocumentCommand{\tutodoc@trans@chges@tech}{}{Information technique}
\NewDocumentCommand{\tutodoc@trans@chges@todo}{}{À faire}
\NewDocumentCommand{\tutodoc@trans@chges@prob}{}{Problème}
\NewDocumentCommand{\tutodoc@trans@chges@break}{}{Bifurcation}
\NewDocumentCommand{\tutodoc@trans@chges@fix}{}{Réparation}
\NewDocumentCommand{\tutodoc@trans@chges@new}{}{Nouveau}
\NewDocumentCommand{\tutodoc@trans@chges@update}{}{Mise à jour}