%%% Unicode to TeX mapping, file uni-193.def, U+C100..U+C1FF, autogenerated by makeunidef.pl
\ifx\ProvidesFile\undefined\else
\ProvidesFile{uni-193.def}[2022/08/07 UCS: Unicode data U+C100..U+C1FF]%
\fi
\gdef\u@cjk@hangul#1#2#3#4{{\fontencoding{C61}\def\CJK@plane{#1#2}\selectfont\char"#3#4\relax}}%
\uc@dclc{49408}{cjkhangul}{\u@cjk@hangul10F1}%
\uc@dclc{49412}{cjkhangul}{\u@cjk@hangul10F2}%
\uc@dclc{49416}{cjkhangul}{\u@cjk@hangul10F3}%
\uc@dclc{49424}{cjkhangul}{\u@cjk@hangul10F4}%
\uc@dclc{49429}{cjkhangul}{\u@cjk@hangul10F5}%
\uc@dclc{49436}{cjkhangul}{\u@cjk@hangul10F6}%
\uc@dclc{49437}{cjkhangul}{\u@cjk@hangul10F7}%
\uc@dclc{49438}{cjkhangul}{\u@cjk@hangul10F8}%
\uc@dclc{49439}{cjkhangul}{\u@cjk@hangul10F9}%
\uc@dclc{49440}{cjkhangul}{\u@cjk@hangul10FA}%
\uc@dclc{49443}{cjkhangul}{\u@cjk@hangul10FB}%
\uc@dclc{49444}{cjkhangul}{\u@cjk@hangul10FC}%
\uc@dclc{49446}{cjkhangul}{\u@cjk@hangul10FD}%
\uc@dclc{49447}{cjkhangul}{\u@cjk@hangul10FE}%
\uc@dclc{49452}{cjkhangul}{\u@cjk@hangul10FF}%
\uc@dclc{49453}{cjkhangul}{\u@cjk@hangul1100}%
\uc@dclc{49455}{cjkhangul}{\u@cjk@hangul1101}%
\uc@dclc{49456}{cjkhangul}{\u@cjk@hangul1102}%
\uc@dclc{49457}{cjkhangul}{\u@cjk@hangul1103}%
\uc@dclc{49462}{cjkhangul}{\u@cjk@hangul1104}%
\uc@dclc{49464}{cjkhangul}{\u@cjk@hangul1105}%
\uc@dclc{49465}{cjkhangul}{\u@cjk@hangul1106}%
\uc@dclc{49468}{cjkhangul}{\u@cjk@hangul1107}%
\uc@dclc{49472}{cjkhangul}{\u@cjk@hangul1108}%
\uc@dclc{49480}{cjkhangul}{\u@cjk@hangul1109}%
\uc@dclc{49481}{cjkhangul}{\u@cjk@hangul110A}%
\uc@dclc{49483}{cjkhangul}{\u@cjk@hangul110B}%
\uc@dclc{49484}{cjkhangul}{\u@cjk@hangul110C}%
\uc@dclc{49485}{cjkhangul}{\u@cjk@hangul110D}%
\uc@dclc{49492}{cjkhangul}{\u@cjk@hangul110E}%
\uc@dclc{49493}{cjkhangul}{\u@cjk@hangul110F}%
\uc@dclc{49496}{cjkhangul}{\u@cjk@hangul1110}%
\uc@dclc{49500}{cjkhangul}{\u@cjk@hangul1111}%
\uc@dclc{49508}{cjkhangul}{\u@cjk@hangul1112}%
\uc@dclc{49509}{cjkhangul}{\u@cjk@hangul1113}%
\uc@dclc{49511}{cjkhangul}{\u@cjk@hangul1114}%
\uc@dclc{49512}{cjkhangul}{\u@cjk@hangul1115}%
\uc@dclc{49513}{cjkhangul}{\u@cjk@hangul1116}%
\uc@dclc{49520}{cjkhangul}{\u@cjk@hangul1117}%
\uc@dclc{49524}{cjkhangul}{\u@cjk@hangul1118}%
\uc@dclc{49528}{cjkhangul}{\u@cjk@hangul1119}%
\uc@dclc{49541}{cjkhangul}{\u@cjk@hangul111A}%
\uc@dclc{49548}{cjkhangul}{\u@cjk@hangul111B}%
\uc@dclc{49549}{cjkhangul}{\u@cjk@hangul111C}%
\uc@dclc{49550}{cjkhangul}{\u@cjk@hangul111D}%
\uc@dclc{49552}{cjkhangul}{\u@cjk@hangul111E}%
\uc@dclc{49556}{cjkhangul}{\u@cjk@hangul111F}%
\uc@dclc{49558}{cjkhangul}{\u@cjk@hangul1120}%
\uc@dclc{49564}{cjkhangul}{\u@cjk@hangul1121}%
\uc@dclc{49565}{cjkhangul}{\u@cjk@hangul1122}%
\uc@dclc{49567}{cjkhangul}{\u@cjk@hangul1123}%
\uc@dclc{49569}{cjkhangul}{\u@cjk@hangul1124}%
\uc@dclc{49573}{cjkhangul}{\u@cjk@hangul1125}%
\uc@dclc{49576}{cjkhangul}{\u@cjk@hangul1126}%
\uc@dclc{49577}{cjkhangul}{\u@cjk@hangul1127}%
\uc@dclc{49580}{cjkhangul}{\u@cjk@hangul1128}%
\uc@dclc{49584}{cjkhangul}{\u@cjk@hangul1129}%
\uc@dclc{49597}{cjkhangul}{\u@cjk@hangul112A}%
\uc@dclc{49604}{cjkhangul}{\u@cjk@hangul112B}%
\uc@dclc{49608}{cjkhangul}{\u@cjk@hangul112C}%
\uc@dclc{49612}{cjkhangul}{\u@cjk@hangul112D}%
\uc@dclc{49620}{cjkhangul}{\u@cjk@hangul112E}%
\uc@dclc{49623}{cjkhangul}{\u@cjk@hangul112F}%
\uc@dclc{49624}{cjkhangul}{\u@cjk@hangul1130}%
\uc@dclc{49632}{cjkhangul}{\u@cjk@hangul1131}%
\uc@dclc{49636}{cjkhangul}{\u@cjk@hangul1132}%
\uc@dclc{49640}{cjkhangul}{\u@cjk@hangul1133}%
\uc@dclc{49648}{cjkhangul}{\u@cjk@hangul1134}%
\uc@dclc{49649}{cjkhangul}{\u@cjk@hangul1135}%
\uc@dclc{49651}{cjkhangul}{\u@cjk@hangul1136}%
\uc@dclc{49660}{cjkhangul}{\u@cjk@hangul1137}%
\uc@dclc{49661}{cjkhangul}{\u@cjk@hangul1138}%
%%% Local Variables: 
%%% mode: latex
%%% coding: utf-8
%%% End: 
