%%% Unicode to TeX mapping, file uni-181.def, U+B500..U+B5FF, autogenerated by makeunidef.pl
\ifx\ProvidesFile\undefined\else
\ProvidesFile{uni-181.def}[2022/08/07 UCS: Unicode data U+B500..U+B5FF]%
\fi
\gdef\u@cjk@hangul#1#2#3#4{{\fontencoding{C61}\def\CJK@plane{#1#2}\selectfont\char"#3#4\relax}}%
\uc@dclc{46356}{cjkhangul}{\u@cjk@hangul08A7}%
\uc@dclc{46357}{cjkhangul}{\u@cjk@hangul08A8}%
\uc@dclc{46360}{cjkhangul}{\u@cjk@hangul08A9}%
\uc@dclc{46363}{cjkhangul}{\u@cjk@hangul08AA}%
\uc@dclc{46364}{cjkhangul}{\u@cjk@hangul08AB}%
\uc@dclc{46372}{cjkhangul}{\u@cjk@hangul08AC}%
\uc@dclc{46373}{cjkhangul}{\u@cjk@hangul08AD}%
\uc@dclc{46375}{cjkhangul}{\u@cjk@hangul08AE}%
\uc@dclc{46376}{cjkhangul}{\u@cjk@hangul08AF}%
\uc@dclc{46377}{cjkhangul}{\u@cjk@hangul08B0}%
\uc@dclc{46378}{cjkhangul}{\u@cjk@hangul08B1}%
\uc@dclc{46384}{cjkhangul}{\u@cjk@hangul08B2}%
\uc@dclc{46385}{cjkhangul}{\u@cjk@hangul08B3}%
\uc@dclc{46388}{cjkhangul}{\u@cjk@hangul08B4}%
\uc@dclc{46392}{cjkhangul}{\u@cjk@hangul08B5}%
\uc@dclc{46400}{cjkhangul}{\u@cjk@hangul08B6}%
\uc@dclc{46401}{cjkhangul}{\u@cjk@hangul08B7}%
\uc@dclc{46403}{cjkhangul}{\u@cjk@hangul08B8}%
\uc@dclc{46404}{cjkhangul}{\u@cjk@hangul08B9}%
\uc@dclc{46405}{cjkhangul}{\u@cjk@hangul08BA}%
\uc@dclc{46411}{cjkhangul}{\u@cjk@hangul08BB}%
\uc@dclc{46412}{cjkhangul}{\u@cjk@hangul08BC}%
\uc@dclc{46413}{cjkhangul}{\u@cjk@hangul08BD}%
\uc@dclc{46416}{cjkhangul}{\u@cjk@hangul08BE}%
\uc@dclc{46420}{cjkhangul}{\u@cjk@hangul08BF}%
\uc@dclc{46428}{cjkhangul}{\u@cjk@hangul08C0}%
\uc@dclc{46429}{cjkhangul}{\u@cjk@hangul08C1}%
\uc@dclc{46431}{cjkhangul}{\u@cjk@hangul08C2}%
\uc@dclc{46432}{cjkhangul}{\u@cjk@hangul08C3}%
\uc@dclc{46433}{cjkhangul}{\u@cjk@hangul08C4}%
\uc@dclc{46496}{cjkhangul}{\u@cjk@hangul08C5}%
\uc@dclc{46497}{cjkhangul}{\u@cjk@hangul08C6}%
\uc@dclc{46500}{cjkhangul}{\u@cjk@hangul08C7}%
\uc@dclc{46504}{cjkhangul}{\u@cjk@hangul08C8}%
\uc@dclc{46506}{cjkhangul}{\u@cjk@hangul08C9}%
\uc@dclc{46507}{cjkhangul}{\u@cjk@hangul08CA}%
\uc@dclc{46512}{cjkhangul}{\u@cjk@hangul08CB}%
\uc@dclc{46513}{cjkhangul}{\u@cjk@hangul08CC}%
\uc@dclc{46515}{cjkhangul}{\u@cjk@hangul08CD}%
\uc@dclc{46516}{cjkhangul}{\u@cjk@hangul08CE}%
\uc@dclc{46517}{cjkhangul}{\u@cjk@hangul08CF}%
\uc@dclc{46523}{cjkhangul}{\u@cjk@hangul08D0}%
\uc@dclc{46524}{cjkhangul}{\u@cjk@hangul08D1}%
\uc@dclc{46525}{cjkhangul}{\u@cjk@hangul08D2}%
\uc@dclc{46528}{cjkhangul}{\u@cjk@hangul08D3}%
\uc@dclc{46532}{cjkhangul}{\u@cjk@hangul08D4}%
\uc@dclc{46540}{cjkhangul}{\u@cjk@hangul08D5}%
\uc@dclc{46541}{cjkhangul}{\u@cjk@hangul08D6}%
\uc@dclc{46543}{cjkhangul}{\u@cjk@hangul08D7}%
\uc@dclc{46544}{cjkhangul}{\u@cjk@hangul08D8}%
\uc@dclc{46545}{cjkhangul}{\u@cjk@hangul08D9}%
\uc@dclc{46552}{cjkhangul}{\u@cjk@hangul08DA}%
\uc@dclc{46572}{cjkhangul}{\u@cjk@hangul08DB}%
%%% Local Variables: 
%%% mode: latex
%%% coding: utf-8
%%% End: 
