% --------------------------------------------------------------------------
% the ELEMENTS package
% 
%   retrieve different properties of chemical elements
% 
% --------------------------------------------------------------------------
% Clemens Niederberger
% Web:    https://github.com/cgnieder/elements/
% E-Mail: contact@mychemistry.eu
% --------------------------------------------------------------------------
% Copyright 2011--2022 Clemens Niederberger
% 
% This work may be distributed and/or modified under the
% conditions of the LaTeX Project Public License, either version 1.3
% of this license or (at your option) any later version.
% The latest version of this license is in
%   http://www.latex-project.org/lppl.txt
% and version 1.3 or later is part of all distributions of LaTeX
% version 2005/12/01 or later.
% 
% This work has the LPPL maintenance status `maintained'.
% 
% The Current Maintainer of this work is Clemens Niederberger.
% --------------------------------------------------------------------------
\DeclareAtomName{1}{Hydrogen}
\DeclareAtomName{2}{Helium}
\DeclareAtomName{3}{Lithium}
\DeclareAtomName{4}{Beryllium}
\DeclareAtomName{5}{Boron}
\DeclareAtomName{6}{Carbon}
\DeclareAtomName{7}{Nitrogen}
\DeclareAtomName{8}{Oxygen}
\DeclareAtomName{9}{Fluorine}
\DeclareAtomName{10}{Neon}
\DeclareAtomName{11}{Sodium}
\DeclareAtomName{12}{Magnesium}
\DeclareAtomName{13}{Aluminium}
\DeclareAtomName{14}{Silicon}
\DeclareAtomName{15}{Phosphorus}
\DeclareAtomName{16}{Sulfur}
\DeclareAtomName{17}{Chlorine}
\DeclareAtomName{18}{Argon}
\DeclareAtomName{19}{Potassium}
\DeclareAtomName{20}{Calcium}
\DeclareAtomName{21}{Scandium}
\DeclareAtomName{22}{Titanium}
\DeclareAtomName{23}{Vanadium}
\DeclareAtomName{24}{Chromium}
\DeclareAtomName{25}{Manganese}
\DeclareAtomName{26}{Iron}
\DeclareAtomName{27}{Cobalt}
\DeclareAtomName{28}{Nickel}
\DeclareAtomName{29}{Copper}
\DeclareAtomName{30}{Zinc}
\DeclareAtomName{31}{Gallium}
\DeclareAtomName{32}{Germanium}
\DeclareAtomName{33}{Arsenic}
\DeclareAtomName{34}{Selenium}
\DeclareAtomName{35}{Bromine}
\DeclareAtomName{36}{Krypton}
\DeclareAtomName{37}{Rubidium}
\DeclareAtomName{38}{Strontium}
\DeclareAtomName{39}{Yttrium}
\DeclareAtomName{40}{Zirconium}
\DeclareAtomName{41}{Niobium}
\DeclareAtomName{42}{Molybdenum}
\DeclareAtomName{43}{Technetium}
\DeclareAtomName{44}{Ruthenium}
\DeclareAtomName{45}{Rhodium}
\DeclareAtomName{46}{Palladium}
\DeclareAtomName{47}{Silver}
\DeclareAtomName{48}{Cadmium}
\DeclareAtomName{49}{Indium}
\DeclareAtomName{50}{Tin}
\DeclareAtomName{51}{Antimony}
\DeclareAtomName{52}{Tellurium}
\DeclareAtomName{53}{Iodine}
\DeclareAtomName{54}{Xenon}
\DeclareAtomName{55}{Caesium}
\DeclareAtomName{56}{Barium}
\DeclareAtomName{57}{Lanthanum}
\DeclareAtomName{58}{Cerium}
\DeclareAtomName{59}{Praseodymium}
\DeclareAtomName{60}{Neodymium}
\DeclareAtomName{61}{Promethium}
\DeclareAtomName{62}{Samarium}
\DeclareAtomName{63}{Europium}
\DeclareAtomName{64}{Gadolinium}
\DeclareAtomName{65}{Terbium}
\DeclareAtomName{66}{Dysprosium}
\DeclareAtomName{67}{Holmium}
\DeclareAtomName{68}{Erbium}
\DeclareAtomName{69}{Thulium}
\DeclareAtomName{70}{Ytterbium}
\DeclareAtomName{71}{Lutetium}
\DeclareAtomName{72}{Hafnium}
\DeclareAtomName{73}{Tantalium}
\DeclareAtomName{74}{Tungsten}
\DeclareAtomName{75}{Rhenium}
\DeclareAtomName{76}{Osmium}
\DeclareAtomName{77}{Iridium}
\DeclareAtomName{78}{Platinum}
\DeclareAtomName{79}{Gold}
\DeclareAtomName{80}{Mercury}
\DeclareAtomName{81}{Thallium}
\DeclareAtomName{82}{Lead}
\DeclareAtomName{83}{Bismuth}
\DeclareAtomName{84}{Polonium}
\DeclareAtomName{85}{Astatine}
\DeclareAtomName{86}{Radon}
\DeclareAtomName{87}{Francium}
\DeclareAtomName{88}{Radium}
\DeclareAtomName{89}{Actinium}
\DeclareAtomName{90}{Thorium}
\DeclareAtomName{91}{Protactinium}
\DeclareAtomName{92}{Uranium}
\DeclareAtomName{93}{Neptunium}
\DeclareAtomName{94}{Plutonium}
\DeclareAtomName{95}{Americium}
\DeclareAtomName{96}{Curium}
\DeclareAtomName{97}{Berkelium}
\DeclareAtomName{98}{Californium}
\DeclareAtomName{99}{Einsteinium}
\DeclareAtomName{100}{Fermium}
\DeclareAtomName{101}{Mendelevium}
\DeclareAtomName{102}{Nobelium}
\DeclareAtomName{103}{Lawrencium}
\DeclareAtomName{104}{Rutherfordium}
\DeclareAtomName{105}{Dubnium}
\DeclareAtomName{106}{Seaborgium}
\DeclareAtomName{107}{Bohrium}
\DeclareAtomName{108}{Hassium}
\DeclareAtomName{109}{Meitnerium}
\DeclareAtomName{110}{Darmstadtium}
\DeclareAtomName{111}{Roentgenium}
\DeclareAtomName{112}{Copernicium}
\DeclareAtomName{113}{Nihonium}
\DeclareAtomName{114}{Flerovium}
\DeclareAtomName{115}{Moscovium}
\DeclareAtomName{116}{Livermorium}
\DeclareAtomName{117}{Tennessine}
\DeclareAtomName{118}{Oganesson}

\endinput
