%%% Unicode to TeX mapping, file uni-213.def, U+D500..U+D5FF, autogenerated by makeunidef.pl
\ifx\ProvidesFile\undefined\else
\ProvidesFile{uni-213.def}[2022/08/07 UCS: Unicode data U+D500..U+D5FF]%
\fi
\gdef\u@cjk@hangul#1#2#3#4{{\fontencoding{C61}\def\CJK@plane{#1#2}\selectfont\char"#3#4\relax}}%
\uc@dclc{54532}{cjkhangul}{\u@cjk@hangul1514}%
\uc@dclc{54536}{cjkhangul}{\u@cjk@hangul1515}%
\uc@dclc{54540}{cjkhangul}{\u@cjk@hangul1516}%
\uc@dclc{54548}{cjkhangul}{\u@cjk@hangul1517}%
\uc@dclc{54549}{cjkhangul}{\u@cjk@hangul1518}%
\uc@dclc{54551}{cjkhangul}{\u@cjk@hangul1519}%
\uc@dclc{54588}{cjkhangul}{\u@cjk@hangul151A}%
\uc@dclc{54589}{cjkhangul}{\u@cjk@hangul151B}%
\uc@dclc{54592}{cjkhangul}{\u@cjk@hangul151C}%
\uc@dclc{54596}{cjkhangul}{\u@cjk@hangul151D}%
\uc@dclc{54604}{cjkhangul}{\u@cjk@hangul151E}%
\uc@dclc{54605}{cjkhangul}{\u@cjk@hangul151F}%
\uc@dclc{54607}{cjkhangul}{\u@cjk@hangul1520}%
\uc@dclc{54609}{cjkhangul}{\u@cjk@hangul1521}%
\uc@dclc{54616}{cjkhangul}{\u@cjk@hangul1522}%
\uc@dclc{54617}{cjkhangul}{\u@cjk@hangul1523}%
\uc@dclc{54620}{cjkhangul}{\u@cjk@hangul1524}%
\uc@dclc{54624}{cjkhangul}{\u@cjk@hangul1525}%
\uc@dclc{54629}{cjkhangul}{\u@cjk@hangul1526}%
\uc@dclc{54632}{cjkhangul}{\u@cjk@hangul1527}%
\uc@dclc{54633}{cjkhangul}{\u@cjk@hangul1528}%
\uc@dclc{54635}{cjkhangul}{\u@cjk@hangul1529}%
\uc@dclc{54637}{cjkhangul}{\u@cjk@hangul152A}%
\uc@dclc{54644}{cjkhangul}{\u@cjk@hangul152B}%
\uc@dclc{54645}{cjkhangul}{\u@cjk@hangul152C}%
\uc@dclc{54648}{cjkhangul}{\u@cjk@hangul152D}%
\uc@dclc{54652}{cjkhangul}{\u@cjk@hangul152E}%
\uc@dclc{54660}{cjkhangul}{\u@cjk@hangul152F}%
\uc@dclc{54661}{cjkhangul}{\u@cjk@hangul1530}%
\uc@dclc{54663}{cjkhangul}{\u@cjk@hangul1531}%
\uc@dclc{54664}{cjkhangul}{\u@cjk@hangul1532}%
\uc@dclc{54665}{cjkhangul}{\u@cjk@hangul1533}%
\uc@dclc{54672}{cjkhangul}{\u@cjk@hangul1534}%
\uc@dclc{54693}{cjkhangul}{\u@cjk@hangul1535}%
\uc@dclc{54728}{cjkhangul}{\u@cjk@hangul1536}%
\uc@dclc{54729}{cjkhangul}{\u@cjk@hangul1537}%
\uc@dclc{54732}{cjkhangul}{\u@cjk@hangul1538}%
\uc@dclc{54736}{cjkhangul}{\u@cjk@hangul1539}%
\uc@dclc{54738}{cjkhangul}{\u@cjk@hangul153A}%
\uc@dclc{54744}{cjkhangul}{\u@cjk@hangul153B}%
\uc@dclc{54745}{cjkhangul}{\u@cjk@hangul153C}%
\uc@dclc{54747}{cjkhangul}{\u@cjk@hangul153D}%
\uc@dclc{54749}{cjkhangul}{\u@cjk@hangul153E}%
\uc@dclc{54756}{cjkhangul}{\u@cjk@hangul153F}%
\uc@dclc{54757}{cjkhangul}{\u@cjk@hangul1540}%
\uc@dclc{54760}{cjkhangul}{\u@cjk@hangul1541}%
\uc@dclc{54764}{cjkhangul}{\u@cjk@hangul1542}%
\uc@dclc{54772}{cjkhangul}{\u@cjk@hangul1543}%
\uc@dclc{54773}{cjkhangul}{\u@cjk@hangul1544}%
\uc@dclc{54775}{cjkhangul}{\u@cjk@hangul1545}%
\uc@dclc{54777}{cjkhangul}{\u@cjk@hangul1546}%
%%% Local Variables: 
%%% mode: latex
%%% coding: utf-8
%%% End: 
