%%% Unicode to TeX mapping, file uni-207.def, U+CF00..U+CFFF, autogenerated by makeunidef.pl
\ifx\ProvidesFile\undefined\else
\ProvidesFile{uni-207.def}[2022/08/07 UCS: Unicode data U+CF00..U+CFFF]%
\fi
\gdef\u@cjk@hangul#1#2#3#4{{\fontencoding{C61}\def\CJK@plane{#1#2}\selectfont\char"#3#4\relax}}%
\uc@dclc{52992}{cjkhangul}{\u@cjk@hangul1402}%
\uc@dclc{52993}{cjkhangul}{\u@cjk@hangul1403}%
\uc@dclc{52996}{cjkhangul}{\u@cjk@hangul1404}%
\uc@dclc{53000}{cjkhangul}{\u@cjk@hangul1405}%
\uc@dclc{53008}{cjkhangul}{\u@cjk@hangul1406}%
\uc@dclc{53009}{cjkhangul}{\u@cjk@hangul1407}%
\uc@dclc{53011}{cjkhangul}{\u@cjk@hangul1408}%
\uc@dclc{53013}{cjkhangul}{\u@cjk@hangul1409}%
\uc@dclc{53020}{cjkhangul}{\u@cjk@hangul140A}%
\uc@dclc{53024}{cjkhangul}{\u@cjk@hangul140B}%
\uc@dclc{53028}{cjkhangul}{\u@cjk@hangul140C}%
\uc@dclc{53036}{cjkhangul}{\u@cjk@hangul140D}%
\uc@dclc{53037}{cjkhangul}{\u@cjk@hangul140E}%
\uc@dclc{53039}{cjkhangul}{\u@cjk@hangul140F}%
\uc@dclc{53040}{cjkhangul}{\u@cjk@hangul1410}%
\uc@dclc{53041}{cjkhangul}{\u@cjk@hangul1411}%
\uc@dclc{53048}{cjkhangul}{\u@cjk@hangul1412}%
\uc@dclc{53076}{cjkhangul}{\u@cjk@hangul1413}%
\uc@dclc{53077}{cjkhangul}{\u@cjk@hangul1414}%
\uc@dclc{53080}{cjkhangul}{\u@cjk@hangul1415}%
\uc@dclc{53084}{cjkhangul}{\u@cjk@hangul1416}%
\uc@dclc{53092}{cjkhangul}{\u@cjk@hangul1417}%
\uc@dclc{53093}{cjkhangul}{\u@cjk@hangul1418}%
\uc@dclc{53095}{cjkhangul}{\u@cjk@hangul1419}%
\uc@dclc{53097}{cjkhangul}{\u@cjk@hangul141A}%
\uc@dclc{53104}{cjkhangul}{\u@cjk@hangul141B}%
\uc@dclc{53105}{cjkhangul}{\u@cjk@hangul141C}%
\uc@dclc{53108}{cjkhangul}{\u@cjk@hangul141D}%
\uc@dclc{53112}{cjkhangul}{\u@cjk@hangul141E}%
\uc@dclc{53120}{cjkhangul}{\u@cjk@hangul141F}%
\uc@dclc{53125}{cjkhangul}{\u@cjk@hangul1420}%
\uc@dclc{53132}{cjkhangul}{\u@cjk@hangul1421}%
\uc@dclc{53153}{cjkhangul}{\u@cjk@hangul1422}%
\uc@dclc{53160}{cjkhangul}{\u@cjk@hangul1423}%
\uc@dclc{53168}{cjkhangul}{\u@cjk@hangul1424}%
\uc@dclc{53188}{cjkhangul}{\u@cjk@hangul1425}%
\uc@dclc{53216}{cjkhangul}{\u@cjk@hangul1426}%
\uc@dclc{53217}{cjkhangul}{\u@cjk@hangul1427}%
\uc@dclc{53220}{cjkhangul}{\u@cjk@hangul1428}%
\uc@dclc{53224}{cjkhangul}{\u@cjk@hangul1429}%
\uc@dclc{53232}{cjkhangul}{\u@cjk@hangul142A}%
\uc@dclc{53233}{cjkhangul}{\u@cjk@hangul142B}%
\uc@dclc{53235}{cjkhangul}{\u@cjk@hangul142C}%
\uc@dclc{53237}{cjkhangul}{\u@cjk@hangul142D}%
\uc@dclc{53244}{cjkhangul}{\u@cjk@hangul142E}%
%%% Local Variables: 
%%% mode: latex
%%% coding: utf-8
%%% End: 
