%%% Unicode to TeX mapping, file uni-47.def, U+2F00..U+2FFF, autogenerated by makeunidef.pl
\ifx\ProvidesFile\undefined\else
\ProvidesFile{uni-47.def}[2022/08/07 UCS: Unicode data U+2F00..U+2FFF]%
\fi
\uc@dclc{12032}{autogenerated}{\unichar{19968}}%
\uc@dclc{12033}{autogenerated}{\unichar{20008}}%
\uc@dclc{12034}{autogenerated}{\unichar{20022}}%
\uc@dclc{12035}{autogenerated}{\unichar{20031}}%
\uc@dclc{12036}{autogenerated}{\unichar{20057}}%
\uc@dclc{12037}{autogenerated}{\unichar{20101}}%
\uc@dclc{12038}{autogenerated}{\unichar{20108}}%
\uc@dclc{12039}{autogenerated}{\unichar{20128}}%
\uc@dclc{12040}{autogenerated}{\unichar{20154}}%
\uc@dclc{12041}{autogenerated}{\unichar{20799}}%
\uc@dclc{12042}{autogenerated}{\unichar{20837}}%
\uc@dclc{12043}{autogenerated}{\unichar{20843}}%
\uc@dclc{12044}{autogenerated}{\unichar{20866}}%
\uc@dclc{12045}{autogenerated}{\unichar{20886}}%
\uc@dclc{12046}{autogenerated}{\unichar{20907}}%
\uc@dclc{12047}{autogenerated}{\unichar{20960}}%
\uc@dclc{12048}{autogenerated}{\unichar{20981}}%
\uc@dclc{12049}{autogenerated}{\unichar{20992}}%
\uc@dclc{12050}{autogenerated}{\unichar{21147}}%
\uc@dclc{12051}{autogenerated}{\unichar{21241}}%
\uc@dclc{12052}{autogenerated}{\unichar{21269}}%
\uc@dclc{12053}{autogenerated}{\unichar{21274}}%
\uc@dclc{12054}{autogenerated}{\unichar{21304}}%
\uc@dclc{12055}{autogenerated}{\unichar{21313}}%
\uc@dclc{12056}{autogenerated}{\unichar{21340}}%
\uc@dclc{12057}{autogenerated}{\unichar{21353}}%
\uc@dclc{12058}{autogenerated}{\unichar{21378}}%
\uc@dclc{12059}{autogenerated}{\unichar{21430}}%
\uc@dclc{12060}{autogenerated}{\unichar{21448}}%
\uc@dclc{12061}{autogenerated}{\unichar{21475}}%
\uc@dclc{12062}{autogenerated}{\unichar{22231}}%
\uc@dclc{12063}{autogenerated}{\unichar{22303}}%
\uc@dclc{12064}{autogenerated}{\unichar{22763}}%
\uc@dclc{12065}{autogenerated}{\unichar{22786}}%
\uc@dclc{12066}{autogenerated}{\unichar{22794}}%
\uc@dclc{12067}{autogenerated}{\unichar{22805}}%
\uc@dclc{12068}{autogenerated}{\unichar{22823}}%
\uc@dclc{12069}{autogenerated}{\unichar{22899}}%
\uc@dclc{12070}{autogenerated}{\unichar{23376}}%
\uc@dclc{12071}{autogenerated}{\unichar{23424}}%
\uc@dclc{12072}{autogenerated}{\unichar{23544}}%
\uc@dclc{12073}{autogenerated}{\unichar{23567}}%
\uc@dclc{12074}{autogenerated}{\unichar{23586}}%
\uc@dclc{12075}{autogenerated}{\unichar{23608}}%
\uc@dclc{12076}{autogenerated}{\unichar{23662}}%
\uc@dclc{12077}{autogenerated}{\unichar{23665}}%
\uc@dclc{12078}{autogenerated}{\unichar{24027}}%
\uc@dclc{12079}{autogenerated}{\unichar{24037}}%
\uc@dclc{12080}{autogenerated}{\unichar{24049}}%
\uc@dclc{12081}{autogenerated}{\unichar{24062}}%
\uc@dclc{12082}{autogenerated}{\unichar{24178}}%
\uc@dclc{12083}{autogenerated}{\unichar{24186}}%
\uc@dclc{12084}{autogenerated}{\unichar{24191}}%
\uc@dclc{12085}{autogenerated}{\unichar{24308}}%
\uc@dclc{12086}{autogenerated}{\unichar{24318}}%
\uc@dclc{12087}{autogenerated}{\unichar{24331}}%
\uc@dclc{12088}{autogenerated}{\unichar{24339}}%
\uc@dclc{12089}{autogenerated}{\unichar{24400}}%
\uc@dclc{12090}{autogenerated}{\unichar{24417}}%
\uc@dclc{12091}{autogenerated}{\unichar{24435}}%
\uc@dclc{12092}{autogenerated}{\unichar{24515}}%
\uc@dclc{12093}{autogenerated}{\unichar{25096}}%
\uc@dclc{12094}{autogenerated}{\unichar{25142}}%
\uc@dclc{12095}{autogenerated}{\unichar{25163}}%
\uc@dclc{12096}{autogenerated}{\unichar{25903}}%
\uc@dclc{12097}{autogenerated}{\unichar{25908}}%
\uc@dclc{12098}{autogenerated}{\unichar{25991}}%
\uc@dclc{12099}{autogenerated}{\unichar{26007}}%
\uc@dclc{12100}{autogenerated}{\unichar{26020}}%
\uc@dclc{12101}{autogenerated}{\unichar{26041}}%
\uc@dclc{12102}{autogenerated}{\unichar{26080}}%
\uc@dclc{12103}{autogenerated}{\unichar{26085}}%
\uc@dclc{12104}{autogenerated}{\unichar{26352}}%
\uc@dclc{12105}{autogenerated}{\unichar{26376}}%
\uc@dclc{12106}{autogenerated}{\unichar{26408}}%
\uc@dclc{12107}{autogenerated}{\unichar{27424}}%
\uc@dclc{12108}{autogenerated}{\unichar{27490}}%
\uc@dclc{12109}{autogenerated}{\unichar{27513}}%
\uc@dclc{12110}{autogenerated}{\unichar{27571}}%
\uc@dclc{12111}{autogenerated}{\unichar{27595}}%
\uc@dclc{12112}{autogenerated}{\unichar{27604}}%
\uc@dclc{12113}{autogenerated}{\unichar{27611}}%
\uc@dclc{12114}{autogenerated}{\unichar{27663}}%
\uc@dclc{12115}{autogenerated}{\unichar{27668}}%
\uc@dclc{12116}{autogenerated}{\unichar{27700}}%
\uc@dclc{12117}{autogenerated}{\unichar{28779}}%
\uc@dclc{12118}{autogenerated}{\unichar{29226}}%
\uc@dclc{12119}{autogenerated}{\unichar{29238}}%
\uc@dclc{12120}{autogenerated}{\unichar{29243}}%
\uc@dclc{12121}{autogenerated}{\unichar{29247}}%
\uc@dclc{12122}{autogenerated}{\unichar{29255}}%
\uc@dclc{12123}{autogenerated}{\unichar{29273}}%
\uc@dclc{12124}{autogenerated}{\unichar{29275}}%
\uc@dclc{12125}{autogenerated}{\unichar{29356}}%
\uc@dclc{12126}{autogenerated}{\unichar{29572}}%
\uc@dclc{12127}{autogenerated}{\unichar{29577}}%
\uc@dclc{12128}{autogenerated}{\unichar{29916}}%
\uc@dclc{12129}{autogenerated}{\unichar{29926}}%
\uc@dclc{12130}{autogenerated}{\unichar{29976}}%
\uc@dclc{12131}{autogenerated}{\unichar{29983}}%
\uc@dclc{12132}{autogenerated}{\unichar{29992}}%
\uc@dclc{12133}{autogenerated}{\unichar{30000}}%
\uc@dclc{12134}{autogenerated}{\unichar{30091}}%
\uc@dclc{12135}{autogenerated}{\unichar{30098}}%
\uc@dclc{12136}{autogenerated}{\unichar{30326}}%
\uc@dclc{12137}{autogenerated}{\unichar{30333}}%
\uc@dclc{12138}{autogenerated}{\unichar{30382}}%
\uc@dclc{12139}{autogenerated}{\unichar{30399}}%
\uc@dclc{12140}{autogenerated}{\unichar{30446}}%
\uc@dclc{12141}{autogenerated}{\unichar{30683}}%
\uc@dclc{12142}{autogenerated}{\unichar{30690}}%
\uc@dclc{12143}{autogenerated}{\unichar{30707}}%
\uc@dclc{12144}{autogenerated}{\unichar{31034}}%
\uc@dclc{12145}{autogenerated}{\unichar{31160}}%
\uc@dclc{12146}{autogenerated}{\unichar{31166}}%
\uc@dclc{12147}{autogenerated}{\unichar{31348}}%
\uc@dclc{12148}{autogenerated}{\unichar{31435}}%
\uc@dclc{12149}{autogenerated}{\unichar{31481}}%
\uc@dclc{12150}{autogenerated}{\unichar{31859}}%
\uc@dclc{12151}{autogenerated}{\unichar{31992}}%
\uc@dclc{12152}{autogenerated}{\unichar{32566}}%
\uc@dclc{12153}{autogenerated}{\unichar{32593}}%
\uc@dclc{12154}{autogenerated}{\unichar{32650}}%
\uc@dclc{12155}{autogenerated}{\unichar{32701}}%
\uc@dclc{12156}{autogenerated}{\unichar{32769}}%
\uc@dclc{12157}{autogenerated}{\unichar{32780}}%
\uc@dclc{12158}{autogenerated}{\unichar{32786}}%
\uc@dclc{12159}{autogenerated}{\unichar{32819}}%
\uc@dclc{12160}{autogenerated}{\unichar{32895}}%
\uc@dclc{12161}{autogenerated}{\unichar{32905}}%
\uc@dclc{12162}{autogenerated}{\unichar{33251}}%
\uc@dclc{12163}{autogenerated}{\unichar{33258}}%
\uc@dclc{12164}{autogenerated}{\unichar{33267}}%
\uc@dclc{12165}{autogenerated}{\unichar{33276}}%
\uc@dclc{12166}{autogenerated}{\unichar{33292}}%
\uc@dclc{12167}{autogenerated}{\unichar{33307}}%
\uc@dclc{12168}{autogenerated}{\unichar{33311}}%
\uc@dclc{12169}{autogenerated}{\unichar{33390}}%
\uc@dclc{12170}{autogenerated}{\unichar{33394}}%
\uc@dclc{12171}{autogenerated}{\unichar{33400}}%
\uc@dclc{12172}{autogenerated}{\unichar{34381}}%
\uc@dclc{12173}{autogenerated}{\unichar{34411}}%
\uc@dclc{12174}{autogenerated}{\unichar{34880}}%
\uc@dclc{12175}{autogenerated}{\unichar{34892}}%
\uc@dclc{12176}{autogenerated}{\unichar{34915}}%
\uc@dclc{12177}{autogenerated}{\unichar{35198}}%
\uc@dclc{12178}{autogenerated}{\unichar{35211}}%
\uc@dclc{12179}{autogenerated}{\unichar{35282}}%
\uc@dclc{12180}{autogenerated}{\unichar{35328}}%
\uc@dclc{12181}{autogenerated}{\unichar{35895}}%
\uc@dclc{12182}{autogenerated}{\unichar{35910}}%
\uc@dclc{12183}{autogenerated}{\unichar{35925}}%
\uc@dclc{12184}{autogenerated}{\unichar{35960}}%
\uc@dclc{12185}{autogenerated}{\unichar{35997}}%
\uc@dclc{12186}{autogenerated}{\unichar{36196}}%
\uc@dclc{12187}{autogenerated}{\unichar{36208}}%
\uc@dclc{12188}{autogenerated}{\unichar{36275}}%
\uc@dclc{12189}{autogenerated}{\unichar{36523}}%
\uc@dclc{12190}{autogenerated}{\unichar{36554}}%
\uc@dclc{12191}{autogenerated}{\unichar{36763}}%
\uc@dclc{12192}{autogenerated}{\unichar{36784}}%
\uc@dclc{12194}{autogenerated}{\unichar{37009}}%
\uc@dclc{12195}{autogenerated}{\unichar{37193}}%
\uc@dclc{12196}{autogenerated}{\unichar{37318}}%
\uc@dclc{12197}{autogenerated}{\unichar{37324}}%
\uc@dclc{12198}{autogenerated}{\unichar{37329}}%
\uc@dclc{12199}{autogenerated}{\unichar{38263}}%
\uc@dclc{12200}{autogenerated}{\unichar{38272}}%
\uc@dclc{12201}{autogenerated}{\unichar{38428}}%
\uc@dclc{12202}{autogenerated}{\unichar{38582}}%
\uc@dclc{12203}{autogenerated}{\unichar{38585}}%
\uc@dclc{12204}{autogenerated}{\unichar{38632}}%
\uc@dclc{12206}{autogenerated}{\unichar{38750}}%
\uc@dclc{12207}{autogenerated}{\unichar{38754}}%
\uc@dclc{12208}{autogenerated}{\unichar{38761}}%
\uc@dclc{12209}{autogenerated}{\unichar{38859}}%
\uc@dclc{12210}{autogenerated}{\unichar{38893}}%
\uc@dclc{12211}{autogenerated}{\unichar{38899}}%
\uc@dclc{12212}{autogenerated}{\unichar{38913}}%
\uc@dclc{12213}{autogenerated}{\unichar{39080}}%
\uc@dclc{12214}{autogenerated}{\unichar{39131}}%
\uc@dclc{12215}{autogenerated}{\unichar{39135}}%
\uc@dclc{12216}{autogenerated}{\unichar{39318}}%
\uc@dclc{12217}{autogenerated}{\unichar{39321}}%
\uc@dclc{12218}{autogenerated}{\unichar{39340}}%
\uc@dclc{12219}{autogenerated}{\unichar{39592}}%
\uc@dclc{12220}{autogenerated}{\unichar{39640}}%
\uc@dclc{12221}{autogenerated}{\unichar{39647}}%
\uc@dclc{12222}{autogenerated}{\unichar{39717}}%
\uc@dclc{12223}{autogenerated}{\unichar{39727}}%
\uc@dclc{12224}{autogenerated}{\unichar{39730}}%
\uc@dclc{12225}{autogenerated}{\unichar{39740}}%
\uc@dclc{12226}{autogenerated}{\unichar{39770}}%
\uc@dclc{12227}{autogenerated}{\unichar{40165}}%
\uc@dclc{12228}{autogenerated}{\unichar{40565}}%
\uc@dclc{12229}{autogenerated}{\unichar{40575}}%
\uc@dclc{12230}{autogenerated}{\unichar{40613}}%
\uc@dclc{12231}{autogenerated}{\unichar{40635}}%
\uc@dclc{12232}{autogenerated}{\unichar{40643}}%
\uc@dclc{12233}{autogenerated}{\unichar{40653}}%
\uc@dclc{12234}{autogenerated}{\unichar{40657}}%
\uc@dclc{12235}{autogenerated}{\unichar{40697}}%
\uc@dclc{12236}{autogenerated}{\unichar{40701}}%
\uc@dclc{12237}{autogenerated}{\unichar{40718}}%
\uc@dclc{12238}{autogenerated}{\unichar{40723}}%
\uc@dclc{12239}{autogenerated}{\unichar{40736}}%
\uc@dclc{12240}{autogenerated}{\unichar{40763}}%
\uc@dclc{12241}{autogenerated}{\unichar{40778}}%
\uc@dclc{12242}{autogenerated}{\unichar{40786}}%
\uc@dclc{12243}{autogenerated}{\unichar{40845}}%
\uc@dclc{12244}{autogenerated}{\unichar{40860}}%
\uc@dclc{12245}{autogenerated}{\unichar{40864}}%
%%% Local Variables: 
%%% mode: latex
%%% coding: utf-8
%%% End: 
