%%% Unicode to TeX mapping, file uni-248.def, U+F800..U+F8FF, autogenerated by makeunidef.pl
\ifx\ProvidesFile\undefined\else
\ProvidesFile{uni-248.def}[2022/08/07 UCS: Unicode data U+F800..U+F8FF]%
\fi
\uc@dclc{63696}{privatecsur}{\klingona}%
\uc@dclc{63697}{privatecsur}{\klingonb}%
\uc@dclc{63698}{privatecsur}{\klingonch}%
\uc@dclc{63699}{privatecsur}{\klingonD}%
\uc@dclc{63700}{privatecsur}{\klingone}%
\uc@dclc{63701}{privatecsur}{\klingongh}%
\uc@dclc{63702}{privatecsur}{\klingonH}%
\uc@dclc{63703}{privatecsur}{\klingonI}%
\uc@dclc{63704}{privatecsur}{\klingonj}%
\uc@dclc{63705}{privatecsur}{\klingonl}%
\uc@dclc{63706}{privatecsur}{\klingonm}%
\uc@dclc{63707}{privatecsur}{\klingonn}%
\uc@dclc{63708}{privatecsur}{\klingonng}%
\uc@dclc{63709}{privatecsur}{\klingono}%
\uc@dclc{63710}{privatecsur}{\klingonp}%
\uc@dclc{63711}{privatecsur}{\klingonq}%
\uc@dclc{63712}{privatecsur}{\klingonQ}%
\uc@dclc{63713}{privatecsur}{\klingonr}%
\uc@dclc{63714}{privatecsur}{\klingonS}%
\uc@dclc{63715}{privatecsur}{\klingont}%
\uc@dclc{63716}{privatecsur}{\klingontlh}%
\uc@dclc{63717}{privatecsur}{\klingonu}%
\uc@dclc{63718}{privatecsur}{\klingonv}%
\uc@dclc{63719}{privatecsur}{\klingonw}%
\uc@dclc{63720}{privatecsur}{\klingony}%
\uc@dclc{63721}{privatecsur}{\klingonglotstop}%
\uc@dclc{63728}{privatecsur}{\klingonzero}%
\uc@dclc{63729}{privatecsur}{\klingonone}%
\uc@dclc{63730}{privatecsur}{\klingontwo}%
\uc@dclc{63731}{privatecsur}{\klingonthree}%
\uc@dclc{63732}{privatecsur}{\klingonfour}%
\uc@dclc{63733}{privatecsur}{\klingonfive}%
\uc@dclc{63734}{privatecsur}{\klingonsix}%
\uc@dclc{63735}{privatecsur}{\klingonseven}%
\uc@dclc{63736}{privatecsur}{\klingoneight}%
\uc@dclc{63737}{privatecsur}{\klingonnine}%
%%% Local Variables: 
%%% mode: latex
%%% coding: utf-8
%%% End: 
