%%% Unicode to TeX mapping, file uni-166.def, U+A600..U+A6FF, autogenerated by makeunidef.pl
\ifx\ProvidesFile\undefined\else
\ProvidesFile{uni-166.def}[2022/08/07 UCS: Unicode data U+A600..U+A6FF]%
\fi
\uc@dclc{42652}{autogenerated}{\unicodesuper{\unichar{1098}}}%
\uc@dclc{42653}{autogenerated}{\unicodesuper{\unichar{1100}}}%
%%% Local Variables: 
%%% mode: latex
%%% coding: utf-8
%%% End: 
