
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%                                                                      %%%%%
%%%%%   Default parameter settings for the  LaTeX  ``TeXshade''  package   %%%%%
%%%%%                                                                      %%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%                                                                      %%%%%
%%%%%   This example file contains all standard settings of the TeXshade   %%%%%
%%%%%   package. It can be used as a template for the creation of perso-   %%%%%
%%%%%   nal parameter files.  All TeXshade user commands are allowed and   %%%%%
%%%%%   functional when specified here.                                    %%%%%
%%%%%                                                                      %%%%%
%%%%%   To activate these settings for your alignment load  this file by   %%%%%
%%%%%   naming it as optional parameter at the beginning of the texshade   %%%%%
%%%%%   environment, e.g.                                                  %%%%%
%%%%%                                                                      %%%%%
%%%%%          \begin{texshade}[myparameterfile]{alignmentfile}            %%%%%
%%%%%             .                                                        %%%%%
%%%%%             .                                                        %%%%%
%%%%%          \end{texshade}                                              %%%%%
%%%%%                                                                      %%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\shadingmode{identical}             %  Shade identical residues only
\shadingcolors{blues}               %  Select the blue color scheme for shading
\constoallseqs                      %  Calculate consensus considering all seqs
\threshold{50}                      %  Consensus threshold percentage is 50
\residuesperline{999}               %  As many residues as possible per line
\numberingwidth{9999}               %  Assign space for 4 digit numbering
\charstretch{1}                     %  Do not stretch character width
\linestretch{1}                     %  Do not stretch lines vertically
\gapchar{.}                         %  . is printed in sequence gaps
\gaprule{0.3pt}                     %  If a rule is printed in gaps use 0.3 pt
\gapcolors{Black}{White}            %  Gap symbols appear `Black on White'
\domaingaprule{1pt}                 %  If a rule is set between domains use 1 pt
\domaingapcolors{Red}{White}        %  Domain separation line appears `Red on White'
\numberingcolor{Black}              %  Numbering color is `Black'
\shownumbering{right}               %  Show sequence numbering on the left
\namescolor{Black}                  %  Names' color is `Black'
\featurenamescolor{Black}           %  Feature names' color is `Black'
\featurestylenamescolor{Black}      %  Feature names' color is `Black'
\shownames{left}                    %  Show sequence names on the right
\consensuscolors{Black}{White}      %  All consensus symbols/letters
                {Black}{White}      %  appear `Black on White'
                {Black}{White}      %
\showconsensus{bottom}              %  Show consensus line at bottom with
\hidesequencelogo                   %  Do not show a sequence logo as consensus
\showlogoscale{leftright}           %  Show vertical scale bar if logo is on
\logostretch{1}                     %  Do not stretch sequence logo vertically
\hidesubfamilylogo                  %  Do not show a subfamily logo
\subfamilythreshold{50}             %  Set subfamily threshold to 50%
\shownegatives                      %  Show negative values in subfamily logo
\showrelevance[Black]{*}            %  Label relevant subfamily deviations
\defconsensus{{}}{*}{!}             %  Blank =no match; * =match; ! =all match
\showleadinggaps                    %  Show gap symbols before sequence start
\rulercolor{Black}                  %  Ruler's color is `Black'
\hideruler                          %  Do not show the ruler
\rulersteps{10}                     %  Ruler ticks every 10 residues
\legendcolor{Black}                 %  Legend text color is `Black'
\hidelegend                         %  Do not show the legend
\alignment{center}                  %  Center alignment on page
\medsepline                         %  Medium height if separation line is on
\medblockskip                       %  Medium skip between sequence blocks
\flexblockspace                     %  Use optimized space between blocks
\featurerule{0.5ex}                 %  Set feature rule thickness to 1/2 ex
\bargraphstretch{1}                 %  Do not stretch bars in feature graphs
\colorscalestretch{1}               %  Do not stretch color scales in features
\backtranstext{horizontal}          %  Horizontal triplets in feature texts
\backtranslabel{alternating}        %  Alternating triplets in feature styles
\setfamily{residues}{tt}            %  Use typewriter family for residues
\setseries{residues}{md}            %  Use normal series for residues
\setshape {residues}{up}            %  Use upright shape for residues
\setsize  {residues}{normalsize}    %  Use normal size for residues
\setfamily{numbering}{tt}           %  Use typewriter family for numbering
\setseries{numbering}{md}           %  Use normal series for numbering
\setshape {numbering}{up}           %  Use upright shape for numbering
\setsize  {numbering}{normalsize}   %  Use normal size for numbering
\setfamily{names}{tt}               %  Use typewriter family for names
\setseries{names}{md}               %  Use normal series for names
\setshape {names}{up}               %  Use upright shape for names
\setsize  {names}{normalsize}       %  Use normal size for names
\setfamily{featurenames}{tt}        %  Use typewriter family for feature names
\setseries{featurenames}{md}        %  Use normal series for feature names
\setshape {featurenames}{up}        %  Use upright shape for feature names
\setsize  {featurenames}{normalsize}%  Use normal size for feature  names
\setfamily{featurestylenames}{tt}   %  Use typewriter family for feature style names
\setseries{featurestylenames}{md}   %  Use normal series for feature style names
\setshape {featurestylenames}{up}   %  Use upright shape for feature style names
\setsize  {featurestylenames}{normalsize}%  Use normal size for feature style names
\setfamily{features}{rm}            %  Use roman family for feature texts
\setseries{features}{md}            %  Use normal series for feature texts
\setshape {features}{it}            %  Use italics shape for feature texts
\setsize  {features}{normalsize}    %  Use normal size for feature texts
\setfamily{featurestyles}{tt}       %  Use typewriter family for feature styles
\setseries{featurestyles}{md}       %  Use normal series for feature styles
\setshape {featurestyles}{up}       %  Use upright shape for feature styles
\setsize {featurestyles}{normalsize}%  Use normal size for feature styles
\setfamily{legend}{tt}              %  Use typewriter family for legend texts
\setseries{legend}{md}              %  Use normal series for legend texts
\setshape {legend}{up}              %  Use upright shape for legend texts
\setsize  {legend}{normalsize}      %  Use normal size for legend texts
\setfamily{ruler}{sf}               %  Use sans serif font for ruler numbers
\tintdefault{medium}                %  Use medium tint intensity
\emphdefault{it}                    %  Use italics to emphasize regions
\showonPHDsec{alpha,beta}           %  Show helices and strands (PHD input)
\showonPHDtopo{internal,external,TM}%  Show int., ext. and TM's (PHD input)
\showonHMMTOP{TM}                   %  Show TM's (not int/ext on HMMTOP input)
\showonSTRIDE{alpha,3-10,pi,beta}   %  Show helices and strands (STRIDE input)
\showonDSSP{alpha,3-10,pi,beta}     %  Show helices and strands (DSSP input)
\secondcolumnDSSP                   %  Use numbering from 2. column in DSSP
\appearance{PHDtopo}{internal}      % \
           {bottom}{'-'}            %  \
           {int.\ \Alphacount}      %   |
\appearance{PHDtopo}{external}      %   |
           {top}{,-,}               %   |
           {ext.\ \Alphacount}      %   |
\appearance{PHDtopo}{TM}{top}       %   |
     {box[LightGray]:TM\numcount}{} %   |
\appearance{HMMTOP}{internal}       %   |
           {bottom}{'-'}            %   |
           {int.\ \Alphacount}      %   |
\appearance{HMMTOP}{external}       %   |
           {top}{,-,}               %   |
           {ext.\ \Alphacount}      %   |
\appearance{HMMTOP}{TM}{top}        %   |
           {helix}{TM\numcount}     %   |
\appearance{PHDsec}{alpha}{top}     %   |
          {box:$\alpha$\numcount}{} %   |
\appearance{PHDsec}{beta}{top}      %   |
          {-->}{$\beta$\numcount}   %   |
\appearance{STRIDE}{alpha}{top}     %   |
          {box:$\alpha$\numcount}{} %   |    Definitions for the appearance of
\appearance{STRIDE}{3-10}{top}      %    \
           {fill:$\circ$}{3$_{10}$} %     >  secondary structures included from|
\appearance{STRIDE}{pi}             %    /
           {top}{---}{$\pi$}        %   |    PHD-, STRIDE-, or DSSP-files.
\appearance{STRIDE}{beta}{top}      %   |
          {-->}{$\beta$\numcount}   %   |
\appearance{STRIDE}{bridge}         %   |
           {top}{fill:$\uparrow$}{} %   |
\appearance{STRIDE}{turn}           %   |
           {top}{,-,}{turn}         %   |
\appearance{DSSP}{alpha}{top}       %   |
          {box:$\alpha$\numcount}{} %   |
\appearance{DSSP}{3-10}{top}        %   |
           {fill:$\circ$}{3$_{10}$} %   |
\appearance{DSSP}{pi}               %   |
           {top}{---}{$\pi$}        %   |
\appearance{DSSP}{beta}{top}        %   |
          {-->}{$\beta$\numcount}   %   |
\appearance{DSSP}{bridge}           %   |
           {top}{fill:$\uparrow$}{} %   |
\appearance{DSSP}{turn}             %   |
           {top}{,-,}{turn}         %   |
\appearance{DSSP}{bend}{top}        %  /
           {fill:$\diamond$}{}      % /

\pepgroups{FYW,ILVM,RK,DE,GA,ST,NQ} %  Amino acid grouping due to similarity

\pepsims{F}{YW}                     %  Y and W are similar to F
\pepsims{Y}{WF}                     %  W and F are similar to Y
\pepsims{W}{YF}                     %  Y and F are similar to W

\pepsims{I}{LVM}                    %  L, V and M are similar to I
\pepsims{L}{VMI}                    %  V, M and I are similar to L
\pepsims{V}{MIL}                    %  M, I and L are similar to V

\pepsims{R}{KH}                     %  K and H are similar to R
\pepsims{K}{HR}                     %  H and R are similar to K
\pepsims{H}{RK}                     %  R and K are similar to H

\pepsims{A}{GS}                     %  G and S are similar to A
\pepsims{G}{A}                      %  A (but not S) is similar to G

\pepsims{S}{TA}                     %  T and A are similar to S
\pepsims{T}{S}                      %  S (but not A) is similar to T

\pepsims{D}{EN}                     %  E and N (but not Q) are similar to D
\pepsims{E}{DQ}                     %  D and Q (but not N) are similar to E
\pepsims{N}{QD}                     %  Q and D (but not E) are similar to N
\pepsims{Q}{NE}                     %  N and E (but not D) are similar to Q

\DNAgroups{GAR,CTY}                 %  Nucleotide grouping due to similarity

\DNAsims{A}{GR}                     %  G and R are similar to A
\DNAsims{G}{AR}                     %  A and R are similar to G
\DNAsims{R}{AG}                     %  A and G are similar to R

\DNAsims{C}{TY}                     %  T and Y are similar to C
\DNAsims{T}{CY}                     %  C and Y are similar to T
\DNAsims{Y}{CT}                     %  C and T are similar to Y
