% from Gerhard A. Bachmaier (gerhard.bachmaier@meduni-graz.at)
%
% triangle shapes in four orientaions:
% triangleup, triangledown, triangleright, triangleleft.
%  version June 21th, 2006

\def\triangleupshape{%
{0}%
{0}b{0}\\%
{8.66}t{-5}{10}\\%
{17.32}t{-10}{20}\\%
{17.32}e{0}%
}
\def\triangleuppar#1{\Shapepar\triangleupshape $\bigtriangleup$ \ignorespaces #1\par}

\def\triangledownshape{%
{0}%
{0}b{0}\\%
{0}t{-10}{20}\\%
{8.66}t{-5}{10}\\%
{17.32}e{0}%
}
\def\triangledownpar#1{\Shapepar\triangledownshape #1\unskip\ $\bigtriangledown$\par}

\def\triangleleftshape{%
{0}%
{0}b{8.66}\\%
{0}t{8.66}{0}\\%
{10}t{-8.66}{17.32}\\%
{20}t{8.66}{0}\\%
{20}e{8.66}%
}
\def\triangleleftpar#1{\Shapepar\triangleleftshape 
  $\triangleleft$ \ignorespaces #1\unskip\ $\triangleleft$\par}

\def\trianglerightshape{%
{0}%
{0}b{-8.66}\\%
{0}t{-8.66}{0}\\%
{10}t{-8.66}{17.32}\\%
{20}t{-8.66}{0}\\%
{20}e{-8.66}%
}
\def\trianglerightpar#1{\Shapepar\trianglerightshape 
   $\triangleright$ \ignorespaces #1\unskip\ $\triangleright$\par}
