%%% Unicode to TeX mapping, file uni-46.def, U+2E00..U+2EFF, autogenerated by makeunidef.pl
\ifx\ProvidesFile\undefined\else
\ProvidesFile{uni-46.def}[2022/08/07 UCS: Unicode data U+2E00..U+2EFF]%
\fi
\uc@dclc{11935}{autogenerated}{\unichar{27597}}%
\uc@dclc{12019}{autogenerated}{\unichar{40863}}%
%%% Local Variables: 
%%% mode: latex
%%% coding: utf-8
%%% End: 
