%!TEX encoding = UTF-8 Unicode
%
% Translation completed on 01/03/2020
\ProvidesFile{ecvmt-utf8.def}[europecv Maltese definitions]
\inputencoding{utf8x}
% Personal information
\def\ecv@infosectionkey{\ecv@utf{Tagħrif personali}}
def\ecv@datekey{\ecv@utf{Aġġornat għal}}
\def\ecv@namekey{\ecv@utf{Isem (Ismijiet)~/ Kunjom(ijiet)}}
\def\ecv@addresskey{\ecv@utf{L-indirizz}}
\def\ecv@faxkey{\ecv@utf{Fax}}
\def\ecv@telkey{\ecv@utf{In-numru tat-telefown}}
\def\ecv@mobilekey{\ecv@utf{Mobile}}
\def\ecv@officekey{\ecv@utf{In-numru tal-faks}}
\def\ecv@emailkey{\ecv@utf{Email}}
\def\ecv@professionalkey{\ecv@utf{Email Professjonali}}
\def\ecv@skypekey{\ecv@utf{Skype}}
\def\ecv@matrixriotkey{\ecv@utf{Matrix/Riot}}
\def\ecv@youtubekey{\ecv@utf{YouTube}}
\def\ecv@peckey{\ecv@utf{PEC}}
\def\ecv@homepagekey{\ecv@utf{Home page}}
\def\ecv@nationalitykey{\ecv@utf{Nazzjonalita' / Nazzjonalitajiet}}
\def\ecv@birthkey{\ecv@utf{Data tat-twelid}}
\def\ecv@genderkey{\ecv@utf{Sess}}
% Footer
\def\ecv@pagekey{\ecv@utf{Paġna}}
\def\ecv@cvofkey{\ecv@utf{Curriculum vit\ae\ ta'}}
% Language table
\def\ecv@mothertonguekey{\ecv@utf{Ilsien~/ ilsna nattiv/i}}
\def\ecv@assesskey{\ecv@utf{Awto-assessjar}}
\def\ecv@levelkey{\ecv@utf{Livell Ewropew}}
\def\ecv@understandkey{\ecv@utf{Fehim tal-lingwa}}
\def\ecv@speakkey{\ecv@utf{Taħdit mitkellma}}
\def\ecv@writekey{\ecv@utf{Lingwa miktuba}}
\def\ecv@listenkey{\ecv@utf{Smigħ}}
\def\ecv@readkey{\ecv@utf{Qari}}
\def\ecv@interactkey{\ecv@utf{Komunikazzjoni Verbali}}
\def\ecv@productkey{\ecv@utf{Ħila fil-komunikkazzjoni}}
\def\ecv@langfooterkey{\ecv@utf{Qafas Ewropew ta’ Referenza Komuni għall-lingwi}}
\def\ecv@cefbasickey{\ecv@utf{Livell elementari}}
\def\ecv@cefindepkey{\ecv@utf{Livell intermedju}}
\def\ecv@cefprofkey{\ecv@utf{Livell avvanzat}}
