%%% Unicode to TeX mapping, file uni-0.def, U+0000..U+00FF, autogenerated by makeunidef.pl
\ifx\ProvidesFile\undefined\else
\ProvidesFile{uni-0.def}[2022/08/07 UCS: Unicode data U+0000..U+00FF]%
\fi
\uc@dclc{32}{default}{\space}%
\gdef\uc@controlbox#1{{\fboxsep=1pt\fbox{\tabcolsep=0pt\ttfamily\tiny\begin{tabular}{c}#1\end{tabular}}}}%
\uc@dclc{32}{ctrlglyphs}{\uc@controlbox{SP}}%
\uc@dclc{33}{default}{\textascii!}%
\uc@dclc{34}{default}{\textquotedbl}%
\uc@dclc{35}{default}{\textascii\#}%
\uc@dclc{36}{default}{\textascii$}%
\uc@dclc{37}{default}{\textascii\%}%
\uc@dclc{38}{default}{\textascii\&}%
\uc@dclc{39}{default}{\textquoteright}%
\uc@dclc{40}{default}{\textascii(}%
\uc@dclc{41}{default}{\textascii)}%
\uc@dclc{42}{default}{\textascii*}%
\uc@dclc{43}{default}{\textascii+}%
\uc@dclc{44}{default}{\textascii,}%
\uc@dclc{45}{default}{\textascii-}%
\uc@dclc{46}{default}{\textascii.}%
\uc@dclc{47}{default}{\textascii/}%
\uc@dclc{48}{default}{\textascii0}%
\uc@dclc{49}{default}{\textascii1}%
\uc@dclc{50}{default}{\textascii2}%
\uc@dclc{51}{default}{\textascii3}%
\uc@dclc{52}{default}{\textascii4}%
\uc@dclc{53}{default}{\textascii5}%
\uc@dclc{54}{default}{\textascii6}%
\uc@dclc{55}{default}{\textascii7}%
\uc@dclc{56}{default}{\textascii8}%
\uc@dclc{57}{default}{\textascii9}%
\uc@dclc{58}{default}{\textascii:}%
\uc@dclc{59}{default}{\textascii;}%
\uc@dclc{60}{default}{\textless}%
\uc@dclc{61}{default}{\textascii=}%
\uc@dclc{62}{default}{\textgreater}%
\uc@dclc{63}{default}{\textascii?}%
\uc@dclc{64}{default}{\textascii @}%
\uc@dclc{65}{default}{\textascii A}%
\uc@dclc{66}{default}{\textascii B}%
\uc@dclc{67}{default}{\textascii C}%
\uc@dclc{68}{default}{\textascii D}%
\uc@dclc{69}{default}{\textascii E}%
\uc@dclc{70}{default}{\textascii F}%
\uc@dclc{71}{default}{\textascii G}%
\uc@dclc{72}{default}{\textascii H}%
\uc@dclc{73}{default}{\textascii I}%
\uc@dclc{74}{default}{\textascii J}%
\uc@dclc{75}{default}{\textascii K}%
\uc@dclc{76}{default}{\textascii L}%
\uc@dclc{77}{default}{\textascii M}%
\uc@dclc{78}{default}{\textascii N}%
\uc@dclc{79}{default}{\textascii O}%
\uc@dclc{80}{default}{\textascii P}%
\uc@dclc{81}{default}{\textascii Q}%
\uc@dclc{82}{default}{\textascii R}%
\uc@dclc{83}{default}{\textascii S}%
\uc@dclc{84}{default}{\textascii T}%
\uc@dclc{85}{default}{\textascii U}%
\uc@dclc{86}{default}{\textascii V}%
\uc@dclc{87}{default}{\textascii W}%
\uc@dclc{88}{default}{\textascii X}%
\uc@dclc{89}{default}{\textascii Y}%
\uc@dclc{90}{default}{\textascii Z}%
\uc@dclc{91}{default}{\textascii[}%
\uc@dclc{92}{default}{\textbackslash}%
\uc@dclc{93}{default}{\textascii]}%
\uc@dclc{94}{default}{\textasciicircum}%
\uc@dclc{95}{default}{\textunderscore}%
\uc@dclc{96}{default}{\textascii`}%
\uc@dclc{97}{default}{\textascii a}%
\uc@dclc{98}{default}{\textascii b}%
\uc@dclc{99}{default}{\textascii c}%
\uc@dclc{100}{default}{\textascii d}%
\uc@dclc{101}{default}{\textascii e}%
\uc@dclc{102}{default}{\textascii f}%
\uc@dclc{103}{default}{\textascii g}%
\uc@dclc{103}{tipa}{\textg}%
\uc@dclc{104}{default}{\textascii h}%
\uc@dclc{105}{default}{\textascii i}%
\uc@dclc{106}{default}{\textascii j}%
\uc@dclc{107}{default}{\textascii k}%
\uc@dclc{108}{default}{\textascii l}%
\uc@dclc{109}{default}{\textascii m}%
\uc@dclc{110}{default}{\textascii n}%
\uc@dclc{111}{default}{\textascii o}%
\uc@dclc{112}{default}{\textascii p}%
\uc@dclc{113}{default}{\textascii q}%
\uc@dclc{114}{default}{\textascii r}%
\uc@dclc{115}{default}{\textascii s}%
\uc@dclc{116}{default}{\textascii t}%
\uc@dclc{117}{default}{\textascii u}%
\uc@dclc{118}{default}{\textascii v}%
\uc@dclc{119}{default}{\textascii w}%
\uc@dclc{120}{default}{\textascii x}%
\uc@dclc{121}{default}{\textascii y}%
\uc@dclc{122}{default}{\textascii z}%
\uc@dclc{123}{default}{\textbraceleft}%
\uc@dclc{124}{default}{\textbar}%
\uc@dclc{125}{default}{\textbraceright}%
\uc@dclc{126}{default}{\textasciitilde}%
\uc@dclc{160}{default}{\nobreakspace}%
\uc@dclc{161}{default}{\textexclamdown}%
\uc@dclc{162}{default}{\textcent}%
\uc@dclc{163}{default}{\pounds}%
\uc@dclc{164}{default}{\textcurrency}%
\uc@dclc{165}{default}{\textyen}%
\uc@dclc{166}{default}{\textbrokenbar}%
\uc@dclc{167}{default}{\S}%
\uc@dclc{168}{default}{\"{\empty}}%
\uc@dclc{169}{default}{\copyright}%
\uc@dclc{169}{postscript}{\Pisymbol{psy}{"D3}}%
\uc@dclc{170}{default}{\textordfeminine}%
\uc@dclc{171}{default}{\guillemotleft}%
\uc@dclc{172}{default}{\ensuremath{\lnot}}%
\uc@dclc{172}{postscript}{\Pisymbol{psy}{"D8}}%
\uc@dclc{173}{default}{\-}%
\uc@dclc{174}{default}{\textregistered}%
\uc@dclc{174}{postscript}{\Pisymbol{psy}{"D2}}%
\uc@dclc{175}{default}{\@tabacckludge={\empty}}%
\uc@dclc{176}{default}{\textdegree}%
\uc@dclc{177}{default}{\ensuremath{\pm}}%
\uc@dclc{178}{mathletters}{\ensuremath{^2}}%
\uc@dclc{178}{default}{\textsuperscript2}%
\uc@dclc{179}{mathletters}{\ensuremath{^3}}%
\uc@dclc{179}{default}{\textsuperscript3}%
\uc@dclc{180}{default}{\@tabacckludge'{\empty}}%
\uc@dclc{181}{default}{\ensuremath{\mu}}%
\uc@dclc{182}{default}{\P}%
\uc@dclc{183}{default}{\textperiodcentered}%
\uc@dclc{184}{default}{\c\space}%
\uc@dclc{185}{mathletters}{\ensuremath{^1}}%
\uc@dclc{185}{default}{\textsuperscript1}%
\uc@dclc{186}{default}{\textordmasculine}%
\uc@dclc{187}{default}{\guillemotright}%
\uc@dclc{188}{default}{\textonequarter}%
\uc@dclc{189}{default}{\textonehalf}%
\uc@dclc{190}{default}{\textthreequarters}%
\uc@dclc{191}{default}{\textquestiondown}%
\uc@dclc{192}{default}{\@tabacckludge`A}%
\uc@dclc{193}{default}{\@tabacckludge'A}%
\uc@dclc{194}{default}{\^A}%
\uc@dclc{195}{default}{\~A}%
\uc@dclc{196}{default}{\"A}%
\uc@dclc{197}{default}{\r A}%
\uc@dclc{198}{default}{\AE}%
\uc@dclc{199}{default}{\c C}%
\uc@dclc{200}{default}{\@tabacckludge`E}%
\uc@dclc{201}{default}{\@tabacckludge'E}%
\uc@dclc{202}{default}{\^E}%
\uc@dclc{203}{default}{\"E}%
\uc@dclc{204}{default}{\@tabacckludge`I}%
\uc@dclc{205}{default}{\@tabacckludge'I}%
\uc@dclc{206}{default}{\^I}%
\uc@dclc{207}{default}{\"I}%
\uc@dclc{208}{default}{\DH}%
\uc@dclc{209}{default}{\~N}%
\uc@dclc{210}{default}{\@tabacckludge`O}%
\uc@dclc{211}{default}{\@tabacckludge'O}%
\uc@dclc{212}{default}{\^O}%
\uc@dclc{213}{default}{\~O}%
\uc@dclc{214}{default}{\"O}%
\uc@dclc{215}{default}{\ensuremath{\times}}%
\uc@dclc{215}{postscript}{\Pisymbol{psy}{"B4}}%
\uc@dclc{216}{default}{\O}%
\uc@dclc{217}{default}{\@tabacckludge`U}%
\uc@dclc{218}{default}{\@tabacckludge'U}%
\uc@dclc{219}{default}{\^U}%
\uc@dclc{220}{default}{\"U}%
\uc@dclc{221}{default}{\@tabacckludge'Y}%
\uc@dclc{222}{default}{\TH}%
\uc@dclc{223}{default}{\ss}%
\uc@dclc{224}{default}{\@tabacckludge`a}%
\uc@dclc{225}{default}{\@tabacckludge'a}%
\uc@dclc{226}{default}{\^a}%
\uc@dclc{227}{default}{\~a}%
\uc@dclc{228}{default}{\"a}%
\uc@dclc{229}{default}{\r a}%
\uc@dclc{230}{default}{\ae}%
\uc@dclc{231}{default}{\c c}%
\uc@dclc{232}{default}{\@tabacckludge`e}%
\uc@dclc{233}{default}{\@tabacckludge'e}%
\uc@dclc{234}{default}{\^e}%
\uc@dclc{235}{default}{\"e}%
\uc@dclc{236}{default}{\@tabacckludge`\i}%
\uc@dclc{237}{default}{\@tabacckludge'\i}%
\uc@dclc{238}{default}{\^\i}%
\uc@dclc{239}{default}{\"\i}%
\uc@dclc{240}{default}{\dh}%
\uc@dclc{241}{default}{\~n}%
\uc@dclc{242}{default}{\@tabacckludge`o}%
\uc@dclc{243}{default}{\@tabacckludge'o}%
\uc@dclc{244}{default}{\^o}%
\uc@dclc{245}{default}{\~o}%
\uc@dclc{246}{default}{\"o}%
\uc@dclc{247}{default}{\ensuremath{\div}}%
\uc@dclc{247}{postscript}{\Pisymbol{psy}{"B8}}%
\uc@dclc{248}{default}{\o}%
\uc@dclc{249}{default}{\@tabacckludge`u}%
\uc@dclc{250}{default}{\@tabacckludge'u}%
\uc@dclc{251}{default}{\^u}%
\uc@dclc{252}{default}{\"u}%
\uc@dclc{253}{default}{\@tabacckludge'y}%
\uc@dclc{254}{default}{\th}%
\uc@dclc{255}{default}{\"y}%
%%% Local Variables: 
%%% mode: latex
%%% coding: utf-8
%%% End: 
