%%
%% This is file `journal.cls',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% paper.dtx  (with options: `journal')
%% 
%% Copyright (C) 1993, 1998 by wenzel_matiaske@notes.uni-paderborn.de
%% 
%% You are not allowed to distribute this file without the
%% original source paper.dtx. For distribution of the
%% sources see the copyright notice in the file paper.dtx.
%% 
\def\filename{journal}
\def\fileversion{1.0l}
\def\filedate{2008/05/30}
\def\docdate{1996/11/02}
\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{journal}[\filedate\space\fileversion\space%
       LaTeX document class (wm).]
\DeclareOption*{\PassOptionsToClass{\CurrentOption}{paper}}
\ProcessOptions
\LoadClass[journal]{paper}
\endinput
%%
%% End of file `journal.cls'.
