%%% unicode global data for ucs.sty, autogenerated by makeunidef.pl
\ifx\ProvidesFile\undefined\else
\ProvidesFile{uni-global.def}[2022/08/07 UCS: Unicode global data]%
\fi
\ifx\newenvironment\undefined\else\newenvironment{ucjk}{\ifx\toplevel@ucjk\undefined\begin{CJK}{JIS}{}\restore@utf@viii@actives\fi\bgroup\let\toplevel@ucjk1}{\egroup\ifx\toplevel@ucjk\undefined\end{CJK}\fi}\fi
\makeatletter
\ProvideTextCommandDefault\textcommabelow[1]
  {\hmode@bgroup\ooalign{\null#1\crcr\hidewidth\raise-.31ex
   \hbox{\check@mathfonts\fontsize\ssf@size\z@
   \math@fontsfalse\selectfont,}\hidewidth}\egroup}
\ifx\ProvideTextCommandDefault\undefined\else
\ProvideTextCommandDefault{\textdegree}{\ensuremath{{^\circ}}}
\ProvideTextCommandDefault{\textonehalf}{\ensuremath{\frac12}}
\ProvideTextCommandDefault{\textonequarter}{\ensuremath{\frac14}}
\ProvideTextCommandDefault{\textthreequarters}{\ensuremath{\frac34}}
\fi
\DeclareUnicodeOption{cjkgb}%
\DeclareUnicodeOption{cjkhangul}%
\DeclareUnicodeOption{dirty}%
\DeclareUnicodeOption{ctrlglyphs}%
\DeclareUnicodeOption{postscript}%
\DeclareUnicodeOption{mathletters}%
\DeclareUnicodeOption{cjkjis}%
\DeclareUnicodeOption{cjkbg5}%
\DeclareUnicodeOption{autogenerated}%
\DeclareUnicodeOption{tipa}%
\DeclareUnicodeOption{default}%
\DeclareUnicodeOption{privatecsur}%
%%% Local Variables: 
%%% mode: latex
%%% coding: utf-8
%%% End: 
