%%
%% This is file `x-mac-cyrillic.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% inputenx.dtx  (with options: `mac-cyrillic')
%% 
%% This is a generated file.
%% 
%% Project: inputenx
%% Version: 2019/11/29 v1.12
%% 
%% Copyright (C)
%%   2006-2011 Heiko Oberdiek
%%   2016-2019 Oberdiek Package Support Group
%% 
%% This work may be distributed and/or modified under the
%% conditions of the LaTeX Project Public License, either
%% version 1.3c of this license or (at your option) any later
%% version. This version of this license is in
%%    https://www.latex-project.org/lppl/lppl-1-3c.txt
%% and the latest version of this license is in
%%    https://www.latex-project.org/lppl.txt
%% and version 1.3 or later is part of all distributions of
%% LaTeX version 2005/12/01 or later.
%% 
%% This work has the LPPL maintenance status "maintained".
%% 
%% The Current Maintainers of this work are
%% Heiko Oberdiek and the Oberdiek Package Support Group
%% https://github.com/ho-tex/inputenx/issues
%% 
%% 
%% This work consists of the main source file inputenx.dtx
%% and the derived files
%%    inputenx.sty, inputenx.pdf, inputenx.ins, inputenx.drv, ix-alias.def,
%%    ix-math.def, ix-name.def, ix-slot.def, ix-uc.def,
%%    ix-utf8enc.dfu, x-ascii.def, x-verbatim.def, x-atarist.def,
%%    x-iso-8859-1.def, x-iso-8859-2.def, x-iso-8859-3.def,
%%    x-iso-8859-4.def, x-iso-8859-5.def, x-iso-8859-8.def,
%%    x-iso-8859-9.def, x-iso-8859-10.def, x-iso-8859-13.def,
%%    x-iso-8859-14.def, x-iso-8859-15.def, x-iso-8859-16.def,
%%    x-cp437.def, x-cp850.def, x-cp852.def, x-cp855.def,
%%    x-cp858.def, x-cp865.def, x-cp866.def, x-cp1250.def,
%%    x-cp1251.def, x-cp1252.def, x-cp1255.def, x-cp1257.def,
%%    x-dec-mcs.def, x-koi8-r.def, x-mac-centeuro.def,
%%    x-mac-cyrillic.def, x-mac-roman.def, x-nextstep.def,
%%    inputenx-licrcmds.txt, inputenx-utf8enc.txt.
%% 
\ProvidesFile{x-mac-cyrillic.def}%
  [2019/11/29 v1.12 Input encoding mac-cyrillic (inputenx)]%
\edef\RestoreAtCatcode{\catcode64=\the\catcode64\relax}
\makeatletter
\ProvideTextCommandDefault{\textapproxequal}{%
  \ensuremath\approx
}
\ProvideTextCommandDefault{\textdegree}{%
  \ensuremath{{^\circ}}%
}
\ProvideTextCommandDefault{\textdiv}{%
  \TextSymbolUnavailable\textdiv
}
\ProvideTextCommandDefault{\texteuro}{%
  \TextSymbolUnavailable\texteuro
}
\ProvideTextCommandDefault{\textflorin}{%
  \textit{f}%
}
\ProvideTextCommandDefault{\textgreaterequal}{%
  \ensuremath\geq
}
\ProvideTextCommandDefault{\textincrement}{%
  \ensuremath\Delta
}
\ProvideTextCommandDefault{\textinfinity}{%
  \ensuremath\infty
}
\ProvideTextCommandDefault{\textlessequal}{%
  \ensuremath\leq
}
\ProvideTextCommandDefault{\textlnot}{%
  \ensuremath\lnot
}
\ProvideTextCommandDefault{\textmu}{%
  \ensuremath\mu
}
\ProvideTextCommandDefault{\textnotequal}{%
  \ensuremath\neq
}
\ProvideTextCommandDefault{\textnumero}{%
  N%
  \bgroup
    \check@mathfonts
    \fontsize\sf@size\z@
    \math@fontsfalse
    \selectfont
    \ooalign{%
      \raise0.5ex\hbox{o}%
      \crcr
      \hline
    }%
  \egroup
}
\ProvideTextCommandDefault{\textpm}{%
  \ensuremath\pm
}
\ProvideTextCommandDefault{\textsurd}{%
  \ensuremath\surd
}
\DeclareInputText{128}{\CYRA}
\DeclareInputText{129}{\CYRB}
\DeclareInputText{130}{\CYRV}
\DeclareInputText{131}{\CYRG}
\DeclareInputText{132}{\CYRD}
\DeclareInputText{133}{\CYRE}
\DeclareInputText{134}{\CYRZH}
\DeclareInputText{135}{\CYRZ}
\DeclareInputText{136}{\CYRI}
\DeclareInputText{137}{\CYRISHRT}
\DeclareInputText{138}{\CYRK}
\DeclareInputText{139}{\CYRL}
\DeclareInputText{140}{\CYRM}
\DeclareInputText{141}{\CYRN}
\DeclareInputText{142}{\CYRO}
\DeclareInputText{143}{\CYRP}
\DeclareInputText{144}{\CYRR}
\DeclareInputText{145}{\CYRS}
\DeclareInputText{146}{\CYRT}
\DeclareInputText{147}{\CYRU}
\DeclareInputText{148}{\CYRF}
\DeclareInputText{149}{\CYRH}
\DeclareInputText{150}{\CYRC}
\DeclareInputText{151}{\CYRCH}
\DeclareInputText{152}{\CYRSH}
\DeclareInputText{153}{\CYRSHCH}
\DeclareInputText{154}{\CYRHRDSN}
\DeclareInputText{155}{\CYRERY}
\DeclareInputText{156}{\CYRSFTSN}
\DeclareInputText{157}{\CYREREV}
\DeclareInputText{158}{\CYRYU}
\DeclareInputText{159}{\CYRYA}
\DeclareInputText{160}{\textdagger}
\DeclareInputText{161}{\textdegree}
\DeclareInputText{162}{\CYRGUP}
\DeclareInputText{163}{\textsterling}
\DeclareInputText{164}{\textsection}
\DeclareInputText{165}{\textbullet}
\DeclareInputText{166}{\textparagraph}
\DeclareInputText{167}{\CYRII}
\DeclareInputText{168}{\textregistered}
\DeclareInputText{169}{\textcopyright}
\DeclareInputText{170}{\texttrademark}
\DeclareInputText{171}{\CYRDJE}
\DeclareInputText{172}{\cyrdje}
\DeclareInputText{173}{\textnotequal}
\DeclareInputText{174}{\@tabacckludge'\CYRG}
\DeclareInputText{175}{\@tabacckludge'\cyrg}
\DeclareInputText{176}{\textinfinity}
\DeclareInputText{177}{\textpm}
\DeclareInputText{178}{\textlessequal}
\DeclareInputText{179}{\textgreaterequal}
\DeclareInputText{180}{\cyrii}
\DeclareInputText{181}{\textmu}
\DeclareInputText{182}{\cyrgup}
\DeclareInputText{183}{\CYRJE}
\DeclareInputText{184}{\CYRIE}
\DeclareInputText{185}{\cyrie}
\DeclareInputText{186}{\CYRYI}
\DeclareInputText{187}{\cyryi}
\DeclareInputText{188}{\CYRLJE}
\DeclareInputText{189}{\cyrlje}
\DeclareInputText{190}{\CYRNJE}
\DeclareInputText{191}{\cyrnje}
\DeclareInputText{192}{\cyrje}
\DeclareInputText{193}{\CYRDZE}
\DeclareInputText{194}{\textlnot}
\DeclareInputText{195}{\textsurd}
\DeclareInputText{196}{\textflorin}
\DeclareInputText{197}{\textapproxequal}
\DeclareInputText{198}{\textincrement}
\DeclareInputText{199}{\guillemotleft}
\DeclareInputText{200}{\guillemotright}
\DeclareInputText{201}{\textellipsis}
\DeclareInputText{202}{\nobreakspace}
\DeclareInputText{203}{\CYRTSHE}
\DeclareInputText{204}{\cyrtshe}
\DeclareInputText{205}{\@tabacckludge'\CYRK}
\DeclareInputText{206}{\@tabacckludge'\cyrk}
\DeclareInputText{207}{\cyrdze}
\DeclareInputText{208}{\textendash}
\DeclareInputText{209}{\textemdash}
\DeclareInputText{210}{\textquotedblleft}
\DeclareInputText{211}{\textquotedblright}
\DeclareInputText{212}{\textquoteleft}
\DeclareInputText{213}{\textquoteright}
\DeclareInputText{214}{\textdiv}
\DeclareInputText{215}{\quotedblbase}
\DeclareInputText{216}{\CYRUSHRT}
\DeclareInputText{217}{\cyrushrt}
\DeclareInputText{218}{\CYRDZHE}
\DeclareInputText{219}{\cyrdzhe}
\DeclareInputText{220}{\textnumero}
\DeclareInputText{221}{\CYRYO}
\DeclareInputText{222}{\cyryo}
\DeclareInputText{223}{\cyrya}
\DeclareInputText{224}{\cyra}
\DeclareInputText{225}{\cyrb}
\DeclareInputText{226}{\cyrv}
\DeclareInputText{227}{\cyrg}
\DeclareInputText{228}{\cyrd}
\DeclareInputText{229}{\cyre}
\DeclareInputText{230}{\cyrzh}
\DeclareInputText{231}{\cyrz}
\DeclareInputText{232}{\cyri}
\DeclareInputText{233}{\cyrishrt}
\DeclareInputText{234}{\cyrk}
\DeclareInputText{235}{\cyrl}
\DeclareInputText{236}{\cyrm}
\DeclareInputText{237}{\cyrn}
\DeclareInputText{238}{\cyro}
\DeclareInputText{239}{\cyrp}
\DeclareInputText{240}{\cyrr}
\DeclareInputText{241}{\cyrs}
\DeclareInputText{242}{\cyrt}
\DeclareInputText{243}{\cyru}
\DeclareInputText{244}{\cyrf}
\DeclareInputText{245}{\cyrh}
\DeclareInputText{246}{\cyrc}
\DeclareInputText{247}{\cyrch}
\DeclareInputText{248}{\cyrsh}
\DeclareInputText{249}{\cyrshch}
\DeclareInputText{250}{\cyrhrdsn}
\DeclareInputText{251}{\cyrery}
\DeclareInputText{252}{\cyrsftsn}
\DeclareInputText{253}{\cyrerev}
\DeclareInputText{254}{\cyryu}
\DeclareInputText{255}{\texteuro}
\RestoreAtCatcode
\endinput
%%
%% End of file `x-mac-cyrillic.def'.
