%%
%% This is file `ltgenc.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% ucs.dtx  (with options: `ltgenc.def')
%% 
%% Copyright 2001 Dominique Unruh  <unruh@ut.ee>
%% Copyright 2013 Wolfgang Jeltsch <wolfgang@cs.ioc.ee>
%% Copyright 2022 David Carlisle https://github.com/LaTeX-Package-Repositories/ucs
%% 
%% This program is provided under the terms of the LaTeX Project Public License with some
%% modifications. See the file LICENSE for information.
%% 
\NeedsTeXFormat{LaTeX2e}[1998/12/01]
\ProvidesFile{ltgenc.def}[2004/10/17 Autogenerated encoding LTG]
\DeclareFontEncoding{LTG}{}{}
\DeclareFontSubstitution{LTG}{c2000}{m}{n}
\DeclareTextCommand{\texttelugustart}{LTG}{}
\DeclareTextCommand{\texttelugustop}{LTG}{}
\DeclareTextSymbol{\guillemotleft}{LTG}{19}
\DeclareTextSymbol{\guillemotright}{LTG}{20}
\DeclareTextSymbol{\guilsinglleft}{LTG}{14}
\DeclareTextSymbol{\guilsinglright}{LTG}{15}
\DeclareTextSymbol{\i}{LTG}{25}
\DeclareTextSymbol{\quotedblbase}{LTG}{18}
\DeclareTextSymbol{\quotesinglbase}{LTG}{13}
\DeclareTextSymbol{\textasciicircum}{LTG}{`\^}
\DeclareTextSymbol{\textasciitilde}{LTG}{`\~}
\DeclareTextSymbol{\textbackslash}{LTG}{`\\}
\DeclareTextSymbol{\textbar}{LTG}{`\|}
\DeclareTextSymbol{\textbraceleft}{LTG}{`\{}
\DeclareTextSymbol{\textbraceright}{LTG}{`\}}
\DeclareTextSymbol{\textdollar}{LTG}{`\$}
\DeclareTextSymbol{\textemdash}{LTG}{22}
\DeclareTextSymbol{\textendash}{LTG}{21}
\DeclareTextSymbol{\textgreater}{LTG}{`\>}
\DeclareTextSymbol{\textless}{LTG}{`\<}
\DeclareTextSymbol{\textquotedblleft}{LTG}{16}
\DeclareTextSymbol{\textquotedblright}{LTG}{17}
\DeclareTextSymbol{\textquotedbl}{LTG}{`\"}
\DeclareTextSymbol{\textquoteleft}{LTG}{`\`}
\DeclareTextSymbol{\textquoteright}{LTG}{`\'}
\DeclareTextSymbol{\textunderscore}{LTG}{95}
\DeclareTextCommand{\texttelugucandrabindu}{LTG}[1]{#1\char129 }
\DeclareTextCommand{\textteluguanusvara}{LTG}[1]{#1\char130 }
\DeclareTextCommand{\textteluguvisarga}{LTG}[1]{#1\char131 }
\DeclareTextSymbol{\texttelugua}{LTG}{133}
\DeclareTextSymbol{\textteluguaa}{LTG}{134}
\DeclareTextSymbol{\texttelugui}{LTG}{135}
\DeclareTextSymbol{\textteluguii}{LTG}{136}
\DeclareTextSymbol{\textteluguu}{LTG}{137}
\DeclareTextSymbol{\textteluguuu}{LTG}{138}
\DeclareTextSymbol{\textteluguvocalicr}{LTG}{139}
\DeclareTextSymbol{\textteluguvocalicl}{LTG}{140}
\DeclareTextSymbol{\texttelugue}{LTG}{142}
\DeclareTextSymbol{\textteluguee}{LTG}{143}
\DeclareTextSymbol{\textteluguai}{LTG}{144}
\DeclareTextSymbol{\textteluguo}{LTG}{146}
\DeclareTextSymbol{\textteluguoo}{LTG}{147}
\DeclareTextSymbol{\textteluguau}{LTG}{148}
\DeclareTextSymbol{\textteluguka}{LTG}{149}
\DeclareTextSymbol{\texttelugukha}{LTG}{150}
\DeclareTextSymbol{\textteluguga}{LTG}{151}
\DeclareTextSymbol{\texttelugugha}{LTG}{152}
\DeclareTextSymbol{\texttelugunga}{LTG}{153}
\DeclareTextSymbol{\textteluguca}{LTG}{154}
\DeclareTextSymbol{\texttelugucha}{LTG}{155}
\DeclareTextSymbol{\textteluguja}{LTG}{156}
\DeclareTextSymbol{\texttelugujha}{LTG}{157}
\DeclareTextSymbol{\texttelugunya}{LTG}{158}
\DeclareTextSymbol{\texttelugutta}{LTG}{159}
\DeclareTextSymbol{\textteluguttha}{LTG}{160}
\DeclareTextSymbol{\texttelugudda}{LTG}{161}
\DeclareTextSymbol{\textteluguddha}{LTG}{162}
\DeclareTextSymbol{\texttelugunna}{LTG}{163}
\DeclareTextSymbol{\textteluguta}{LTG}{164}
\DeclareTextSymbol{\texttelugutha}{LTG}{165}
\DeclareTextSymbol{\textteluguda}{LTG}{166}
\DeclareTextSymbol{\texttelugudha}{LTG}{167}
\DeclareTextSymbol{\textteluguna}{LTG}{168}
\DeclareTextSymbol{\texttelugupa}{LTG}{170}
\DeclareTextSymbol{\texttelugupha}{LTG}{171}
\DeclareTextSymbol{\textteluguba}{LTG}{172}
\DeclareTextSymbol{\texttelugubha}{LTG}{173}
\DeclareTextSymbol{\textteluguma}{LTG}{174}
\DeclareTextSymbol{\textteluguya}{LTG}{175}
\DeclareTextSymbol{\texttelugura}{LTG}{176}
\DeclareTextSymbol{\texttelugurra}{LTG}{177}
\DeclareTextSymbol{\texttelugula}{LTG}{178}
\DeclareTextSymbol{\texttelugulla}{LTG}{179}
\DeclareTextSymbol{\textteluguva}{LTG}{181}
\DeclareTextSymbol{\texttelugusha}{LTG}{182}
\DeclareTextSymbol{\texttelugussa}{LTG}{183}
\DeclareTextSymbol{\texttelugusa}{LTG}{184}
\DeclareTextSymbol{\textteluguha}{LTG}{185}
\DeclareTextCommand{\textteluguvowelaa}{LTG}[1]{#1\char190 }
\DeclareTextCommand{\textteluguvoweli}{LTG}[1]{#1\char191 }
\DeclareTextCommand{\textteluguvowelii}{LTG}[1]{#1\char192 }
\DeclareTextCommand{\textteluguvowelu}{LTG}[1]{#1\char193 }
\DeclareTextCommand{\textteluguvoweluu}{LTG}[1]{#1\char194 }
\DeclareTextCommand{\textteluguvowelvocalicr}{LTG}[1]{#1\char195 }
\DeclareTextCommand{\textteluguvowelvocalicrr}{LTG}[1]{#1\char196 }
\DeclareTextCommand{\textteluguvowele}{LTG}[1]{#1\char198 }
\DeclareTextCommand{\textteluguvowelee}{LTG}[1]{#1\char199 }
\DeclareTextCommand{\textteluguvowelai}{LTG}[1]{#1\char200 }
\DeclareTextCommand{\textteluguvowelo}{LTG}[1]{#1\char202 }
\DeclareTextCommand{\textteluguvoweloo}{LTG}[1]{#1\char203 }
\DeclareTextCommand{\textteluguvowelau}{LTG}[1]{#1\char204 }
\DeclareTextCommand{\textteluguvirama}{LTG}[1]{#1\char205 }
\DeclareTextCommand{\texttelugulengthmark}{LTG}[1]{#1\char213 }
\DeclareTextCommand{\textteluguailengthmark}{LTG}[1]{#1\char214 }
\DeclareTextSymbol{\textteluguvocalicrr}{LTG}{224}
\DeclareTextSymbol{\textteluguvocalicll}{LTG}{225}
\DeclareTextSymbol{\textteluguzero}{LTG}{230}
\DeclareTextSymbol{\textteluguone}{LTG}{231}
\DeclareTextSymbol{\texttelugutwo}{LTG}{232}
\DeclareTextSymbol{\textteluguthree}{LTG}{233}
\DeclareTextSymbol{\texttelugufour}{LTG}{234}
\DeclareTextSymbol{\texttelugufive}{LTG}{235}
\DeclareTextSymbol{\texttelugusix}{LTG}{236}
\DeclareTextSymbol{\textteluguseven}{LTG}{237}
\DeclareTextSymbol{\texttelugueight}{LTG}{238}
\DeclareTextSymbol{\texttelugunine}{LTG}{239}
