%%
%% This is file `box.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% circ.dtx  (with options: `box')
%% CIRC is a LaTeX package to typeset circuit and optics diagrams.
%% Copyright (C) 1997,1998,2003  Sebastian Tannert and Andreas Tille
%% 
%%   This program is free software; you can redistribute it and/or modify
%%   it under the terms of the GNU General Public License as published by
%%   the Free Software Foundation; either version 2 of the License, or
%%   (at your option) any later version.
%% 
%%   This program is distributed in the hope that it will be useful,
%%   but WITHOUT ANY WARRANTY; without even the implied warranty of
%%   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%%   GNU General Public License for more details.
%% 
%%   You should have received a copy of the GNU General Public License
%%   along with this program; if not, write to the Free Software
%%   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
%% 
%% For error reports concerning UNCHANGED versions of this file no
%% more than one year old, see CIRC.DVI after installation.
%% If installation fails search thru this file for 'bug'.
\ProvidesFile{box.def}
\freecirc
\bbdef        BBa         \c*fntb  252
\bbdef        BBd         \c*fntb  253
\bbdefNeT oscillograph \c*fnt  142 {}
\bbdefNeT G    \c*fntb 250 \vbox{\hc*{\symfont G}\kern1.5\*spc%
                                 \hc*{\c*fnts\char16}}
\bbdefNeT Gvar \c*fntb 250 \vbox{\hc*{\symfont G}\kern1.5\*spc%
                                 \hc*{\c*fnts\char17}}
\bbdefNeT Impulse \c*fntb 250 \c*fnts\char13
\bbdefNeT Amp  \c*fntb 250 \c*fnts\char24
\sbdef ACtoDC \c*fntb 251 \hbox{\raise.6\ht*\hbox{\c*fnts\char16}%
                                \lower.6\dp*\hbox{\symfont$=$}}
\protectcirc
\endinput
%%
%% End of file `box.def'.
