%%% Unicode to TeX mapping, file uni-212.def, U+D400..U+D4FF, autogenerated by makeunidef.pl
\ifx\ProvidesFile\undefined\else
\ProvidesFile{uni-212.def}[2022/08/07 UCS: Unicode data U+D400..U+D4FF]%
\fi
\gdef\u@cjk@hangul#1#2#3#4{{\fontencoding{C61}\def\CJK@plane{#1#2}\selectfont\char"#3#4\relax}}%
\uc@dclc{54273}{cjkhangul}{\u@cjk@hangul14F3}%
\uc@dclc{54280}{cjkhangul}{\u@cjk@hangul14F4}%
\uc@dclc{54301}{cjkhangul}{\u@cjk@hangul14F5}%
\uc@dclc{54336}{cjkhangul}{\u@cjk@hangul14F6}%
\uc@dclc{54340}{cjkhangul}{\u@cjk@hangul14F7}%
\uc@dclc{54364}{cjkhangul}{\u@cjk@hangul14F8}%
\uc@dclc{54368}{cjkhangul}{\u@cjk@hangul14F9}%
\uc@dclc{54372}{cjkhangul}{\u@cjk@hangul14FA}%
\uc@dclc{54381}{cjkhangul}{\u@cjk@hangul14FB}%
\uc@dclc{54383}{cjkhangul}{\u@cjk@hangul14FC}%
\uc@dclc{54392}{cjkhangul}{\u@cjk@hangul14FD}%
\uc@dclc{54393}{cjkhangul}{\u@cjk@hangul14FE}%
\uc@dclc{54396}{cjkhangul}{\u@cjk@hangul14FF}%
\uc@dclc{54399}{cjkhangul}{\u@cjk@hangul1500}%
\uc@dclc{54400}{cjkhangul}{\u@cjk@hangul1501}%
\uc@dclc{54402}{cjkhangul}{\u@cjk@hangul1502}%
\uc@dclc{54408}{cjkhangul}{\u@cjk@hangul1503}%
\uc@dclc{54409}{cjkhangul}{\u@cjk@hangul1504}%
\uc@dclc{54411}{cjkhangul}{\u@cjk@hangul1505}%
\uc@dclc{54413}{cjkhangul}{\u@cjk@hangul1506}%
\uc@dclc{54420}{cjkhangul}{\u@cjk@hangul1507}%
\uc@dclc{54441}{cjkhangul}{\u@cjk@hangul1508}%
\uc@dclc{54476}{cjkhangul}{\u@cjk@hangul1509}%
\uc@dclc{54480}{cjkhangul}{\u@cjk@hangul150A}%
\uc@dclc{54484}{cjkhangul}{\u@cjk@hangul150B}%
\uc@dclc{54492}{cjkhangul}{\u@cjk@hangul150C}%
\uc@dclc{54495}{cjkhangul}{\u@cjk@hangul150D}%
\uc@dclc{54504}{cjkhangul}{\u@cjk@hangul150E}%
\uc@dclc{54508}{cjkhangul}{\u@cjk@hangul150F}%
\uc@dclc{54512}{cjkhangul}{\u@cjk@hangul1510}%
\uc@dclc{54520}{cjkhangul}{\u@cjk@hangul1511}%
\uc@dclc{54523}{cjkhangul}{\u@cjk@hangul1512}%
\uc@dclc{54525}{cjkhangul}{\u@cjk@hangul1513}%
%%% Local Variables: 
%%% mode: latex
%%% coding: utf-8
%%% End: 
