%%% Unicode to TeX mapping, file uni-177.def, U+B100..U+B1FF, autogenerated by makeunidef.pl
\ifx\ProvidesFile\undefined\else
\ProvidesFile{uni-177.def}[2022/08/07 UCS: Unicode data U+B100..U+B1FF]%
\fi
\gdef\u@cjk@hangul#1#2#3#4{{\fontencoding{C61}\def\CJK@plane{#1#2}\selectfont\char"#3#4\relax}}%
\uc@dclc{45320}{cjkhangul}{\u@cjk@hangul07C5}%
\uc@dclc{45321}{cjkhangul}{\u@cjk@hangul07C6}%
\uc@dclc{45323}{cjkhangul}{\u@cjk@hangul07C7}%
\uc@dclc{45324}{cjkhangul}{\u@cjk@hangul07C8}%
\uc@dclc{45328}{cjkhangul}{\u@cjk@hangul07C9}%
\uc@dclc{45330}{cjkhangul}{\u@cjk@hangul07CA}%
\uc@dclc{45331}{cjkhangul}{\u@cjk@hangul07CB}%
\uc@dclc{45336}{cjkhangul}{\u@cjk@hangul07CC}%
\uc@dclc{45337}{cjkhangul}{\u@cjk@hangul07CD}%
\uc@dclc{45339}{cjkhangul}{\u@cjk@hangul07CE}%
\uc@dclc{45340}{cjkhangul}{\u@cjk@hangul07CF}%
\uc@dclc{45341}{cjkhangul}{\u@cjk@hangul07D0}%
\uc@dclc{45347}{cjkhangul}{\u@cjk@hangul07D1}%
\uc@dclc{45348}{cjkhangul}{\u@cjk@hangul07D2}%
\uc@dclc{45349}{cjkhangul}{\u@cjk@hangul07D3}%
\uc@dclc{45352}{cjkhangul}{\u@cjk@hangul07D4}%
\uc@dclc{45356}{cjkhangul}{\u@cjk@hangul07D5}%
\uc@dclc{45364}{cjkhangul}{\u@cjk@hangul07D6}%
\uc@dclc{45365}{cjkhangul}{\u@cjk@hangul07D7}%
\uc@dclc{45367}{cjkhangul}{\u@cjk@hangul07D8}%
\uc@dclc{45368}{cjkhangul}{\u@cjk@hangul07D9}%
\uc@dclc{45369}{cjkhangul}{\u@cjk@hangul07DA}%
\uc@dclc{45376}{cjkhangul}{\u@cjk@hangul07DB}%
\uc@dclc{45377}{cjkhangul}{\u@cjk@hangul07DC}%
\uc@dclc{45380}{cjkhangul}{\u@cjk@hangul07DD}%
\uc@dclc{45384}{cjkhangul}{\u@cjk@hangul07DE}%
\uc@dclc{45392}{cjkhangul}{\u@cjk@hangul07DF}%
\uc@dclc{45393}{cjkhangul}{\u@cjk@hangul07E0}%
\uc@dclc{45396}{cjkhangul}{\u@cjk@hangul07E1}%
\uc@dclc{45397}{cjkhangul}{\u@cjk@hangul07E2}%
\uc@dclc{45400}{cjkhangul}{\u@cjk@hangul07E3}%
\uc@dclc{45404}{cjkhangul}{\u@cjk@hangul07E4}%
\uc@dclc{45408}{cjkhangul}{\u@cjk@hangul07E5}%
\uc@dclc{45432}{cjkhangul}{\u@cjk@hangul07E6}%
\uc@dclc{45433}{cjkhangul}{\u@cjk@hangul07E7}%
\uc@dclc{45436}{cjkhangul}{\u@cjk@hangul07E8}%
\uc@dclc{45440}{cjkhangul}{\u@cjk@hangul07E9}%
\uc@dclc{45442}{cjkhangul}{\u@cjk@hangul07EA}%
\uc@dclc{45448}{cjkhangul}{\u@cjk@hangul07EB}%
\uc@dclc{45449}{cjkhangul}{\u@cjk@hangul07EC}%
\uc@dclc{45451}{cjkhangul}{\u@cjk@hangul07ED}%
\uc@dclc{45453}{cjkhangul}{\u@cjk@hangul07EE}%
\uc@dclc{45458}{cjkhangul}{\u@cjk@hangul07EF}%
\uc@dclc{45459}{cjkhangul}{\u@cjk@hangul07F0}%
\uc@dclc{45460}{cjkhangul}{\u@cjk@hangul07F1}%
\uc@dclc{45464}{cjkhangul}{\u@cjk@hangul07F2}%
\uc@dclc{45468}{cjkhangul}{\u@cjk@hangul07F3}%
\uc@dclc{45480}{cjkhangul}{\u@cjk@hangul07F4}%
\uc@dclc{45516}{cjkhangul}{\u@cjk@hangul07F5}%
\uc@dclc{45520}{cjkhangul}{\u@cjk@hangul07F6}%
\uc@dclc{45524}{cjkhangul}{\u@cjk@hangul07F7}%
\uc@dclc{45532}{cjkhangul}{\u@cjk@hangul07F8}%
\uc@dclc{45533}{cjkhangul}{\u@cjk@hangul07F9}%
\uc@dclc{45535}{cjkhangul}{\u@cjk@hangul07FA}%
\uc@dclc{45544}{cjkhangul}{\u@cjk@hangul07FB}%
\uc@dclc{45545}{cjkhangul}{\u@cjk@hangul07FC}%
\uc@dclc{45548}{cjkhangul}{\u@cjk@hangul07FD}%
\uc@dclc{45552}{cjkhangul}{\u@cjk@hangul07FE}%
\uc@dclc{45561}{cjkhangul}{\u@cjk@hangul07FF}%
\uc@dclc{45563}{cjkhangul}{\u@cjk@hangul0800}%
\uc@dclc{45565}{cjkhangul}{\u@cjk@hangul0801}%
%%% Local Variables: 
%%% mode: latex
%%% coding: utf-8
%%% End: 
