%%% Unicode to TeX mapping, file uni-33.def, U+2100..U+21FF, autogenerated by makeunidef.pl
\ifx\ProvidesFile\undefined\else
\ProvidesFile{uni-33.def}[2022/08/07 UCS: Unicode data U+2100..U+21FF]%
\fi
\uc@dclc{8448}{autogenerated}{\unichar{97}\unichar{47}\unichar{99}}%
\uc@dclc{8449}{autogenerated}{\unichar{97}\unichar{47}\unichar{115}}%
\uc@dclc{8450}{default}{\ensuremath{\mathbb C}}%
\uc@dclc{8451}{autogenerated}{\unichar{176}\unichar{67}}%
\uc@dclc{8453}{autogenerated}{\unichar{99}\unichar{47}\unichar{111}}%
\uc@dclc{8454}{autogenerated}{\unichar{99}\unichar{47}\unichar{117}}%
\uc@dclc{8455}{autogenerated}{\unichar{400}}%
\uc@dclc{8457}{autogenerated}{\unichar{176}\unichar{70}}%
\uc@dclc{8458}{autogenerated}{\unichar{103}}%
\uc@dclc{8459}{default}{\ensuremath{\mathscr H}}%
\uc@dclc{8460}{default}{\ensuremath{\mathfrak H}}%
\uc@dclc{8461}{default}{\ensuremath{\mathbb H}}%
\uc@dclc{8462}{default}{\ensuremath{\mathit h}}%
\uc@dclc{8463}{default}{\ensuremath{\hbar}}%
\uc@dclc{8464}{default}{\ensuremath{\mathscr I}}%
\uc@dclc{8465}{default}{\ensuremath{\Im}}%
\uc@dclc{8465}{postscript}{\Pisymbol{psy}{"C1}}%
\uc@dclc{8466}{default}{\ensuremath{\mathscr L}}%
\uc@dclc{8467}{default}{\ensuremath{\ell}}%
\uc@dclc{8469}{default}{\ensuremath{\mathbb N}}%
\uc@dclc{8470}{default}{\textnumero}%
\uc@dclc{8472}{default}{\ensuremath{\wp}}%
\uc@dclc{8472}{postscript}{\Pisymbol{psy}{"C3}}%
\uc@dclc{8473}{default}{\ensuremath{\mathbb P}}%
\uc@dclc{8474}{default}{\ensuremath{\mathbb Q}}%
\uc@dclc{8475}{default}{\ensuremath{\mathscr R}}%
\uc@dclc{8476}{default}{\ensuremath{\Re}}%
\uc@dclc{8476}{postscript}{\Pisymbol{psy}{"C2}}%
\uc@dclc{8477}{default}{\ensuremath{\mathbb R}}%
\uc@dclc{8480}{default}{\textsuperscript{SM}}%
\uc@dclc{8481}{autogenerated}{\unichar{84}\unichar{69}\unichar{76}}%
\uc@dclc{8482}{default}{\texttrademark}%
\uc@dclc{8482}{postscript}{\Pisymbol{psy}{"D4}}%
\uc@dclc{8484}{default}{\ensuremath{\mathbb Z}}%
\uc@dclc{8486}{default}{\ensuremath{\Omega}}%
\uc@dclc{8487}{default}{\ensuremath{\mho}}%
\uc@dclc{8488}{default}{\ensuremath{\mathfrak Z}}%
\uc@dclc{8490}{default}{\ensuremath{\mathrm K}}%
\uc@dclc{8491}{autogenerated}{\unichar{197}}%
\uc@dclc{8492}{default}{\ensuremath{\mathscr B}}%
\uc@dclc{8493}{default}{\ensuremath{\mathfrak C}}%
\uc@dclc{8495}{autogenerated}{\unichar{101}}%
\uc@dclc{8496}{default}{\ensuremath{\mathscr E}}%
\uc@dclc{8497}{default}{\ensuremath{\mathscr F}}%
\uc@dclc{8499}{default}{\ensuremath{\mathscr M}}%
\uc@dclc{8500}{default}{\ensuremath{o}}%
\uc@dclc{8501}{default}{\ensuremath\aleph}%
\uc@dclc{8501}{postscript}{\Pisymbol{psy}{"C0}}%
\uc@dclc{8502}{default}{\ensuremath\beth}%
\uc@dclc{8503}{default}{\ensuremath\gimel}%
\uc@dclc{8504}{default}{\ensuremath\daleth}%
\uc@dclc{8505}{autogenerated}{\unichar{105}}%
\uc@dclc{8507}{autogenerated}{\unichar{70}\unichar{65}\unichar{88}}%
\uc@dclc{8508}{autogenerated}{\unichar{960}}%
\uc@dclc{8509}{autogenerated}{\unichar{947}}%
\uc@dclc{8510}{autogenerated}{\unichar{915}}%
\uc@dclc{8511}{autogenerated}{\unichar{928}}%
\uc@dclc{8512}{autogenerated}{\unichar{8721}}%
\uc@dclc{8517}{autogenerated}{\unichar{68}}%
\uc@dclc{8518}{autogenerated}{\unichar{100}}%
\uc@dclc{8519}{autogenerated}{\unichar{101}}%
\uc@dclc{8520}{autogenerated}{\unichar{105}}%
\uc@dclc{8521}{autogenerated}{\unichar{106}}%
\uc@dclc{8523}{default}{\ensuremath{\invamp}}%
\uc@dclc{8528}{autogenerated}{\unichar{49}\unichar{8260}\unichar{55}}%
\uc@dclc{8529}{autogenerated}{\unichar{49}\unichar{8260}\unichar{57}}%
\uc@dclc{8530}{autogenerated}{\unichar{49}\unichar{8260}\unichar{49}\unichar{48}}%
\uc@dclc{8531}{autogenerated}{\unichar{49}\unichar{8260}\unichar{51}}%
\uc@dclc{8532}{autogenerated}{\unichar{50}\unichar{8260}\unichar{51}}%
\uc@dclc{8533}{autogenerated}{\unichar{49}\unichar{8260}\unichar{53}}%
\uc@dclc{8534}{autogenerated}{\unichar{50}\unichar{8260}\unichar{53}}%
\uc@dclc{8535}{autogenerated}{\unichar{51}\unichar{8260}\unichar{53}}%
\uc@dclc{8536}{autogenerated}{\unichar{52}\unichar{8260}\unichar{53}}%
\uc@dclc{8537}{autogenerated}{\unichar{49}\unichar{8260}\unichar{54}}%
\uc@dclc{8538}{autogenerated}{\unichar{53}\unichar{8260}\unichar{54}}%
\uc@dclc{8539}{autogenerated}{\unichar{49}\unichar{8260}\unichar{56}}%
\uc@dclc{8540}{autogenerated}{\unichar{51}\unichar{8260}\unichar{56}}%
\uc@dclc{8541}{autogenerated}{\unichar{53}\unichar{8260}\unichar{56}}%
\uc@dclc{8542}{autogenerated}{\unichar{55}\unichar{8260}\unichar{56}}%
\uc@dclc{8543}{autogenerated}{\unichar{49}\unichar{8260}}%
\uc@dclc{8544}{autogenerated}{\unichar{73}}%
\uc@dclc{8545}{autogenerated}{\unichar{73}\unichar{73}}%
\uc@dclc{8546}{autogenerated}{\unichar{73}\unichar{73}\unichar{73}}%
\uc@dclc{8547}{autogenerated}{\unichar{73}\unichar{86}}%
\uc@dclc{8548}{autogenerated}{\unichar{86}}%
\uc@dclc{8549}{autogenerated}{\unichar{86}\unichar{73}}%
\uc@dclc{8550}{autogenerated}{\unichar{86}\unichar{73}\unichar{73}}%
\uc@dclc{8551}{autogenerated}{\unichar{86}\unichar{73}\unichar{73}\unichar{73}}%
\uc@dclc{8552}{autogenerated}{\unichar{73}\unichar{88}}%
\uc@dclc{8553}{autogenerated}{\unichar{88}}%
\uc@dclc{8554}{autogenerated}{\unichar{88}\unichar{73}}%
\uc@dclc{8555}{autogenerated}{\unichar{88}\unichar{73}\unichar{73}}%
\uc@dclc{8556}{autogenerated}{\unichar{76}}%
\uc@dclc{8557}{autogenerated}{\unichar{67}}%
\uc@dclc{8558}{autogenerated}{\unichar{68}}%
\uc@dclc{8559}{autogenerated}{\unichar{77}}%
\uc@dclc{8560}{autogenerated}{\unichar{105}}%
\uc@dclc{8561}{autogenerated}{\unichar{105}\unichar{105}}%
\uc@dclc{8562}{autogenerated}{\unichar{105}\unichar{105}\unichar{105}}%
\uc@dclc{8563}{autogenerated}{\unichar{105}\unichar{118}}%
\uc@dclc{8564}{autogenerated}{\unichar{118}}%
\uc@dclc{8565}{autogenerated}{\unichar{118}\unichar{105}}%
\uc@dclc{8566}{autogenerated}{\unichar{118}\unichar{105}\unichar{105}}%
\uc@dclc{8567}{autogenerated}{\unichar{118}\unichar{105}\unichar{105}\unichar{105}}%
\uc@dclc{8568}{autogenerated}{\unichar{105}\unichar{120}}%
\uc@dclc{8569}{autogenerated}{\unichar{120}}%
\uc@dclc{8570}{autogenerated}{\unichar{120}\unichar{105}}%
\uc@dclc{8571}{autogenerated}{\unichar{120}\unichar{105}\unichar{105}}%
\uc@dclc{8572}{autogenerated}{\unichar{108}}%
\uc@dclc{8573}{autogenerated}{\unichar{99}}%
\uc@dclc{8574}{autogenerated}{\unichar{100}}%
\uc@dclc{8575}{autogenerated}{\unichar{109}}%
\uc@dclc{8585}{autogenerated}{\unichar{48}\unichar{8260}\unichar{51}}%
\uc@dclc{8592}{default}{\ensuremath{\leftarrow}}%
\uc@dclc{8592}{postscript}{\Pisymbol{psy}{"AC}}%
\uc@dclc{8593}{default}{\ensuremath{\uparrow}}%
\uc@dclc{8593}{postscript}{\Pisymbol{psy}{"AD}}%
\uc@dclc{8594}{default}{\ensuremath{\rightarrow}}%
\uc@dclc{8594}{postscript}{\Pisymbol{psy}{"AE}}%
\uc@dclc{8595}{default}{\ensuremath{\downarrow}}%
\uc@dclc{8595}{postscript}{\Pisymbol{psy}{"AF}}%
\uc@dclc{8596}{default}{\ensuremath{\leftrightarrow}}%
\uc@dclc{8596}{postscript}{\ding{"D6}}%
\uc@dclc{8597}{default}{\ensuremath{\updownarrow}}%
\uc@dclc{8597}{postscript}{\ding{"D7}}%
\uc@dclc{8605}{default}{\ensuremath\leadsto}%
\uc@dclc{8606}{default}{\ensuremath\twoheadleftarrow}%
\uc@dclc{8608}{default}{\ensuremath\twoheadrightarrow}%
\uc@dclc{8610}{default}{\ensuremath\leftarrowtail}%
\uc@dclc{8611}{default}{\ensuremath\rightarrowtail}%
\uc@dclc{8614}{default}{\ensuremath{\mapsto}}%
\uc@dclc{8617}{default}{\ensuremath{\hookleftarrow}}%
\uc@dclc{8618}{default}{\ensuremath{\hookrightarrow}}%
\uc@dclc{8629}{postscript}{\Pisymbol{psy}{"BF}}%
\uc@dclc{8636}{default}{\ensuremath{\leftharpoonup}}%
\uc@dclc{8637}{default}{\ensuremath{\leftharpoondown}}%
\uc@dclc{8638}{default}{\ensuremath\upharpoonright}%
\uc@dclc{8639}{default}{\ensuremath\upharpoonleft}%
\uc@dclc{8640}{default}{\ensuremath{\rightharpoonup}}%
\uc@dclc{8641}{default}{\ensuremath{\rightharpoondown}}%
\uc@dclc{8642}{default}{\ensuremath\downharpoonright}%
\uc@dclc{8643}{default}{\ensuremath\downharpoonleft}%
\uc@dclc{8651}{default}{\ensuremath\leftrightharpoons}%
\uc@dclc{8652}{default}{\ensuremath{\rightleftharpoons}}%
\uc@dclc{8656}{default}{\ensuremath{\Leftarrow}}%
\uc@dclc{8656}{postscript}{\Pisymbol{psy}{"DC}}%
\uc@dclc{8657}{default}{\ensuremath{\Uparrow}}%
\uc@dclc{8657}{postscript}{\Pisymbol{psy}{"DD}}%
\uc@dclc{8658}{default}{\ensuremath{\Rightarrow}}%
\uc@dclc{8658}{postscript}{\Pisymbol{psy}{"DE}}%
\uc@dclc{8659}{default}{\ensuremath{\Downarrow}}%
\uc@dclc{8659}{postscript}{\Pisymbol{psy}{"DF}}%
\uc@dclc{8660}{default}{\ensuremath{\Leftrightarrow}}%
\uc@dclc{8660}{postscript}{\Pisymbol{psy}{"DB}}%
\uc@dclc{8661}{default}{\ensuremath{\Updownarrow}}%
%%% Local Variables: 
%%% mode: latex
%%% coding: utf-8
%%% End: 
