%%
%% This is file `fithesis-english.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% english.dtx  (with options: `base')
%% 
%% Copyright 1998--2024  Daniel Marek (DM), Jan Pavlovič (JP),
%%                       Petr Sojka (PS), Vít Starý Novotný (VN),
%%                       Tereza Vrabcová (TV)
%% http://www.fi.muni.cz/tech/unix/tex/fithesis.xhtml
%% Faculty of Informatics, Masaryk University (Brno, Czech Republic)
%% 
%% This work may be distributed and/or modified under the
%% conditions of the LaTeX Project Public License, either version
%% 1.3 of this license or (at your option) any later version.
%% The latest version of this license is available at
%% 
%%   http://www.latex-project.org/lppl.txt
%% 
%% and version 1.3 or later is part of all distributions of LaTeX
%% version 2005/12/01 or later.
%% 
%% This work has the LPPL maintenance status `maintained'.
%% 
%% The Current Maintainer of this work is Vít Starý Novotný (VN).
%% Send bug reports, requests for additions and questions
%% either to the fithesis discussion forum at
%% 
%%   http://is.muni.cz/auth/df/fithesis-sazba/
%% 
%% or to the e-mail address <witiko@mail.muni.cz>.
%% 
%% 
%% MODIFICATION ADVICE:
%% 
%% If you want to customize this file, it is best to make a copy of
%% the source file(s) from which it was produced.  Use a different
%% name for your copy(ies) and modify the copy(ies); this will ensure
%% that your modifications do not get overwritten when you install a
%% new release of the standard system.  You should also ensure that
%% your modified source file does not generate any modified file with
%% the same name as a standard file.
%% 
%% You will also need to produce your own, suitably named, .ins file to
%% control the generation of files from your source file; this file
%% should contain your own preambles for the files it generates, not
%% those in the standard .ins files.
%% 
%% The names of the source files used are shown above.
%% 
\ProvidesFile{fithesis/locale/fithesis-english.def}[2021/02/26]

\gdef\thesis@english@universityName{University name}
\gdef\thesis@english@facultyName{Faculty name}
\gdef\thesis@english@assignment{%
  This is where a copy of the official signed thesis assignment
  is located in the printed version of the document.}
\gdef\thesis@english@declaration{Declaration text ...}

\gdef\thesis@english@csquotesStyle{english}

\gdef\thesis@english@spring{Spring}
\gdef\thesis@english@fall{Fall}
\gdef\thesis@english@semester{%
  \thesis@{english@\thesis@season} \thesis@seasonYear}
\gdef\thesis@english@formattedDate{{%
  \thesis@day.
  \newcount\@month\expandafter\@month\thesis@month\relax
  \ifnum\@month=1%
    January
  \else\ifnum\@month=2%
    February
  \else\ifnum\@month=3%
    March
  \else\ifnum\@month=4%
    April
  \else\ifnum\@month=5%
    May
  \else\ifnum\@month=6%
    June
  \else\ifnum\@month=7%
    July
  \else\ifnum\@month=8%
    August
  \else\ifnum\@month=9%
    September
  \else\ifnum\@month=10%
    October
  \else\ifnum\@month=11%
    November
  \else\ifnum\@month=12%
    December
  \else
    <<unknown month (\the\@month)>>
  \fi\fi\fi\fi\fi\fi
  \fi\fi\fi\fi\fi\fi
  \thesis@year}}

\gdef\thesis@english@authorSignature{Author's signature}
\gdef\thesis@english@advisorSignature{Signature of Thesis
  \thesis@english@advisorTitle}
\gdef\thesis@english@fieldTitle{Field of Study}
\gdef\thesis@english@advisorTitle{Advisor}
\gdef\thesis@english@authorTitle{Author}
\gdef\thesis@english@abstractTitle{Abstract}
\gdef\thesis@english@keywordsTitle{Keywords}
\gdef\thesis@english@thanksTitle{Acknowledgements}
\gdef\thesis@english@declarationTitle{Declaration}
\gdef\thesis@english@summaryTitle{Summary}
\gdef\thesis@english@idTitle{ID}
\gdef\thesis@english@typeName@sempaper{Seminar Paper}
\gdef\thesis@english@typeName@bachelors{Bachelor's Thesis}
\gdef\thesis@english@typeName@masters{Master's Thesis}
\gdef\thesis@english@typeName@proposal{Thesis Proposal}
\gdef\thesis@english@typeName@doctoral{Doctoral Thesis}
\gdef\thesis@english@typeName@rigorous{Rigorous Thesis}
\gdef\thesis@english@typeName{%
  \ifx\thesis@type\thesis@sempaper
    \thesis@english@typeName@sempaper
  \else\ifx\thesis@type\thesis@bachelors
    \thesis@english@typeName@bachelors
  \else\ifx\thesis@type\thesis@masters
    \thesis@english@typeName@masters
  \else\ifx\thesis@type\thesis@proposal
    \thesis@english@typeName@proposal
  \else\ifx\thesis@type\thesis@doctoral
    \thesis@english@typeName@doctoral
  \else\ifx\thesis@type\thesis@rigorous
    \thesis@english@typeName@rigorous
  \else
    <<Unknown thesis type (\thesis@type)>>%
  \fi\fi\fi\fi\fi\fi}
\endinput
%%
%% End of file `fithesis-english.def'.
