%%% Unicode to TeX mapping, file uni-182.def, U+B600..U+B6FF, autogenerated by makeunidef.pl
\ifx\ProvidesFile\undefined\else
\ProvidesFile{uni-182.def}[2022/08/07 UCS: Unicode data U+B600..U+B6FF]%
\fi
\gdef\u@cjk@hangul#1#2#3#4{{\fontencoding{C61}\def\CJK@plane{#1#2}\selectfont\char"#3#4\relax}}%
\uc@dclc{46608}{cjkhangul}{\u@cjk@hangul08DC}%
\uc@dclc{46609}{cjkhangul}{\u@cjk@hangul08DD}%
\uc@dclc{46612}{cjkhangul}{\u@cjk@hangul08DE}%
\uc@dclc{46616}{cjkhangul}{\u@cjk@hangul08DF}%
\uc@dclc{46629}{cjkhangul}{\u@cjk@hangul08E0}%
\uc@dclc{46636}{cjkhangul}{\u@cjk@hangul08E1}%
\uc@dclc{46644}{cjkhangul}{\u@cjk@hangul08E2}%
\uc@dclc{46664}{cjkhangul}{\u@cjk@hangul08E3}%
\uc@dclc{46692}{cjkhangul}{\u@cjk@hangul08E4}%
\uc@dclc{46696}{cjkhangul}{\u@cjk@hangul08E5}%
\uc@dclc{46748}{cjkhangul}{\u@cjk@hangul08E6}%
\uc@dclc{46749}{cjkhangul}{\u@cjk@hangul08E7}%
\uc@dclc{46752}{cjkhangul}{\u@cjk@hangul08E8}%
\uc@dclc{46756}{cjkhangul}{\u@cjk@hangul08E9}%
\uc@dclc{46763}{cjkhangul}{\u@cjk@hangul08EA}%
\uc@dclc{46764}{cjkhangul}{\u@cjk@hangul08EB}%
\uc@dclc{46769}{cjkhangul}{\u@cjk@hangul08EC}%
\uc@dclc{46804}{cjkhangul}{\u@cjk@hangul08ED}%
\uc@dclc{46832}{cjkhangul}{\u@cjk@hangul08EE}%
\uc@dclc{46836}{cjkhangul}{\u@cjk@hangul08EF}%
\uc@dclc{46840}{cjkhangul}{\u@cjk@hangul08F0}%
%%% Local Variables: 
%%% mode: latex
%%% coding: utf-8
%%% End: 
