%%% Unicode to TeX mapping, file uni-174.def, U+AE00..U+AEFF, autogenerated by makeunidef.pl
\ifx\ProvidesFile\undefined\else
\ProvidesFile{uni-174.def}[2022/08/07 UCS: Unicode data U+AE00..U+AEFF]%
\fi
\gdef\u@cjk@hangul#1#2#3#4{{\fontencoding{C61}\def\CJK@plane{#1#2}\selectfont\char"#3#4\relax}}%
\uc@dclc{44544}{cjkhangul}{\u@cjk@hangul071A}%
\uc@dclc{44545}{cjkhangul}{\u@cjk@hangul071B}%
\uc@dclc{44552}{cjkhangul}{\u@cjk@hangul071C}%
\uc@dclc{44553}{cjkhangul}{\u@cjk@hangul071D}%
\uc@dclc{44555}{cjkhangul}{\u@cjk@hangul071E}%
\uc@dclc{44557}{cjkhangul}{\u@cjk@hangul071F}%
\uc@dclc{44564}{cjkhangul}{\u@cjk@hangul0720}%
\uc@dclc{44592}{cjkhangul}{\u@cjk@hangul0721}%
\uc@dclc{44593}{cjkhangul}{\u@cjk@hangul0722}%
\uc@dclc{44596}{cjkhangul}{\u@cjk@hangul0723}%
\uc@dclc{44599}{cjkhangul}{\u@cjk@hangul0724}%
\uc@dclc{44600}{cjkhangul}{\u@cjk@hangul0725}%
\uc@dclc{44602}{cjkhangul}{\u@cjk@hangul0726}%
\uc@dclc{44608}{cjkhangul}{\u@cjk@hangul0727}%
\uc@dclc{44609}{cjkhangul}{\u@cjk@hangul0728}%
\uc@dclc{44611}{cjkhangul}{\u@cjk@hangul0729}%
\uc@dclc{44613}{cjkhangul}{\u@cjk@hangul072A}%
\uc@dclc{44614}{cjkhangul}{\u@cjk@hangul072B}%
\uc@dclc{44618}{cjkhangul}{\u@cjk@hangul072C}%
\uc@dclc{44620}{cjkhangul}{\u@cjk@hangul072D}%
\uc@dclc{44621}{cjkhangul}{\u@cjk@hangul072E}%
\uc@dclc{44622}{cjkhangul}{\u@cjk@hangul072F}%
\uc@dclc{44624}{cjkhangul}{\u@cjk@hangul0730}%
\uc@dclc{44628}{cjkhangul}{\u@cjk@hangul0731}%
\uc@dclc{44630}{cjkhangul}{\u@cjk@hangul0732}%
\uc@dclc{44636}{cjkhangul}{\u@cjk@hangul0733}%
\uc@dclc{44637}{cjkhangul}{\u@cjk@hangul0734}%
\uc@dclc{44639}{cjkhangul}{\u@cjk@hangul0735}%
\uc@dclc{44640}{cjkhangul}{\u@cjk@hangul0736}%
\uc@dclc{44641}{cjkhangul}{\u@cjk@hangul0737}%
\uc@dclc{44645}{cjkhangul}{\u@cjk@hangul0738}%
\uc@dclc{44648}{cjkhangul}{\u@cjk@hangul0739}%
\uc@dclc{44649}{cjkhangul}{\u@cjk@hangul073A}%
\uc@dclc{44652}{cjkhangul}{\u@cjk@hangul073B}%
\uc@dclc{44656}{cjkhangul}{\u@cjk@hangul073C}%
\uc@dclc{44664}{cjkhangul}{\u@cjk@hangul073D}%
\uc@dclc{44665}{cjkhangul}{\u@cjk@hangul073E}%
\uc@dclc{44667}{cjkhangul}{\u@cjk@hangul073F}%
\uc@dclc{44668}{cjkhangul}{\u@cjk@hangul0740}%
\uc@dclc{44669}{cjkhangul}{\u@cjk@hangul0741}%
\uc@dclc{44676}{cjkhangul}{\u@cjk@hangul0742}%
\uc@dclc{44677}{cjkhangul}{\u@cjk@hangul0743}%
\uc@dclc{44684}{cjkhangul}{\u@cjk@hangul0744}%
\uc@dclc{44732}{cjkhangul}{\u@cjk@hangul0745}%
\uc@dclc{44733}{cjkhangul}{\u@cjk@hangul0746}%
\uc@dclc{44734}{cjkhangul}{\u@cjk@hangul0747}%
\uc@dclc{44736}{cjkhangul}{\u@cjk@hangul0748}%
\uc@dclc{44740}{cjkhangul}{\u@cjk@hangul0749}%
\uc@dclc{44748}{cjkhangul}{\u@cjk@hangul074A}%
\uc@dclc{44749}{cjkhangul}{\u@cjk@hangul074B}%
\uc@dclc{44751}{cjkhangul}{\u@cjk@hangul074C}%
\uc@dclc{44752}{cjkhangul}{\u@cjk@hangul074D}%
\uc@dclc{44753}{cjkhangul}{\u@cjk@hangul074E}%
\uc@dclc{44760}{cjkhangul}{\u@cjk@hangul074F}%
\uc@dclc{44761}{cjkhangul}{\u@cjk@hangul0750}%
\uc@dclc{44764}{cjkhangul}{\u@cjk@hangul0751}%
\uc@dclc{44776}{cjkhangul}{\u@cjk@hangul0752}%
\uc@dclc{44779}{cjkhangul}{\u@cjk@hangul0753}%
\uc@dclc{44781}{cjkhangul}{\u@cjk@hangul0754}%
\uc@dclc{44788}{cjkhangul}{\u@cjk@hangul0755}%
\uc@dclc{44792}{cjkhangul}{\u@cjk@hangul0756}%
\uc@dclc{44796}{cjkhangul}{\u@cjk@hangul0757}%
%%% Local Variables: 
%%% mode: latex
%%% coding: utf-8
%%% End: 
