\NewDocumentCommand{\tutodoc@trans@date}{mmm}{#1/#2/#3}
\NewDocumentCommand{\tutodoc@trans@in@EN}{m}{#1 en inglés}
\NewDocumentCommand{\tutodoc@trans@this@gives}{m}{Esto da #1}
\NewDocumentCommand{\tutodoc@trans@latex@show@start}{}{Inicio de la representación real}
\NewDocumentCommand{\tutodoc@trans@latex@show@end}{}{Fin de la representación real}
\NewDocumentCommand{\tutodoc@trans@exa@title}{}{Ejemplo}
\NewDocumentCommand{\tutodoc@trans@rem@title}{}{Observación}
\NewDocumentCommand{\tutodoc@trans@note@title}{}{Nota}
\NewDocumentCommand{\tutodoc@trans@tip@title}{}{Astucia}
\NewDocumentCommand{\tutodoc@trans@imp@title}{}{Importante}
\NewDocumentCommand{\tutodoc@trans@caut@title}{}{Recomendación}
\NewDocumentCommand{\tutodoc@trans@warn@title}{}{Advertencia}
\NewDocumentCommand{\tutodoc@trans@chges@tech}{}{Información técnica}
\NewDocumentCommand{\tutodoc@trans@chges@todo}{}{A hacer}
\NewDocumentCommand{\tutodoc@trans@chges@prob}{}{Problema}
\NewDocumentCommand{\tutodoc@trans@chges@break}{}{Bifurcación}
\NewDocumentCommand{\tutodoc@trans@chges@fix}{}{Reparación}
\NewDocumentCommand{\tutodoc@trans@chges@new}{}{Nuevo}
\NewDocumentCommand{\tutodoc@trans@chges@update}{}{Actualización}