%%% Unicode to TeX mapping, file uni-183.def, U+B700..U+B7FF, autogenerated by makeunidef.pl
\ifx\ProvidesFile\undefined\else
\ProvidesFile{uni-183.def}[2022/08/07 UCS: Unicode data U+B700..U+B7FF]%
\fi
\gdef\u@cjk@hangul#1#2#3#4{{\fontencoding{C61}\def\CJK@plane{#1#2}\selectfont\char"#3#4\relax}}%
\uc@dclc{46848}{cjkhangul}{\u@cjk@hangul08F1}%
\uc@dclc{46849}{cjkhangul}{\u@cjk@hangul08F2}%
\uc@dclc{46853}{cjkhangul}{\u@cjk@hangul08F3}%
\uc@dclc{46888}{cjkhangul}{\u@cjk@hangul08F4}%
\uc@dclc{46889}{cjkhangul}{\u@cjk@hangul08F5}%
\uc@dclc{46892}{cjkhangul}{\u@cjk@hangul08F6}%
\uc@dclc{46895}{cjkhangul}{\u@cjk@hangul08F7}%
\uc@dclc{46896}{cjkhangul}{\u@cjk@hangul08F8}%
\uc@dclc{46904}{cjkhangul}{\u@cjk@hangul08F9}%
\uc@dclc{46905}{cjkhangul}{\u@cjk@hangul08FA}%
\uc@dclc{46907}{cjkhangul}{\u@cjk@hangul08FB}%
\uc@dclc{46916}{cjkhangul}{\u@cjk@hangul08FC}%
\uc@dclc{46920}{cjkhangul}{\u@cjk@hangul08FD}%
\uc@dclc{46924}{cjkhangul}{\u@cjk@hangul08FE}%
\uc@dclc{46932}{cjkhangul}{\u@cjk@hangul08FF}%
\uc@dclc{46933}{cjkhangul}{\u@cjk@hangul0900}%
\uc@dclc{46944}{cjkhangul}{\u@cjk@hangul0901}%
\uc@dclc{46948}{cjkhangul}{\u@cjk@hangul0902}%
\uc@dclc{46952}{cjkhangul}{\u@cjk@hangul0903}%
\uc@dclc{46960}{cjkhangul}{\u@cjk@hangul0904}%
\uc@dclc{46961}{cjkhangul}{\u@cjk@hangul0905}%
\uc@dclc{46963}{cjkhangul}{\u@cjk@hangul0906}%
\uc@dclc{46965}{cjkhangul}{\u@cjk@hangul0907}%
\uc@dclc{46972}{cjkhangul}{\u@cjk@hangul0908}%
\uc@dclc{46973}{cjkhangul}{\u@cjk@hangul0909}%
\uc@dclc{46976}{cjkhangul}{\u@cjk@hangul090A}%
\uc@dclc{46980}{cjkhangul}{\u@cjk@hangul090B}%
\uc@dclc{46988}{cjkhangul}{\u@cjk@hangul090C}%
\uc@dclc{46989}{cjkhangul}{\u@cjk@hangul090D}%
\uc@dclc{46991}{cjkhangul}{\u@cjk@hangul090E}%
\uc@dclc{46992}{cjkhangul}{\u@cjk@hangul090F}%
\uc@dclc{46993}{cjkhangul}{\u@cjk@hangul0910}%
\uc@dclc{46994}{cjkhangul}{\u@cjk@hangul0911}%
\uc@dclc{46998}{cjkhangul}{\u@cjk@hangul0912}%
\uc@dclc{46999}{cjkhangul}{\u@cjk@hangul0913}%
\uc@dclc{47000}{cjkhangul}{\u@cjk@hangul0914}%
\uc@dclc{47001}{cjkhangul}{\u@cjk@hangul0915}%
\uc@dclc{47004}{cjkhangul}{\u@cjk@hangul0916}%
\uc@dclc{47008}{cjkhangul}{\u@cjk@hangul0917}%
\uc@dclc{47016}{cjkhangul}{\u@cjk@hangul0918}%
\uc@dclc{47017}{cjkhangul}{\u@cjk@hangul0919}%
\uc@dclc{47019}{cjkhangul}{\u@cjk@hangul091A}%
\uc@dclc{47020}{cjkhangul}{\u@cjk@hangul091B}%
\uc@dclc{47021}{cjkhangul}{\u@cjk@hangul091C}%
\uc@dclc{47028}{cjkhangul}{\u@cjk@hangul091D}%
\uc@dclc{47029}{cjkhangul}{\u@cjk@hangul091E}%
\uc@dclc{47032}{cjkhangul}{\u@cjk@hangul091F}%
\uc@dclc{47047}{cjkhangul}{\u@cjk@hangul0920}%
\uc@dclc{47049}{cjkhangul}{\u@cjk@hangul0921}%
\uc@dclc{47084}{cjkhangul}{\u@cjk@hangul0922}%
\uc@dclc{47085}{cjkhangul}{\u@cjk@hangul0923}%
\uc@dclc{47088}{cjkhangul}{\u@cjk@hangul0924}%
\uc@dclc{47092}{cjkhangul}{\u@cjk@hangul0925}%
\uc@dclc{47100}{cjkhangul}{\u@cjk@hangul0926}%
\uc@dclc{47101}{cjkhangul}{\u@cjk@hangul0927}%
\uc@dclc{47103}{cjkhangul}{\u@cjk@hangul0928}%
%%% Local Variables: 
%%% mode: latex
%%% coding: utf-8
%%% End: 
