%%% Unicode to TeX mapping, file uni-251.def, U+FB00..U+FBFF, autogenerated by makeunidef.pl
\ifx\ProvidesFile\undefined\else
\ProvidesFile{uni-251.def}[2022/08/07 UCS: Unicode data U+FB00..U+FBFF]%
\fi
\uc@dclc{64256}{autogenerated}{\unichar{102}\unichar{102}}%
\uc@dclc{64257}{autogenerated}{\unichar{102}\unichar{105}}%
\uc@dclc{64258}{autogenerated}{\unichar{102}\unichar{108}}%
\uc@dclc{64259}{autogenerated}{\unichar{102}\unichar{102}\unichar{105}}%
\uc@dclc{64260}{autogenerated}{\unichar{102}\unichar{102}\unichar{108}}%
\uc@dclc{64261}{autogenerated}{\unichar{383}\unichar{116}}%
\uc@dclc{64262}{autogenerated}{\unichar{115}\unichar{116}}%
\uc@dclc{64285}{default}{\hiriq\hebyod}%
\uc@dclc{64287}{default}{\patah\doubleyod}%
\uc@dclc{64288}{autogenerated}{\unichar{1506}}%
\uc@dclc{64289}{autogenerated}{\unichar{1488}}%
\uc@dclc{64290}{autogenerated}{\unichar{1491}}%
\uc@dclc{64291}{autogenerated}{\unichar{1492}}%
\uc@dclc{64292}{autogenerated}{\unichar{1499}}%
\uc@dclc{64293}{autogenerated}{\unichar{1500}}%
\uc@dclc{64294}{autogenerated}{\unichar{1501}}%
\uc@dclc{64295}{autogenerated}{\unichar{1512}}%
\uc@dclc{64296}{autogenerated}{\unichar{1514}}%
\uc@dclc{64297}{autogenerated}{\unichar{43}}%
\uc@dclc{64298}{default}{\shindot\hebshin}%
\uc@dclc{64299}{default}{\sindot\hebshin}%
\uc@dclc{64300}{default}{\shindot{\dagesh\hebshin}}%
\uc@dclc{64301}{default}{\sindot{\dagesh\hebshin}}%
\uc@dclc{64302}{default}{\patah\hebalef}%
\uc@dclc{64303}{default}{\qamats\hebalef}%
\uc@dclc{64304}{default}{\dagesh\hebalef}%
\uc@dclc{64305}{default}{\dagesh\hebbet}%
\uc@dclc{64306}{default}{\dagesh\hebgimel}%
\uc@dclc{64307}{default}{\dagesh\hebdalet}%
\uc@dclc{64308}{default}{\dagesh\hebhe}%
\uc@dclc{64309}{default}{\dagesh\hebvav}%
\uc@dclc{64310}{default}{\dagesh\hebzayin}%
\uc@dclc{64312}{default}{\dagesh\hebtet}%
\uc@dclc{64313}{default}{\dagesh\hebyod}%
\uc@dclc{64314}{default}{\dagesh\hebfinalkaf}%
\uc@dclc{64315}{default}{\dagesh\hebkaf}%
\uc@dclc{64316}{default}{\dagesh\heblamed}%
\uc@dclc{64318}{default}{\dagesh\hebmem}%
\uc@dclc{64320}{default}{\dagesh\hebnun}%
\uc@dclc{64321}{default}{\dagesh\hebsamekh}%
\uc@dclc{64323}{default}{\dagesh\hebfinalpe}%
\uc@dclc{64324}{default}{\dagesh\hebpe}%
\uc@dclc{64326}{default}{\dagesh\hebtsadi}%
\uc@dclc{64327}{default}{\dagesh\hebqof}%
\uc@dclc{64328}{default}{\dagesh\hebresh}%
\uc@dclc{64329}{default}{\dagesh\hebshin}%
\uc@dclc{64330}{default}{\dagesh\hebtav}%
\uc@dclc{64331}{default}{\holam\hebvav}%
\uc@dclc{64332}{default}{\rafe\hebbet}%
\uc@dclc{64333}{default}{\rafe\hebkaf}%
\uc@dclc{64334}{default}{\rafe\hebpe}%
\uc@dclc{64335}{autogenerated}{\unichar{1488}\unichar{1500}}%
%%% Local Variables: 
%%% mode: latex
%%% coding: utf-8
%%% End: 
