%%% Unicode to TeX mapping, file uni-470.def, U+1D600..U+1D6FF, autogenerated by makeunidef.pl
\ifx\ProvidesFile\undefined\else
\ProvidesFile{uni-470.def}[2022/08/07 UCS: Unicode data U+1D600..U+1D6FF]%
\fi
\uc@dclc{120320}{autogenerated}{\unichar{115}}%
\uc@dclc{120321}{autogenerated}{\unichar{116}}%
\uc@dclc{120322}{autogenerated}{\unichar{117}}%
\uc@dclc{120323}{autogenerated}{\unichar{118}}%
\uc@dclc{120324}{autogenerated}{\unichar{119}}%
\uc@dclc{120325}{autogenerated}{\unichar{120}}%
\uc@dclc{120326}{autogenerated}{\unichar{121}}%
\uc@dclc{120327}{autogenerated}{\unichar{122}}%
\uc@dclc{120328}{autogenerated}{\unichar{65}}%
\uc@dclc{120329}{autogenerated}{\unichar{66}}%
\uc@dclc{120330}{autogenerated}{\unichar{67}}%
\uc@dclc{120331}{autogenerated}{\unichar{68}}%
\uc@dclc{120332}{autogenerated}{\unichar{69}}%
\uc@dclc{120333}{autogenerated}{\unichar{70}}%
\uc@dclc{120334}{autogenerated}{\unichar{71}}%
\uc@dclc{120335}{autogenerated}{\unichar{72}}%
\uc@dclc{120336}{autogenerated}{\unichar{73}}%
\uc@dclc{120337}{autogenerated}{\unichar{74}}%
\uc@dclc{120338}{autogenerated}{\unichar{75}}%
\uc@dclc{120339}{autogenerated}{\unichar{76}}%
\uc@dclc{120340}{autogenerated}{\unichar{77}}%
\uc@dclc{120341}{autogenerated}{\unichar{78}}%
\uc@dclc{120342}{autogenerated}{\unichar{79}}%
\uc@dclc{120343}{autogenerated}{\unichar{80}}%
\uc@dclc{120344}{autogenerated}{\unichar{81}}%
\uc@dclc{120345}{autogenerated}{\unichar{82}}%
\uc@dclc{120346}{autogenerated}{\unichar{83}}%
\uc@dclc{120347}{autogenerated}{\unichar{84}}%
\uc@dclc{120348}{autogenerated}{\unichar{85}}%
\uc@dclc{120349}{autogenerated}{\unichar{86}}%
\uc@dclc{120350}{autogenerated}{\unichar{87}}%
\uc@dclc{120351}{autogenerated}{\unichar{88}}%
\uc@dclc{120352}{autogenerated}{\unichar{89}}%
\uc@dclc{120353}{autogenerated}{\unichar{90}}%
\uc@dclc{120354}{autogenerated}{\unichar{97}}%
\uc@dclc{120355}{autogenerated}{\unichar{98}}%
\uc@dclc{120356}{autogenerated}{\unichar{99}}%
\uc@dclc{120357}{autogenerated}{\unichar{100}}%
\uc@dclc{120358}{autogenerated}{\unichar{101}}%
\uc@dclc{120359}{autogenerated}{\unichar{102}}%
\uc@dclc{120360}{autogenerated}{\unichar{103}}%
\uc@dclc{120361}{autogenerated}{\unichar{104}}%
\uc@dclc{120362}{autogenerated}{\unichar{105}}%
\uc@dclc{120363}{autogenerated}{\unichar{106}}%
\uc@dclc{120364}{autogenerated}{\unichar{107}}%
\uc@dclc{120365}{autogenerated}{\unichar{108}}%
\uc@dclc{120366}{autogenerated}{\unichar{109}}%
\uc@dclc{120367}{autogenerated}{\unichar{110}}%
\uc@dclc{120368}{autogenerated}{\unichar{111}}%
\uc@dclc{120369}{autogenerated}{\unichar{112}}%
\uc@dclc{120370}{autogenerated}{\unichar{113}}%
\uc@dclc{120371}{autogenerated}{\unichar{114}}%
\uc@dclc{120372}{autogenerated}{\unichar{115}}%
\uc@dclc{120373}{autogenerated}{\unichar{116}}%
\uc@dclc{120374}{autogenerated}{\unichar{117}}%
\uc@dclc{120375}{autogenerated}{\unichar{118}}%
\uc@dclc{120376}{autogenerated}{\unichar{119}}%
\uc@dclc{120377}{autogenerated}{\unichar{120}}%
\uc@dclc{120378}{autogenerated}{\unichar{121}}%
\uc@dclc{120379}{autogenerated}{\unichar{122}}%
\uc@dclc{120380}{autogenerated}{\unichar{65}}%
\uc@dclc{120381}{autogenerated}{\unichar{66}}%
\uc@dclc{120382}{autogenerated}{\unichar{67}}%
\uc@dclc{120383}{autogenerated}{\unichar{68}}%
\uc@dclc{120384}{autogenerated}{\unichar{69}}%
\uc@dclc{120385}{autogenerated}{\unichar{70}}%
\uc@dclc{120386}{autogenerated}{\unichar{71}}%
\uc@dclc{120387}{autogenerated}{\unichar{72}}%
\uc@dclc{120388}{autogenerated}{\unichar{73}}%
\uc@dclc{120389}{autogenerated}{\unichar{74}}%
\uc@dclc{120390}{autogenerated}{\unichar{75}}%
\uc@dclc{120391}{autogenerated}{\unichar{76}}%
\uc@dclc{120392}{autogenerated}{\unichar{77}}%
\uc@dclc{120393}{autogenerated}{\unichar{78}}%
\uc@dclc{120394}{autogenerated}{\unichar{79}}%
\uc@dclc{120395}{autogenerated}{\unichar{80}}%
\uc@dclc{120396}{autogenerated}{\unichar{81}}%
\uc@dclc{120397}{autogenerated}{\unichar{82}}%
\uc@dclc{120398}{autogenerated}{\unichar{83}}%
\uc@dclc{120399}{autogenerated}{\unichar{84}}%
\uc@dclc{120400}{autogenerated}{\unichar{85}}%
\uc@dclc{120401}{autogenerated}{\unichar{86}}%
\uc@dclc{120402}{autogenerated}{\unichar{87}}%
\uc@dclc{120403}{autogenerated}{\unichar{88}}%
\uc@dclc{120404}{autogenerated}{\unichar{89}}%
\uc@dclc{120405}{autogenerated}{\unichar{90}}%
\uc@dclc{120406}{autogenerated}{\unichar{97}}%
\uc@dclc{120407}{autogenerated}{\unichar{98}}%
\uc@dclc{120408}{autogenerated}{\unichar{99}}%
\uc@dclc{120409}{autogenerated}{\unichar{100}}%
\uc@dclc{120410}{autogenerated}{\unichar{101}}%
\uc@dclc{120411}{autogenerated}{\unichar{102}}%
\uc@dclc{120412}{autogenerated}{\unichar{103}}%
\uc@dclc{120413}{autogenerated}{\unichar{104}}%
\uc@dclc{120414}{autogenerated}{\unichar{105}}%
\uc@dclc{120415}{autogenerated}{\unichar{106}}%
\uc@dclc{120416}{autogenerated}{\unichar{107}}%
\uc@dclc{120417}{autogenerated}{\unichar{108}}%
\uc@dclc{120418}{autogenerated}{\unichar{109}}%
\uc@dclc{120419}{autogenerated}{\unichar{110}}%
\uc@dclc{120420}{autogenerated}{\unichar{111}}%
\uc@dclc{120421}{autogenerated}{\unichar{112}}%
\uc@dclc{120422}{autogenerated}{\unichar{113}}%
\uc@dclc{120423}{autogenerated}{\unichar{114}}%
\uc@dclc{120424}{autogenerated}{\unichar{115}}%
\uc@dclc{120425}{autogenerated}{\unichar{116}}%
\uc@dclc{120426}{autogenerated}{\unichar{117}}%
\uc@dclc{120427}{autogenerated}{\unichar{118}}%
\uc@dclc{120428}{autogenerated}{\unichar{119}}%
\uc@dclc{120429}{autogenerated}{\unichar{120}}%
\uc@dclc{120430}{autogenerated}{\unichar{121}}%
\uc@dclc{120431}{autogenerated}{\unichar{122}}%
\uc@dclc{120432}{default}{\ensuremath{\mathtt A}}%
\uc@dclc{120433}{default}{\ensuremath{\mathtt B}}%
\uc@dclc{120434}{default}{\ensuremath{\mathtt C}}%
\uc@dclc{120435}{default}{\ensuremath{\mathtt D}}%
\uc@dclc{120436}{default}{\ensuremath{\mathtt E}}%
\uc@dclc{120437}{default}{\ensuremath{\mathtt F}}%
\uc@dclc{120438}{default}{\ensuremath{\mathtt G}}%
\uc@dclc{120439}{default}{\ensuremath{\mathtt H}}%
\uc@dclc{120440}{default}{\ensuremath{\mathtt I}}%
\uc@dclc{120441}{default}{\ensuremath{\mathtt J}}%
\uc@dclc{120442}{default}{\ensuremath{\mathtt K}}%
\uc@dclc{120443}{default}{\ensuremath{\mathtt L}}%
\uc@dclc{120444}{default}{\ensuremath{\mathtt M}}%
\uc@dclc{120445}{default}{\ensuremath{\mathtt N}}%
\uc@dclc{120446}{default}{\ensuremath{\mathtt O}}%
\uc@dclc{120447}{default}{\ensuremath{\mathtt P}}%
\uc@dclc{120448}{default}{\ensuremath{\mathtt Q}}%
\uc@dclc{120449}{default}{\ensuremath{\mathtt R}}%
\uc@dclc{120450}{default}{\ensuremath{\mathtt S}}%
\uc@dclc{120451}{default}{\ensuremath{\mathtt T}}%
\uc@dclc{120452}{default}{\ensuremath{\mathtt U}}%
\uc@dclc{120453}{default}{\ensuremath{\mathtt V}}%
\uc@dclc{120454}{default}{\ensuremath{\mathtt W}}%
\uc@dclc{120455}{default}{\ensuremath{\mathtt X}}%
\uc@dclc{120456}{default}{\ensuremath{\mathtt Y}}%
\uc@dclc{120457}{default}{\ensuremath{\mathtt Z}}%
\uc@dclc{120458}{default}{\ensuremath{\mathtt a}}%
\uc@dclc{120459}{default}{\ensuremath{\mathtt b}}%
\uc@dclc{120460}{default}{\ensuremath{\mathtt c}}%
\uc@dclc{120461}{default}{\ensuremath{\mathtt d}}%
\uc@dclc{120462}{default}{\ensuremath{\mathtt e}}%
\uc@dclc{120463}{default}{\ensuremath{\mathtt f}}%
\uc@dclc{120464}{default}{\ensuremath{\mathtt g}}%
\uc@dclc{120465}{default}{\ensuremath{\mathtt h}}%
\uc@dclc{120466}{default}{\ensuremath{\mathtt i}}%
\uc@dclc{120467}{default}{\ensuremath{\mathtt j}}%
\uc@dclc{120468}{default}{\ensuremath{\mathtt k}}%
\uc@dclc{120469}{default}{\ensuremath{\mathtt l}}%
\uc@dclc{120470}{default}{\ensuremath{\mathtt m}}%
\uc@dclc{120471}{default}{\ensuremath{\mathtt n}}%
\uc@dclc{120472}{default}{\ensuremath{\mathtt o}}%
\uc@dclc{120473}{default}{\ensuremath{\mathtt p}}%
\uc@dclc{120474}{default}{\ensuremath{\mathtt q}}%
\uc@dclc{120475}{default}{\ensuremath{\mathtt r}}%
\uc@dclc{120476}{default}{\ensuremath{\mathtt s}}%
\uc@dclc{120477}{default}{\ensuremath{\mathtt t}}%
\uc@dclc{120478}{default}{\ensuremath{\mathtt u}}%
\uc@dclc{120479}{default}{\ensuremath{\mathtt v}}%
\uc@dclc{120480}{default}{\ensuremath{\mathtt w}}%
\uc@dclc{120481}{default}{\ensuremath{\mathtt x}}%
\uc@dclc{120482}{default}{\ensuremath{\mathtt y}}%
\uc@dclc{120483}{default}{\ensuremath{\mathtt z}}%
\uc@dclc{120484}{autogenerated}{\unichar{305}}%
\uc@dclc{120488}{autogenerated}{\unichar{913}}%
\uc@dclc{120489}{autogenerated}{\unichar{914}}%
\uc@dclc{120490}{autogenerated}{\unichar{915}}%
\uc@dclc{120491}{autogenerated}{\unichar{916}}%
\uc@dclc{120492}{autogenerated}{\unichar{917}}%
\uc@dclc{120493}{autogenerated}{\unichar{918}}%
\uc@dclc{120494}{autogenerated}{\unichar{919}}%
\uc@dclc{120495}{autogenerated}{\unichar{920}}%
\uc@dclc{120496}{autogenerated}{\unichar{921}}%
\uc@dclc{120497}{autogenerated}{\unichar{922}}%
\uc@dclc{120498}{autogenerated}{\unichar{923}}%
\uc@dclc{120499}{autogenerated}{\unichar{924}}%
\uc@dclc{120500}{autogenerated}{\unichar{925}}%
\uc@dclc{120501}{autogenerated}{\unichar{926}}%
\uc@dclc{120502}{autogenerated}{\unichar{927}}%
\uc@dclc{120503}{autogenerated}{\unichar{928}}%
\uc@dclc{120504}{autogenerated}{\unichar{929}}%
\uc@dclc{120505}{autogenerated}{\unichar{1012}}%
\uc@dclc{120506}{autogenerated}{\unichar{931}}%
\uc@dclc{120507}{autogenerated}{\unichar{932}}%
\uc@dclc{120508}{autogenerated}{\unichar{933}}%
\uc@dclc{120509}{autogenerated}{\unichar{934}}%
\uc@dclc{120510}{autogenerated}{\unichar{935}}%
\uc@dclc{120511}{autogenerated}{\unichar{936}}%
\uc@dclc{120512}{autogenerated}{\unichar{937}}%
\uc@dclc{120513}{autogenerated}{\unichar{8711}}%
\uc@dclc{120514}{autogenerated}{\unichar{945}}%
\uc@dclc{120515}{autogenerated}{\unichar{946}}%
\uc@dclc{120516}{autogenerated}{\unichar{947}}%
\uc@dclc{120517}{autogenerated}{\unichar{948}}%
\uc@dclc{120518}{autogenerated}{\unichar{949}}%
\uc@dclc{120519}{autogenerated}{\unichar{950}}%
\uc@dclc{120520}{autogenerated}{\unichar{951}}%
\uc@dclc{120521}{autogenerated}{\unichar{952}}%
\uc@dclc{120522}{autogenerated}{\unichar{953}}%
\uc@dclc{120523}{autogenerated}{\unichar{954}}%
\uc@dclc{120524}{autogenerated}{\unichar{955}}%
\uc@dclc{120525}{autogenerated}{\unichar{956}}%
\uc@dclc{120526}{autogenerated}{\unichar{957}}%
\uc@dclc{120527}{autogenerated}{\unichar{958}}%
\uc@dclc{120528}{autogenerated}{\unichar{959}}%
\uc@dclc{120529}{autogenerated}{\unichar{960}}%
\uc@dclc{120530}{autogenerated}{\unichar{961}}%
\uc@dclc{120531}{autogenerated}{\unichar{962}}%
\uc@dclc{120532}{autogenerated}{\unichar{963}}%
\uc@dclc{120533}{autogenerated}{\unichar{964}}%
\uc@dclc{120534}{autogenerated}{\unichar{965}}%
\uc@dclc{120535}{autogenerated}{\unichar{966}}%
\uc@dclc{120536}{autogenerated}{\unichar{967}}%
\uc@dclc{120537}{autogenerated}{\unichar{968}}%
\uc@dclc{120538}{autogenerated}{\unichar{969}}%
\uc@dclc{120539}{autogenerated}{\unichar{8706}}%
\uc@dclc{120540}{autogenerated}{\unichar{1013}}%
\uc@dclc{120541}{autogenerated}{\unichar{977}}%
\uc@dclc{120542}{autogenerated}{\unichar{1008}}%
\uc@dclc{120543}{autogenerated}{\unichar{981}}%
\uc@dclc{120544}{autogenerated}{\unichar{1009}}%
\uc@dclc{120545}{autogenerated}{\unichar{982}}%
\uc@dclc{120546}{autogenerated}{\unichar{913}}%
\uc@dclc{120547}{autogenerated}{\unichar{914}}%
\uc@dclc{120548}{autogenerated}{\unichar{915}}%
\uc@dclc{120549}{autogenerated}{\unichar{916}}%
\uc@dclc{120550}{autogenerated}{\unichar{917}}%
\uc@dclc{120551}{autogenerated}{\unichar{918}}%
\uc@dclc{120552}{autogenerated}{\unichar{919}}%
\uc@dclc{120553}{autogenerated}{\unichar{920}}%
\uc@dclc{120554}{autogenerated}{\unichar{921}}%
\uc@dclc{120555}{autogenerated}{\unichar{922}}%
\uc@dclc{120556}{autogenerated}{\unichar{923}}%
\uc@dclc{120557}{autogenerated}{\unichar{924}}%
\uc@dclc{120558}{autogenerated}{\unichar{925}}%
\uc@dclc{120559}{autogenerated}{\unichar{926}}%
\uc@dclc{120560}{autogenerated}{\unichar{927}}%
\uc@dclc{120561}{autogenerated}{\unichar{928}}%
\uc@dclc{120562}{autogenerated}{\unichar{929}}%
\uc@dclc{120563}{autogenerated}{\unichar{1012}}%
\uc@dclc{120564}{autogenerated}{\unichar{931}}%
\uc@dclc{120565}{autogenerated}{\unichar{932}}%
\uc@dclc{120566}{autogenerated}{\unichar{933}}%
\uc@dclc{120567}{autogenerated}{\unichar{934}}%
\uc@dclc{120568}{autogenerated}{\unichar{935}}%
\uc@dclc{120569}{autogenerated}{\unichar{936}}%
\uc@dclc{120570}{autogenerated}{\unichar{937}}%
\uc@dclc{120571}{autogenerated}{\unichar{8711}}%
\uc@dclc{120572}{autogenerated}{\unichar{945}}%
\uc@dclc{120573}{autogenerated}{\unichar{946}}%
\uc@dclc{120574}{autogenerated}{\unichar{947}}%
\uc@dclc{120575}{autogenerated}{\unichar{948}}%
%%% Local Variables: 
%%% mode: latex
%%% coding: utf-8
%%% End: 
