%%
%% This is file `cp1257.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% inputenc.dtx  (with options: `cp1257')
%% 
%% This is a generated file.
%% 
%% The source is maintained by the LaTeX Project team and bug
%% reports for it can be opened at https://latex-project.org/bugs.html
%% (but please observe conditions on bug reports sent to that address!)
%% 
%% 
%% Copyright (C) 1993-2025
%% The LaTeX Project and any individual authors listed elsewhere
%% in this file.
%% 
%% This file was generated from file(s) of the LaTeX base system.
%% --------------------------------------------------------------
%% 
%% It may be distributed and/or modified under the
%% conditions of the LaTeX Project Public License, either version 1.3c
%% of this license or (at your option) any later version.
%% The latest version of this license is in
%%    https://www.latex-project.org/lppl.txt
%% and version 1.3c or later is part of all distributions of LaTeX
%% version 2008 or later.
%% 
%% This file has the LPPL maintenance status "maintained".
%% 
%% This file may only be distributed together with a copy of the LaTeX
%% base system. You may however distribute the LaTeX base system without
%% such generated files.
%% 
%% The list of all files belonging to the LaTeX base distribution is
%% given in the file `manifest.txt'. See also `legal.txt' for additional
%% information.
%% 
%% The list of derived (unpacked) files belonging to the distribution
%% and covered by LPPL is defined by the unpacking scripts (with
%% extension .ins) which are part of the distribution.

  \ProvidesFile{cp1257.def}
   [2024/02/08 v1.3d Input encoding file]
\ProvideTextCommandDefault{\textdegree}{\ensuremath{{^\circ}}}
\ProvideTextCommandDefault{\textonehalf}{\ensuremath{\frac12}}
\ProvideTextCommandDefault{\textonequarter}{\ensuremath{\frac14}}
\ProvideTextCommandDefault{\textthreequarters}{\ensuremath{\frac34}}
\ProvideTextCommandDefault{\textcent}
   {\TextSymbolUnavailable\textcent}
\ProvideTextCommandDefault{\texteuro}
   {\TextSymbolUnavailable\texteuro}
\ProvideTextCommandDefault{\textcurrency}
   {\TextSymbolUnavailable\textcurrency}
\ProvideTextCommandDefault{\textbrokenbar}
   {\TextSymbolUnavailable\textbrokenbar}
\ProvideTextCommandDefault{\textperthousand}
   {\TextSymbolUnavailable\textperthousand}
\providecommand{\mathonesuperior}{{^1}}
\providecommand{\maththreesuperior}{{^3}}
\providecommand{\mathtwosuperior}{{^2}}
\DeclareInputText{128}{\texteuro}
\DeclareInputText{130}{\quotesinglbase}
\DeclareInputText{132}{\quotedblbase}
\DeclareInputText{133}{\dots}
\DeclareInputText{134}{\dag}
\DeclareInputText{135}{\ddag}
\DeclareInputText{137}{\textperthousand}
\DeclareInputText{139}{\guilsinglleft}
\DeclareInputText{141}{\"{}}
\DeclareInputText{142}{\v{}}
\DeclareInputText{143}{\c\ }
\DeclareInputText{145}{\textquoteleft}
\DeclareInputText{146}{\textquoteright}
\DeclareInputText{147}{\textquotedblleft}
\DeclareInputText{148}{\textquotedblright}
\DeclareInputText{149}{\textbullet}
\DeclareInputText{150}{\textendash}
\DeclareInputText{151}{\textemdash}
\DeclareInputText{153}{\texttrademark}
\DeclareInputText{155}{\guilsinglright}
\DeclareInputText{157}{\@tabacckludge={}}
\DeclareInputText{158}{\k\ }
\DeclareInputText{160}{\nobreakspace}
\DeclareInputText{162}{\textcent}
\DeclareInputText{163}{\pounds}
\DeclareInputText{164}{\textcurrency}
\DeclareInputText{166}{\textbrokenbar}
\DeclareInputText{167}{\S}
\DeclareInputText{168}{\O}
\DeclareInputText{169}{\copyright}
\DeclareInputText{170}{\c R}
\DeclareInputText{171}{\guillemetleft}
\DeclareInputMath{172}{\lnot}
\DeclareInputText{173}{\-}
\DeclareInputText{174}{\textregistered}
\DeclareInputText{175}{\AE}
\DeclareInputText{176}{\textdegree}
\DeclareInputMath{177}{\pm}
\DeclareInputMath{178}{\mathtwosuperior}
\DeclareInputMath{179}{\maththreesuperior}
\DeclareInputText{180}{\@tabacckludge'{}}
\DeclareInputMath{181}{\mu}
\DeclareInputText{182}{\P}
\DeclareInputText{183}{\textperiodcentered}
\DeclareInputText{184}{\o}
\DeclareInputMath{185}{\mathonesuperior}
\DeclareInputText{186}{\c r}
\DeclareInputText{187}{\guillemetright}
\DeclareInputText{188}{\textonequarter}
\DeclareInputText{189}{\textonehalf}
\DeclareInputText{190}{\textthreequarters}
\DeclareInputText{191}{\ae}
\DeclareInputText{192}{\k A}
\DeclareInputText{193}{\k I}
\DeclareInputText{194}{\@tabacckludge=A}
\DeclareInputText{195}{\@tabacckludge'C}
\DeclareInputText{196}{\"A}
\DeclareInputText{197}{\r A}
\DeclareInputText{198}{\k E}
\DeclareInputText{199}{\@tabacckludge=E}
\DeclareInputText{200}{\v C}
\DeclareInputText{201}{\@tabacckludge'E}
\DeclareInputText{202}{\@tabacckludge'Z}
\DeclareInputText{203}{\.{E}}
\DeclareInputText{204}{\c G}
\DeclareInputText{205}{\c K}
\DeclareInputText{206}{\@tabacckludge=I}
\DeclareInputText{207}{\c L}
\DeclareInputText{208}{\v S}
\DeclareInputText{209}{\@tabacckludge'N}
\DeclareInputText{210}{\c N}
\DeclareInputText{211}{\@tabacckludge'O}
\DeclareInputText{212}{\@tabacckludge=O}
\DeclareInputText{213}{\~O}
\DeclareInputText{214}{\"O}
\DeclareInputMath{215}{\times}
\DeclareInputText{216}{\k U}
\DeclareInputText{217}{\L}
\DeclareInputText{218}{\@tabacckludge'S}
\DeclareInputText{219}{\@tabacckludge=U}
\DeclareInputText{220}{\"U}
\DeclareInputText{221}{\.Z}
\DeclareInputText{222}{\v Z}
\DeclareInputText{223}{\ss}
\DeclareInputText{224}{\k a}
\DeclareInputText{225}{\k i}
\DeclareInputText{226}{\@tabacckludge=a}
\DeclareInputText{227}{\@tabacckludge'c}
\DeclareInputText{228}{\"a}
\DeclareInputText{229}{\r a}
\DeclareInputText{230}{\k e}
\DeclareInputText{231}{\@tabacckludge=e}
\DeclareInputText{232}{\v c}
\DeclareInputText{233}{\@tabacckludge'e}
\DeclareInputText{234}{\@tabacckludge'z}
\DeclareInputText{235}{\.{e}}
\DeclareInputText{236}{\c g}
\DeclareInputText{237}{\c k}
\DeclareInputText{238}{\@tabacckludge=\i}
\DeclareInputText{239}{\c l}
\DeclareInputText{240}{\v s}
\DeclareInputText{241}{\@tabacckludge'n}
\DeclareInputText{242}{\c n}
\DeclareInputText{243}{\@tabacckludge'o}
\DeclareInputText{244}{\@tabacckludge=o}
\DeclareInputText{245}{\~o}
\DeclareInputText{246}{\"o}
\DeclareInputMath{247}{\div}
\DeclareInputText{248}{\k u}
\DeclareInputText{249}{\l}
\DeclareInputText{250}{\@tabacckludge's}
\DeclareInputText{251}{\@tabacckludge=u}
\DeclareInputText{252}{\"u}
\DeclareInputText{253}{\.z}
\DeclareInputText{254}{\v z}
\DeclareInputText{255}{\.{}}
\endinput
%%
%% End of file `cp1257.def'.
