%!TEX encoding = UTF-8 Unicode
%
% Translation completed on 01/03/2020
\ProvidesFile{ecvfi.def}[europecv Finnish definitions]
% Personal information
\def\ecv@infosectionkey{\ecv@utf{Henkil\"otiedot}}
\def\ecv@datekey{\ecv@utf{Päivitetty}}
\def\ecv@namekey{\ecv@utf{Etunimet~/ Suku-~ja}}
\def\ecv@addresskey{\ecv@utf{Osoitteet}}
\def\ecv@telkey{\ecv@utf{Puhelinnumero(t)}}
\def\ecv@mobilekey{\ecv@utf{Matkapuhelin}}
\def\ecv@faxkey{\ecv@utf{Fax}}
\def\ecv@officekey{\ecv@utf{Toimisto}}
\def\ecv@emailkey{\ecv@utf{S\"ahk\"oposti(t)}}
\def\ecv@professionalkey{\ecv@utf{Ammatillinen Sähköposti}}
\def\ecv@skypekey{\ecv@utf{Skype}}
\def\ecv@matrixriotkey{\ecv@utf{Matrix/Riot}}
\def\ecv@youtubekey{\ecv@utf{YouTube}}
\def\ecv@peckey{\ecv@utf{PEC}}
\def\ecv@homepagekey{\ecv@utf{Home page}}
\def\ecv@nationalitykey{\ecv@utf{Kansalaisuus}}
\def\ecv@birthkey{\ecv@utf{Syntym\"aaika}}
\def\ecv@genderkey{\ecv@utf{Sukupuoli}}
% Footer
\def\ecv@pagekey{\ecv@utf{Sivu}}
\def\ecv@cvofkey{\ecv@utf{Ansioluettelo}}
% Language table
\def\ecv@mothertonguekey{\ecv@utf{\"Aidinkieli}}
\def\ecv@assesskey{\ecv@utf{Itsearviointi}}
\def\ecv@levelkey{\ecv@utf{Eurooppalainen taitotaso}}
\def\ecv@understandkey{\ecv@utf{Ymm\"art\"aminen}}
\def\ecv@speakkey{\ecv@utf{Puhuminen}}
\def\ecv@writekey{\ecv@utf{Kirjoittaminen}}
\def\ecv@listenkey{\ecv@utf{Kuuntelu}}
\def\ecv@readkey{\ecv@utf{Lukeminen}}
\def\ecv@interactkey{\ecv@utf{Suullinen vuorovaikutus}}
\def\ecv@productkey{\ecv@utf{Suullinen tuottaminen}}
\def\ecv@langfooterkey{\ecv@utf{Kieli\"a koskeva yhteinen eurooppalainen viitekehys}}
\def\ecv@cefbasickey{\ecv@utf{Peruskielitaito}}
\def\ecv@cefindepkey{\ecv@utf{Itsen\"aisen kielenk\"aytt\"aj\"an kielitaito}}
\def\ecv@cefprofkey{\ecv@utf{Taitavan kielenk\"aytt\"aj\"an kielitaito}}

\renewcommand*{\ecvbranding}{\ecv@utf{\Large\textbf{E\ecv@kern u\ecv@kern
r\ecv@kern o\ecv@kern p\ecv@kern a\ecv@kern s\ecv@kern s}\\[5pt]}}
\renewcommand*\ecvtitle{\ecvbranding\ecv@utf{
\Large\textbf{a\ecv@kern n\ecv@kern s\ecv@kern i\ecv@kern
o\ecv@kern l\ecv@kern u\ecv@kern e\ecv@kern t\ecv@kern t\ecv@kern
e\ecv@kern l\ecv@kern o\ecv@kern m\ecv@kern a\ecv@kern l\ecv@kern
l\ecv@kern i}}}
