%%% Unicode to TeX mapping, file uni-18.def, U+1200..U+12FF, autogenerated by makeunidef.pl
\ifx\ProvidesFile\undefined\else
\ProvidesFile{uni-18.def}[2022/08/07 UCS: Unicode data U+1200..U+12FF]%
\fi
\uc@dclc{4608}{default}{\textethiopicha}%
\uc@dclc{4609}{default}{\textethiopichu}%
\uc@dclc{4610}{default}{\textethiopichi}%
\uc@dclc{4611}{default}{\textethiopichaa}%
\uc@dclc{4612}{default}{\textethiopichee}%
\uc@dclc{4613}{default}{\textethiopiche}%
\uc@dclc{4614}{default}{\textethiopicho}%
\uc@dclc{4616}{default}{\textethiopicla}%
\uc@dclc{4617}{default}{\textethiopiclu}%
\uc@dclc{4618}{default}{\textethiopicli}%
\uc@dclc{4619}{default}{\textethiopiclaa}%
\uc@dclc{4620}{default}{\textethiopiclee}%
\uc@dclc{4621}{default}{\textethiopicle}%
\uc@dclc{4622}{default}{\textethiopiclo}%
\uc@dclc{4623}{default}{\textethiopiclwa}%
\uc@dclc{4624}{default}{\textethiopichha}%
\uc@dclc{4625}{default}{\textethiopichhu}%
\uc@dclc{4626}{default}{\textethiopichhi}%
\uc@dclc{4627}{default}{\textethiopichhaa}%
\uc@dclc{4628}{default}{\textethiopichhee}%
\uc@dclc{4629}{default}{\textethiopichhe}%
\uc@dclc{4630}{default}{\textethiopichho}%
\uc@dclc{4631}{default}{\textethiopichhwa}%
\uc@dclc{4632}{default}{\textethiopicma}%
\uc@dclc{4633}{default}{\textethiopicmu}%
\uc@dclc{4634}{default}{\textethiopicmi}%
\uc@dclc{4635}{default}{\textethiopicmaa}%
\uc@dclc{4636}{default}{\textethiopicmee}%
\uc@dclc{4637}{default}{\textethiopicme}%
\uc@dclc{4638}{default}{\textethiopicmo}%
\uc@dclc{4639}{default}{\textethiopicmwa}%
\uc@dclc{4640}{default}{\textethiopicsza}%
\uc@dclc{4641}{default}{\textethiopicszu}%
\uc@dclc{4642}{default}{\textethiopicszi}%
\uc@dclc{4643}{default}{\textethiopicszaa}%
\uc@dclc{4644}{default}{\textethiopicszee}%
\uc@dclc{4645}{default}{\textethiopicsze}%
\uc@dclc{4646}{default}{\textethiopicszo}%
\uc@dclc{4647}{default}{\textethiopicszwa}%
\uc@dclc{4648}{default}{\textethiopicra}%
\uc@dclc{4649}{default}{\textethiopicru}%
\uc@dclc{4650}{default}{\textethiopicri}%
\uc@dclc{4651}{default}{\textethiopicraa}%
\uc@dclc{4652}{default}{\textethiopicree}%
\uc@dclc{4653}{default}{\textethiopicre}%
\uc@dclc{4654}{default}{\textethiopicro}%
\uc@dclc{4655}{default}{\textethiopicrwa}%
\uc@dclc{4656}{default}{\textethiopicsa}%
\uc@dclc{4657}{default}{\textethiopicsu}%
\uc@dclc{4658}{default}{\textethiopicsi}%
\uc@dclc{4659}{default}{\textethiopicsaa}%
\uc@dclc{4660}{default}{\textethiopicsee}%
\uc@dclc{4661}{default}{\textethiopicse}%
\uc@dclc{4662}{default}{\textethiopicso}%
\uc@dclc{4663}{default}{\textethiopicswa}%
\uc@dclc{4664}{default}{\textethiopicsha}%
\uc@dclc{4665}{default}{\textethiopicshu}%
\uc@dclc{4666}{default}{\textethiopicshi}%
\uc@dclc{4667}{default}{\textethiopicshaa}%
\uc@dclc{4668}{default}{\textethiopicshee}%
\uc@dclc{4669}{default}{\textethiopicshe}%
\uc@dclc{4670}{default}{\textethiopicsho}%
\uc@dclc{4671}{default}{\textethiopicshwa}%
\uc@dclc{4672}{default}{\textethiopicqa}%
\uc@dclc{4673}{default}{\textethiopicqu}%
\uc@dclc{4674}{default}{\textethiopicqi}%
\uc@dclc{4675}{default}{\textethiopicqaa}%
\uc@dclc{4676}{default}{\textethiopicqee}%
\uc@dclc{4677}{default}{\textethiopicqe}%
\uc@dclc{4678}{default}{\textethiopicqo}%
\uc@dclc{4680}{default}{\textethiopicqwa}%
\uc@dclc{4682}{default}{\textethiopicqwi}%
\uc@dclc{4683}{default}{\textethiopicqwaa}%
\uc@dclc{4684}{default}{\textethiopicqwee}%
\uc@dclc{4685}{default}{\textethiopicqwe}%
\uc@dclc{4688}{default}{\textethiopicqha}%
\uc@dclc{4689}{default}{\textethiopicqhu}%
\uc@dclc{4690}{default}{\textethiopicqhi}%
\uc@dclc{4691}{default}{\textethiopicqhaa}%
\uc@dclc{4692}{default}{\textethiopicqhee}%
\uc@dclc{4693}{default}{\textethiopicqhe}%
\uc@dclc{4694}{default}{\textethiopicqho}%
\uc@dclc{4696}{default}{\textethiopicqhwa}%
\uc@dclc{4698}{default}{\textethiopicqhwi}%
\uc@dclc{4699}{default}{\textethiopicqhwaa}%
\uc@dclc{4700}{default}{\textethiopicqhwee}%
\uc@dclc{4701}{default}{\textethiopicqhwe}%
\uc@dclc{4704}{default}{\textethiopicba}%
\uc@dclc{4705}{default}{\textethiopicbu}%
\uc@dclc{4706}{default}{\textethiopicbi}%
\uc@dclc{4707}{default}{\textethiopicbaa}%
\uc@dclc{4708}{default}{\textethiopicbee}%
\uc@dclc{4709}{default}{\textethiopicbe}%
\uc@dclc{4710}{default}{\textethiopicbo}%
\uc@dclc{4711}{default}{\textethiopicbwa}%
\uc@dclc{4712}{default}{\textethiopicva}%
\uc@dclc{4713}{default}{\textethiopicvu}%
\uc@dclc{4714}{default}{\textethiopicvi}%
\uc@dclc{4715}{default}{\textethiopicvaa}%
\uc@dclc{4716}{default}{\textethiopicvee}%
\uc@dclc{4717}{default}{\textethiopicve}%
\uc@dclc{4718}{default}{\textethiopicvo}%
\uc@dclc{4719}{default}{\textethiopicvwa}%
\uc@dclc{4720}{default}{\textethiopicta}%
\uc@dclc{4721}{default}{\textethiopictu}%
\uc@dclc{4722}{default}{\textethiopicti}%
\uc@dclc{4723}{default}{\textethiopictaa}%
\uc@dclc{4724}{default}{\textethiopictee}%
\uc@dclc{4725}{default}{\textethiopicte}%
\uc@dclc{4726}{default}{\textethiopicto}%
\uc@dclc{4727}{default}{\textethiopictwa}%
\uc@dclc{4728}{default}{\textethiopicca}%
\uc@dclc{4729}{default}{\textethiopiccu}%
\uc@dclc{4730}{default}{\textethiopicci}%
\uc@dclc{4731}{default}{\textethiopiccaa}%
\uc@dclc{4732}{default}{\textethiopiccee}%
\uc@dclc{4733}{default}{\textethiopicce}%
\uc@dclc{4734}{default}{\textethiopicco}%
\uc@dclc{4735}{default}{\textethiopiccwa}%
\uc@dclc{4736}{default}{\textethiopicxa}%
\uc@dclc{4737}{default}{\textethiopicxu}%
\uc@dclc{4738}{default}{\textethiopicxi}%
\uc@dclc{4739}{default}{\textethiopicxaa}%
\uc@dclc{4740}{default}{\textethiopicxee}%
\uc@dclc{4741}{default}{\textethiopicxe}%
\uc@dclc{4742}{default}{\textethiopicxo}%
\uc@dclc{4744}{default}{\textethiopicxwa}%
\uc@dclc{4746}{default}{\textethiopicxwi}%
\uc@dclc{4747}{default}{\textethiopicxwaa}%
\uc@dclc{4748}{default}{\textethiopicxwee}%
\uc@dclc{4749}{default}{\textethiopicxwe}%
\uc@dclc{4752}{default}{\textethiopicna}%
\uc@dclc{4753}{default}{\textethiopicnu}%
\uc@dclc{4754}{default}{\textethiopicni}%
\uc@dclc{4755}{default}{\textethiopicnaa}%
\uc@dclc{4756}{default}{\textethiopicnee}%
\uc@dclc{4757}{default}{\textethiopicne}%
\uc@dclc{4758}{default}{\textethiopicno}%
\uc@dclc{4759}{default}{\textethiopicnwa}%
\uc@dclc{4760}{default}{\textethiopicnya}%
\uc@dclc{4761}{default}{\textethiopicnyu}%
\uc@dclc{4762}{default}{\textethiopicnyi}%
\uc@dclc{4763}{default}{\textethiopicnyaa}%
\uc@dclc{4764}{default}{\textethiopicnyee}%
\uc@dclc{4765}{default}{\textethiopicnye}%
\uc@dclc{4766}{default}{\textethiopicnyo}%
\uc@dclc{4767}{default}{\textethiopicnywa}%
\uc@dclc{4768}{default}{\textethiopicglottala}%
\uc@dclc{4769}{default}{\textethiopicglottalu}%
\uc@dclc{4770}{default}{\textethiopicglottali}%
\uc@dclc{4771}{default}{\textethiopicglottalaa}%
\uc@dclc{4772}{default}{\textethiopicglottalee}%
\uc@dclc{4773}{default}{\textethiopicglottale}%
\uc@dclc{4774}{default}{\textethiopicglottalo}%
\uc@dclc{4775}{default}{\textethiopicglottalwa}%
\uc@dclc{4776}{default}{\textethiopicka}%
\uc@dclc{4777}{default}{\textethiopicku}%
\uc@dclc{4778}{default}{\textethiopicki}%
\uc@dclc{4779}{default}{\textethiopickaa}%
\uc@dclc{4780}{default}{\textethiopickee}%
\uc@dclc{4781}{default}{\textethiopicke}%
\uc@dclc{4782}{default}{\textethiopicko}%
\uc@dclc{4784}{default}{\textethiopickwa}%
\uc@dclc{4786}{default}{\textethiopickwi}%
\uc@dclc{4787}{default}{\textethiopickwaa}%
\uc@dclc{4788}{default}{\textethiopickwee}%
\uc@dclc{4789}{default}{\textethiopickwe}%
\uc@dclc{4792}{default}{\textethiopickxa}%
\uc@dclc{4793}{default}{\textethiopickxu}%
\uc@dclc{4794}{default}{\textethiopickxi}%
\uc@dclc{4795}{default}{\textethiopickxaa}%
\uc@dclc{4796}{default}{\textethiopickxee}%
\uc@dclc{4797}{default}{\textethiopickxe}%
\uc@dclc{4798}{default}{\textethiopickxo}%
\uc@dclc{4800}{default}{\textethiopickxwa}%
\uc@dclc{4802}{default}{\textethiopickxwi}%
\uc@dclc{4803}{default}{\textethiopickxwaa}%
\uc@dclc{4804}{default}{\textethiopickxwee}%
\uc@dclc{4805}{default}{\textethiopickxwe}%
\uc@dclc{4808}{default}{\textethiopicwa}%
\uc@dclc{4809}{default}{\textethiopicwu}%
\uc@dclc{4810}{default}{\textethiopicwi}%
\uc@dclc{4811}{default}{\textethiopicwaa}%
\uc@dclc{4812}{default}{\textethiopicwee}%
\uc@dclc{4813}{default}{\textethiopicwe}%
\uc@dclc{4814}{default}{\textethiopicwo}%
\uc@dclc{4816}{default}{\textethiopicpharyngeala}%
\uc@dclc{4817}{default}{\textethiopicpharyngealu}%
\uc@dclc{4818}{default}{\textethiopicpharyngeali}%
\uc@dclc{4819}{default}{\textethiopicpharyngealaa}%
\uc@dclc{4820}{default}{\textethiopicpharyngealee}%
\uc@dclc{4821}{default}{\textethiopicpharyngeale}%
\uc@dclc{4822}{default}{\textethiopicpharyngealo}%
\uc@dclc{4824}{default}{\textethiopicza}%
\uc@dclc{4825}{default}{\textethiopiczu}%
\uc@dclc{4826}{default}{\textethiopiczi}%
\uc@dclc{4827}{default}{\textethiopiczaa}%
\uc@dclc{4828}{default}{\textethiopiczee}%
\uc@dclc{4829}{default}{\textethiopicze}%
\uc@dclc{4830}{default}{\textethiopiczo}%
\uc@dclc{4831}{default}{\textethiopiczwa}%
\uc@dclc{4832}{default}{\textethiopiczha}%
\uc@dclc{4833}{default}{\textethiopiczhu}%
\uc@dclc{4834}{default}{\textethiopiczhi}%
\uc@dclc{4835}{default}{\textethiopiczhaa}%
\uc@dclc{4836}{default}{\textethiopiczhee}%
\uc@dclc{4837}{default}{\textethiopiczhe}%
\uc@dclc{4838}{default}{\textethiopiczho}%
\uc@dclc{4839}{default}{\textethiopiczhwa}%
\uc@dclc{4840}{default}{\textethiopicya}%
\uc@dclc{4841}{default}{\textethiopicyu}%
\uc@dclc{4842}{default}{\textethiopicyi}%
\uc@dclc{4843}{default}{\textethiopicyaa}%
\uc@dclc{4844}{default}{\textethiopicyee}%
\uc@dclc{4845}{default}{\textethiopicye}%
\uc@dclc{4846}{default}{\textethiopicyo}%
\uc@dclc{4848}{default}{\textethiopicda}%
\uc@dclc{4849}{default}{\textethiopicdu}%
\uc@dclc{4850}{default}{\textethiopicdi}%
\uc@dclc{4851}{default}{\textethiopicdaa}%
\uc@dclc{4852}{default}{\textethiopicdee}%
\uc@dclc{4853}{default}{\textethiopicde}%
\uc@dclc{4854}{default}{\textethiopicdo}%
\uc@dclc{4855}{default}{\textethiopicdwa}%
\uc@dclc{4856}{default}{\textethiopicdda}%
\uc@dclc{4857}{default}{\textethiopicddu}%
\uc@dclc{4858}{default}{\textethiopicddi}%
\uc@dclc{4859}{default}{\textethiopicddaa}%
\uc@dclc{4860}{default}{\textethiopicddee}%
\uc@dclc{4861}{default}{\textethiopicdde}%
\uc@dclc{4862}{default}{\textethiopicddo}%
\uc@dclc{4863}{default}{\textethiopicddwa}%
%%% Local Variables: 
%%% mode: latex
%%% coding: utf-8
%%% End: 
