%%% Unicode to TeX mapping, file uni-263.def, U+10700..U+107FF, autogenerated by makeunidef.pl
\ifx\ProvidesFile\undefined\else
\ProvidesFile{uni-263.def}[2022/08/07 UCS: Unicode data U+10700..U+107FF]%
\fi
\uc@dclc{67457}{autogenerated}{\unicodesuper{\unichar{720}}}%
\uc@dclc{67459}{autogenerated}{\unicodesuper{\unichar{230}}}%
\uc@dclc{67460}{autogenerated}{\unicodesuper{\unichar{665}}}%
\uc@dclc{67461}{autogenerated}{\unicodesuper{\unichar{595}}}%
\uc@dclc{67463}{autogenerated}{\unicodesuper{\unichar{675}}}%
\uc@dclc{67465}{autogenerated}{\unicodesuper{\unichar{677}}}%
\uc@dclc{67466}{autogenerated}{\unicodesuper{\unichar{676}}}%
\uc@dclc{67467}{autogenerated}{\unicodesuper{\unichar{598}}}%
\uc@dclc{67468}{autogenerated}{\unicodesuper{\unichar{599}}}%
\uc@dclc{67470}{autogenerated}{\unicodesuper{\unichar{600}}}%
\uc@dclc{67471}{autogenerated}{\unicodesuper{\unichar{606}}}%
\uc@dclc{67473}{autogenerated}{\unicodesuper{\unichar{612}}}%
\uc@dclc{67474}{autogenerated}{\unicodesuper{\unichar{610}}}%
\uc@dclc{67475}{autogenerated}{\unicodesuper{\unichar{608}}}%
\uc@dclc{67476}{autogenerated}{\unicodesuper{\unichar{667}}}%
\uc@dclc{67477}{autogenerated}{\unicodesuper{\unichar{295}}}%
\uc@dclc{67478}{autogenerated}{\unicodesuper{\unichar{668}}}%
\uc@dclc{67479}{autogenerated}{\unicodesuper{\unichar{615}}}%
\uc@dclc{67480}{autogenerated}{\unicodesuper{\unichar{644}}}%
\uc@dclc{67483}{autogenerated}{\unicodesuper{\unichar{620}}}%
\uc@dclc{67486}{autogenerated}{\unicodesuper{\unichar{622}}}%
\uc@dclc{67488}{autogenerated}{\unicodesuper{\unichar{654}}}%
\uc@dclc{67490}{autogenerated}{\unicodesuper{\unichar{248}}}%
\uc@dclc{67491}{autogenerated}{\unicodesuper{\unichar{630}}}%
\uc@dclc{67492}{autogenerated}{\unicodesuper{\unichar{631}}}%
\uc@dclc{67493}{autogenerated}{\unicodesuper{\unichar{113}}}%
\uc@dclc{67494}{autogenerated}{\unicodesuper{\unichar{634}}}%
\uc@dclc{67496}{autogenerated}{\unicodesuper{\unichar{637}}}%
\uc@dclc{67497}{autogenerated}{\unicodesuper{\unichar{638}}}%
\uc@dclc{67498}{autogenerated}{\unicodesuper{\unichar{640}}}%
\uc@dclc{67499}{autogenerated}{\unicodesuper{\unichar{680}}}%
\uc@dclc{67500}{autogenerated}{\unicodesuper{\unichar{678}}}%
\uc@dclc{67502}{autogenerated}{\unicodesuper{\unichar{679}}}%
\uc@dclc{67503}{autogenerated}{\unicodesuper{\unichar{648}}}%
\uc@dclc{67506}{autogenerated}{\unicodesuper{\unichar{655}}}%
\uc@dclc{67507}{autogenerated}{\unicodesuper{\unichar{673}}}%
\uc@dclc{67508}{autogenerated}{\unicodesuper{\unichar{674}}}%
\uc@dclc{67509}{autogenerated}{\unicodesuper{\unichar{664}}}%
%%% Local Variables: 
%%% mode: latex
%%% coding: utf-8
%%% End: 
