%%
%% This is file `dviwin.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% drivers.dtx  (with options: `dviwin,nops')
%% 
%% drivers.dtx Copyright (C) 1994      David Carlisle Sebastian Rahtz
%%             Copyright (C) 1995 1996 1997 1998 1999 David Carlisle
%%             Copyright (C) 2000-2025 LaTeX Project
%% The LaTeX Project and any individual authors listed elsewhere
%% in this file.
%%
%% This file is part of the Standard LaTeX `Graphics Bundle'.
%% It may be distributed under the terms of the LaTeX Project Public
%% License, as described in lppl.txt in the base LaTeX distribution.
%% Either version 1.3 or, at your option, any later version.
%%
\ProvidesFile{dviwin.def}
        [2016/06/17 v3.0m Driver-dependent file (DPC,SPQR)]
\@namedef{Gin@rule@*}#1{{bmp}{}{#1}}
\def\Ginclude@bmp#1{%
  \raise\Gin@req@height\hbox{%
   \special{anisoscale #1,
   \the\Gin@req@width\space \the\Gin@req@height}}}
\@namedef{Gin@rule@.ps}#1{{eps}{.ps}{#1}}
\@namedef{Gin@rule@.eps}#1{{eps}{.eps}{#1}}
\let\Ginclude@eps\Ginclude@bmp
\def\Gin@extensions{.eps,.ps,.wmf,.tif}
\def\Gin@PS@raw#1{}
\def\Gin@PS@restored#1{}
\def\Gin@PS@literal@header#1{}
\def\Gin@PS@file@header#1{}
\endinput
%%
%% End of file `dviwin.def'.
