%%
%% This is file `ic.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% circ.dtx  (with options: `ic')
%% CIRC is a LaTeX package to typeset circuit and optics diagrams.
%% Copyright (C) 1997,1998,2003  Sebastian Tannert and Andreas Tille
%% 
%%   This program is free software; you can redistribute it and/or modify
%%   it under the terms of the GNU General Public License as published by
%%   the Free Software Foundation; either version 2 of the License, or
%%   (at your option) any later version.
%% 
%%   This program is distributed in the hope that it will be useful,
%%   but WITHOUT ANY WARRANTY; without even the implied warranty of
%%   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%%   GNU General Public License for more details.
%% 
%%   You should have received a copy of the GNU General Public License
%%   along with this program; if not, write to the Free Software
%%   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
%% 
%% For error reports concerning UNCHANGED versions of this file no
%% more than one year old, see CIRC.DVI after installation.
%% If installation fails search thru this file for 'bug'.
\ProvidesFile{ic.def}
\freecirc
\def\**[#1 #2 #3 #4 {\cc*\cnta*\advance\cc*32 \advance\cc*#1
  \Cstore*\*Ilist{#2}\Cadd*\*Ilist
  \rlap{\kern\pin*ind\ifpin\raise\pinnum*spc\hc*{\pinnumberfont{#3}}\fi
  \kern\io*ind\c*fntb\vc*{\hc*{\inlabelfont{#4}}}}\char\cc*
  \cc*\cnta*\advance\cc*97\char\cc*}
\def\**]#1 #2 #3 #4 {\cc*\cnta*\advance\cc*48 \advance\cc*#1
  \Cstore*\*Olist{#2}\Cadd*\*Olist
  \rlap{\kern.5\mid*ind\vc*{\hc*{\inlabelfont{#3}}}\kern\io*ind
  \ifpin\raise\pinnum*spc\hc*{\pinnumberfont{#4}}\fi}\char\cc*}
\def\*F[#1 #2 #3 #4 #5 {\cc*\cnta*\advance\cc*#1
  \X*check\Cstore*\*Ilist{#2}\Cadd*\*Ilist
  \rlap{\kern\pin*ind\ifpin\raise\pinnum*spc\hc*{\pinnumberfont{#3}}\fi
  \kern\io*ind\c*fntb\vc*{\hc*{\inlabelfont{#4}}}}%
  \rlap{\kern\io*ind\kern\mid*ind
  \blap{\kern0pt\hc*{\functionfont{#5}}}}\char\cc*
  \cc*\cnta*\advance\cc*96\char\cc*}
\def\*F]#1 #2 #3 #4 {\cc*\cnta*\advance\cc*16 \advance\cc*#1
  \LX*check\*Olist\Cstore*\*Olist{#2}\Cadd*\*Olist
  \rlap{\kern.5\mid*ind\vc*{\hc*{\inlabelfont{#3}}}\kern\io*ind
  \ifpin\raise\pinnum*spc\hc*{\pinnumberfont{#4}}\fi}\char\cc*}
\def\*L[#1 #2 #3 #4 #5 {\cc*\cnta*\advance\cc*64 \advance\cc*#1
  \Cstore*\*Ilist{#2}\Cadd*\*Ilist
  \rlap{\kern\pin*ind\ifpin\raise\pinnum*spc\hc*{\pinnumberfont{#3}}\fi
  \kern\io*ind\c*fntb\vc*{\hc*{\inlabelfont{#4}}}}%
  \rlap{\iflab*\kern\io*ind\kern\mid*ind
  \vtop{\kern\fontdimen17\c*fntb\kern\outerspace
  \hc*{\circlabelfont{#5}}}\fi}\char\cc*
  \cc*\cnta*\advance\cc*98\char\cc*}
\def\*L]#1 #2 #3 #4 {\cc*\cnta*\advance\cc*80 \advance\cc*#1
  \Cstore*\*Olist{#2}\Cadd*\*Olist
  \rlap{\kern.5\mid*ind\vc*{\hc*{\inlabelfont{#3}}}\kern\io*ind
  \ifpin\raise\pinnum*spc\hc*{\pinnumberfont{#4}}\fi}\char\cc*}
\def\*H#1 {\cc*\cnta*\X*check\Cadd*\*Ilist
 \rlap{\kern\io*ind\kern\mid*ind\blap{\kern-\*spc\labelfont\hc*{#1\ }}}%
  \char\cc*\cc*\cnta*\advance\cc*96\char\cc*\cc*\cnta*\advance\cc*16
  \LX*check\*Olist\Cadd*\*Olist\char\cc*}
\def\C*init{\dimen4\*X*\dimen5\*Y*
  \setbox\*bbox=\vtop\bgroup\c*fntb\cnta*=0 \ignorespaces}
\def\C*exit#1{\egroup\shift*IOlist{#1}\put*box\*X*\dimen4\*Y*\dimen5}
\def\*o#1{$\overline{\hbox{#1}}$}
\def\*|#1| {\hbox{#1}}
\def\JKMSFF#1 #2 #3 #4 {\name*{JKMSFF#1}\C*init
\*|\*F[2  S   {}   S   {}     \*F]0  .  {}      {} |
\*|\**[1  J   {}   1J         \**]1  Q  $\neg$  {} |
\*|\**[3  C   {}   C1         \**]0  .  {}      {} |
\*|\**[1  K   {}   1K         \**]2  NQ $\neg$  {} |
\*|\*L[2  R   {}   R   {#2}   \*L]0  .  {}      {} |
\C*exit{#3}}
\def\DFF#1 #2 #3 #4 {\name*{DFF#1}\C*init
\*|\*F[1  D   {}   1D  {}     \*F]1  Q  {}      {} |
\*|\**[0  .   {}   {}         \**]0  .  {}      {} |
\*|\*L[3  C   {}   C1  {#2}   \*L]2  NQ {}      {} |
\C*exit{#3}}
\def\RSFF#1 #2 #3 #4 {\name*{RSFF#1}\C*init
\*|\*F[1  R   {}   R   {}     \*F]1  Q  {}      {} |
\*|\**[0  .   {}   {}         \**]0  .  {}      {} |
\*|\*L[1  S   {}   S  {#2}    \*L]2  NQ {}      {} |
\C*exit{#3}}
\def\NRSFF#1 #2 #3 #4 {\name*{NRSFF#1}\C*init
\*|\*F[2  R   {}   R   {}     \*F]1  Q  {}      {} |
\*|\**[0  .   {}   {}         \**]0  .  {}      {} |
\*|\*L[2  S   {}   S  {#2}    \*L]2  NQ {}      {} |
\C*exit{#3}}
\def\fff#1 #2 #3 #4 {\name*{fff#1}\C*init
\*|\*F[1  IS  {6}  IS   {         }     \*F]1  OK  OK 5  |
\*|\**[0  .   {}   {}                   \**]0  .   {} {} |
\*|\**[1  IT  {2}  IT                   \**]1  O   O  3  |
\*|\**[0  .   {}   {}                   \**]0  .   {} {} |
\*|\*L[2  R   {4}  R    {#2}            \*L]1  OD  OD 7  |
\C*exit{#3}}
\def\NULL#1 #2 #3 #4 {\name*{NULL#1}\C*init
\*|\*H{$\vcenter{\hbox{\c*fnts\char25}}\ \infty$} |
\*|\**[1  i+  {}  +             \**]1  o+ +  {} |
\*|\**[0  .   {}  {}            \**]0  .  {} {} |
\*|\*L[1  i-  {}  $-$  {#2}     \*L]1  o- $-$  {} |
\C*exit{#3}}
\protectcirc
\endinput
%%
%% End of file `ic.def'.
