%%% Unicode to TeX mapping, file uni-202.def, U+CA00..U+CAFF, autogenerated by makeunidef.pl
\ifx\ProvidesFile\undefined\else
\ProvidesFile{uni-202.def}[2022/08/07 UCS: Unicode data U+CA00..U+CAFF]%
\fi
\gdef\u@cjk@hangul#1#2#3#4{{\fontencoding{C61}\def\CJK@plane{#1#2}\selectfont\char"#3#4\relax}}%
\uc@dclc{51712}{cjkhangul}{\u@cjk@hangul1330}%
\uc@dclc{51720}{cjkhangul}{\u@cjk@hangul1331}%
\uc@dclc{51721}{cjkhangul}{\u@cjk@hangul1332}%
\uc@dclc{51723}{cjkhangul}{\u@cjk@hangul1333}%
\uc@dclc{51724}{cjkhangul}{\u@cjk@hangul1334}%
\uc@dclc{51725}{cjkhangul}{\u@cjk@hangul1335}%
\uc@dclc{51732}{cjkhangul}{\u@cjk@hangul1336}%
\uc@dclc{51736}{cjkhangul}{\u@cjk@hangul1337}%
\uc@dclc{51753}{cjkhangul}{\u@cjk@hangul1338}%
\uc@dclc{51788}{cjkhangul}{\u@cjk@hangul1339}%
\uc@dclc{51789}{cjkhangul}{\u@cjk@hangul133A}%
\uc@dclc{51792}{cjkhangul}{\u@cjk@hangul133B}%
\uc@dclc{51796}{cjkhangul}{\u@cjk@hangul133C}%
\uc@dclc{51804}{cjkhangul}{\u@cjk@hangul133D}%
\uc@dclc{51805}{cjkhangul}{\u@cjk@hangul133E}%
\uc@dclc{51807}{cjkhangul}{\u@cjk@hangul133F}%
\uc@dclc{51808}{cjkhangul}{\u@cjk@hangul1340}%
\uc@dclc{51809}{cjkhangul}{\u@cjk@hangul1341}%
\uc@dclc{51816}{cjkhangul}{\u@cjk@hangul1342}%
\uc@dclc{51837}{cjkhangul}{\u@cjk@hangul1343}%
\uc@dclc{51844}{cjkhangul}{\u@cjk@hangul1344}%
\uc@dclc{51864}{cjkhangul}{\u@cjk@hangul1345}%
\uc@dclc{51900}{cjkhangul}{\u@cjk@hangul1346}%
\uc@dclc{51901}{cjkhangul}{\u@cjk@hangul1347}%
\uc@dclc{51904}{cjkhangul}{\u@cjk@hangul1348}%
\uc@dclc{51908}{cjkhangul}{\u@cjk@hangul1349}%
\uc@dclc{51916}{cjkhangul}{\u@cjk@hangul134A}%
\uc@dclc{51917}{cjkhangul}{\u@cjk@hangul134B}%
\uc@dclc{51919}{cjkhangul}{\u@cjk@hangul134C}%
\uc@dclc{51921}{cjkhangul}{\u@cjk@hangul134D}%
\uc@dclc{51923}{cjkhangul}{\u@cjk@hangul134E}%
\uc@dclc{51928}{cjkhangul}{\u@cjk@hangul134F}%
\uc@dclc{51929}{cjkhangul}{\u@cjk@hangul1350}%
\uc@dclc{51936}{cjkhangul}{\u@cjk@hangul1351}%
\uc@dclc{51948}{cjkhangul}{\u@cjk@hangul1352}%
\uc@dclc{51956}{cjkhangul}{\u@cjk@hangul1353}%
%%% Local Variables: 
%%% mode: latex
%%% coding: utf-8
%%% End: 
