%%% Unicode to TeX mapping, file uni-38.def, U+2600..U+26FF, autogenerated by makeunidef.pl
\ifx\ProvidesFile\undefined\else
\ProvidesFile{uni-38.def}[2022/08/07 UCS: Unicode data U+2600..U+26FF]%
\fi
\uc@dclc{9733}{postscript}{\ding{"48}}%
\uc@dclc{9742}{postscript}{\ding{"25}}%
\uc@dclc{9755}{postscript}{\ding{"2A}}%
\uc@dclc{9758}{postscript}{\ding{"2B}}%
\uc@dclc{9824}{default}{\ensuremath{\spadesuit}}%
\uc@dclc{9824}{postscript}{\Pisymbol{psy}{"AA}}%
\uc@dclc{9825}{default}{\ensuremath{\heartsuit}}%
\uc@dclc{9826}{default}{\ensuremath{\diamondsuit}}%
\uc@dclc{9827}{default}{\ensuremath{\clubsuit}}%
\uc@dclc{9827}{postscript}{\Pisymbol{psy}{"A7}}%
\uc@dclc{9829}{postscript}{\ding{"AA}}%
\uc@dclc{9830}{postscript}{\ding{"A9}}%
\uc@dclc{9833}{default}{\quarternote}%
\uc@dclc{9834}{default}{\eighthnote}%
\uc@dclc{9835}{default}{\twonotes}%
\uc@dclc{9837}{default}{\ensuremath{\flat}}%
\uc@dclc{9838}{default}{\ensuremath{\natural}}%
\uc@dclc{9839}{default}{\ensuremath{\sharp}}%
%%% Local Variables: 
%%% mode: latex
%%% coding: utf-8
%%% End: 
