%%
%% This is file `fc-italian.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% fmtcount.dtx  (with options: `fc-italian.def')
%% 
%%  fmtcount.dtx
%%  Copyright 2025 Nicola Talbot (inactive), Vincent Belaïche and Erik Nijenhuis
%% 
%%  This work may be distributed and/or modified under the
%%  conditions of the LaTeX Project Public License, either version 1.3
%%  of this license or (at your option) any later version.
%%  The latest version of this license is in
%%    http://www.latex-project.org/lppl.txt
%%  and version 1.3 or later is part of all distributions of LaTeX
%%  version 2005/12/01 or later.
%% 
%%  This work has the LPPL maintenance status `maintained'.
%% 
%%  The Current Maintainer of this work is Nicola Talbot (inactive), Vincent Belaïche and Erik Nijenhuis.
%% 
%%  This work consists of the files fmtcount.dtx and fmtcount.ins and the derived files fc-american.def, fc-brazilian.def, fc-british.def, fc-dutch.def, fc-english.def, fc-francais.def, fc-french.def, fc-frenchb.def, fc-german.def, fc-germanb.def, fc-italian.def, fc-ngerman.def, fc-ngermanb.def, fc-portuges.def, fc-portuguese.def, fc-spanish.def, fc-UKenglish.def, fc-USenglish.def, fcnumparser.sty, fcprefix.sty, fmtcount.sty.
%% 
\ProvidesFCLanguage{italian}[2013/08/17]

\RequirePackage{itnumpar}

\newcommand{\@numberstringMitalian}[2]{%
  \begingroup
    \def\np@oa{o}%
    \count@=#1
    \edef\@tempa{\def\noexpand#2{\@numeroinparole{\count@}}}%
    \expandafter
  \endgroup\@tempa
}
\global\let\@numberstringMitalian\@numberstringMitalian

\newcommand{\@numberstringFitalian}[2]{%
  \begingroup
    \def\np@oa{a}%
    \count@=#1
    \edef\@tempa{\def\noexpand#2{\@numeroinparole{\count@}}}%
    \expandafter
  \endgroup\@tempa
}

\global\let\@numberstringFitalian\@numberstringFitalian

\newcommand{\@NumberstringMitalian}[2]{%
  \begingroup
    \def\np@oa{o}%
    \count@=#1
    \edef\@tempa{\def\noexpand#2{\@Numeroinparole{\count@}}}%
    \expandafter
  \endgroup\@tempa
}
\global\let\@NumberstringMitalian\@NumberstringMitalian

\newcommand{\@NumberstringFitalian}[2]{%
  \begingroup
    \def\np@oa{a}%
    \count@=#1
    \edef\@tempa{\def\noexpand#2{\@Numeroinparole{\count@}}}%
    \expandafter
  \endgroup\@tempa
}
\global\let\@NumberstringFitalian\@NumberstringFitalian

\newcommand{\@ordinalstringMitalian}[2]{%
  \begingroup
    \count@=#1
    \edef\@tempa{\def\noexpand#2{\@ordinalem{\count@}}}%
    \expandafter
  \endgroup\@tempa
}
\global\let\@ordinalstringMitalian\@ordinalstringMitalian

\newcommand{\@ordinalstringFitalian}[2]{%
  \begingroup
    \count@=#1
    \edef\@tempa{\def\noexpand#2{\@ordinalef{\count@}}}%
    \expandafter
  \endgroup\@tempa
}
\global\let\@ordinalstringFitalian\@ordinalstringFitalian

\newcommand{\@OrdinalstringMitalian}[2]{%
  \begingroup
    \count@=#1
    \edef\@tempa{\def\noexpand#2{\@Ordinalem{\count@}}}%
    \expandafter
  \endgroup\@tempa
}
\global\let\@OrdinalstringMitalian\@OrdinalstringMitalian

\newcommand{\@OrdinalstringFitalian}[2]{%
  \begingroup
    \count@=#1
    \edef\@tempa{\def\noexpand#2{\@Ordinalef{\count@}}}%
    \expandafter
  \endgroup\@tempa
}
\global\let\@OrdinalstringFitalian\@OrdinalstringFitalian

\newcommand{\@ordinalMitalian}[2]{%
  \edef#2{#1\relax\noexpand\fmtord{o}}}

\global\let\@ordinalMitalian\@ordinalMitalian

\newcommand{\@ordinalFitalian}[2]{%
  \edef#2{#1\relax\noexpand\fmtord{a}}}
\global\let\@ordinalFitalian\@ordinalFitalian
\endinput
%%
%% End of file `fc-italian.def'.
