% In this input encoding, each non-ASCII character just maps to its
% own byte value. This is intended for specialized uses where binary
% data must be processed.
% 
% Written in 2014 by Peter Selinger <selinger@mathstat.dal.ca>.
% Public Domain.

\ProvidesFile{8bit.def}
   [2008/03/30 v1.1d Input encoding file]
\makeatletter
\DeclareInputText{1}{\string^^01}
\DeclareInputText{2}{\string^^02}
\DeclareInputText{3}{\string^^03}
\DeclareInputText{4}{\string^^04}
\DeclareInputText{5}{\string^^05}
\DeclareInputText{6}{\string^^06}
\DeclareInputText{7}{\string^^07}
\DeclareInputText{8}{\string^^08}
\DeclareInputText{11}{\string^^0b}
\DeclareInputText{14}{\string^^0e}
\DeclareInputText{15}{\string^^0f}
\DeclareInputText{16}{\string^^10}
\DeclareInputText{17}{\string^^11}
\DeclareInputText{18}{\string^^12}
\DeclareInputText{19}{\string^^13}
\DeclareInputText{20}{\string^^14}
\DeclareInputText{21}{\string^^15}
\DeclareInputText{22}{\string^^16}
\DeclareInputText{23}{\string^^17}
\DeclareInputText{24}{\string^^18}
\DeclareInputText{25}{\string^^19}
\DeclareInputText{26}{\string^^1a}
\DeclareInputText{27}{\string^^1b}
\DeclareInputText{28}{\string^^1c}
\DeclareInputText{29}{\string^^1d}
\DeclareInputText{30}{\string^^1e}
\DeclareInputText{31}{\string^^1f}
\DeclareInputText{127}{\string^^7f}
\DeclareInputText{128}{\string^^80}
\DeclareInputText{129}{\string^^81}
\DeclareInputText{130}{\string^^82}
\DeclareInputText{131}{\string^^83}
\DeclareInputText{132}{\string^^84}
\DeclareInputText{133}{\string^^85}
\DeclareInputText{134}{\string^^86}
\DeclareInputText{135}{\string^^87}
\DeclareInputText{136}{\string^^88}
\DeclareInputText{137}{\string^^89}
\DeclareInputText{138}{\string^^8a}
\DeclareInputText{139}{\string^^8b}
\DeclareInputText{140}{\string^^8c}
\DeclareInputText{141}{\string^^8d}
\DeclareInputText{142}{\string^^8e}
\DeclareInputText{143}{\string^^8f}
\DeclareInputText{144}{\string^^90}
\DeclareInputText{145}{\string^^91}
\DeclareInputText{146}{\string^^92}
\DeclareInputText{147}{\string^^93}
\DeclareInputText{148}{\string^^94}
\DeclareInputText{149}{\string^^95}
\DeclareInputText{150}{\string^^96}
\DeclareInputText{151}{\string^^97}
\DeclareInputText{152}{\string^^98}
\DeclareInputText{153}{\string^^99}
\DeclareInputText{154}{\string^^9a}
\DeclareInputText{155}{\string^^9b}
\DeclareInputText{156}{\string^^9c}
\DeclareInputText{157}{\string^^9d}
\DeclareInputText{158}{\string^^9e}
\DeclareInputText{159}{\string^^9f}
\DeclareInputText{160}{\string^^a0}
\DeclareInputText{161}{\string^^a1}
\DeclareInputText{162}{\string^^a2}
\DeclareInputText{163}{\string^^a3}
\DeclareInputText{164}{\string^^a4}
\DeclareInputText{165}{\string^^a5}
\DeclareInputText{166}{\string^^a6}
\DeclareInputText{167}{\string^^a7}
\DeclareInputText{168}{\string^^a8}
\DeclareInputText{169}{\string^^a9}
\DeclareInputText{170}{\string^^aa}
\DeclareInputText{171}{\string^^ab}
\DeclareInputText{172}{\string^^ac}
\DeclareInputText{173}{\string^^ad}
\DeclareInputText{174}{\string^^ae}
\DeclareInputText{175}{\string^^af}
\DeclareInputText{176}{\string^^b0}
\DeclareInputText{177}{\string^^b1}
\DeclareInputText{178}{\string^^b2}
\DeclareInputText{179}{\string^^b3}
\DeclareInputText{180}{\string^^b4}
\DeclareInputText{181}{\string^^b5}
\DeclareInputText{182}{\string^^b6}
\DeclareInputText{183}{\string^^b7}
\DeclareInputText{184}{\string^^b8}
\DeclareInputText{185}{\string^^b9}
\DeclareInputText{186}{\string^^ba}
\DeclareInputText{187}{\string^^bb}
\DeclareInputText{188}{\string^^bc}
\DeclareInputText{189}{\string^^bd}
\DeclareInputText{190}{\string^^be}
\DeclareInputText{191}{\string^^bf}
\DeclareInputText{192}{\string^^c0}
\DeclareInputText{193}{\string^^c1}
\DeclareInputText{194}{\string^^c2}
\DeclareInputText{195}{\string^^c3}
\DeclareInputText{196}{\string^^c4}
\DeclareInputText{197}{\string^^c5}
\DeclareInputText{198}{\string^^c6}
\DeclareInputText{199}{\string^^c7}
\DeclareInputText{200}{\string^^c8}
\DeclareInputText{201}{\string^^c9}
\DeclareInputText{202}{\string^^ca}
\DeclareInputText{203}{\string^^cb}
\DeclareInputText{204}{\string^^cc}
\DeclareInputText{205}{\string^^cd}
\DeclareInputText{206}{\string^^ce}
\DeclareInputText{207}{\string^^cf}
\DeclareInputText{208}{\string^^d0}
\DeclareInputText{209}{\string^^d1}
\DeclareInputText{210}{\string^^d2}
\DeclareInputText{211}{\string^^d3}
\DeclareInputText{212}{\string^^d4}
\DeclareInputText{213}{\string^^d5}
\DeclareInputText{214}{\string^^d6}
\DeclareInputText{215}{\string^^d7}
\DeclareInputText{216}{\string^^d8}
\DeclareInputText{217}{\string^^d9}
\DeclareInputText{218}{\string^^da}
\DeclareInputText{219}{\string^^db}
\DeclareInputText{220}{\string^^dc}
\DeclareInputText{221}{\string^^dd}
\DeclareInputText{222}{\string^^de}
\DeclareInputText{223}{\string^^df}
\DeclareInputText{224}{\string^^e0}
\DeclareInputText{225}{\string^^e1}
\DeclareInputText{226}{\string^^e2}
\DeclareInputText{227}{\string^^e3}
\DeclareInputText{228}{\string^^e4}
\DeclareInputText{229}{\string^^e5}
\DeclareInputText{230}{\string^^e6}
\DeclareInputText{231}{\string^^e7}
\DeclareInputText{232}{\string^^e8}
\DeclareInputText{233}{\string^^e9}
\DeclareInputText{234}{\string^^ea}
\DeclareInputText{235}{\string^^eb}
\DeclareInputText{236}{\string^^ec}
\DeclareInputText{237}{\string^^ed}
\DeclareInputText{238}{\string^^ee}
\DeclareInputText{239}{\string^^ef}
\DeclareInputText{240}{\string^^f0}
\DeclareInputText{241}{\string^^f1}
\DeclareInputText{242}{\string^^f2}
\DeclareInputText{243}{\string^^f3}
\DeclareInputText{244}{\string^^f4}
\DeclareInputText{245}{\string^^f5}
\DeclareInputText{246}{\string^^f6}
\DeclareInputText{247}{\string^^f7}
\DeclareInputText{248}{\string^^f8}
\DeclareInputText{249}{\string^^f9}
\DeclareInputText{250}{\string^^fa}
\DeclareInputText{251}{\string^^fb}
\DeclareInputText{252}{\string^^fc}
\DeclareInputText{253}{\string^^fd}
\DeclareInputText{254}{\string^^fe}
\DeclareInputText{255}{\string^^ff}
\makeatother
\endinput
%%
%% End of file `8bit.def'.
