%%% Unicode to TeX mapping, file uni-471.def, U+1D700..U+1D7FF, autogenerated by makeunidef.pl
\ifx\ProvidesFile\undefined\else
\ProvidesFile{uni-471.def}[2022/08/07 UCS: Unicode data U+1D700..U+1D7FF]%
\fi
\uc@dclc{120576}{autogenerated}{\unichar{949}}%
\uc@dclc{120577}{autogenerated}{\unichar{950}}%
\uc@dclc{120578}{autogenerated}{\unichar{951}}%
\uc@dclc{120579}{autogenerated}{\unichar{952}}%
\uc@dclc{120580}{autogenerated}{\unichar{953}}%
\uc@dclc{120581}{autogenerated}{\unichar{954}}%
\uc@dclc{120582}{autogenerated}{\unichar{955}}%
\uc@dclc{120583}{autogenerated}{\unichar{956}}%
\uc@dclc{120584}{autogenerated}{\unichar{957}}%
\uc@dclc{120585}{autogenerated}{\unichar{958}}%
\uc@dclc{120586}{autogenerated}{\unichar{959}}%
\uc@dclc{120587}{autogenerated}{\unichar{960}}%
\uc@dclc{120588}{autogenerated}{\unichar{961}}%
\uc@dclc{120589}{autogenerated}{\unichar{962}}%
\uc@dclc{120590}{autogenerated}{\unichar{963}}%
\uc@dclc{120591}{autogenerated}{\unichar{964}}%
\uc@dclc{120592}{autogenerated}{\unichar{965}}%
\uc@dclc{120593}{autogenerated}{\unichar{966}}%
\uc@dclc{120594}{autogenerated}{\unichar{967}}%
\uc@dclc{120595}{autogenerated}{\unichar{968}}%
\uc@dclc{120596}{autogenerated}{\unichar{969}}%
\uc@dclc{120597}{autogenerated}{\unichar{8706}}%
\uc@dclc{120598}{autogenerated}{\unichar{1013}}%
\uc@dclc{120599}{autogenerated}{\unichar{977}}%
\uc@dclc{120600}{autogenerated}{\unichar{1008}}%
\uc@dclc{120601}{autogenerated}{\unichar{981}}%
\uc@dclc{120602}{autogenerated}{\unichar{1009}}%
\uc@dclc{120603}{autogenerated}{\unichar{982}}%
\uc@dclc{120604}{autogenerated}{\unichar{913}}%
\uc@dclc{120605}{autogenerated}{\unichar{914}}%
\uc@dclc{120606}{autogenerated}{\unichar{915}}%
\uc@dclc{120607}{autogenerated}{\unichar{916}}%
\uc@dclc{120608}{autogenerated}{\unichar{917}}%
\uc@dclc{120609}{autogenerated}{\unichar{918}}%
\uc@dclc{120610}{autogenerated}{\unichar{919}}%
\uc@dclc{120611}{autogenerated}{\unichar{920}}%
\uc@dclc{120612}{autogenerated}{\unichar{921}}%
\uc@dclc{120613}{autogenerated}{\unichar{922}}%
\uc@dclc{120614}{autogenerated}{\unichar{923}}%
\uc@dclc{120615}{autogenerated}{\unichar{924}}%
\uc@dclc{120616}{autogenerated}{\unichar{925}}%
\uc@dclc{120617}{autogenerated}{\unichar{926}}%
\uc@dclc{120618}{autogenerated}{\unichar{927}}%
\uc@dclc{120619}{autogenerated}{\unichar{928}}%
\uc@dclc{120620}{autogenerated}{\unichar{929}}%
\uc@dclc{120621}{autogenerated}{\unichar{1012}}%
\uc@dclc{120622}{autogenerated}{\unichar{931}}%
\uc@dclc{120623}{autogenerated}{\unichar{932}}%
\uc@dclc{120624}{autogenerated}{\unichar{933}}%
\uc@dclc{120625}{autogenerated}{\unichar{934}}%
\uc@dclc{120626}{autogenerated}{\unichar{935}}%
\uc@dclc{120627}{autogenerated}{\unichar{936}}%
\uc@dclc{120628}{autogenerated}{\unichar{937}}%
\uc@dclc{120629}{autogenerated}{\unichar{8711}}%
\uc@dclc{120630}{autogenerated}{\unichar{945}}%
\uc@dclc{120631}{autogenerated}{\unichar{946}}%
\uc@dclc{120632}{autogenerated}{\unichar{947}}%
\uc@dclc{120633}{autogenerated}{\unichar{948}}%
\uc@dclc{120634}{autogenerated}{\unichar{949}}%
\uc@dclc{120635}{autogenerated}{\unichar{950}}%
\uc@dclc{120636}{autogenerated}{\unichar{951}}%
\uc@dclc{120637}{autogenerated}{\unichar{952}}%
\uc@dclc{120638}{autogenerated}{\unichar{953}}%
\uc@dclc{120639}{autogenerated}{\unichar{954}}%
\uc@dclc{120640}{autogenerated}{\unichar{955}}%
\uc@dclc{120641}{autogenerated}{\unichar{956}}%
\uc@dclc{120642}{autogenerated}{\unichar{957}}%
\uc@dclc{120643}{autogenerated}{\unichar{958}}%
\uc@dclc{120644}{autogenerated}{\unichar{959}}%
\uc@dclc{120645}{autogenerated}{\unichar{960}}%
\uc@dclc{120646}{autogenerated}{\unichar{961}}%
\uc@dclc{120647}{autogenerated}{\unichar{962}}%
\uc@dclc{120648}{autogenerated}{\unichar{963}}%
\uc@dclc{120649}{autogenerated}{\unichar{964}}%
\uc@dclc{120650}{autogenerated}{\unichar{965}}%
\uc@dclc{120651}{autogenerated}{\unichar{966}}%
\uc@dclc{120652}{autogenerated}{\unichar{967}}%
\uc@dclc{120653}{autogenerated}{\unichar{968}}%
\uc@dclc{120654}{autogenerated}{\unichar{969}}%
\uc@dclc{120655}{autogenerated}{\unichar{8706}}%
\uc@dclc{120656}{autogenerated}{\unichar{1013}}%
\uc@dclc{120657}{autogenerated}{\unichar{977}}%
\uc@dclc{120658}{autogenerated}{\unichar{1008}}%
\uc@dclc{120659}{autogenerated}{\unichar{981}}%
\uc@dclc{120660}{autogenerated}{\unichar{1009}}%
\uc@dclc{120661}{autogenerated}{\unichar{982}}%
\uc@dclc{120662}{autogenerated}{\unichar{913}}%
\uc@dclc{120663}{autogenerated}{\unichar{914}}%
\uc@dclc{120664}{autogenerated}{\unichar{915}}%
\uc@dclc{120665}{autogenerated}{\unichar{916}}%
\uc@dclc{120666}{autogenerated}{\unichar{917}}%
\uc@dclc{120667}{autogenerated}{\unichar{918}}%
\uc@dclc{120668}{autogenerated}{\unichar{919}}%
\uc@dclc{120669}{autogenerated}{\unichar{920}}%
\uc@dclc{120670}{autogenerated}{\unichar{921}}%
\uc@dclc{120671}{autogenerated}{\unichar{922}}%
\uc@dclc{120672}{autogenerated}{\unichar{923}}%
\uc@dclc{120673}{autogenerated}{\unichar{924}}%
\uc@dclc{120674}{autogenerated}{\unichar{925}}%
\uc@dclc{120675}{autogenerated}{\unichar{926}}%
\uc@dclc{120676}{autogenerated}{\unichar{927}}%
\uc@dclc{120677}{autogenerated}{\unichar{928}}%
\uc@dclc{120678}{autogenerated}{\unichar{929}}%
\uc@dclc{120679}{autogenerated}{\unichar{1012}}%
\uc@dclc{120680}{autogenerated}{\unichar{931}}%
\uc@dclc{120681}{autogenerated}{\unichar{932}}%
\uc@dclc{120682}{autogenerated}{\unichar{933}}%
\uc@dclc{120683}{autogenerated}{\unichar{934}}%
\uc@dclc{120684}{autogenerated}{\unichar{935}}%
\uc@dclc{120685}{autogenerated}{\unichar{936}}%
\uc@dclc{120686}{autogenerated}{\unichar{937}}%
\uc@dclc{120687}{autogenerated}{\unichar{8711}}%
\uc@dclc{120688}{autogenerated}{\unichar{945}}%
\uc@dclc{120689}{autogenerated}{\unichar{946}}%
\uc@dclc{120690}{autogenerated}{\unichar{947}}%
\uc@dclc{120691}{autogenerated}{\unichar{948}}%
\uc@dclc{120692}{autogenerated}{\unichar{949}}%
\uc@dclc{120693}{autogenerated}{\unichar{950}}%
\uc@dclc{120694}{autogenerated}{\unichar{951}}%
\uc@dclc{120695}{autogenerated}{\unichar{952}}%
\uc@dclc{120696}{autogenerated}{\unichar{953}}%
\uc@dclc{120697}{autogenerated}{\unichar{954}}%
\uc@dclc{120698}{autogenerated}{\unichar{955}}%
\uc@dclc{120699}{autogenerated}{\unichar{956}}%
\uc@dclc{120700}{autogenerated}{\unichar{957}}%
\uc@dclc{120701}{autogenerated}{\unichar{958}}%
\uc@dclc{120702}{autogenerated}{\unichar{959}}%
\uc@dclc{120703}{autogenerated}{\unichar{960}}%
\uc@dclc{120704}{autogenerated}{\unichar{961}}%
\uc@dclc{120705}{autogenerated}{\unichar{962}}%
\uc@dclc{120706}{autogenerated}{\unichar{963}}%
\uc@dclc{120707}{autogenerated}{\unichar{964}}%
\uc@dclc{120708}{autogenerated}{\unichar{965}}%
\uc@dclc{120709}{autogenerated}{\unichar{966}}%
\uc@dclc{120710}{autogenerated}{\unichar{967}}%
\uc@dclc{120711}{autogenerated}{\unichar{968}}%
\uc@dclc{120712}{autogenerated}{\unichar{969}}%
\uc@dclc{120713}{autogenerated}{\unichar{8706}}%
\uc@dclc{120714}{autogenerated}{\unichar{1013}}%
\uc@dclc{120715}{autogenerated}{\unichar{977}}%
\uc@dclc{120716}{autogenerated}{\unichar{1008}}%
\uc@dclc{120717}{autogenerated}{\unichar{981}}%
\uc@dclc{120718}{autogenerated}{\unichar{1009}}%
\uc@dclc{120719}{autogenerated}{\unichar{982}}%
\uc@dclc{120720}{autogenerated}{\unichar{913}}%
\uc@dclc{120721}{autogenerated}{\unichar{914}}%
\uc@dclc{120722}{autogenerated}{\unichar{915}}%
\uc@dclc{120723}{autogenerated}{\unichar{916}}%
\uc@dclc{120724}{autogenerated}{\unichar{917}}%
\uc@dclc{120725}{autogenerated}{\unichar{918}}%
\uc@dclc{120726}{autogenerated}{\unichar{919}}%
\uc@dclc{120727}{autogenerated}{\unichar{920}}%
\uc@dclc{120728}{autogenerated}{\unichar{921}}%
\uc@dclc{120729}{autogenerated}{\unichar{922}}%
\uc@dclc{120730}{autogenerated}{\unichar{923}}%
\uc@dclc{120731}{autogenerated}{\unichar{924}}%
\uc@dclc{120732}{autogenerated}{\unichar{925}}%
\uc@dclc{120733}{autogenerated}{\unichar{926}}%
\uc@dclc{120734}{autogenerated}{\unichar{927}}%
\uc@dclc{120735}{autogenerated}{\unichar{928}}%
\uc@dclc{120736}{autogenerated}{\unichar{929}}%
\uc@dclc{120737}{autogenerated}{\unichar{1012}}%
\uc@dclc{120738}{autogenerated}{\unichar{931}}%
\uc@dclc{120739}{autogenerated}{\unichar{932}}%
\uc@dclc{120740}{autogenerated}{\unichar{933}}%
\uc@dclc{120741}{autogenerated}{\unichar{934}}%
\uc@dclc{120742}{autogenerated}{\unichar{935}}%
\uc@dclc{120743}{autogenerated}{\unichar{936}}%
\uc@dclc{120744}{autogenerated}{\unichar{937}}%
\uc@dclc{120745}{autogenerated}{\unichar{8711}}%
\uc@dclc{120746}{autogenerated}{\unichar{945}}%
\uc@dclc{120747}{autogenerated}{\unichar{946}}%
\uc@dclc{120748}{autogenerated}{\unichar{947}}%
\uc@dclc{120749}{autogenerated}{\unichar{948}}%
\uc@dclc{120750}{autogenerated}{\unichar{949}}%
\uc@dclc{120751}{autogenerated}{\unichar{950}}%
\uc@dclc{120752}{autogenerated}{\unichar{951}}%
\uc@dclc{120753}{autogenerated}{\unichar{952}}%
\uc@dclc{120754}{autogenerated}{\unichar{953}}%
\uc@dclc{120755}{autogenerated}{\unichar{954}}%
\uc@dclc{120756}{autogenerated}{\unichar{955}}%
\uc@dclc{120757}{autogenerated}{\unichar{956}}%
\uc@dclc{120758}{autogenerated}{\unichar{957}}%
\uc@dclc{120759}{autogenerated}{\unichar{958}}%
\uc@dclc{120760}{autogenerated}{\unichar{959}}%
\uc@dclc{120761}{autogenerated}{\unichar{960}}%
\uc@dclc{120762}{autogenerated}{\unichar{961}}%
\uc@dclc{120763}{autogenerated}{\unichar{962}}%
\uc@dclc{120764}{autogenerated}{\unichar{963}}%
\uc@dclc{120765}{autogenerated}{\unichar{964}}%
\uc@dclc{120766}{autogenerated}{\unichar{965}}%
\uc@dclc{120767}{autogenerated}{\unichar{966}}%
\uc@dclc{120768}{autogenerated}{\unichar{967}}%
\uc@dclc{120769}{autogenerated}{\unichar{968}}%
\uc@dclc{120770}{autogenerated}{\unichar{969}}%
\uc@dclc{120771}{autogenerated}{\unichar{8706}}%
\uc@dclc{120772}{autogenerated}{\unichar{1013}}%
\uc@dclc{120773}{autogenerated}{\unichar{977}}%
\uc@dclc{120774}{autogenerated}{\unichar{1008}}%
\uc@dclc{120775}{autogenerated}{\unichar{981}}%
\uc@dclc{120776}{autogenerated}{\unichar{1009}}%
\uc@dclc{120777}{autogenerated}{\unichar{982}}%
\uc@dclc{120778}{autogenerated}{\unichar{988}}%
\uc@dclc{120779}{autogenerated}{\unichar{989}}%
\uc@dclc{120782}{default}{\ensuremath{\mathbf0}}%
\uc@dclc{120783}{default}{\ensuremath{\mathbf1}}%
\uc@dclc{120784}{default}{\ensuremath{\mathbf2}}%
\uc@dclc{120785}{default}{\ensuremath{\mathbf3}}%
\uc@dclc{120786}{default}{\ensuremath{\mathbf4}}%
\uc@dclc{120787}{default}{\ensuremath{\mathbf5}}%
\uc@dclc{120788}{default}{\ensuremath{\mathbf6}}%
\uc@dclc{120789}{default}{\ensuremath{\mathbf7}}%
\uc@dclc{120790}{default}{\ensuremath{\mathbf8}}%
\uc@dclc{120791}{default}{\ensuremath{\mathbf9}}%
\uc@dclc{120792}{autogenerated}{\unichar{48}}%
\uc@dclc{120793}{autogenerated}{\unichar{49}}%
\uc@dclc{120794}{autogenerated}{\unichar{50}}%
\uc@dclc{120795}{autogenerated}{\unichar{51}}%
\uc@dclc{120796}{autogenerated}{\unichar{52}}%
\uc@dclc{120797}{autogenerated}{\unichar{53}}%
\uc@dclc{120798}{autogenerated}{\unichar{54}}%
\uc@dclc{120799}{autogenerated}{\unichar{55}}%
\uc@dclc{120800}{autogenerated}{\unichar{56}}%
\uc@dclc{120801}{autogenerated}{\unichar{57}}%
\uc@dclc{120802}{default}{\ensuremath{\mathsf0}}%
\uc@dclc{120803}{default}{\ensuremath{\mathsf1}}%
\uc@dclc{120804}{default}{\ensuremath{\mathsf2}}%
\uc@dclc{120805}{default}{\ensuremath{\mathsf3}}%
\uc@dclc{120806}{default}{\ensuremath{\mathsf4}}%
\uc@dclc{120807}{default}{\ensuremath{\mathsf5}}%
\uc@dclc{120808}{default}{\ensuremath{\mathsf6}}%
\uc@dclc{120809}{default}{\ensuremath{\mathsf7}}%
\uc@dclc{120810}{default}{\ensuremath{\mathsf8}}%
\uc@dclc{120811}{default}{\ensuremath{\mathsf9}}%
\uc@dclc{120812}{autogenerated}{\unichar{48}}%
\uc@dclc{120813}{autogenerated}{\unichar{49}}%
\uc@dclc{120814}{autogenerated}{\unichar{50}}%
\uc@dclc{120815}{autogenerated}{\unichar{51}}%
\uc@dclc{120816}{autogenerated}{\unichar{52}}%
\uc@dclc{120817}{autogenerated}{\unichar{53}}%
\uc@dclc{120818}{autogenerated}{\unichar{54}}%
\uc@dclc{120819}{autogenerated}{\unichar{55}}%
\uc@dclc{120820}{autogenerated}{\unichar{56}}%
\uc@dclc{120821}{autogenerated}{\unichar{57}}%
\uc@dclc{120822}{default}{\ensuremath{\mathtt0}}%
\uc@dclc{120823}{default}{\ensuremath{\mathtt1}}%
\uc@dclc{120824}{default}{\ensuremath{\mathtt2}}%
\uc@dclc{120825}{default}{\ensuremath{\mathtt3}}%
\uc@dclc{120826}{default}{\ensuremath{\mathtt4}}%
\uc@dclc{120827}{default}{\ensuremath{\mathtt5}}%
\uc@dclc{120828}{default}{\ensuremath{\mathtt6}}%
\uc@dclc{120829}{default}{\ensuremath{\mathtt7}}%
\uc@dclc{120830}{default}{\ensuremath{\mathtt8}}%
\uc@dclc{120831}{default}{\ensuremath{\mathtt9}}%
%%% Local Variables: 
%%% mode: latex
%%% coding: utf-8
%%% End: 
