%%
%% This is file `cp852.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% inputenc.dtx  (with options: `cp852')
%% 
%% This is a generated file.
%% 
%% The source is maintained by the LaTeX Project team and bug
%% reports for it can be opened at https://latex-project.org/bugs.html
%% (but please observe conditions on bug reports sent to that address!)
%% 
%% 
%% Copyright (C) 1993-2025
%% The LaTeX Project and any individual authors listed elsewhere
%% in this file.
%% 
%% This file was generated from file(s) of the LaTeX base system.
%% --------------------------------------------------------------
%% 
%% It may be distributed and/or modified under the
%% conditions of the LaTeX Project Public License, either version 1.3c
%% of this license or (at your option) any later version.
%% The latest version of this license is in
%%    https://www.latex-project.org/lppl.txt
%% and version 1.3c or later is part of all distributions of LaTeX
%% version 2008 or later.
%% 
%% This file has the LPPL maintenance status "maintained".
%% 
%% This file may only be distributed together with a copy of the LaTeX
%% base system. You may however distribute the LaTeX base system without
%% such generated files.
%% 
%% The list of all files belonging to the LaTeX base distribution is
%% given in the file `manifest.txt'. See also `legal.txt' for additional
%% information.
%% 
%% The list of derived (unpacked) files belonging to the distribution
%% and covered by LPPL is defined by the unpacking scripts (with
%% extension .ins) which are part of the distribution.

  \ProvidesFile{cp852.def}
   [2024/02/08 v1.3d Input encoding file]
\ProvideTextCommandDefault{\textdegree}{\ensuremath{{^\circ}}}
\ProvideTextCommandDefault{\textonehalf}{\ensuremath{\frac12}}
\ProvideTextCommandDefault{\textonequarter}{\ensuremath{\frac14}}
\ProvideTextCommandDefault{\textthreequarters}{\ensuremath{\frac34}}
\ProvideTextCommandDefault{\textblacksquare}
{\vrule \@width .3em \@height .4em \@depth -.1em\relax}
\ProvideTextCommandDefault{\textcurrency}
   {\TextSymbolUnavailable\textcurrency}
\ProvideTextCommandDefault{\textbrokenbar}
   {\TextSymbolUnavailable\textbrokenbar}
\DeclareInputText{128}{\c C}
\DeclareInputText{144}{\@tabacckludge'E}
\DeclareInputText{129}{\"u}
\DeclareInputText{145}{\@tabacckludge'L}
\DeclareInputText{130}{\@tabacckludge'e}
\DeclareInputText{146}{\@tabacckludge'l}
\DeclareInputText{131}{\^a}
\DeclareInputText{147}{\^o}
\DeclareInputText{132}{\"a}
\DeclareInputText{148}{\"o}
\DeclareInputText{133}{\r u}
\DeclareInputText{149}{\v L}
\DeclareInputText{134}{\@tabacckludge'c}
\DeclareInputText{150}{\v l}
\DeclareInputText{135}{\c c}
\DeclareInputText{151}{\@tabacckludge'S}
\DeclareInputText{136}{\l}
\DeclareInputText{152}{\@tabacckludge's}
\DeclareInputText{137}{\"e}
\DeclareInputText{153}{\"O}
\DeclareInputText{138}{\H O}
\DeclareInputText{154}{\"U}
\DeclareInputText{139}{\H o}
\DeclareInputText{155}{\v T}
\DeclareInputText{140}{\^\i}
\DeclareInputText{156}{\v t}
\DeclareInputText{141}{\@tabacckludge'Z}
\DeclareInputText{157}{\L}
\DeclareInputText{142}{\"A}
\DeclareInputMath{158}{\times}
\DeclareInputText{143}{\@tabacckludge'C}
\DeclareInputText{159}{\v c}
\DeclareInputText{160}{\@tabacckludge'a}
\DeclareInputText{161}{\@tabacckludge'\i}
\DeclareInputText{162}{\@tabacckludge'o}
\DeclareInputText{163}{\@tabacckludge'u}
\DeclareInputText{164}{\k A}
\DeclareInputText{165}{\k a}
\DeclareInputText{166}{\v Z}
\DeclareInputText{167}{\v z}
\DeclareInputText{168}{\k E}
\DeclareInputText{169}{\k e}
\DeclareInputMath{170}{\lnot}
\DeclareInputText{171}{\@tabacckludge'z}
\DeclareInputText{172}{\v C}
\DeclareInputText{173}{\c s}
\DeclareInputText{174}{\guillemetleft}
\DeclareInputText{175}{\guillemetright}
\DeclareInputText{181}{\@tabacckludge'A}
\DeclareInputText{182}{\^A}
\DeclareInputText{183}{\v E}
\DeclareInputText{184}{\c S}
\DeclareInputText{189}{\.Z}
\DeclareInputText{190}{\.z}
\DeclareInputText{198}{\u A}
\DeclareInputText{199}{\u a}
\DeclareInputText{207}{\textcurrency}
\DeclareInputText{208}{\dj}
\DeclareInputText{209}{\DJ}
\DeclareInputText{210}{\v D}
\DeclareInputText{211}{\"E}
\DeclareInputText{212}{\v d} % d caron
\DeclareInputText{213}{\v N}
\DeclareInputText{214}{\@tabacckludge'I}
\DeclareInputText{215}{\^I}
\DeclareInputText{216}{\v e}
\DeclareInputText{221}{\c T}
\DeclareInputText{222}{\r U}
\DeclareInputText{224}{\@tabacckludge'O}
\DeclareInputText{240}{\-}
\DeclareInputText{225}{\ss}
\DeclareInputText{241}{\H{}}
\DeclareInputText{226}{\^O}
\DeclareInputText{242}{\k\ }
\DeclareInputText{227}{\@tabacckludge'N}
\DeclareInputText{243}{\v{}}
\DeclareInputText{228}{\@tabacckludge'n}
\DeclareInputText{244}{\u{}}
\DeclareInputText{229}{\v n}
\DeclareInputText{245}{\S}
\DeclareInputText{230}{\v S}
\DeclareInputMath{246}{\div}
\DeclareInputText{231}{\v s}
\DeclareInputText{247}{\c\ }
\DeclareInputText{232}{\@tabacckludge'R}
\DeclareInputText{248}{\textdegree}
\DeclareInputText{233}{\@tabacckludge'U}
\DeclareInputText{249}{\"{}}
\DeclareInputText{234}{\@tabacckludge'r}
\DeclareInputText{250}{\.{}}
\DeclareInputText{235}{\H U}
\DeclareInputText{251}{\H u}
\DeclareInputText{236}{\@tabacckludge'y}
\DeclareInputText{252}{\v R}
\DeclareInputText{237}{\@tabacckludge'Y}
\DeclareInputText{253}{\v r}
\DeclareInputText{238}{\c t}
\DeclareInputText{254}{\textblacksquare} % right name?
\DeclareInputText{239}{\@tabacckludge'{}}
\DeclareInputText{255}{\nobreakspace}
\endinput
%%
%% End of file `cp852.def'.
