%%
%% This is file `quotmark-estonian.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% quotmark.dtx  (with options: `quotmark-estonian.def,package')
%% 
%%  quotmark.dtx
%%  Copyright 2007 Nicola Talbot
%% 
%%  This work may be distributed and/or modified under the
%%  conditions of the LaTeX Project Public License, either version 1.3
%%  of this license of (at your option) any later version.
%%  The latest version of this license is in
%%    http://www.latex-project.org/lppl.txt
%%  and version 1.3 or later is part of all distributions of LaTeX
%%  version 2005/12/01 or later.
%% 
%%  This work has the LPPL maintenance status `maintained'.
%% 
%%  The Current Maintainer of this work is Nicola Talbot.
%% 
%%  This work consists of the files quotmark.dtx and quotmark.ins and the derived files quotmark.sty, quotmark-afrikaans.def, quotmark-brazil.def, quotmark-bulgarian.def, quotmark-catalan.def, quotmark-croatian.def, quotmark-czech.def, quotmark-danish.def, quotmark-dutch.def, quotmark-estonian.def, quotmark-finnish.def, quotmark-frenchb.def, quotmark-germanb.def, quotmark-greek.def, quotmark-hebrew.def, quotmark-icelandic.def, quotmark-irish.def, quotmark-italian.def, quotmark-magyar.def, quotmark-ngermanb.def, quotmark-norsk.def, quotmark-polish.def, quotmark-portuges.def, quotmark-romanian.def, quotmark-russianb.def, quotmark-serbian.def, quotmark-slovak.def, quotmark-slovene.def, quotmark-sorbian.def, quotmark-spanish.def, quotmark-swedish.def, quotmark-swiss.def, quotmark-turkish.def, quotmark-UKenglish.def, quotmark-ukraineb.def, quotmark-USenglish.def, quotmark-welsh.def.
%% 
%% \CharacterTable
%%  {Upper-case    \A\B\C\D\E\F\G\H\I\J\K\L\M\N\O\P\Q\R\S\T\U\V\W\X\Y\Z
%%   Lower-case    \a\b\c\d\e\f\g\h\i\j\k\l\m\n\o\p\q\r\s\t\u\v\w\x\y\z
%%   Digits        \0\1\2\3\4\5\6\7\8\9
%%   Exclamation   \!     Double quote  \"     Hash (number) \#
%%   Dollar        \$     Percent       \%     Ampersand     \&
%%   Acute accent  \'     Left paren    \(     Right paren   \)
%%   Asterisk      \*     Plus          \+     Comma         \,
%%   Minus         \-     Point         \.     Solidus       \/
%%   Colon         \:     Semicolon     \;     Less than     \<
%%   Equals        \=     Greater than  \>     Question mark \?
%%   Commercial at \@     Left bracket  \[     Backslash     \\
%%   Right bracket \]     Circumflex    \^     Underscore    \_
%%   Grave accent  \`     Left brace    \{     Vertical bar  \|
%%   Right brace   \}     Tilde         \~}
\ProvidesFile{quotmark-estonian}[2007/12/11]
\@namedef{quotemarks\CurrentOption}{%
  \setquotemarks{{\glqq}{\grqq}}%
  \setparquotemarks{}{}}
\setlanguagequotemarks{\CurrentOption}
\endinput
%%
%% End of file `quotmark-estonian.def'.
