\NewDocumentCommand{\tutodoc@trans@date}{mmm}{#1-#2-#3}
\NewDocumentCommand{\tutodoc@trans@in@EN}{m}{#1 in English}
\NewDocumentCommand{\tutodoc@trans@this@gives}{m}{This gives #1}
\NewDocumentCommand{\tutodoc@trans@latex@show@start}{}{Start of the real output}
\NewDocumentCommand{\tutodoc@trans@latex@show@end}{}{End of the real output}
\NewDocumentCommand{\tutodoc@trans@exa@title}{}{Example}
\NewDocumentCommand{\tutodoc@trans@rem@title}{}{Remark}
\NewDocumentCommand{\tutodoc@trans@note@title}{}{Note}
\NewDocumentCommand{\tutodoc@trans@tip@title}{}{Tip}
\NewDocumentCommand{\tutodoc@trans@imp@title}{}{Important}
\NewDocumentCommand{\tutodoc@trans@caut@title}{}{Caution}
\NewDocumentCommand{\tutodoc@trans@warn@title}{}{Warning}
\NewDocumentCommand{\tutodoc@trans@chges@tech}{}{Technical information}
\NewDocumentCommand{\tutodoc@trans@chges@todo}{}{Todo}
\NewDocumentCommand{\tutodoc@trans@chges@prob}{}{Problem}
\NewDocumentCommand{\tutodoc@trans@chges@break}{}{Break}
\NewDocumentCommand{\tutodoc@trans@chges@fix}{}{Fix}
\NewDocumentCommand{\tutodoc@trans@chges@new}{}{New}
\NewDocumentCommand{\tutodoc@trans@chges@update}{}{Update}