%%% Unicode to TeX mapping, file uni-188.def, U+BC00..U+BCFF, autogenerated by makeunidef.pl
\ifx\ProvidesFile\undefined\else
\ProvidesFile{uni-188.def}[2022/08/07 UCS: Unicode data U+BC00..U+BCFF]%
\fi
\gdef\u@cjk@hangul#1#2#3#4{{\fontencoding{C61}\def\CJK@plane{#1#2}\selectfont\char"#3#4\relax}}%
\uc@dclc{48128}{cjkhangul}{\u@cjk@hangul09FF}%
\uc@dclc{48130}{cjkhangul}{\u@cjk@hangul1000}%
\uc@dclc{48136}{cjkhangul}{\u@cjk@hangul1001}%
\uc@dclc{48137}{cjkhangul}{\u@cjk@hangul1002}%
\uc@dclc{48139}{cjkhangul}{\u@cjk@hangul1003}%
\uc@dclc{48140}{cjkhangul}{\u@cjk@hangul1004}%
\uc@dclc{48141}{cjkhangul}{\u@cjk@hangul1005}%
\uc@dclc{48143}{cjkhangul}{\u@cjk@hangul1006}%
\uc@dclc{48145}{cjkhangul}{\u@cjk@hangul1007}%
\uc@dclc{48148}{cjkhangul}{\u@cjk@hangul1008}%
\uc@dclc{48149}{cjkhangul}{\u@cjk@hangul1009}%
\uc@dclc{48150}{cjkhangul}{\u@cjk@hangul100A}%
\uc@dclc{48151}{cjkhangul}{\u@cjk@hangul100B}%
\uc@dclc{48152}{cjkhangul}{\u@cjk@hangul100C}%
\uc@dclc{48155}{cjkhangul}{\u@cjk@hangul100D}%
\uc@dclc{48156}{cjkhangul}{\u@cjk@hangul100E}%
\uc@dclc{48157}{cjkhangul}{\u@cjk@hangul100F}%
\uc@dclc{48158}{cjkhangul}{\u@cjk@hangul1010}%
\uc@dclc{48159}{cjkhangul}{\u@cjk@hangul1011}%
\uc@dclc{48164}{cjkhangul}{\u@cjk@hangul1012}%
\uc@dclc{48165}{cjkhangul}{\u@cjk@hangul1013}%
\uc@dclc{48167}{cjkhangul}{\u@cjk@hangul1014}%
\uc@dclc{48169}{cjkhangul}{\u@cjk@hangul1015}%
\uc@dclc{48173}{cjkhangul}{\u@cjk@hangul1016}%
\uc@dclc{48176}{cjkhangul}{\u@cjk@hangul1017}%
\uc@dclc{48177}{cjkhangul}{\u@cjk@hangul1018}%
\uc@dclc{48180}{cjkhangul}{\u@cjk@hangul1019}%
\uc@dclc{48184}{cjkhangul}{\u@cjk@hangul101A}%
\uc@dclc{48192}{cjkhangul}{\u@cjk@hangul101B}%
\uc@dclc{48193}{cjkhangul}{\u@cjk@hangul101C}%
\uc@dclc{48195}{cjkhangul}{\u@cjk@hangul101D}%
\uc@dclc{48196}{cjkhangul}{\u@cjk@hangul101E}%
\uc@dclc{48197}{cjkhangul}{\u@cjk@hangul101F}%
\uc@dclc{48201}{cjkhangul}{\u@cjk@hangul1020}%
\uc@dclc{48204}{cjkhangul}{\u@cjk@hangul1021}%
\uc@dclc{48205}{cjkhangul}{\u@cjk@hangul1022}%
\uc@dclc{48208}{cjkhangul}{\u@cjk@hangul1023}%
\uc@dclc{48221}{cjkhangul}{\u@cjk@hangul1024}%
\uc@dclc{48260}{cjkhangul}{\u@cjk@hangul1025}%
\uc@dclc{48261}{cjkhangul}{\u@cjk@hangul1026}%
\uc@dclc{48264}{cjkhangul}{\u@cjk@hangul1027}%
\uc@dclc{48267}{cjkhangul}{\u@cjk@hangul1028}%
\uc@dclc{48268}{cjkhangul}{\u@cjk@hangul1029}%
\uc@dclc{48270}{cjkhangul}{\u@cjk@hangul102A}%
\uc@dclc{48276}{cjkhangul}{\u@cjk@hangul102B}%
\uc@dclc{48277}{cjkhangul}{\u@cjk@hangul102C}%
\uc@dclc{48279}{cjkhangul}{\u@cjk@hangul102D}%
\uc@dclc{48281}{cjkhangul}{\u@cjk@hangul102E}%
\uc@dclc{48282}{cjkhangul}{\u@cjk@hangul102F}%
\uc@dclc{48288}{cjkhangul}{\u@cjk@hangul1030}%
\uc@dclc{48289}{cjkhangul}{\u@cjk@hangul1031}%
\uc@dclc{48292}{cjkhangul}{\u@cjk@hangul1032}%
\uc@dclc{48295}{cjkhangul}{\u@cjk@hangul1033}%
\uc@dclc{48296}{cjkhangul}{\u@cjk@hangul1034}%
\uc@dclc{48304}{cjkhangul}{\u@cjk@hangul1035}%
\uc@dclc{48305}{cjkhangul}{\u@cjk@hangul1036}%
\uc@dclc{48307}{cjkhangul}{\u@cjk@hangul1037}%
\uc@dclc{48308}{cjkhangul}{\u@cjk@hangul1038}%
\uc@dclc{48309}{cjkhangul}{\u@cjk@hangul1039}%
\uc@dclc{48316}{cjkhangul}{\u@cjk@hangul103A}%
\uc@dclc{48317}{cjkhangul}{\u@cjk@hangul103B}%
\uc@dclc{48320}{cjkhangul}{\u@cjk@hangul103C}%
\uc@dclc{48324}{cjkhangul}{\u@cjk@hangul103D}%
\uc@dclc{48333}{cjkhangul}{\u@cjk@hangul103E}%
\uc@dclc{48335}{cjkhangul}{\u@cjk@hangul103F}%
\uc@dclc{48336}{cjkhangul}{\u@cjk@hangul1040}%
\uc@dclc{48337}{cjkhangul}{\u@cjk@hangul1041}%
\uc@dclc{48341}{cjkhangul}{\u@cjk@hangul1042}%
\uc@dclc{48344}{cjkhangul}{\u@cjk@hangul1043}%
\uc@dclc{48348}{cjkhangul}{\u@cjk@hangul1044}%
\uc@dclc{48372}{cjkhangul}{\u@cjk@hangul1045}%
\uc@dclc{48373}{cjkhangul}{\u@cjk@hangul1046}%
\uc@dclc{48374}{cjkhangul}{\u@cjk@hangul1047}%
\uc@dclc{48376}{cjkhangul}{\u@cjk@hangul1048}%
\uc@dclc{48380}{cjkhangul}{\u@cjk@hangul1049}%
%%% Local Variables: 
%%% mode: latex
%%% coding: utf-8
%%% End: 
