%%% Unicode to TeX mapping, file uni-497.def, U+1F100..U+1F1FF, autogenerated by makeunidef.pl
\ifx\ProvidesFile\undefined\else
\ProvidesFile{uni-497.def}[2022/08/07 UCS: Unicode data U+1F100..U+1F1FF]%
\fi
\uc@dclc{127232}{autogenerated}{\unichar{48}\unichar{46}}%
\uc@dclc{127233}{autogenerated}{\unichar{48}\unichar{44}}%
\uc@dclc{127234}{autogenerated}{\unichar{49}\unichar{44}}%
\uc@dclc{127235}{autogenerated}{\unichar{50}\unichar{44}}%
\uc@dclc{127236}{autogenerated}{\unichar{51}\unichar{44}}%
\uc@dclc{127237}{autogenerated}{\unichar{52}\unichar{44}}%
\uc@dclc{127238}{autogenerated}{\unichar{53}\unichar{44}}%
\uc@dclc{127239}{autogenerated}{\unichar{54}\unichar{44}}%
\uc@dclc{127240}{autogenerated}{\unichar{55}\unichar{44}}%
\uc@dclc{127241}{autogenerated}{\unichar{56}\unichar{44}}%
\uc@dclc{127242}{autogenerated}{\unichar{57}\unichar{44}}%
\uc@dclc{127248}{autogenerated}{\unichar{40}\unichar{65}\unichar{41}}%
\uc@dclc{127249}{autogenerated}{\unichar{40}\unichar{66}\unichar{41}}%
\uc@dclc{127250}{autogenerated}{\unichar{40}\unichar{67}\unichar{41}}%
\uc@dclc{127251}{autogenerated}{\unichar{40}\unichar{68}\unichar{41}}%
\uc@dclc{127252}{autogenerated}{\unichar{40}\unichar{69}\unichar{41}}%
\uc@dclc{127253}{autogenerated}{\unichar{40}\unichar{70}\unichar{41}}%
\uc@dclc{127254}{autogenerated}{\unichar{40}\unichar{71}\unichar{41}}%
\uc@dclc{127255}{autogenerated}{\unichar{40}\unichar{72}\unichar{41}}%
\uc@dclc{127256}{autogenerated}{\unichar{40}\unichar{73}\unichar{41}}%
\uc@dclc{127257}{autogenerated}{\unichar{40}\unichar{74}\unichar{41}}%
\uc@dclc{127258}{autogenerated}{\unichar{40}\unichar{75}\unichar{41}}%
\uc@dclc{127259}{autogenerated}{\unichar{40}\unichar{76}\unichar{41}}%
\uc@dclc{127260}{autogenerated}{\unichar{40}\unichar{77}\unichar{41}}%
\uc@dclc{127261}{autogenerated}{\unichar{40}\unichar{78}\unichar{41}}%
\uc@dclc{127262}{autogenerated}{\unichar{40}\unichar{79}\unichar{41}}%
\uc@dclc{127263}{autogenerated}{\unichar{40}\unichar{80}\unichar{41}}%
\uc@dclc{127264}{autogenerated}{\unichar{40}\unichar{81}\unichar{41}}%
\uc@dclc{127265}{autogenerated}{\unichar{40}\unichar{82}\unichar{41}}%
\uc@dclc{127266}{autogenerated}{\unichar{40}\unichar{83}\unichar{41}}%
\uc@dclc{127267}{autogenerated}{\unichar{40}\unichar{84}\unichar{41}}%
\uc@dclc{127268}{autogenerated}{\unichar{40}\unichar{85}\unichar{41}}%
\uc@dclc{127269}{autogenerated}{\unichar{40}\unichar{86}\unichar{41}}%
\uc@dclc{127270}{autogenerated}{\unichar{40}\unichar{87}\unichar{41}}%
\uc@dclc{127271}{autogenerated}{\unichar{40}\unichar{88}\unichar{41}}%
\uc@dclc{127272}{autogenerated}{\unichar{40}\unichar{89}\unichar{41}}%
\uc@dclc{127273}{autogenerated}{\unichar{40}\unichar{90}\unichar{41}}%
\uc@dclc{127274}{autogenerated}{\unichar{12308}\unichar{83}\unichar{12309}}%
\uc@dclc{127275}{autogenerated}{\unicodecircle{\unichar{67}}}%
\uc@dclc{127276}{autogenerated}{\unicodecircle{\unichar{82}}}%
\uc@dclc{127277}{autogenerated}{\unicodecircle{\unichar{67}\unichar{68}}}%
\uc@dclc{127278}{autogenerated}{\unicodecircle{\unichar{87}\unichar{90}}}%
\uc@dclc{127280}{autogenerated}{\unicodesquare{\unichar{65}}}%
\uc@dclc{127281}{autogenerated}{\unicodesquare{\unichar{66}}}%
\uc@dclc{127282}{autogenerated}{\unicodesquare{\unichar{67}}}%
\uc@dclc{127283}{autogenerated}{\unicodesquare{\unichar{68}}}%
\uc@dclc{127284}{autogenerated}{\unicodesquare{\unichar{69}}}%
\uc@dclc{127285}{autogenerated}{\unicodesquare{\unichar{70}}}%
\uc@dclc{127286}{autogenerated}{\unicodesquare{\unichar{71}}}%
\uc@dclc{127287}{autogenerated}{\unicodesquare{\unichar{72}}}%
\uc@dclc{127288}{autogenerated}{\unicodesquare{\unichar{73}}}%
\uc@dclc{127289}{autogenerated}{\unicodesquare{\unichar{74}}}%
\uc@dclc{127290}{autogenerated}{\unicodesquare{\unichar{75}}}%
\uc@dclc{127291}{autogenerated}{\unicodesquare{\unichar{76}}}%
\uc@dclc{127292}{autogenerated}{\unicodesquare{\unichar{77}}}%
\uc@dclc{127293}{autogenerated}{\unicodesquare{\unichar{78}}}%
\uc@dclc{127294}{autogenerated}{\unicodesquare{\unichar{79}}}%
\uc@dclc{127295}{autogenerated}{\unicodesquare{\unichar{80}}}%
\uc@dclc{127296}{autogenerated}{\unicodesquare{\unichar{81}}}%
\uc@dclc{127297}{autogenerated}{\unicodesquare{\unichar{82}}}%
\uc@dclc{127298}{autogenerated}{\unicodesquare{\unichar{83}}}%
\uc@dclc{127299}{autogenerated}{\unicodesquare{\unichar{84}}}%
\uc@dclc{127300}{autogenerated}{\unicodesquare{\unichar{85}}}%
\uc@dclc{127301}{autogenerated}{\unicodesquare{\unichar{86}}}%
\uc@dclc{127302}{autogenerated}{\unicodesquare{\unichar{87}}}%
\uc@dclc{127303}{autogenerated}{\unicodesquare{\unichar{88}}}%
\uc@dclc{127304}{autogenerated}{\unicodesquare{\unichar{89}}}%
\uc@dclc{127305}{autogenerated}{\unicodesquare{\unichar{90}}}%
\uc@dclc{127306}{autogenerated}{\unicodesquare{\unichar{72}\unichar{86}}}%
\uc@dclc{127307}{autogenerated}{\unicodesquare{\unichar{77}\unichar{86}}}%
\uc@dclc{127308}{autogenerated}{\unicodesquare{\unichar{83}\unichar{68}}}%
\uc@dclc{127309}{autogenerated}{\unicodesquare{\unichar{83}\unichar{83}}}%
\uc@dclc{127310}{autogenerated}{\unicodesquare{\unichar{80}\unichar{80}\unichar{86}}}%
\uc@dclc{127311}{autogenerated}{\unicodesquare{\unichar{87}\unichar{67}}}%
\uc@dclc{127338}{autogenerated}{\unicodesuper{\unichar{77}\unichar{67}}}%
\uc@dclc{127339}{autogenerated}{\unicodesuper{\unichar{77}\unichar{68}}}%
\uc@dclc{127340}{autogenerated}{\unicodesuper{\unichar{77}\unichar{82}}}%
\uc@dclc{127376}{autogenerated}{\unicodesquare{\unichar{68}\unichar{74}}}%
%%% Local Variables: 
%%% mode: latex
%%% coding: utf-8
%%% End: 
