%!TEX encoding = UTF-8 Unicode
%
%
\ProvidesFile{europasscv_pt.def}[europasscv Portuguese definitions]
% Personal information
\def\ecv@infosectionkey{\ecv@utf{Informa\c{c}\~ao pessoal}}
\def\ecv@namekey{\ecv@utf{Nome Apelido}}
\def\ecv@addresskey{\ecv@utf{Morada}}
\def\ecv@telkey{\ecv@utf{Telefone}}
\def\ecv@mobilekey{\ecv@utf{Telem\'ovel}}
\def\ecv@faxkey{\ecv@utf{Fax}}
\def\ecv@emailkey{\ecv@utf{Correio eletr\'onico}}
\def\ecv@nationalitykey{\ecv@utf{Nacionalidade}}
\def\ecv@birthkey{\ecv@utf{Data de nascimento}}
\def\ecv@genderkey{\ecv@utf{Sexo}}
% Footer
\def\ecv@pagekey{\ecv@utf{P\'agina}}
\def\ecv@cvofkey{\ecv@utf{Curriculum vit\ae\ de}}
% Language table
\def\ecv@mothertonguekey{\ecv@utf{L\'ingua materna}}
\def\ecv@otherlanguageskey{\ecv@utf{Outras l\'inguas}}
\def\ecv@assesskey{\ecv@utf{Autoavalia\c{c}\~ao}}
\def\ecv@levelkey{\ecv@utf{N\'ivel  europeu}}
\def\ecv@understandkey{\ecv@utf{Compreender}}
\def\ecv@speakkey{\ecv@utf{Falar}}
\def\ecv@writekey{\ecv@utf{Escrever}}
\def\ecv@listenkey{\ecv@utf{Compreens\~ao oral}}
\def\ecv@readkey{\ecv@utf{Leitura}}
\def\ecv@interactkey{\ecv@utf{Intera\c{c}\~ao oral}}
\def\ecv@productkey{\ecv@utf{Produ\c{c}\~ao oral}}
\def\ecv@langshortdesckey{\ecv@utf{N\'iveis: A1 e A2: Utilizador b\'asico -- B1 e B2: Utilizador independente -- C1 e C2: Utilizador avan\c{c}ado}}
\def\ecv@langfooterkey{\ecv@utf{Quadro Europeu Comum de Refer\^encia para as L\'inguas }}
\def\ecv@langlinkkey{\ecv@utf{https://europass.cedefop.europa.eu/pt/resources/european-language-levels-cefr}}
\def\ecv@cefbasickey{\ecv@utf{Utilizador b\'asico}}
\def\ecv@cefindepkey{\ecv@utf{Utilizador independente}}
\def\ecv@cefprofkey{\ecv@utf{Utilizador avan\c{c}ado}}
\def\ecv@europeanunionkey{\ecv@utf{Uni\~ao Europeia}}
% Digital competences self-assessment grid
\def\ecv@digitalcompetenceskey{\ecv@utf{Compet{\^e}ncias digitais}}
\def\ecv@informationprocessingkey{\ecv@utf{Processamento de informa\c{c}{\~a}o}}
\def\ecv@communicationkey{\ecv@utf{Comunica\c{c}{\~a}o}}
\def\ecv@contentcreationkey{\ecv@utf{Cria\c{c}{\~a}o de conte{\'u}dos}}
\def\ecv@safetykey{\ecv@utf{Seguran\c{c}a}}
\def\ecv@problensolvingkey{\ecv@utf{Resolu\c{c}{\~a}o de problemas}}
\def\ecv@digcompfooterkey{\ecv@utf{Compet{\^e}ncias digitais - Grelha de autoavalia\c{c}{\~a}o}}
\def\ecv@digcomplinkkey{\ecv@utf{https://europass.cedefop.europa.eu/pt/resources/digital-competences}}
\def\ecv@dcbasickey{\ecv@utf{Utilizador b{\'a}sico}}
\def\ecv@dcindepkey{\ecv@utf{Utilizador independente}}
\def\ecv@dcprofkey{\ecv@utf{Utilizador avan\c{c}ado}}

% Width of language columns
\def\ecv@langcola{0.22}
\def\ecv@langcolb{0.22}
\def\ecv@langcolc{0.19}
\def\ecv@langcold{0.19}
\def\ecv@langcole{0.18}
