%%
%% This is file `ydoc.cls',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% ydoc.dtx  (with options: `ydoc.cls')
%% 
\NeedsTeXFormat{LaTeX2e}[1999/12/01]
\ProvidesClass{ydoc}[%
    2022/10/26
    v0.7alpha
    ydoc class: document LaTeX class and packages]
\PassOptionsToClass{a4paper}{article}
\DeclareOption*{\expandafter\PassOptionsToClass\expandafter{\CurrentOption}{article}}
\ProcessOptions\relax
\LoadClass{article}
\RequirePackage{ydoc}
\endinput
%%
%% End of file `ydoc.cls'.
