%%% Unicode to TeX mapping, file uni-49.def, U+3100..U+31FF, autogenerated by makeunidef.pl
\ifx\ProvidesFile\undefined\else
\ProvidesFile{uni-49.def}[2022/08/07 UCS: Unicode data U+3100..U+31FF]%
\fi
\gdef\u@cjk@Bgv#1#2#3#4{{\fontencoding{C00}\def\CJK@plane{#1#2}\selectfont\char"#3#4\relax}}%
\uc@dclc{12549}{cjkbg5}{\u@cjk@Bgv026E}%
\uc@dclc{12550}{cjkbg5}{\u@cjk@Bgv026F}%
\uc@dclc{12551}{cjkbg5}{\u@cjk@Bgv0270}%
\uc@dclc{12552}{cjkbg5}{\u@cjk@Bgv0271}%
\uc@dclc{12553}{cjkbg5}{\u@cjk@Bgv0272}%
\uc@dclc{12554}{cjkbg5}{\u@cjk@Bgv0273}%
\uc@dclc{12555}{cjkbg5}{\u@cjk@Bgv0274}%
\uc@dclc{12556}{cjkbg5}{\u@cjk@Bgv0275}%
\uc@dclc{12557}{cjkbg5}{\u@cjk@Bgv0276}%
\uc@dclc{12558}{cjkbg5}{\u@cjk@Bgv0277}%
\uc@dclc{12559}{cjkbg5}{\u@cjk@Bgv0278}%
\uc@dclc{12560}{cjkbg5}{\u@cjk@Bgv0279}%
\uc@dclc{12561}{cjkbg5}{\u@cjk@Bgv027A}%
\uc@dclc{12562}{cjkbg5}{\u@cjk@Bgv027B}%
\uc@dclc{12563}{cjkbg5}{\u@cjk@Bgv027C}%
\uc@dclc{12564}{cjkbg5}{\u@cjk@Bgv027D}%
\uc@dclc{12565}{cjkbg5}{\u@cjk@Bgv027E}%
\uc@dclc{12566}{cjkbg5}{\u@cjk@Bgv027F}%
\uc@dclc{12567}{cjkbg5}{\u@cjk@Bgv0280}%
\uc@dclc{12568}{cjkbg5}{\u@cjk@Bgv0281}%
\uc@dclc{12569}{cjkbg5}{\u@cjk@Bgv0282}%
\uc@dclc{12570}{cjkbg5}{\u@cjk@Bgv0283}%
\uc@dclc{12571}{cjkbg5}{\u@cjk@Bgv0284}%
\uc@dclc{12572}{cjkbg5}{\u@cjk@Bgv0285}%
\uc@dclc{12573}{cjkbg5}{\u@cjk@Bgv0286}%
\uc@dclc{12574}{cjkbg5}{\u@cjk@Bgv0287}%
\uc@dclc{12575}{cjkbg5}{\u@cjk@Bgv0288}%
\uc@dclc{12576}{cjkbg5}{\u@cjk@Bgv0289}%
\uc@dclc{12577}{cjkbg5}{\u@cjk@Bgv028A}%
\uc@dclc{12578}{cjkbg5}{\u@cjk@Bgv028B}%
\uc@dclc{12579}{cjkbg5}{\u@cjk@Bgv028C}%
\uc@dclc{12580}{cjkbg5}{\u@cjk@Bgv028D}%
\uc@dclc{12581}{cjkbg5}{\u@cjk@Bgv028E}%
\uc@dclc{12582}{cjkbg5}{\u@cjk@Bgv028F}%
\uc@dclc{12583}{cjkbg5}{\u@cjk@Bgv0290}%
\uc@dclc{12584}{cjkbg5}{\u@cjk@Bgv0291}%
\uc@dclc{12585}{cjkbg5}{\u@cjk@Bgv0292}%
\gdef\u@cjk@hangul#1#2#3#4{{\fontencoding{C61}\def\CJK@plane{#1#2}\selectfont\char"#3#4\relax}}%
\uc@dclc{12593}{cjkhangul}{\u@cjk@hangul021A}%
\uc@dclc{12594}{cjkhangul}{\u@cjk@hangul021B}%
\uc@dclc{12595}{cjkhangul}{\u@cjk@hangul021C}%
\uc@dclc{12596}{cjkhangul}{\u@cjk@hangul021D}%
\uc@dclc{12597}{cjkhangul}{\u@cjk@hangul021E}%
\uc@dclc{12598}{cjkhangul}{\u@cjk@hangul021F}%
\uc@dclc{12599}{cjkhangul}{\u@cjk@hangul0220}%
\uc@dclc{12600}{cjkhangul}{\u@cjk@hangul0221}%
\uc@dclc{12601}{cjkhangul}{\u@cjk@hangul0222}%
\uc@dclc{12602}{cjkhangul}{\u@cjk@hangul0223}%
\uc@dclc{12603}{cjkhangul}{\u@cjk@hangul0224}%
\uc@dclc{12604}{cjkhangul}{\u@cjk@hangul0225}%
\uc@dclc{12605}{cjkhangul}{\u@cjk@hangul0226}%
\uc@dclc{12606}{cjkhangul}{\u@cjk@hangul0227}%
\uc@dclc{12607}{cjkhangul}{\u@cjk@hangul0228}%
\uc@dclc{12608}{cjkhangul}{\u@cjk@hangul0229}%
\uc@dclc{12609}{cjkhangul}{\u@cjk@hangul022A}%
\uc@dclc{12610}{cjkhangul}{\u@cjk@hangul022B}%
\uc@dclc{12611}{cjkhangul}{\u@cjk@hangul022C}%
\uc@dclc{12612}{cjkhangul}{\u@cjk@hangul022D}%
\uc@dclc{12613}{cjkhangul}{\u@cjk@hangul022E}%
\uc@dclc{12614}{cjkhangul}{\u@cjk@hangul022F}%
\uc@dclc{12615}{cjkhangul}{\u@cjk@hangul0230}%
\uc@dclc{12616}{cjkhangul}{\u@cjk@hangul0231}%
\uc@dclc{12617}{cjkhangul}{\u@cjk@hangul0232}%
\uc@dclc{12618}{cjkhangul}{\u@cjk@hangul0233}%
\uc@dclc{12619}{cjkhangul}{\u@cjk@hangul0234}%
\uc@dclc{12620}{cjkhangul}{\u@cjk@hangul0235}%
\uc@dclc{12621}{cjkhangul}{\u@cjk@hangul0236}%
\uc@dclc{12622}{cjkhangul}{\u@cjk@hangul0237}%
\uc@dclc{12623}{cjkhangul}{\u@cjk@hangul0238}%
\uc@dclc{12624}{cjkhangul}{\u@cjk@hangul0239}%
\uc@dclc{12625}{cjkhangul}{\u@cjk@hangul023A}%
\uc@dclc{12626}{cjkhangul}{\u@cjk@hangul023B}%
\uc@dclc{12627}{cjkhangul}{\u@cjk@hangul023C}%
\uc@dclc{12628}{cjkhangul}{\u@cjk@hangul023D}%
\uc@dclc{12629}{cjkhangul}{\u@cjk@hangul023E}%
\uc@dclc{12630}{cjkhangul}{\u@cjk@hangul023F}%
\uc@dclc{12631}{cjkhangul}{\u@cjk@hangul0240}%
\uc@dclc{12632}{cjkhangul}{\u@cjk@hangul0241}%
\uc@dclc{12633}{cjkhangul}{\u@cjk@hangul0242}%
\uc@dclc{12634}{cjkhangul}{\u@cjk@hangul0243}%
\uc@dclc{12635}{cjkhangul}{\u@cjk@hangul0244}%
\uc@dclc{12636}{cjkhangul}{\u@cjk@hangul0245}%
\uc@dclc{12637}{cjkhangul}{\u@cjk@hangul0246}%
\uc@dclc{12638}{cjkhangul}{\u@cjk@hangul0247}%
\uc@dclc{12639}{cjkhangul}{\u@cjk@hangul0248}%
\uc@dclc{12640}{cjkhangul}{\u@cjk@hangul0249}%
\uc@dclc{12641}{cjkhangul}{\u@cjk@hangul024A}%
\uc@dclc{12642}{cjkhangul}{\u@cjk@hangul024B}%
\uc@dclc{12643}{cjkhangul}{\u@cjk@hangul024C}%
\uc@dclc{12644}{cjkhangul}{\u@cjk@hangul024D}%
\uc@dclc{12645}{cjkhangul}{\u@cjk@hangul024E}%
\uc@dclc{12646}{cjkhangul}{\u@cjk@hangul024F}%
\uc@dclc{12647}{cjkhangul}{\u@cjk@hangul0250}%
\uc@dclc{12648}{cjkhangul}{\u@cjk@hangul0251}%
\uc@dclc{12649}{cjkhangul}{\u@cjk@hangul0252}%
\uc@dclc{12650}{cjkhangul}{\u@cjk@hangul0253}%
\uc@dclc{12651}{cjkhangul}{\u@cjk@hangul0254}%
\uc@dclc{12652}{cjkhangul}{\u@cjk@hangul0255}%
\uc@dclc{12653}{cjkhangul}{\u@cjk@hangul0256}%
\uc@dclc{12654}{cjkhangul}{\u@cjk@hangul0257}%
\uc@dclc{12655}{cjkhangul}{\u@cjk@hangul0258}%
\uc@dclc{12656}{cjkhangul}{\u@cjk@hangul0259}%
\uc@dclc{12657}{cjkhangul}{\u@cjk@hangul025A}%
\uc@dclc{12658}{cjkhangul}{\u@cjk@hangul025B}%
\uc@dclc{12659}{cjkhangul}{\u@cjk@hangul025C}%
\uc@dclc{12660}{cjkhangul}{\u@cjk@hangul025D}%
\uc@dclc{12661}{cjkhangul}{\u@cjk@hangul025E}%
\uc@dclc{12662}{cjkhangul}{\u@cjk@hangul025F}%
\uc@dclc{12663}{cjkhangul}{\u@cjk@hangul0260}%
\uc@dclc{12664}{cjkhangul}{\u@cjk@hangul0261}%
\uc@dclc{12665}{cjkhangul}{\u@cjk@hangul0262}%
\uc@dclc{12666}{cjkhangul}{\u@cjk@hangul0263}%
\uc@dclc{12667}{cjkhangul}{\u@cjk@hangul0264}%
\uc@dclc{12668}{cjkhangul}{\u@cjk@hangul0265}%
\uc@dclc{12669}{cjkhangul}{\u@cjk@hangul0266}%
\uc@dclc{12670}{cjkhangul}{\u@cjk@hangul0267}%
\uc@dclc{12671}{cjkhangul}{\u@cjk@hangul0268}%
\uc@dclc{12672}{cjkhangul}{\u@cjk@hangul0269}%
\uc@dclc{12673}{cjkhangul}{\u@cjk@hangul026A}%
\uc@dclc{12674}{cjkhangul}{\u@cjk@hangul026B}%
\uc@dclc{12675}{cjkhangul}{\u@cjk@hangul026C}%
\uc@dclc{12676}{cjkhangul}{\u@cjk@hangul026D}%
\uc@dclc{12677}{cjkhangul}{\u@cjk@hangul026E}%
\uc@dclc{12678}{cjkhangul}{\u@cjk@hangul026F}%
\uc@dclc{12679}{cjkhangul}{\u@cjk@hangul0270}%
\uc@dclc{12680}{cjkhangul}{\u@cjk@hangul0271}%
\uc@dclc{12681}{cjkhangul}{\u@cjk@hangul0272}%
\uc@dclc{12682}{cjkhangul}{\u@cjk@hangul0273}%
\uc@dclc{12683}{cjkhangul}{\u@cjk@hangul0274}%
\uc@dclc{12684}{cjkhangul}{\u@cjk@hangul0275}%
\uc@dclc{12685}{cjkhangul}{\u@cjk@hangul0276}%
\uc@dclc{12686}{cjkhangul}{\u@cjk@hangul0277}%
\uc@dclc{12690}{autogenerated}{\unicodesuper{\unichar{19968}}}%
\uc@dclc{12691}{autogenerated}{\unicodesuper{\unichar{20108}}}%
\uc@dclc{12692}{autogenerated}{\unicodesuper{\unichar{19977}}}%
\uc@dclc{12693}{autogenerated}{\unicodesuper{\unichar{22235}}}%
\uc@dclc{12694}{autogenerated}{\unicodesuper{\unichar{19978}}}%
\uc@dclc{12695}{autogenerated}{\unicodesuper{\unichar{20013}}}%
\uc@dclc{12696}{autogenerated}{\unicodesuper{\unichar{19979}}}%
\uc@dclc{12697}{autogenerated}{\unicodesuper{\unichar{30002}}}%
\uc@dclc{12698}{autogenerated}{\unicodesuper{\unichar{20057}}}%
\uc@dclc{12699}{autogenerated}{\unicodesuper{\unichar{19993}}}%
\uc@dclc{12700}{autogenerated}{\unicodesuper{\unichar{19969}}}%
\uc@dclc{12701}{autogenerated}{\unicodesuper{\unichar{22825}}}%
\uc@dclc{12702}{autogenerated}{\unicodesuper{\unichar{22320}}}%
\uc@dclc{12703}{autogenerated}{\unicodesuper{\unichar{20154}}}%
%%% Local Variables: 
%%% mode: latex
%%% coding: utf-8
%%% End: 
