%%% Unicode to TeX mapping, file uni-198.def, U+C600..U+C6FF, autogenerated by makeunidef.pl
\ifx\ProvidesFile\undefined\else
\ProvidesFile{uni-198.def}[2022/08/07 UCS: Unicode data U+C600..U+C6FF]%
\fi
\gdef\u@cjk@hangul#1#2#3#4{{\fontencoding{C61}\def\CJK@plane{#1#2}\selectfont\char"#3#4\relax}}%
\uc@dclc{50688}{cjkhangul}{\u@cjk@hangul1217}%
\uc@dclc{50689}{cjkhangul}{\u@cjk@hangul1218}%
\uc@dclc{50693}{cjkhangul}{\u@cjk@hangul1219}%
\uc@dclc{50694}{cjkhangul}{\u@cjk@hangul121A}%
\uc@dclc{50695}{cjkhangul}{\u@cjk@hangul121B}%
\uc@dclc{50696}{cjkhangul}{\u@cjk@hangul121C}%
\uc@dclc{50700}{cjkhangul}{\u@cjk@hangul121D}%
\uc@dclc{50704}{cjkhangul}{\u@cjk@hangul121E}%
\uc@dclc{50712}{cjkhangul}{\u@cjk@hangul121F}%
\uc@dclc{50713}{cjkhangul}{\u@cjk@hangul1220}%
\uc@dclc{50715}{cjkhangul}{\u@cjk@hangul1221}%
\uc@dclc{50716}{cjkhangul}{\u@cjk@hangul1222}%
\uc@dclc{50724}{cjkhangul}{\u@cjk@hangul1223}%
\uc@dclc{50725}{cjkhangul}{\u@cjk@hangul1224}%
\uc@dclc{50728}{cjkhangul}{\u@cjk@hangul1225}%
\uc@dclc{50732}{cjkhangul}{\u@cjk@hangul1226}%
\uc@dclc{50733}{cjkhangul}{\u@cjk@hangul1227}%
\uc@dclc{50734}{cjkhangul}{\u@cjk@hangul1228}%
\uc@dclc{50736}{cjkhangul}{\u@cjk@hangul1229}%
\uc@dclc{50739}{cjkhangul}{\u@cjk@hangul122A}%
\uc@dclc{50740}{cjkhangul}{\u@cjk@hangul122B}%
\uc@dclc{50741}{cjkhangul}{\u@cjk@hangul122C}%
\uc@dclc{50743}{cjkhangul}{\u@cjk@hangul122D}%
\uc@dclc{50745}{cjkhangul}{\u@cjk@hangul122E}%
\uc@dclc{50747}{cjkhangul}{\u@cjk@hangul122F}%
\uc@dclc{50752}{cjkhangul}{\u@cjk@hangul1230}%
\uc@dclc{50753}{cjkhangul}{\u@cjk@hangul1231}%
\uc@dclc{50756}{cjkhangul}{\u@cjk@hangul1232}%
\uc@dclc{50760}{cjkhangul}{\u@cjk@hangul1233}%
\uc@dclc{50768}{cjkhangul}{\u@cjk@hangul1234}%
\uc@dclc{50769}{cjkhangul}{\u@cjk@hangul1235}%
\uc@dclc{50771}{cjkhangul}{\u@cjk@hangul1236}%
\uc@dclc{50772}{cjkhangul}{\u@cjk@hangul1237}%
\uc@dclc{50773}{cjkhangul}{\u@cjk@hangul1238}%
\uc@dclc{50780}{cjkhangul}{\u@cjk@hangul1239}%
\uc@dclc{50781}{cjkhangul}{\u@cjk@hangul123A}%
\uc@dclc{50784}{cjkhangul}{\u@cjk@hangul123B}%
\uc@dclc{50796}{cjkhangul}{\u@cjk@hangul123C}%
\uc@dclc{50799}{cjkhangul}{\u@cjk@hangul123D}%
\uc@dclc{50801}{cjkhangul}{\u@cjk@hangul123E}%
\uc@dclc{50808}{cjkhangul}{\u@cjk@hangul123F}%
\uc@dclc{50809}{cjkhangul}{\u@cjk@hangul1240}%
\uc@dclc{50812}{cjkhangul}{\u@cjk@hangul1241}%
\uc@dclc{50816}{cjkhangul}{\u@cjk@hangul1242}%
\uc@dclc{50824}{cjkhangul}{\u@cjk@hangul1243}%
\uc@dclc{50825}{cjkhangul}{\u@cjk@hangul1244}%
\uc@dclc{50827}{cjkhangul}{\u@cjk@hangul1245}%
\uc@dclc{50829}{cjkhangul}{\u@cjk@hangul1246}%
\uc@dclc{50836}{cjkhangul}{\u@cjk@hangul1247}%
\uc@dclc{50837}{cjkhangul}{\u@cjk@hangul1248}%
\uc@dclc{50840}{cjkhangul}{\u@cjk@hangul1249}%
\uc@dclc{50844}{cjkhangul}{\u@cjk@hangul124A}%
\uc@dclc{50852}{cjkhangul}{\u@cjk@hangul124B}%
\uc@dclc{50853}{cjkhangul}{\u@cjk@hangul124C}%
\uc@dclc{50855}{cjkhangul}{\u@cjk@hangul124D}%
\uc@dclc{50857}{cjkhangul}{\u@cjk@hangul124E}%
\uc@dclc{50864}{cjkhangul}{\u@cjk@hangul124F}%
\uc@dclc{50865}{cjkhangul}{\u@cjk@hangul1250}%
\uc@dclc{50868}{cjkhangul}{\u@cjk@hangul1251}%
\uc@dclc{50872}{cjkhangul}{\u@cjk@hangul1252}%
\uc@dclc{50873}{cjkhangul}{\u@cjk@hangul1253}%
\uc@dclc{50874}{cjkhangul}{\u@cjk@hangul1254}%
\uc@dclc{50880}{cjkhangul}{\u@cjk@hangul1255}%
\uc@dclc{50881}{cjkhangul}{\u@cjk@hangul1256}%
\uc@dclc{50883}{cjkhangul}{\u@cjk@hangul1257}%
\uc@dclc{50885}{cjkhangul}{\u@cjk@hangul1258}%
\uc@dclc{50892}{cjkhangul}{\u@cjk@hangul1259}%
\uc@dclc{50893}{cjkhangul}{\u@cjk@hangul125A}%
\uc@dclc{50896}{cjkhangul}{\u@cjk@hangul125B}%
\uc@dclc{50900}{cjkhangul}{\u@cjk@hangul125C}%
\uc@dclc{50908}{cjkhangul}{\u@cjk@hangul125D}%
\uc@dclc{50909}{cjkhangul}{\u@cjk@hangul125E}%
\uc@dclc{50912}{cjkhangul}{\u@cjk@hangul125F}%
\uc@dclc{50913}{cjkhangul}{\u@cjk@hangul1260}%
\uc@dclc{50920}{cjkhangul}{\u@cjk@hangul1261}%
\uc@dclc{50921}{cjkhangul}{\u@cjk@hangul1262}%
\uc@dclc{50924}{cjkhangul}{\u@cjk@hangul1263}%
\uc@dclc{50928}{cjkhangul}{\u@cjk@hangul1264}%
\uc@dclc{50936}{cjkhangul}{\u@cjk@hangul1265}%
\uc@dclc{50937}{cjkhangul}{\u@cjk@hangul1266}%
\uc@dclc{50941}{cjkhangul}{\u@cjk@hangul1267}%
%%% Local Variables: 
%%% mode: latex
%%% coding: utf-8
%%% End: 
