%%% Unicode to TeX mapping, file uni-175.def, U+AF00..U+AFFF, autogenerated by makeunidef.pl
\ifx\ProvidesFile\undefined\else
\ProvidesFile{uni-175.def}[2022/08/07 UCS: Unicode data U+AF00..U+AFFF]%
\fi
\gdef\u@cjk@hangul#1#2#3#4{{\fontencoding{C61}\def\CJK@plane{#1#2}\selectfont\char"#3#4\relax}}%
\uc@dclc{44807}{cjkhangul}{\u@cjk@hangul0758}%
\uc@dclc{44808}{cjkhangul}{\u@cjk@hangul0759}%
\uc@dclc{44813}{cjkhangul}{\u@cjk@hangul075A}%
\uc@dclc{44816}{cjkhangul}{\u@cjk@hangul075B}%
\uc@dclc{44844}{cjkhangul}{\u@cjk@hangul075C}%
\uc@dclc{44845}{cjkhangul}{\u@cjk@hangul075D}%
\uc@dclc{44848}{cjkhangul}{\u@cjk@hangul075E}%
\uc@dclc{44850}{cjkhangul}{\u@cjk@hangul075F}%
\uc@dclc{44852}{cjkhangul}{\u@cjk@hangul0760}%
\uc@dclc{44860}{cjkhangul}{\u@cjk@hangul0761}%
\uc@dclc{44861}{cjkhangul}{\u@cjk@hangul0762}%
\uc@dclc{44863}{cjkhangul}{\u@cjk@hangul0763}%
\uc@dclc{44865}{cjkhangul}{\u@cjk@hangul0764}%
\uc@dclc{44866}{cjkhangul}{\u@cjk@hangul0765}%
\uc@dclc{44867}{cjkhangul}{\u@cjk@hangul0766}%
\uc@dclc{44872}{cjkhangul}{\u@cjk@hangul0767}%
\uc@dclc{44873}{cjkhangul}{\u@cjk@hangul0768}%
\uc@dclc{44880}{cjkhangul}{\u@cjk@hangul0769}%
\uc@dclc{44892}{cjkhangul}{\u@cjk@hangul076A}%
\uc@dclc{44893}{cjkhangul}{\u@cjk@hangul076B}%
\uc@dclc{44900}{cjkhangul}{\u@cjk@hangul076C}%
\uc@dclc{44901}{cjkhangul}{\u@cjk@hangul076D}%
\uc@dclc{44921}{cjkhangul}{\u@cjk@hangul076E}%
\uc@dclc{44928}{cjkhangul}{\u@cjk@hangul076F}%
\uc@dclc{44932}{cjkhangul}{\u@cjk@hangul0770}%
\uc@dclc{44936}{cjkhangul}{\u@cjk@hangul0771}%
\uc@dclc{44944}{cjkhangul}{\u@cjk@hangul0772}%
\uc@dclc{44945}{cjkhangul}{\u@cjk@hangul0773}%
\uc@dclc{44949}{cjkhangul}{\u@cjk@hangul0774}%
\uc@dclc{44956}{cjkhangul}{\u@cjk@hangul0775}%
\uc@dclc{44984}{cjkhangul}{\u@cjk@hangul0776}%
\uc@dclc{44985}{cjkhangul}{\u@cjk@hangul0777}%
\uc@dclc{44988}{cjkhangul}{\u@cjk@hangul0778}%
\uc@dclc{44992}{cjkhangul}{\u@cjk@hangul0779}%
\uc@dclc{44999}{cjkhangul}{\u@cjk@hangul077A}%
\uc@dclc{45000}{cjkhangul}{\u@cjk@hangul077B}%
\uc@dclc{45001}{cjkhangul}{\u@cjk@hangul077C}%
\uc@dclc{45003}{cjkhangul}{\u@cjk@hangul077D}%
\uc@dclc{45005}{cjkhangul}{\u@cjk@hangul077E}%
\uc@dclc{45006}{cjkhangul}{\u@cjk@hangul077F}%
\uc@dclc{45012}{cjkhangul}{\u@cjk@hangul0780}%
\uc@dclc{45020}{cjkhangul}{\u@cjk@hangul0781}%
\uc@dclc{45032}{cjkhangul}{\u@cjk@hangul0782}%
\uc@dclc{45033}{cjkhangul}{\u@cjk@hangul0783}%
\uc@dclc{45040}{cjkhangul}{\u@cjk@hangul0784}%
\uc@dclc{45041}{cjkhangul}{\u@cjk@hangul0785}%
\uc@dclc{45044}{cjkhangul}{\u@cjk@hangul0786}%
\uc@dclc{45048}{cjkhangul}{\u@cjk@hangul0787}%
%%% Local Variables: 
%%% mode: latex
%%% coding: utf-8
%%% End: 
