%%% Unicode to TeX mapping, file uni-196.def, U+C400..U+C4FF, autogenerated by makeunidef.pl
\ifx\ProvidesFile\undefined\else
\ProvidesFile{uni-196.def}[2022/08/07 UCS: Unicode data U+C400..U+C4FF]%
\fi
\gdef\u@cjk@hangul#1#2#3#4{{\fontencoding{C61}\def\CJK@plane{#1#2}\selectfont\char"#3#4\relax}}%
\uc@dclc{50184}{cjkhangul}{\u@cjk@hangul11A1}%
\uc@dclc{50192}{cjkhangul}{\u@cjk@hangul11A2}%
\uc@dclc{50212}{cjkhangul}{\u@cjk@hangul11A3}%
\uc@dclc{50220}{cjkhangul}{\u@cjk@hangul11A4}%
\uc@dclc{50224}{cjkhangul}{\u@cjk@hangul11A5}%
\uc@dclc{50228}{cjkhangul}{\u@cjk@hangul11A6}%
\uc@dclc{50236}{cjkhangul}{\u@cjk@hangul11A7}%
\uc@dclc{50237}{cjkhangul}{\u@cjk@hangul11A8}%
\uc@dclc{50248}{cjkhangul}{\u@cjk@hangul11A9}%
\uc@dclc{50276}{cjkhangul}{\u@cjk@hangul11AA}%
\uc@dclc{50277}{cjkhangul}{\u@cjk@hangul11AB}%
\uc@dclc{50280}{cjkhangul}{\u@cjk@hangul11AC}%
\uc@dclc{50284}{cjkhangul}{\u@cjk@hangul11AD}%
\uc@dclc{50292}{cjkhangul}{\u@cjk@hangul11AE}%
\uc@dclc{50293}{cjkhangul}{\u@cjk@hangul11AF}%
\uc@dclc{50297}{cjkhangul}{\u@cjk@hangul11B0}%
\uc@dclc{50304}{cjkhangul}{\u@cjk@hangul11B1}%
\uc@dclc{50324}{cjkhangul}{\u@cjk@hangul11B2}%
\uc@dclc{50332}{cjkhangul}{\u@cjk@hangul11B3}%
\uc@dclc{50360}{cjkhangul}{\u@cjk@hangul11B4}%
\uc@dclc{50364}{cjkhangul}{\u@cjk@hangul11B5}%
\uc@dclc{50409}{cjkhangul}{\u@cjk@hangul11B6}%
\uc@dclc{50416}{cjkhangul}{\u@cjk@hangul11B7}%
\uc@dclc{50417}{cjkhangul}{\u@cjk@hangul11B8}%
\uc@dclc{50420}{cjkhangul}{\u@cjk@hangul11B9}%
\uc@dclc{50424}{cjkhangul}{\u@cjk@hangul11BA}%
\uc@dclc{50426}{cjkhangul}{\u@cjk@hangul11BB}%
\uc@dclc{50431}{cjkhangul}{\u@cjk@hangul11BC}%
%%% Local Variables: 
%%% mode: latex
%%% coding: utf-8
%%% End: 
