%%% Unicode to TeX mapping, file uni-215.def, U+D700..U+D7FF, autogenerated by makeunidef.pl
\ifx\ProvidesFile\undefined\else
\ProvidesFile{uni-215.def}[2022/08/07 UCS: Unicode data U+D700..U+D7FF]%
\fi
\gdef\u@cjk@hangul#1#2#3#4{{\fontencoding{C61}\def\CJK@plane{#1#2}\selectfont\char"#3#4\relax}}%
\uc@dclc{55040}{cjkhangul}{\u@cjk@hangul1584}%
\uc@dclc{55044}{cjkhangul}{\u@cjk@hangul1585}%
\uc@dclc{55057}{cjkhangul}{\u@cjk@hangul1586}%
\uc@dclc{55064}{cjkhangul}{\u@cjk@hangul1587}%
\uc@dclc{55065}{cjkhangul}{\u@cjk@hangul1588}%
\uc@dclc{55068}{cjkhangul}{\u@cjk@hangul1589}%
\uc@dclc{55072}{cjkhangul}{\u@cjk@hangul158A}%
\uc@dclc{55080}{cjkhangul}{\u@cjk@hangul158B}%
\uc@dclc{55081}{cjkhangul}{\u@cjk@hangul158C}%
\uc@dclc{55083}{cjkhangul}{\u@cjk@hangul158D}%
\uc@dclc{55085}{cjkhangul}{\u@cjk@hangul158E}%
\uc@dclc{55092}{cjkhangul}{\u@cjk@hangul158F}%
\uc@dclc{55093}{cjkhangul}{\u@cjk@hangul1590}%
\uc@dclc{55096}{cjkhangul}{\u@cjk@hangul1591}%
\uc@dclc{55100}{cjkhangul}{\u@cjk@hangul1592}%
\uc@dclc{55108}{cjkhangul}{\u@cjk@hangul1593}%
\uc@dclc{55111}{cjkhangul}{\u@cjk@hangul1594}%
\uc@dclc{55113}{cjkhangul}{\u@cjk@hangul1595}%
\uc@dclc{55120}{cjkhangul}{\u@cjk@hangul1596}%
\uc@dclc{55121}{cjkhangul}{\u@cjk@hangul1597}%
\uc@dclc{55124}{cjkhangul}{\u@cjk@hangul1598}%
\uc@dclc{55126}{cjkhangul}{\u@cjk@hangul1599}%
\uc@dclc{55127}{cjkhangul}{\u@cjk@hangul159A}%
\uc@dclc{55128}{cjkhangul}{\u@cjk@hangul159B}%
\uc@dclc{55129}{cjkhangul}{\u@cjk@hangul159C}%
\uc@dclc{55136}{cjkhangul}{\u@cjk@hangul159D}%
\uc@dclc{55137}{cjkhangul}{\u@cjk@hangul159E}%
\uc@dclc{55139}{cjkhangul}{\u@cjk@hangul159F}%
\uc@dclc{55141}{cjkhangul}{\u@cjk@hangul15A0}%
\uc@dclc{55145}{cjkhangul}{\u@cjk@hangul15A1}%
\uc@dclc{55148}{cjkhangul}{\u@cjk@hangul15A2}%
\uc@dclc{55152}{cjkhangul}{\u@cjk@hangul15A3}%
\uc@dclc{55156}{cjkhangul}{\u@cjk@hangul15A4}%
\uc@dclc{55164}{cjkhangul}{\u@cjk@hangul15A5}%
\uc@dclc{55165}{cjkhangul}{\u@cjk@hangul15A6}%
\uc@dclc{55169}{cjkhangul}{\u@cjk@hangul15A7}%
\uc@dclc{55176}{cjkhangul}{\u@cjk@hangul15A8}%
\uc@dclc{55177}{cjkhangul}{\u@cjk@hangul15A9}%
\uc@dclc{55180}{cjkhangul}{\u@cjk@hangul15AA}%
\uc@dclc{55184}{cjkhangul}{\u@cjk@hangul15AB}%
\uc@dclc{55192}{cjkhangul}{\u@cjk@hangul15AC}%
\uc@dclc{55193}{cjkhangul}{\u@cjk@hangul15AD}%
\uc@dclc{55195}{cjkhangul}{\u@cjk@hangul15AE}%
\uc@dclc{55197}{cjkhangul}{\u@cjk@hangul15AF}%
%%% Local Variables: 
%%% mode: latex
%%% coding: utf-8
%%% End: 
