%%% Unicode to TeX mapping, file uni-468.def, U+1D400..U+1D4FF, autogenerated by makeunidef.pl
\ifx\ProvidesFile\undefined\else
\ProvidesFile{uni-468.def}[2022/08/07 UCS: Unicode data U+1D400..U+1D4FF]%
\fi
\uc@dclc{119808}{default}{\ensuremath{\mathbf A}}%
\uc@dclc{119809}{default}{\ensuremath{\mathbf B}}%
\uc@dclc{119810}{default}{\ensuremath{\mathbf C}}%
\uc@dclc{119811}{default}{\ensuremath{\mathbf D}}%
\uc@dclc{119812}{default}{\ensuremath{\mathbf E}}%
\uc@dclc{119813}{default}{\ensuremath{\mathbf F}}%
\uc@dclc{119814}{default}{\ensuremath{\mathbf G}}%
\uc@dclc{119815}{default}{\ensuremath{\mathbf H}}%
\uc@dclc{119816}{default}{\ensuremath{\mathbf I}}%
\uc@dclc{119817}{default}{\ensuremath{\mathbf J}}%
\uc@dclc{119818}{default}{\ensuremath{\mathbf K}}%
\uc@dclc{119819}{default}{\ensuremath{\mathbf L}}%
\uc@dclc{119820}{default}{\ensuremath{\mathbf M}}%
\uc@dclc{119821}{default}{\ensuremath{\mathbf N}}%
\uc@dclc{119822}{default}{\ensuremath{\mathbf O}}%
\uc@dclc{119823}{default}{\ensuremath{\mathbf P}}%
\uc@dclc{119824}{default}{\ensuremath{\mathbf Q}}%
\uc@dclc{119825}{default}{\ensuremath{\mathbf R}}%
\uc@dclc{119826}{default}{\ensuremath{\mathbf S}}%
\uc@dclc{119827}{default}{\ensuremath{\mathbf T}}%
\uc@dclc{119828}{default}{\ensuremath{\mathbf U}}%
\uc@dclc{119829}{default}{\ensuremath{\mathbf V}}%
\uc@dclc{119830}{default}{\ensuremath{\mathbf W}}%
\uc@dclc{119831}{default}{\ensuremath{\mathbf X}}%
\uc@dclc{119832}{default}{\ensuremath{\mathbf Y}}%
\uc@dclc{119833}{default}{\ensuremath{\mathbf Z}}%
\uc@dclc{119834}{default}{\ensuremath{\mathbf a}}%
\uc@dclc{119835}{default}{\ensuremath{\mathbf b}}%
\uc@dclc{119836}{default}{\ensuremath{\mathbf c}}%
\uc@dclc{119837}{default}{\ensuremath{\mathbf d}}%
\uc@dclc{119838}{default}{\ensuremath{\mathbf e}}%
\uc@dclc{119839}{default}{\ensuremath{\mathbf f}}%
\uc@dclc{119840}{default}{\ensuremath{\mathbf g}}%
\uc@dclc{119841}{default}{\ensuremath{\mathbf h}}%
\uc@dclc{119842}{default}{\ensuremath{\mathbf i}}%
\uc@dclc{119843}{default}{\ensuremath{\mathbf j}}%
\uc@dclc{119844}{default}{\ensuremath{\mathbf k}}%
\uc@dclc{119845}{default}{\ensuremath{\mathbf l}}%
\uc@dclc{119846}{default}{\ensuremath{\mathbf m}}%
\uc@dclc{119847}{default}{\ensuremath{\mathbf n}}%
\uc@dclc{119848}{default}{\ensuremath{\mathbf o}}%
\uc@dclc{119849}{default}{\ensuremath{\mathbf p}}%
\uc@dclc{119850}{default}{\ensuremath{\mathbf q}}%
\uc@dclc{119851}{default}{\ensuremath{\mathbf r}}%
\uc@dclc{119852}{default}{\ensuremath{\mathbf s}}%
\uc@dclc{119853}{default}{\ensuremath{\mathbf t}}%
\uc@dclc{119854}{default}{\ensuremath{\mathbf u}}%
\uc@dclc{119855}{default}{\ensuremath{\mathbf v}}%
\uc@dclc{119856}{default}{\ensuremath{\mathbf w}}%
\uc@dclc{119857}{default}{\ensuremath{\mathbf x}}%
\uc@dclc{119858}{default}{\ensuremath{\mathbf y}}%
\uc@dclc{119859}{default}{\ensuremath{\mathbf z}}%
\uc@dclc{119860}{default}{\ensuremath{\mathit A}}%
\uc@dclc{119861}{default}{\ensuremath{\mathit B}}%
\uc@dclc{119862}{default}{\ensuremath{\mathit C}}%
\uc@dclc{119863}{default}{\ensuremath{\mathit D}}%
\uc@dclc{119864}{default}{\ensuremath{\mathit E}}%
\uc@dclc{119865}{default}{\ensuremath{\mathit F}}%
\uc@dclc{119866}{default}{\ensuremath{\mathit G}}%
\uc@dclc{119867}{default}{\ensuremath{\mathit H}}%
\uc@dclc{119868}{default}{\ensuremath{\mathit I}}%
\uc@dclc{119869}{default}{\ensuremath{\mathit J}}%
\uc@dclc{119870}{default}{\ensuremath{\mathit K}}%
\uc@dclc{119871}{default}{\ensuremath{\mathit L}}%
\uc@dclc{119872}{default}{\ensuremath{\mathit M}}%
\uc@dclc{119873}{default}{\ensuremath{\mathit N}}%
\uc@dclc{119874}{default}{\ensuremath{\mathit O}}%
\uc@dclc{119875}{default}{\ensuremath{\mathit P}}%
\uc@dclc{119876}{default}{\ensuremath{\mathit Q}}%
\uc@dclc{119877}{default}{\ensuremath{\mathit R}}%
\uc@dclc{119878}{default}{\ensuremath{\mathit S}}%
\uc@dclc{119879}{default}{\ensuremath{\mathit T}}%
\uc@dclc{119880}{default}{\ensuremath{\mathit U}}%
\uc@dclc{119881}{default}{\ensuremath{\mathit V}}%
\uc@dclc{119882}{default}{\ensuremath{\mathit W}}%
\uc@dclc{119883}{default}{\ensuremath{\mathit X}}%
\uc@dclc{119884}{default}{\ensuremath{\mathit Y}}%
\uc@dclc{119885}{default}{\ensuremath{\mathit Z}}%
\uc@dclc{119886}{default}{\ensuremath{\mathit a}}%
\uc@dclc{119887}{default}{\ensuremath{\mathit b}}%
\uc@dclc{119888}{default}{\ensuremath{\mathit c}}%
\uc@dclc{119889}{default}{\ensuremath{\mathit d}}%
\uc@dclc{119890}{default}{\ensuremath{\mathit e}}%
\uc@dclc{119891}{default}{\ensuremath{\mathit f}}%
\uc@dclc{119892}{default}{\ensuremath{\mathit g}}%
\uc@dclc{119894}{default}{\ensuremath{\mathit i}}%
\uc@dclc{119895}{default}{\ensuremath{\mathit j}}%
\uc@dclc{119896}{default}{\ensuremath{\mathit k}}%
\uc@dclc{119897}{default}{\ensuremath{\mathit l}}%
\uc@dclc{119898}{default}{\ensuremath{\mathit m}}%
\uc@dclc{119899}{default}{\ensuremath{\mathit n}}%
\uc@dclc{119900}{default}{\ensuremath{\mathit o}}%
\uc@dclc{119901}{default}{\ensuremath{\mathit p}}%
\uc@dclc{119902}{default}{\ensuremath{\mathit q}}%
\uc@dclc{119903}{default}{\ensuremath{\mathit r}}%
\uc@dclc{119904}{default}{\ensuremath{\mathit s}}%
\uc@dclc{119905}{default}{\ensuremath{\mathit t}}%
\uc@dclc{119906}{default}{\ensuremath{\mathit u}}%
\uc@dclc{119907}{default}{\ensuremath{\mathit v}}%
\uc@dclc{119908}{default}{\ensuremath{\mathit w}}%
\uc@dclc{119909}{default}{\ensuremath{\mathit x}}%
\uc@dclc{119910}{default}{\ensuremath{\mathit y}}%
\uc@dclc{119911}{default}{\ensuremath{\mathit z}}%
\uc@dclc{119912}{autogenerated}{\unichar{65}}%
\uc@dclc{119913}{autogenerated}{\unichar{66}}%
\uc@dclc{119914}{autogenerated}{\unichar{67}}%
\uc@dclc{119915}{autogenerated}{\unichar{68}}%
\uc@dclc{119916}{autogenerated}{\unichar{69}}%
\uc@dclc{119917}{autogenerated}{\unichar{70}}%
\uc@dclc{119918}{autogenerated}{\unichar{71}}%
\uc@dclc{119919}{autogenerated}{\unichar{72}}%
\uc@dclc{119920}{autogenerated}{\unichar{73}}%
\uc@dclc{119921}{autogenerated}{\unichar{74}}%
\uc@dclc{119922}{autogenerated}{\unichar{75}}%
\uc@dclc{119923}{autogenerated}{\unichar{76}}%
\uc@dclc{119924}{autogenerated}{\unichar{77}}%
\uc@dclc{119925}{autogenerated}{\unichar{78}}%
\uc@dclc{119926}{autogenerated}{\unichar{79}}%
\uc@dclc{119927}{autogenerated}{\unichar{80}}%
\uc@dclc{119928}{autogenerated}{\unichar{81}}%
\uc@dclc{119929}{autogenerated}{\unichar{82}}%
\uc@dclc{119930}{autogenerated}{\unichar{83}}%
\uc@dclc{119931}{autogenerated}{\unichar{84}}%
\uc@dclc{119932}{autogenerated}{\unichar{85}}%
\uc@dclc{119933}{autogenerated}{\unichar{86}}%
\uc@dclc{119934}{autogenerated}{\unichar{87}}%
\uc@dclc{119935}{autogenerated}{\unichar{88}}%
\uc@dclc{119936}{autogenerated}{\unichar{89}}%
\uc@dclc{119937}{autogenerated}{\unichar{90}}%
\uc@dclc{119938}{autogenerated}{\unichar{97}}%
\uc@dclc{119939}{autogenerated}{\unichar{98}}%
\uc@dclc{119940}{autogenerated}{\unichar{99}}%
\uc@dclc{119941}{autogenerated}{\unichar{100}}%
\uc@dclc{119942}{autogenerated}{\unichar{101}}%
\uc@dclc{119943}{autogenerated}{\unichar{102}}%
\uc@dclc{119944}{autogenerated}{\unichar{103}}%
\uc@dclc{119945}{autogenerated}{\unichar{104}}%
\uc@dclc{119946}{autogenerated}{\unichar{105}}%
\uc@dclc{119947}{autogenerated}{\unichar{106}}%
\uc@dclc{119948}{autogenerated}{\unichar{107}}%
\uc@dclc{119949}{autogenerated}{\unichar{108}}%
\uc@dclc{119950}{autogenerated}{\unichar{109}}%
\uc@dclc{119951}{autogenerated}{\unichar{110}}%
\uc@dclc{119952}{autogenerated}{\unichar{111}}%
\uc@dclc{119953}{autogenerated}{\unichar{112}}%
\uc@dclc{119954}{autogenerated}{\unichar{113}}%
\uc@dclc{119955}{autogenerated}{\unichar{114}}%
\uc@dclc{119956}{autogenerated}{\unichar{115}}%
\uc@dclc{119957}{autogenerated}{\unichar{116}}%
\uc@dclc{119958}{autogenerated}{\unichar{117}}%
\uc@dclc{119959}{autogenerated}{\unichar{118}}%
\uc@dclc{119960}{autogenerated}{\unichar{119}}%
\uc@dclc{119961}{autogenerated}{\unichar{120}}%
\uc@dclc{119962}{autogenerated}{\unichar{121}}%
\uc@dclc{119963}{autogenerated}{\unichar{122}}%
\uc@dclc{119964}{default}{\ensuremath{\mathscr A}}%
\uc@dclc{119966}{default}{\ensuremath{\mathscr C}}%
\uc@dclc{119967}{default}{\ensuremath{\mathscr D}}%
\uc@dclc{119970}{default}{\ensuremath{\mathscr G}}%
\uc@dclc{119973}{default}{\ensuremath{\mathscr J}}%
\uc@dclc{119974}{default}{\ensuremath{\mathscr K}}%
\uc@dclc{119977}{default}{\ensuremath{\mathscr N}}%
\uc@dclc{119978}{default}{\ensuremath{\mathscr O}}%
\uc@dclc{119979}{default}{\ensuremath{\mathscr P}}%
\uc@dclc{119980}{default}{\ensuremath{\mathscr Q}}%
\uc@dclc{119982}{default}{\ensuremath{\mathscr S}}%
\uc@dclc{119983}{default}{\ensuremath{\mathscr T}}%
\uc@dclc{119984}{default}{\ensuremath{\mathscr U}}%
\uc@dclc{119985}{default}{\ensuremath{\mathscr V}}%
\uc@dclc{119986}{default}{\ensuremath{\mathscr W}}%
\uc@dclc{119987}{default}{\ensuremath{\mathscr X}}%
\uc@dclc{119988}{default}{\ensuremath{\mathscr Y}}%
\uc@dclc{119989}{default}{\ensuremath{\mathscr Z}}%
\uc@dclc{119990}{autogenerated}{\unichar{97}}%
\uc@dclc{119991}{autogenerated}{\unichar{98}}%
\uc@dclc{119992}{autogenerated}{\unichar{99}}%
\uc@dclc{119993}{autogenerated}{\unichar{100}}%
\uc@dclc{119995}{autogenerated}{\unichar{102}}%
\uc@dclc{119997}{autogenerated}{\unichar{104}}%
\uc@dclc{119998}{autogenerated}{\unichar{105}}%
\uc@dclc{119999}{autogenerated}{\unichar{106}}%
\uc@dclc{120000}{autogenerated}{\unichar{107}}%
\uc@dclc{120001}{autogenerated}{\unichar{108}}%
\uc@dclc{120002}{autogenerated}{\unichar{109}}%
\uc@dclc{120003}{autogenerated}{\unichar{110}}%
\uc@dclc{120005}{autogenerated}{\unichar{112}}%
\uc@dclc{120006}{autogenerated}{\unichar{113}}%
\uc@dclc{120007}{autogenerated}{\unichar{114}}%
\uc@dclc{120008}{autogenerated}{\unichar{115}}%
\uc@dclc{120009}{autogenerated}{\unichar{116}}%
\uc@dclc{120010}{autogenerated}{\unichar{117}}%
\uc@dclc{120011}{autogenerated}{\unichar{118}}%
\uc@dclc{120012}{autogenerated}{\unichar{119}}%
\uc@dclc{120013}{autogenerated}{\unichar{120}}%
\uc@dclc{120014}{autogenerated}{\unichar{121}}%
\uc@dclc{120015}{autogenerated}{\unichar{122}}%
\uc@dclc{120016}{autogenerated}{\unichar{65}}%
\uc@dclc{120017}{autogenerated}{\unichar{66}}%
\uc@dclc{120018}{autogenerated}{\unichar{67}}%
\uc@dclc{120019}{autogenerated}{\unichar{68}}%
\uc@dclc{120020}{autogenerated}{\unichar{69}}%
\uc@dclc{120021}{autogenerated}{\unichar{70}}%
\uc@dclc{120022}{autogenerated}{\unichar{71}}%
\uc@dclc{120023}{autogenerated}{\unichar{72}}%
\uc@dclc{120024}{autogenerated}{\unichar{73}}%
\uc@dclc{120025}{autogenerated}{\unichar{74}}%
\uc@dclc{120026}{autogenerated}{\unichar{75}}%
\uc@dclc{120027}{autogenerated}{\unichar{76}}%
\uc@dclc{120028}{autogenerated}{\unichar{77}}%
\uc@dclc{120029}{autogenerated}{\unichar{78}}%
\uc@dclc{120030}{autogenerated}{\unichar{79}}%
\uc@dclc{120031}{autogenerated}{\unichar{80}}%
\uc@dclc{120032}{autogenerated}{\unichar{81}}%
\uc@dclc{120033}{autogenerated}{\unichar{82}}%
\uc@dclc{120034}{autogenerated}{\unichar{83}}%
\uc@dclc{120035}{autogenerated}{\unichar{84}}%
\uc@dclc{120036}{autogenerated}{\unichar{85}}%
\uc@dclc{120037}{autogenerated}{\unichar{86}}%
\uc@dclc{120038}{autogenerated}{\unichar{87}}%
\uc@dclc{120039}{autogenerated}{\unichar{88}}%
\uc@dclc{120040}{autogenerated}{\unichar{89}}%
\uc@dclc{120041}{autogenerated}{\unichar{90}}%
\uc@dclc{120042}{autogenerated}{\unichar{97}}%
\uc@dclc{120043}{autogenerated}{\unichar{98}}%
\uc@dclc{120044}{autogenerated}{\unichar{99}}%
\uc@dclc{120045}{autogenerated}{\unichar{100}}%
\uc@dclc{120046}{autogenerated}{\unichar{101}}%
\uc@dclc{120047}{autogenerated}{\unichar{102}}%
\uc@dclc{120048}{autogenerated}{\unichar{103}}%
\uc@dclc{120049}{autogenerated}{\unichar{104}}%
\uc@dclc{120050}{autogenerated}{\unichar{105}}%
\uc@dclc{120051}{autogenerated}{\unichar{106}}%
\uc@dclc{120052}{autogenerated}{\unichar{107}}%
\uc@dclc{120053}{autogenerated}{\unichar{108}}%
\uc@dclc{120054}{autogenerated}{\unichar{109}}%
\uc@dclc{120055}{autogenerated}{\unichar{110}}%
\uc@dclc{120056}{autogenerated}{\unichar{111}}%
\uc@dclc{120057}{autogenerated}{\unichar{112}}%
\uc@dclc{120058}{autogenerated}{\unichar{113}}%
\uc@dclc{120059}{autogenerated}{\unichar{114}}%
\uc@dclc{120060}{autogenerated}{\unichar{115}}%
\uc@dclc{120061}{autogenerated}{\unichar{116}}%
\uc@dclc{120062}{autogenerated}{\unichar{117}}%
\uc@dclc{120063}{autogenerated}{\unichar{118}}%
%%% Local Variables: 
%%% mode: latex
%%% coding: utf-8
%%% End: 
