%%% Unicode to TeX mapping, file uni-465.def, U+1D100..U+1D1FF, autogenerated by makeunidef.pl
\ifx\ProvidesFile\undefined\else
\ProvidesFile{uni-465.def}[2022/08/07 UCS: Unicode data U+1D100..U+1D1FF]%
\fi
\uc@dclc{119133}{default}{\fullnote}%
\uc@dclc{119134}{default}{\halfnote}%
\uc@dclc{119135}{default}{\quarternote}%
\uc@dclc{119136}{default}{\eighthnote}%
%%% Local Variables: 
%%% mode: latex
%%% coding: utf-8
%%% End: 
