%%
%% This is file `tagpdf-ns-latex-book.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% tagpdf-data.dtx  (with options: `ns-latex-book')
%% 
%% Copyright (C) 2019-2024 Ulrike Fischer
%% 
%% It may be distributed and/or modified under the conditions of
%% the LaTeX Project Public License (LPPL), either version 1.3c of
%% this license or (at your option) any later version.  The latest
%% version of this license is in the file:
%% 
%%    https://www.latex-project.org/lppl.txt
%% 
%% This file is part of the "tagpdf bundle" (The Work in LPPL)
%% and all files in that bundle must be distributed together.
%% 
%% File: tagpdf-data.dtx
%% \ProvidesExplFile {tagpdf-ns-latex-book.def} {2025-03-05} {0.99o}
%% {latex-book} {https://www.latex-project.org/ns/book}{}
chapter,       H1,pdf2,
section,       H2,pdf2,
subsection,    H3,pdf2,
subsubsection, H4,pdf2,
paragraph,     H5,pdf2,
subparagraph,  H6,pdf2,
%% 
%%
%% End of file `tagpdf-ns-latex-book.def'.
