%!TEX encoding = UTF-8 Unicode
%
% Translation completed on 04/02/2021
\ProvidesFile{ecvpt.def}[europecv Portuguese definitions]
% Personal information
\def\ecv@infosectionkey{\ecv@utf{Informa\c{c}\~ao pessoal}}
\def\ecv@datekey{\ecv@utf{Atualizado a}}
\def\ecv@namekey{\ecv@utf{Nome(s)~/ Apelido(s)}}
\def\ecv@addresskey{\ecv@utf{Morada(s)}}
\def\ecv@telkey{\ecv@utf{Telefone(s)}}
\def\ecv@mobilekey{\ecv@utf{Telem\'ovel}}
\def\ecv@faxkey{\ecv@utf{Fax}}
\def\ecv@officekey{\ecv@utf{Escritório}}
\def\ecv@emailkey{\ecv@utf{\textit{E-mail} Pessoal}}
\def\ecv@professionalkey{\ecv@utf{\textit{E-mail} Profissional}}
\def\ecv@skypekey{\ecv@utf{Skype}}
\def\ecv@matrixriotkey{\ecv@utf{Matrix/Riot}}
\def\ecv@youtubekey{\ecv@utf{YouTube}}
\def\ecv@peckey{\ecv@utf{PEC}}
\def\ecv@homepagekey{\ecv@utf{\textit{Home page}}}
\def\ecv@nationalitykey{\ecv@utf{Nacionalidade(s)}}
\def\ecv@birthkey{\ecv@utf{Data de nascimento}}
\def\ecv@genderkey{\ecv@utf{Sexo}}
% Footer
\def\ecv@pagekey{\ecv@utf{P\'agina}}
\def\ecv@cvofkey{\ecv@utf{Curriculum vit\ae\ de}}
% Language table
\def\ecv@mothertonguekey{\ecv@utf{L\'ingua(s) materna(s)}}
\def\ecv@assesskey{\ecv@utf{Auto-avalia\c{c}\~ao}}
\def\ecv@levelkey{\ecv@utf{N\'ivel  europeu}}
\def\ecv@understandkey{\ecv@utf{Compreens\~ao}}
\def\ecv@speakkey{\ecv@utf{Conversa\c{c}\~ao}}
\def\ecv@writekey{\ecv@utf{Escrita}}
\def\ecv@listenkey{\ecv@utf{Compreens\~ao oral}}
\def\ecv@readkey{\ecv@utf{Compreens\~ao escrita}}
\def\ecv@interactkey{\ecv@utf{Interac\c{c}\~ao oral}}
\def\ecv@productkey{\ecv@utf{Produ\c{c}\~ao oral}}
\def\ecv@langfooterkey{\ecv@utf{N\'ivel do Quadro Europeu Comum de Refer\^encia \ecv@upshape{(}CECR\ecv@upshape{)}}}
\def\ecv@cefbasickey{\ecv@utf{Utilizador elementar}}
\def\ecv@cefindepkey{\ecv@utf{Utilizador independente}}
\def\ecv@cefprofkey{\ecv@utf{Utilizador experiente}}

\renewcommand*\ecvtitle{\ecv@utf{\Large\textbf{C\ecv@kern u\ecv@kern r\ecv@kern r\ecv@kern i\ecv@kern c\ecv@kern u\ecv@kern l\ecv@kern u\ecv@kern m \ecv@kern v\ecv@kern i\ecv@kern t\ecv@kern a\ecv@kern e}\\[5pt]
\Large\textbf{E\ecv@kern u\ecv@kern
r\ecv@kern o\ecv@kern p\ecv@kern a\ecv@kern s\ecv@kern s}}}
