%%
%% This is file `l3str-enc-iso88591.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% l3str-convert.dtx  (with options: `iso88591')
%% 
%% Copyright (C) 1990-2025 The LaTeX Project
%% 
%% It may be distributed and/or modified under the conditions of
%% the LaTeX Project Public License (LPPL), either version 1.3c of
%% this license or (at your option) any later version.  The latest
%% version of this license is in the file:
%% 
%%    https://www.latex-project.org/lppl.txt
%% 
%% This file is part of the "l3kernel bundle" (The Work in LPPL)
%% and all files in that bundle must be distributed together.
%% 
%% File: l3str-convert.dtx
\__str_declare_eight_bit_encoding:nnnn { iso88591 } { 256 }
  {
  }
  {
  }
%% 
%%
%% End of file `l3str-enc-iso88591.def'.
