%%% Unicode to TeX mapping, file uni-199.def, U+C700..U+C7FF, autogenerated by makeunidef.pl
\ifx\ProvidesFile\undefined\else
\ProvidesFile{uni-199.def}[2022/08/07 UCS: Unicode data U+C700..U+C7FF]%
\fi
\gdef\u@cjk@hangul#1#2#3#4{{\fontencoding{C61}\def\CJK@plane{#1#2}\selectfont\char"#3#4\relax}}%
\uc@dclc{50948}{cjkhangul}{\u@cjk@hangul1268}%
\uc@dclc{50949}{cjkhangul}{\u@cjk@hangul1269}%
\uc@dclc{50952}{cjkhangul}{\u@cjk@hangul126A}%
\uc@dclc{50956}{cjkhangul}{\u@cjk@hangul126B}%
\uc@dclc{50964}{cjkhangul}{\u@cjk@hangul126C}%
\uc@dclc{50965}{cjkhangul}{\u@cjk@hangul126D}%
\uc@dclc{50967}{cjkhangul}{\u@cjk@hangul126E}%
\uc@dclc{50969}{cjkhangul}{\u@cjk@hangul126F}%
\uc@dclc{50976}{cjkhangul}{\u@cjk@hangul1270}%
\uc@dclc{50977}{cjkhangul}{\u@cjk@hangul1271}%
\uc@dclc{50980}{cjkhangul}{\u@cjk@hangul1272}%
\uc@dclc{50984}{cjkhangul}{\u@cjk@hangul1273}%
\uc@dclc{50992}{cjkhangul}{\u@cjk@hangul1274}%
\uc@dclc{50993}{cjkhangul}{\u@cjk@hangul1275}%
\uc@dclc{50995}{cjkhangul}{\u@cjk@hangul1276}%
\uc@dclc{50997}{cjkhangul}{\u@cjk@hangul1277}%
\uc@dclc{50999}{cjkhangul}{\u@cjk@hangul1278}%
\uc@dclc{51004}{cjkhangul}{\u@cjk@hangul1279}%
\uc@dclc{51005}{cjkhangul}{\u@cjk@hangul127A}%
\uc@dclc{51008}{cjkhangul}{\u@cjk@hangul127B}%
\uc@dclc{51012}{cjkhangul}{\u@cjk@hangul127C}%
\uc@dclc{51018}{cjkhangul}{\u@cjk@hangul127D}%
\uc@dclc{51020}{cjkhangul}{\u@cjk@hangul127E}%
\uc@dclc{51021}{cjkhangul}{\u@cjk@hangul127F}%
\uc@dclc{51023}{cjkhangul}{\u@cjk@hangul1280}%
\uc@dclc{51025}{cjkhangul}{\u@cjk@hangul1281}%
\uc@dclc{51026}{cjkhangul}{\u@cjk@hangul1282}%
\uc@dclc{51027}{cjkhangul}{\u@cjk@hangul1283}%
\uc@dclc{51028}{cjkhangul}{\u@cjk@hangul1284}%
\uc@dclc{51029}{cjkhangul}{\u@cjk@hangul1285}%
\uc@dclc{51030}{cjkhangul}{\u@cjk@hangul1286}%
\uc@dclc{51031}{cjkhangul}{\u@cjk@hangul1287}%
\uc@dclc{51032}{cjkhangul}{\u@cjk@hangul1288}%
\uc@dclc{51036}{cjkhangul}{\u@cjk@hangul1289}%
\uc@dclc{51040}{cjkhangul}{\u@cjk@hangul128A}%
\uc@dclc{51048}{cjkhangul}{\u@cjk@hangul128B}%
\uc@dclc{51051}{cjkhangul}{\u@cjk@hangul128C}%
\uc@dclc{51060}{cjkhangul}{\u@cjk@hangul128D}%
\uc@dclc{51061}{cjkhangul}{\u@cjk@hangul128E}%
\uc@dclc{51064}{cjkhangul}{\u@cjk@hangul128F}%
\uc@dclc{51068}{cjkhangul}{\u@cjk@hangul1290}%
\uc@dclc{51069}{cjkhangul}{\u@cjk@hangul1291}%
\uc@dclc{51070}{cjkhangul}{\u@cjk@hangul1292}%
\uc@dclc{51075}{cjkhangul}{\u@cjk@hangul1293}%
\uc@dclc{51076}{cjkhangul}{\u@cjk@hangul1294}%
\uc@dclc{51077}{cjkhangul}{\u@cjk@hangul1295}%
\uc@dclc{51079}{cjkhangul}{\u@cjk@hangul1296}%
\uc@dclc{51080}{cjkhangul}{\u@cjk@hangul1297}%
\uc@dclc{51081}{cjkhangul}{\u@cjk@hangul1298}%
\uc@dclc{51082}{cjkhangul}{\u@cjk@hangul1299}%
\uc@dclc{51086}{cjkhangul}{\u@cjk@hangul129A}%
\uc@dclc{51088}{cjkhangul}{\u@cjk@hangul129B}%
\uc@dclc{51089}{cjkhangul}{\u@cjk@hangul129C}%
\uc@dclc{51092}{cjkhangul}{\u@cjk@hangul129D}%
\uc@dclc{51094}{cjkhangul}{\u@cjk@hangul129E}%
\uc@dclc{51095}{cjkhangul}{\u@cjk@hangul129F}%
\uc@dclc{51096}{cjkhangul}{\u@cjk@hangul12A0}%
\uc@dclc{51098}{cjkhangul}{\u@cjk@hangul12A1}%
\uc@dclc{51104}{cjkhangul}{\u@cjk@hangul12A2}%
\uc@dclc{51105}{cjkhangul}{\u@cjk@hangul12A3}%
\uc@dclc{51107}{cjkhangul}{\u@cjk@hangul12A4}%
\uc@dclc{51108}{cjkhangul}{\u@cjk@hangul12A5}%
\uc@dclc{51109}{cjkhangul}{\u@cjk@hangul12A6}%
\uc@dclc{51110}{cjkhangul}{\u@cjk@hangul12A7}%
\uc@dclc{51116}{cjkhangul}{\u@cjk@hangul12A8}%
\uc@dclc{51117}{cjkhangul}{\u@cjk@hangul12A9}%
\uc@dclc{51120}{cjkhangul}{\u@cjk@hangul12AA}%
\uc@dclc{51124}{cjkhangul}{\u@cjk@hangul12AB}%
\uc@dclc{51132}{cjkhangul}{\u@cjk@hangul12AC}%
\uc@dclc{51133}{cjkhangul}{\u@cjk@hangul12AD}%
\uc@dclc{51135}{cjkhangul}{\u@cjk@hangul12AE}%
\uc@dclc{51136}{cjkhangul}{\u@cjk@hangul12AF}%
\uc@dclc{51137}{cjkhangul}{\u@cjk@hangul12B0}%
\uc@dclc{51144}{cjkhangul}{\u@cjk@hangul12B1}%
\uc@dclc{51145}{cjkhangul}{\u@cjk@hangul12B2}%
\uc@dclc{51148}{cjkhangul}{\u@cjk@hangul12B3}%
\uc@dclc{51150}{cjkhangul}{\u@cjk@hangul12B4}%
\uc@dclc{51152}{cjkhangul}{\u@cjk@hangul12B5}%
\uc@dclc{51160}{cjkhangul}{\u@cjk@hangul12B6}%
\uc@dclc{51165}{cjkhangul}{\u@cjk@hangul12B7}%
\uc@dclc{51172}{cjkhangul}{\u@cjk@hangul12B8}%
\uc@dclc{51176}{cjkhangul}{\u@cjk@hangul12B9}%
\uc@dclc{51180}{cjkhangul}{\u@cjk@hangul12BA}%
%%% Local Variables: 
%%% mode: latex
%%% coding: utf-8
%%% End: 
