%%
%% This is file `stmnamibian.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% bankstatement.dtx  (with options: `namibian')
%% 
%% Copyright (C) 2015 by:
%% Josef Kleber
%% <josef.kleber@gmx.de>
%% 
%% This file may be distributed and/or modified under the conditions of
%% the LaTeX Project Public License, either version 1.3 of this license
%% or (at your option) any later version.  The latest version of this
%% license is in:
%% 
%%    http://www.latex-project.org/lppl.txt
%% 
%% and version 1.3 or later is part of all distributions of LaTeX version
%% 2003/12/01 or later.
%% 
%% This work has the LPPL maintenance status "maintained".
%% 
%% The Current Maintainer of this work is Josef Kleber.
%% 
%% This work consists of all files listed in manifest.txt.
%% 
\renewcommand*\STM@JK@holdername{Account Holder}%
\renewcommand*\STM@JK@bicname{Branch Code}%
\renewcommand*\STM@JK@ibanname{Account Number}%
\renewcommand*\STM@JK@firstcolumnheading{\bfseries Date}%
\renewcommand*\STM@JK@secondcolumnheading{\bfseries Reference}%
\renewcommand*\STM@JK@thirdcolumnheading{\bfseries Amount (NAD)}%
\renewcommand*\STM@JK@openingbalancename{Opening Balance}%
\renewcommand*\STM@JK@closingbalancename{Closing Balance}%
\sisetup{output-decimal-marker={.}}%
\endinput
%%
%% End of file `stmnamibian.def'.
