%!TEX encoding = UTF-8 Unicode
%
% Translation completed on 01/03/2020
\ProvidesFile{ecvet.def}[europecv Estonian definitions]
% Personal information
\def\ecv@infosectionkey{\ecv@utf{Isikuandmed}}
\def\ecv@datekey{\ecv@utf{Ajakohastatud}}
\def\ecv@namekey{\ecv@utf{Eesnimi~/ Perekonnanimi/}}
\def\ecv@addresskey{\ecv@utf{Aadress(id)}}
\def\ecv@telkey{\ecv@utf{Telefon(id)}}
\def\ecv@mobilekey{\ecv@utf{Mobiiltelefon}}
\def\ecv@faxkey{\ecv@utf{Faks(id)}}
\def\ecv@officekey{\ecv@utf{Kontor}}
\def\ecv@emailkey{\ecv@utf{E-post(id)}}
\def\ecv@professionalkey{\ecv@utf{Töö E-post(id)}}
\def\ecv@skypekey{\ecv@utf{Skype}}
\def\ecv@matrixriotkey{\ecv@utf{Matrix/Riot}}
\def\ecv@youtubekey{\ecv@utf{YouTube}}
\def\ecv@peckey{\ecv@utf{PEC}}
\def\ecv@homepagekey{\ecv@utf{Home page}}
\def\ecv@nationalitykey{\ecv@utf{Kodakondsus}}
\def\ecv@birthkey{\ecv@utf{S\"unniaeg}}
\def\ecv@genderkey{\ecv@utf{Sugu}}
% Footer
\def\ecv@pagekey{\ecv@utf{lk}}
\def\ecv@cvofkey{\ecv@utf{Curriculum vit\ae}}
% Language table
\def\ecv@mothertonguekey{\ecv@utf{Emakeel(ed)}}
\def\ecv@assesskey{\ecv@utf{Enesehindamine}}
\def\ecv@levelkey{\ecv@utf{Euroopa tase}}
\def\ecv@understandkey{\ecv@utf{M\~{o}istmine}}
\def\ecv@speakkey{\ecv@utf{R\"{a}\"{a}kimine}}
\def\ecv@writekey{\ecv@utf{Kirjutamine}}
\def\ecv@listenkey{\ecv@utf{Kuulamine}}
\def\ecv@readkey{\ecv@utf{Lugemine}}
\def\ecv@interactkey{\ecv@utf{Suuline suhtlus}}
\def\ecv@productkey{\ecv@utf{Suuline esitus}}
\def\ecv@langfooterkey{\ecv@utf{Euroopa keele\~{o}ppe raamdokument}}
\def\ecv@cefbasickey{\ecv@utf{Algeline keelekasutus}}
\def\ecv@cefindepkey{\ecv@utf{Iseseisev  keelekasutus}}
\def\ecv@cefprofkey{\ecv@utf{Vaba keelekasutus}}

\renewcommand*{\ecvbranding}{\ecv@utf{\Large\textbf{E\ecv@kern u\ecv@kern
r\ecv@kern o\ecv@kern p\ecv@kern a\ecv@kern s\ecv@kern s}\\[5pt]}}
\renewcommand*\ecvtitle{\ecvbranding\ecv@utf{
\Large\textbf{c\ecv@kern u\ecv@kern r\ecv@kern r\ecv@kern
i\ecv@kern c\ecv@kern u\ecv@kern l\ecv@kern u\ecv@kern m \ecv@kern v\ecv@kern
i\ecv@kern t\ecv@kern a\ecv@kern e}}}
