%% ***********************************************************************
%%            Copyright 2024 by M.Y. XIA <xiamyphys@gmail.com>           *
%%                                                                       *
%%    This work may be distributed and/or modified under the conditions  *
%%    of the LaTeX Project Public License                                *
%%                                                                       *
%%               http://www.latex-project.org/lppl.txt                   *
%%                                                                       *
%%    either version 1.3c of this license or any later version.          *
%%                                                                       *
%%    This work has the LPPL maintenance status `obsoleted'.             *
%%    This work has the LPPL maintenance status `obsoleted'.             *
%%    This work has the LPPL maintenance status `obsoleted'.             *
%% ***********************************************************************
\ProvidesExplClass {litesolution} {2024/11/26} {2.4a}
  {Now replaced by the whatsnote class}

\msg_new:nnn { litesolution } { Obsolete~LaTeX~Package }
  { The~litesolution~class~is~now~obsoleted.~
    Please~load~the~`whatsnote'~class~instead,~or~
    access~the~'obsolete~packages'~dictionary~on~CTAN. }
\msg_error:nn { litesolution } { Obsolete~LaTeX~Package }

\LoadClass{minimal}

\endinput