%%
%% This is file `x-iso-8859-8.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% inputenx.dtx  (with options: `iso-8859-8')
%% 
%% This is a generated file.
%% 
%% Project: inputenx
%% Version: 2019/11/29 v1.12
%% 
%% Copyright (C)
%%   2006-2011 Heiko Oberdiek
%%   2016-2019 Oberdiek Package Support Group
%% 
%% This work may be distributed and/or modified under the
%% conditions of the LaTeX Project Public License, either
%% version 1.3c of this license or (at your option) any later
%% version. This version of this license is in
%%    https://www.latex-project.org/lppl/lppl-1-3c.txt
%% and the latest version of this license is in
%%    https://www.latex-project.org/lppl.txt
%% and version 1.3 or later is part of all distributions of
%% LaTeX version 2005/12/01 or later.
%% 
%% This work has the LPPL maintenance status "maintained".
%% 
%% The Current Maintainers of this work are
%% Heiko Oberdiek and the Oberdiek Package Support Group
%% https://github.com/ho-tex/inputenx/issues
%% 
%% 
%% This work consists of the main source file inputenx.dtx
%% and the derived files
%%    inputenx.sty, inputenx.pdf, inputenx.ins, inputenx.drv, ix-alias.def,
%%    ix-math.def, ix-name.def, ix-slot.def, ix-uc.def,
%%    ix-utf8enc.dfu, x-ascii.def, x-verbatim.def, x-atarist.def,
%%    x-iso-8859-1.def, x-iso-8859-2.def, x-iso-8859-3.def,
%%    x-iso-8859-4.def, x-iso-8859-5.def, x-iso-8859-8.def,
%%    x-iso-8859-9.def, x-iso-8859-10.def, x-iso-8859-13.def,
%%    x-iso-8859-14.def, x-iso-8859-15.def, x-iso-8859-16.def,
%%    x-cp437.def, x-cp850.def, x-cp852.def, x-cp855.def,
%%    x-cp858.def, x-cp865.def, x-cp866.def, x-cp1250.def,
%%    x-cp1251.def, x-cp1252.def, x-cp1255.def, x-cp1257.def,
%%    x-dec-mcs.def, x-koi8-r.def, x-mac-centeuro.def,
%%    x-mac-cyrillic.def, x-mac-roman.def, x-nextstep.def,
%%    inputenx-licrcmds.txt, inputenx-utf8enc.txt.
%% 
\ProvidesFile{x-iso-8859-8.def}%
  [2019/11/29 v1.12 Input encoding iso-8859-8 (inputenx)]%
\edef\RestoreAtCatcode{\catcode64=\the\catcode64\relax}
\makeatletter
\ProvideTextCommandDefault{\textasciiacute}{%
  \@tabacckludge'{}%
}
\ProvideTextCommandDefault{\textasciidieresis}{%
  \"{}%
}
\ProvideTextCommandDefault{\textasciimacron}{%
  \@tabacckludge={}%
}
\ProvideTextCommandDefault{\textbrokenbar}{%
  \TextSymbolUnavailable\textbrokenbar
}
\ProvideTextCommandDefault{\textcent}{%
  \TextSymbolUnavailable\textcent
}
\ProvideTextCommandDefault{\textcurrency}{%
  \TextSymbolUnavailable\textcurrency
}
\ProvideTextCommandDefault{\textdbllowline}{%
  \begingroup
    \sbox0{\textunderscore}%
    \leavevmode
    \ifdim\dp0<.2ex\relax
      \rlap{\raisebox{-.2ex}[0pt]{\textunderscore}}%
    \else
      \rlap{\raisebox{.2ex}[0pt]{\textunderscore}}%
    \fi
    \textunderscore
  \endgroup
}
\ProvideTextCommandDefault{\textdegree}{%
  \ensuremath{{^\circ}}%
}
\ProvideTextCommandDefault{\textdiv}{%
  \TextSymbolUnavailable\textdiv
}
\ProvideTextCommandDefault{\textlnot}{%
  \ensuremath\lnot
}
\ProvideTextCommandDefault{\textmu}{%
  \ensuremath\mu
}
\ProvideTextCommandDefault{\textonehalf}{%
  \ensuremath{\frac12}%
}
\ProvideTextCommandDefault{\textonequarter}{%
  \ensuremath{\frac14}%
}
\ProvideTextCommandDefault{\textonesuperior}{%
  \ensuremath{{^1}}%
}
\ProvideTextCommandDefault{\textpm}{%
  \ensuremath\pm
}
\ProvideTextCommandDefault{\textthreequarters}{%
  \ensuremath{\frac34}%
}
\ProvideTextCommandDefault{\textthreesuperior}{%
  \ensuremath{{^3}}%
}
\ProvideTextCommandDefault{\texttimes}{%
  \ensuremath\times
}
\ProvideTextCommandDefault{\texttwosuperior}{%
  \ensuremath{{^2}}%
}
\ProvideTextCommandDefault{\textyen}{%
  \TextSymbolUnavailable\textyen
}
\DeclareInputText{160}{\nobreakspace}
\DeclareInputText{162}{\textcent}
\DeclareInputText{163}{\textsterling}
\DeclareInputText{164}{\textcurrency}
\DeclareInputText{165}{\textyen}
\DeclareInputText{166}{\textbrokenbar}
\DeclareInputText{167}{\textsection}
\DeclareInputText{168}{\textasciidieresis}
\DeclareInputText{169}{\textcopyright}
\DeclareInputText{170}{\texttimes}
\DeclareInputText{171}{\guillemotleft}
\DeclareInputText{172}{\textlnot}
\DeclareInputText{173}{\-}
\DeclareInputText{174}{\textregistered}
\DeclareInputText{175}{\textasciimacron}
\DeclareInputText{176}{\textdegree}
\DeclareInputText{177}{\textpm}
\DeclareInputText{178}{\texttwosuperior}
\DeclareInputText{179}{\textthreesuperior}
\DeclareInputText{180}{\textasciiacute}
\DeclareInputText{181}{\textmu}
\DeclareInputText{182}{\textparagraph}
\DeclareInputText{183}{\textperiodcentered}
\DeclareInputText{184}{\c\ }
\DeclareInputText{185}{\textonesuperior}
\DeclareInputText{186}{\textdiv}
\DeclareInputText{187}{\guillemotright}
\DeclareInputText{188}{\textonequarter}
\DeclareInputText{189}{\textonehalf}
\DeclareInputText{190}{\textthreequarters}
\DeclareInputText{223}{\textdbllowline}
\DeclareInputText{224}{\hebalef}
\DeclareInputText{225}{\hebbet}
\DeclareInputText{226}{\hebgimel}
\DeclareInputText{227}{\hebdalet}
\DeclareInputText{228}{\hebhe}
\DeclareInputText{229}{\hebvav}
\DeclareInputText{230}{\hebzayin}
\DeclareInputText{231}{\hebhet}
\DeclareInputText{232}{\hebtet}
\DeclareInputText{233}{\hebyod}
\DeclareInputText{234}{\hebfinalkaf}
\DeclareInputText{235}{\hebkaf}
\DeclareInputText{236}{\heblamed}
\DeclareInputText{237}{\hebfinalmem}
\DeclareInputText{238}{\hebmem}
\DeclareInputText{239}{\hebfinalnun}
\DeclareInputText{240}{\hebnun}
\DeclareInputText{241}{\hebsamekh}
\DeclareInputText{242}{\hebayin}
\DeclareInputText{243}{\hebfinalpe}
\DeclareInputText{244}{\hebpe}
\DeclareInputText{245}{\hebfinaltsadi}
\DeclareInputText{246}{\hebtsadi}
\DeclareInputText{247}{\hebqof}
\DeclareInputText{248}{\hebresh}
\DeclareInputText{249}{\hebshin}
\DeclareInputText{250}{\hebtav}
\RestoreAtCatcode
\endinput
%%
%% End of file `x-iso-8859-8.def'.
