%%% Unicode to TeX mapping, file uni-30.def, U+1E00..U+1EFF, autogenerated by makeunidef.pl
\ifx\ProvidesFile\undefined\else
\ProvidesFile{uni-30.def}[2022/08/07 UCS: Unicode data U+1E00..U+1EFF]%
\fi
\uc@dclc{7680}{autogenerated}{\unichar{65}\unichar{805}}%
\uc@dclc{7681}{autogenerated}{\unichar{97}\unichar{805}}%
\gdef \charettesubbreve#1{\oalign{#1\crcr\hidewidth% BREVE BELOW U+032E
   \vbox to.2ex{\hbox{\ifnum\fontdimen1\font=0%
     \kern-0.0em\else\kern-0.40em\fi\u{}}\vss}\hidewidth}}%
\uc@dclc{7682}{default}{\.B}%
\uc@dclc{7683}{default}{\.b}%
\uc@dclc{7684}{default}{\d B}%
\uc@dclc{7685}{default}{\d b}%
\uc@dclc{7686}{default}{\b B}%
\uc@dclc{7687}{default}{\b b}%
\uc@dclc{7688}{autogenerated}{\unichar{199}\unichar{769}}%
\uc@dclc{7689}{autogenerated}{\unichar{231}\unichar{769}}%
\uc@dclc{7690}{default}{\.D}%
\uc@dclc{7691}{default}{\.d}%
\uc@dclc{7692}{default}{\d D}%
\uc@dclc{7693}{default}{\d d}%
\uc@dclc{7694}{default}{\b D}%
\uc@dclc{7695}{default}{\b d}%
\uc@dclc{7696}{default}{\c D}%
\uc@dclc{7697}{default}{\c d}%
\uc@dclc{7700}{autogenerated}{\unichar{274}\unichar{768}}%
\uc@dclc{7701}{autogenerated}{\unichar{275}\unichar{768}}%
\uc@dclc{7702}{autogenerated}{\unichar{274}\unichar{769}}%
\uc@dclc{7703}{autogenerated}{\unichar{275}\unichar{769}}%
\uc@dclc{7706}{autogenerated}{\unichar{69}\unichar{816}}%
\uc@dclc{7707}{autogenerated}{\unichar{101}\unichar{816}}%
\uc@dclc{7708}{autogenerated}{\unichar{552}\unichar{774}}%
\uc@dclc{7709}{autogenerated}{\unichar{553}\unichar{774}}%
\uc@dclc{7710}{default}{\.F}%
\uc@dclc{7711}{default}{\.f}%
\uc@dclc{7712}{default}{\@tabacckludge=G}%
\uc@dclc{7713}{default}{\@tabacckludge=g}%
\uc@dclc{7714}{default}{\.H}%
\uc@dclc{7715}{default}{\.h}%
\uc@dclc{7716}{default}{\d H}%
\uc@dclc{7717}{default}{\d h}%
\uc@dclc{7718}{default}{\"H}%
\uc@dclc{7719}{default}{\"h}%
\uc@dclc{7720}{default}{\c H}%
\uc@dclc{7721}{default}{\c h}%
\uc@dclc{7722}{default}{\charettesubbreve H}%
\uc@dclc{7723}{default}{\charettesubbreve h}%
\uc@dclc{7724}{autogenerated}{\unichar{73}\unichar{816}}%
\uc@dclc{7725}{autogenerated}{\unichar{105}\unichar{816}}%
\uc@dclc{7726}{autogenerated}{\unichar{207}\unichar{769}}%
\uc@dclc{7727}{autogenerated}{\unichar{239}\unichar{769}}%
\uc@dclc{7728}{default}{\@tabacckludge'K}%
\uc@dclc{7729}{default}{\@tabacckludge'k}%
\uc@dclc{7730}{default}{\d K}%
\uc@dclc{7731}{default}{\d k}%
\uc@dclc{7732}{default}{\b K}%
\uc@dclc{7733}{default}{\b k}%
\uc@dclc{7734}{default}{\d L}%
\uc@dclc{7735}{default}{\d l}%
\uc@dclc{7736}{autogenerated}{\unichar{7734}\unichar{772}}%
\uc@dclc{7737}{autogenerated}{\unichar{7735}\unichar{772}}%
\uc@dclc{7738}{default}{\b L}%
\uc@dclc{7739}{default}{\b l}%
\uc@dclc{7742}{default}{\@tabacckludge'M}%
\uc@dclc{7743}{default}{\@tabacckludge'm}%
\uc@dclc{7744}{default}{\.M}%
\uc@dclc{7745}{default}{\.m}%
\uc@dclc{7746}{default}{\d M}%
\uc@dclc{7747}{default}{\d m}%
\uc@dclc{7748}{default}{\.N}%
\uc@dclc{7749}{default}{\.n}%
\uc@dclc{7750}{default}{\d N}%
\uc@dclc{7751}{default}{\d n}%
\uc@dclc{7752}{default}{\b N}%
\uc@dclc{7753}{default}{\b n}%
\uc@dclc{7756}{autogenerated}{\unichar{213}\unichar{769}}%
\uc@dclc{7757}{autogenerated}{\unichar{245}\unichar{769}}%
\uc@dclc{7758}{autogenerated}{\unichar{213}\unichar{776}}%
\uc@dclc{7759}{autogenerated}{\unichar{245}\unichar{776}}%
\uc@dclc{7760}{autogenerated}{\unichar{332}\unichar{768}}%
\uc@dclc{7761}{autogenerated}{\unichar{333}\unichar{768}}%
\uc@dclc{7762}{autogenerated}{\unichar{332}\unichar{769}}%
\uc@dclc{7763}{autogenerated}{\unichar{333}\unichar{769}}%
\uc@dclc{7764}{default}{\@tabacckludge'P}%
\uc@dclc{7765}{default}{\@tabacckludge'p}%
\uc@dclc{7766}{default}{\.P}%
\uc@dclc{7767}{default}{\.p}%
\uc@dclc{7768}{default}{\.R}%
\uc@dclc{7769}{default}{\.r}%
\uc@dclc{7770}{default}{\d R}%
\uc@dclc{7771}{default}{\d r}%
\uc@dclc{7772}{autogenerated}{\unichar{7770}\unichar{772}}%
\uc@dclc{7773}{autogenerated}{\unichar{7771}\unichar{772}}%
\uc@dclc{7774}{default}{\b R}%
\uc@dclc{7775}{default}{\b r}%
\uc@dclc{7776}{default}{\.S}%
\uc@dclc{7777}{default}{\.s}%
\uc@dclc{7778}{default}{\d S}%
\uc@dclc{7779}{default}{\d s}%
\uc@dclc{7780}{autogenerated}{\unichar{346}\unichar{775}}%
\uc@dclc{7781}{autogenerated}{\unichar{347}\unichar{775}}%
\uc@dclc{7782}{autogenerated}{\unichar{352}\unichar{775}}%
\uc@dclc{7783}{autogenerated}{\unichar{353}\unichar{775}}%
\uc@dclc{7784}{autogenerated}{\unichar{7778}\unichar{775}}%
\uc@dclc{7785}{autogenerated}{\unichar{7779}\unichar{775}}%
\uc@dclc{7786}{default}{\.T}%
\uc@dclc{7787}{default}{\.t}%
\uc@dclc{7788}{default}{\d T}%
\uc@dclc{7789}{default}{\d t}%
\uc@dclc{7790}{default}{\b T}%
\uc@dclc{7791}{default}{\b t}%
\uc@dclc{7794}{autogenerated}{\unichar{85}\unichar{804}}%
\uc@dclc{7795}{autogenerated}{\unichar{117}\unichar{804}}%
\uc@dclc{7796}{autogenerated}{\unichar{85}\unichar{816}}%
\uc@dclc{7797}{autogenerated}{\unichar{117}\unichar{816}}%
\uc@dclc{7800}{autogenerated}{\unichar{360}\unichar{769}}%
\uc@dclc{7801}{autogenerated}{\unichar{361}\unichar{769}}%
\uc@dclc{7802}{autogenerated}{\unichar{362}\unichar{776}}%
\uc@dclc{7803}{autogenerated}{\unichar{363}\unichar{776}}%
\uc@dclc{7804}{default}{\~V}%
\uc@dclc{7805}{default}{\~v}%
\uc@dclc{7806}{default}{\d V}%
\uc@dclc{7807}{default}{\d v}%
\uc@dclc{7808}{default}{\@tabacckludge`W}%
\uc@dclc{7809}{default}{\@tabacckludge`w}%
\uc@dclc{7810}{default}{\@tabacckludge'W}%
\uc@dclc{7811}{default}{\@tabacckludge'w}%
\uc@dclc{7812}{default}{\"W}%
\uc@dclc{7813}{default}{\"w}%
\uc@dclc{7814}{default}{\.W}%
\uc@dclc{7815}{default}{\.w}%
\uc@dclc{7816}{default}{\d W}%
\uc@dclc{7817}{default}{\d w}%
\uc@dclc{7818}{default}{\.X}%
\uc@dclc{7819}{default}{\.x}%
\uc@dclc{7820}{default}{\"X}%
\uc@dclc{7821}{default}{\"x}%
\uc@dclc{7822}{default}{\.Y}%
\uc@dclc{7823}{default}{\.y}%
\uc@dclc{7824}{default}{\^Z}%
\uc@dclc{7825}{default}{\^z}%
\uc@dclc{7826}{default}{\d Z}%
\uc@dclc{7827}{default}{\d z}%
\uc@dclc{7828}{default}{\b Z}%
\uc@dclc{7829}{default}{\b z}%
\uc@dclc{7830}{default}{\b h}%
\uc@dclc{7831}{default}{\"t}%
\uc@dclc{7832}{default}{\r w}%
\uc@dclc{7833}{default}{\r y}%
\uc@dclc{7834}{autogenerated}{\unichar{97}\unichar{702}}%
\uc@dclc{7835}{autogenerated}{\unichar{383}\unichar{775}}%
\uc@dclc{7840}{default}{\d A}%
\uc@dclc{7841}{default}{\d a}%
\uc@dclc{7842}{default}{\h A}%
\uc@dclc{7843}{default}{\h a}%
\uc@dclc{7844}{default}{\@tabacckludge'\ACIRCUMFLEX}%
\uc@dclc{7845}{default}{\@tabacckludge'\acircumflex}%
\uc@dclc{7846}{default}{\@tabacckludge`\ACIRCUMFLEX}%
\uc@dclc{7847}{default}{\@tabacckludge`\acircumflex}%
\uc@dclc{7848}{default}{\h\ACIRCUMFLEX}%
\uc@dclc{7849}{default}{\h\acircumflex}%
\uc@dclc{7850}{default}{\~\ACIRCUMFLEX}%
\uc@dclc{7851}{default}{\~\acircumflex}%
\uc@dclc{7852}{default}{\d\ACIRCUMFLEX}%
\uc@dclc{7853}{default}{\d\acircumflex}%
\uc@dclc{7854}{default}{\@tabacckludge'\ABREVE}%
\uc@dclc{7855}{default}{\@tabacckludge'\abreve}%
\uc@dclc{7856}{default}{\@tabacckludge`\ABREVE}%
\uc@dclc{7857}{default}{\@tabacckludge`\abreve}%
\uc@dclc{7858}{default}{\h\ABREVE}%
\uc@dclc{7859}{default}{\h\abreve}%
\uc@dclc{7860}{default}{\~\ABREVE}%
\uc@dclc{7861}{default}{\~\abreve}%
\uc@dclc{7862}{default}{\d\ABREVE}%
\uc@dclc{7863}{default}{\d\abreve}%
\uc@dclc{7864}{default}{\d E}%
\uc@dclc{7865}{default}{\d e}%
\uc@dclc{7866}{default}{\h E}%
\uc@dclc{7867}{default}{\h e}%
\uc@dclc{7868}{default}{\~E}%
\uc@dclc{7869}{default}{\~e}%
\uc@dclc{7870}{default}{\@tabacckludge'\ECIRCUMFLEX}%
\uc@dclc{7871}{default}{\@tabacckludge'\ecircumflex}%
\uc@dclc{7872}{default}{\@tabacckludge`\ECIRCUMFLEX}%
\uc@dclc{7873}{default}{\@tabacckludge`\ecircumflex}%
\uc@dclc{7874}{default}{\h\ECIRCUMFLEX}%
\uc@dclc{7875}{default}{\h\ecircumflex}%
\uc@dclc{7876}{default}{\~\ECIRCUMFLEX}%
\uc@dclc{7877}{default}{\~\ecircumflex}%
\uc@dclc{7878}{default}{\d\ECIRCUMFLEX}%
\uc@dclc{7879}{default}{\d\ecircumflex}%
\uc@dclc{7880}{default}{\h I}%
\uc@dclc{7881}{default}{\h i}%
\uc@dclc{7882}{default}{\d I}%
\uc@dclc{7883}{default}{\d i}%
\uc@dclc{7884}{default}{\d O}%
\uc@dclc{7885}{default}{\d o}%
\uc@dclc{7886}{default}{\h O}%
\uc@dclc{7887}{default}{\h o}%
\uc@dclc{7888}{default}{\@tabacckludge'\OCIRCUMFLEX}%
\uc@dclc{7889}{default}{\@tabacckludge'\ocircumflex}%
\uc@dclc{7890}{default}{\@tabacckludge`\OCIRCUMFLEX}%
\uc@dclc{7891}{default}{\@tabacckludge`\ocircumflex}%
\uc@dclc{7892}{default}{\h\OCIRCUMFLEX}%
\uc@dclc{7893}{default}{\h\ocircumflex}%
\uc@dclc{7894}{default}{\~\OCIRCUMFLEX}%
\uc@dclc{7895}{default}{\~\ocircumflex}%
\uc@dclc{7896}{default}{\d\OCIRCUMFLEX}%
\uc@dclc{7897}{default}{\d\ocircumflex}%
\uc@dclc{7898}{default}{\@tabacckludge'\OHORN}%
\uc@dclc{7899}{default}{\@tabacckludge'\ohorn}%
\uc@dclc{7900}{default}{\@tabacckludge`\OHORN}%
\uc@dclc{7901}{default}{\@tabacckludge`\ohorn}%
\uc@dclc{7902}{default}{\h\OHORN}%
\uc@dclc{7903}{default}{\h\ohorn}%
\uc@dclc{7904}{default}{\~\OHORN}%
\uc@dclc{7905}{default}{\~\ohorn}%
\uc@dclc{7906}{default}{\d\OHORN}%
\uc@dclc{7907}{default}{\d\ohorn}%
\uc@dclc{7908}{default}{\d U}%
\uc@dclc{7909}{default}{\d u}%
\uc@dclc{7910}{default}{\h U}%
\uc@dclc{7911}{default}{\h u}%
\uc@dclc{7912}{default}{\@tabacckludge'\UHORN}%
\uc@dclc{7913}{default}{\@tabacckludge'\uhorn}%
\uc@dclc{7914}{default}{\@tabacckludge`\UHORN}%
\uc@dclc{7915}{default}{\@tabacckludge`\uhorn}%
\uc@dclc{7916}{default}{\h\UHORN}%
\uc@dclc{7917}{default}{\h\uhorn}%
\uc@dclc{7918}{default}{\~\UHORN}%
\uc@dclc{7919}{default}{\~\uhorn}%
\uc@dclc{7920}{default}{\d\UHORN}%
\uc@dclc{7921}{default}{\d\uhorn}%
\uc@dclc{7922}{default}{\@tabacckludge`Y}%
\uc@dclc{7923}{default}{\@tabacckludge`y}%
\uc@dclc{7924}{default}{\d Y}%
\uc@dclc{7925}{default}{\d y}%
\uc@dclc{7926}{default}{\h Y}%
\uc@dclc{7927}{default}{\h y}%
\uc@dclc{7928}{default}{\~Y}%
\uc@dclc{7929}{default}{\~y}%
%%% Local Variables: 
%%% mode: latex
%%% coding: utf-8
%%% End: 
