%%
%% This is file `ltlenc.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% ucs.dtx  (with options: `ltlenc.def')
%% 
%% Copyright 2001 Dominique Unruh  <unruh@ut.ee>
%% Copyright 2013 Wolfgang Jeltsch <wolfgang@cs.ioc.ee>
%% Copyright 2022 David Carlisle https://github.com/LaTeX-Package-Repositories/ucs
%% 
%% This program is provided under the terms of the LaTeX Project Public License with some
%% modifications. See the file LICENSE for information.
%% 
\DeclareFontEncoding{LTL}{}{}
\DeclareFontSubstitution{LTL}{cmr}{m}{n}
\let\uc@temp@a\@@input
\def\@@input#1 {\def\@tempa{tlxlate}\def\@tempb{#1}\ifx\@tempb\@tempa\expandafter\@firstoftwo\else\expandafter\@secondoftwo\fi{\@gobble}{\uc@temp@a#1 }}%
\input tlsyllable
\let\@@input\uc@temp@a
\let\ltl@state0
\let\ltl@tlvoa\tlvoa
\DeclareTextCommand{\texttelugustart}{LTL}{\let\ltl@state1}
\newcommand\ltl@vowel[2]{\let\ltl@tlvoa\empty#1\let\ltl@tlvoa\tlvoa\ifx\ltl@state2\let\ltl@state1\fi#2}
\newcommand\ltl@cons[1]{\ifx\ltl@state2\let\ltl@state1\fi#1\ltl@tlvoa}
\newcommand\ltl@ivowel[1]{\ifx\ltl@state2\let\ltl@state1\tlvoX\fi#1}
\newcommand\ltl@dcons[1]{\ifx\ltl@state1\let\ltl@state2\fi#1\ifx\ltl@state0\tlvoX\fi}
\DeclareTextCommand{\texttelugustop}{LTL}{\ifx\ltl@state2\tlvoX\fi\let\ltl@state0}
\DeclareTextCommand{\textascii}{LTL}[1]{\@textascii@switch{#1}}
\DeclareTextCommand{\textteluguvirama}{LTL}[1]{\ltl@vowel{#1}{\tlvoX}}
\DeclareTextCommand{\texttelugucandrabindu}{LTL}[1]{#1\ltl@ivowel{\tluaas}}
\DeclareTextCommand{\textteluguanusvara}{LTL}[1]{#1\ltl@ivowel{\tluasu}}
\DeclareTextCommand{\textteluguvisarga}{LTL}[1]{#1\ltl@ivowel{\tluavi}}
\DeclareTextCommand{\texttelugudda}{LTL}{\ltl@cons{\tlcbD}}
\DeclareTextCompositeCommand{\textteluguvirama}{LTL}{\texttelugudda}{\ltl@dcons{\tlcbD}}
\DeclareTextCommand{\texttelugubha}{LTL}{\ltl@cons{\tlcbbh}}
\DeclareTextCompositeCommand{\textteluguvirama}{LTL}{\texttelugubha}{\ltl@dcons{\tlcbbh}}
\DeclareTextCommand{\texttelugunga}{LTL}{\ltl@cons{\tlcbNG}}
\DeclareTextCompositeCommand{\textteluguvirama}{LTL}{\texttelugunga}{\ltl@dcons{\tlcbNG}}
\DeclareTextCommand{\texttelugudha}{LTL}{\ltl@cons{\tlcbdh}}
\DeclareTextCompositeCommand{\textteluguvirama}{LTL}{\texttelugudha}{\ltl@dcons{\tlcbdh}}
\DeclareTextCommand{\textteluguka}{LTL}{\ltl@cons{\tlcbk}}
\DeclareTextCompositeCommand{\textteluguvirama}{LTL}{\textteluguka}{\ltl@dcons{\tlcbk}}
\DeclareTextCommand{\texttelugussa}{LTL}{\ltl@cons{\tlcbSh}}
\DeclareTextCompositeCommand{\textteluguvirama}{LTL}{\texttelugussa}{\ltl@dcons{\tlcbSh}}
\DeclareTextCommand{\textteluguma}{LTL}{\ltl@cons{\tlcbm}}
\DeclareTextCompositeCommand{\textteluguvirama}{LTL}{\textteluguma}{\ltl@dcons{\tlcbm}}
\DeclareTextCommand{\texttelugutta}{LTL}{\ltl@cons{\tlcbT}}
\DeclareTextCompositeCommand{\textteluguvirama}{LTL}{\texttelugutta}{\ltl@dcons{\tlcbT}}
\DeclareTextCommand{\texttelugusha}{LTL}{\ltl@cons{\tlcbS}}
\DeclareTextCompositeCommand{\textteluguvirama}{LTL}{\texttelugusha}{\ltl@dcons{\tlcbS}}
\DeclareTextCommand{\textteluguba}{LTL}{\ltl@cons{\tlcbb}}
\DeclareTextCompositeCommand{\textteluguvirama}{LTL}{\textteluguba}{\ltl@dcons{\tlcbb}}
\DeclareTextCommand{\texttelugusa}{LTL}{\ltl@cons{\tlcbs}}
\DeclareTextCompositeCommand{\textteluguvirama}{LTL}{\texttelugusa}{\ltl@dcons{\tlcbs}}
\DeclareTextCommand{\textteluguda}{LTL}{\ltl@cons{\tlcbd}}
\DeclareTextCompositeCommand{\textteluguvirama}{LTL}{\textteluguda}{\ltl@dcons{\tlcbd}}
\DeclareTextCommand{\texttelugujha}{LTL}{\ltl@cons{\tlcbjh}}
\DeclareTextCompositeCommand{\textteluguvirama}{LTL}{\texttelugujha}{\ltl@dcons{\tlcbjh}}
\DeclareTextCommand{\textteluguha}{LTL}{\ltl@cons{\tlcbH}}
\DeclareTextCompositeCommand{\textteluguvirama}{LTL}{\textteluguha}{\ltl@dcons{\tlcbH}}
\DeclareTextCommand{\textteluguttha}{LTL}{\ltl@cons{\tlcbTh}}
\DeclareTextCompositeCommand{\textteluguvirama}{LTL}{\textteluguttha}{\ltl@dcons{\tlcbTh}}
\DeclareTextCommand{\textteluguya}{LTL}{\ltl@cons{\tlcbY}}
\DeclareTextCompositeCommand{\textteluguvirama}{LTL}{\textteluguya}{\ltl@dcons{\tlcbY}}
\DeclareTextCommand{\texttelugucha}{LTL}{\ltl@cons{\tlcbch}}
\DeclareTextCompositeCommand{\textteluguvirama}{LTL}{\texttelugucha}{\ltl@dcons{\tlcbch}}
\DeclareTextCommand{\textteluguja}{LTL}{\ltl@cons{\tlcbj}}
\DeclareTextCompositeCommand{\textteluguvirama}{LTL}{\textteluguja}{\ltl@dcons{\tlcbj}}
\DeclareTextCommand{\texttelugunya}{LTL}{\ltl@cons{\tlcbnx}}
\DeclareTextCompositeCommand{\textteluguvirama}{LTL}{\texttelugunya}{\ltl@dcons{\tlcbnx}}
\DeclareTextCommand{\texttelugulla}{LTL}{\ltl@cons{\tlcbL}}
\DeclareTextCompositeCommand{\textteluguvirama}{LTL}{\texttelugulla}{\ltl@dcons{\tlcbL}}
\DeclareTextCommand{\texttelugupha}{LTL}{\ltl@cons{\tlcbph}}
\DeclareTextCompositeCommand{\textteluguvirama}{LTL}{\texttelugupha}{\ltl@dcons{\tlcbph}}
\DeclareTextCommand{\textteluguna}{LTL}{\ltl@cons{\tlcbn}}
\DeclareTextCompositeCommand{\textteluguvirama}{LTL}{\textteluguna}{\ltl@dcons{\tlcbn}}
\DeclareTextCommand{\texttelugugha}{LTL}{\ltl@cons{\tlcbgh}}
\DeclareTextCompositeCommand{\textteluguvirama}{LTL}{\texttelugugha}{\ltl@dcons{\tlcbgh}}
\DeclareTextCommand{\textteluguddha}{LTL}{\ltl@cons{\tlcbDh}}
\DeclareTextCompositeCommand{\textteluguvirama}{LTL}{\textteluguddha}{\ltl@dcons{\tlcbDh}}
\DeclareTextCommand{\texttelugunna}{LTL}{\ltl@cons{\tlcbN}}
\DeclareTextCompositeCommand{\textteluguvirama}{LTL}{\texttelugunna}{\ltl@dcons{\tlcbN}}
\DeclareTextCommand{\texttelugupa}{LTL}{\ltl@cons{\tlcbp}}
\DeclareTextCompositeCommand{\textteluguvirama}{LTL}{\texttelugupa}{\ltl@dcons{\tlcbp}}
\DeclareTextCommand{\texttelugura}{LTL}{\ltl@cons{\tlcbr}}
\DeclareTextCompositeCommand{\textteluguvirama}{LTL}{\texttelugura}{\ltl@dcons{\tlcbr}}
\DeclareTextCommand{\textteluguca}{LTL}{\ltl@cons{\tlcbc}}
\DeclareTextCompositeCommand{\textteluguvirama}{LTL}{\textteluguca}{\ltl@dcons{\tlcbc}}
\DeclareTextCommand{\texttelugutha}{LTL}{\ltl@cons{\tlcbth}}
\DeclareTextCompositeCommand{\textteluguvirama}{LTL}{\texttelugutha}{\ltl@dcons{\tlcbth}}
\DeclareTextCommand{\texttelugukha}{LTL}{\ltl@cons{\tlcbkh}}
\DeclareTextCompositeCommand{\textteluguvirama}{LTL}{\texttelugukha}{\ltl@dcons{\tlcbkh}}
\DeclareTextCommand{\textteluguga}{LTL}{\ltl@cons{\tlcbg}}
\DeclareTextCompositeCommand{\textteluguvirama}{LTL}{\textteluguga}{\ltl@dcons{\tlcbg}}
\DeclareTextCommand{\texttelugurra}{LTL}{\ltl@cons{\tlcbR}}
\DeclareTextCompositeCommand{\textteluguvirama}{LTL}{\texttelugurra}{\ltl@dcons{\tlcbR}}
\DeclareTextCommand{\texttelugula}{LTL}{\ltl@cons{\tlcbl}}
\DeclareTextCompositeCommand{\textteluguvirama}{LTL}{\texttelugula}{\ltl@dcons{\tlcbl}}
\DeclareTextCommand{\textteluguta}{LTL}{\ltl@cons{\tlcbt}}
\DeclareTextCompositeCommand{\textteluguvirama}{LTL}{\textteluguta}{\ltl@dcons{\tlcbt}}
\DeclareTextCommand{\textteluguva}{LTL}{\ltl@cons{\tlcbv}}
\DeclareTextCompositeCommand{\textteluguvirama}{LTL}{\textteluguva}{\ltl@dcons{\tlcbv}}
\DeclareTextCommand{\texttelugublackbox}{LTL}{\ltl@cons{\tlcbbb}}
\DeclareTextCompositeCommand{\textteluguvirama}{LTL}{\texttelugublackbox}{\ltl@dcons{\tlcbbb}}
\DeclareTextCommand{\textteluguemptybox}{LTL}{\ltl@cons{\tlcbeb}}
\DeclareTextCompositeCommand{\textteluguvirama}{LTL}{\textteluguemptybox}{\ltl@dcons{\tlcbeb}}
\DeclareTextCommand{\textteluguoutlinebox}{LTL}{\ltl@cons{\tlcbob}}
\DeclareTextCompositeCommand{\textteluguvirama}{LTL}{\textteluguoutlinebox}{\ltl@dcons{\tlcbob}}
\DeclareTextCommand{\textteluguvowela}{LTL}[1]{\ltl@vowel{#1}{\tlvoa}}
\DeclareTextCommand{\texttelugua}{LTL}{\ltl@ivowel{\tlvoa}}
\DeclareTextCommand{\textteluguvowelaa}{LTL}[1]{\ltl@vowel{#1}{\tlvoA}}
\DeclareTextCommand{\textteluguaa}{LTL}{\ltl@ivowel{\tlvoA}}
\DeclareTextCommand{\textteluguvoweli}{LTL}[1]{\ltl@vowel{#1}{\tlvoi}}
\DeclareTextCommand{\texttelugui}{LTL}{\ltl@ivowel{\tlvoi}}
\DeclareTextCommand{\textteluguvowelii}{LTL}[1]{\ltl@vowel{#1}{\tlvoI}}
\DeclareTextCommand{\textteluguii}{LTL}{\ltl@ivowel{\tlvoI}}
\DeclareTextCommand{\textteluguvowelu}{LTL}[1]{\ltl@vowel{#1}{\tlvou}}
\DeclareTextCommand{\textteluguu}{LTL}{\ltl@ivowel{\tlvou}}
\DeclareTextCommand{\textteluguvoweluu}{LTL}[1]{\ltl@vowel{#1}{\tlvoU}}
\DeclareTextCommand{\textteluguuu}{LTL}{\ltl@ivowel{\tlvoU}}
\DeclareTextCommand{\textteluguvowelvocalicr}{LTL}[1]{\ltl@vowel{#1}{\tlvorx}}
\DeclareTextCommand{\textteluguvocalicr}{LTL}{\ltl@ivowel{\tlvorx}}
\DeclareTextCommand{\textteluguvowelvocalicl}{LTL}[1]{\ltl@vowel{#1}{\tlvolx}}
\DeclareTextCommand{\textteluguvocalicl}{LTL}{\ltl@ivowel{\tlvolx}}
\DeclareTextCommand{\textteluguvowelvocalicrr}{LTL}[1]{\ltl@vowel{#1}{\tlvoRx}}
\DeclareTextCommand{\textteluguvocalicrr}{LTL}{\ltl@ivowel{\tlvoRx}}
\DeclareTextCommand{\textteluguvowelvocalicll}{LTL}[1]{\ltl@vowel{#1}{\tlvoLx}}
\DeclareTextCommand{\textteluguvocalicll}{LTL}{\ltl@ivowel{\tlvoLx}}
\DeclareTextCommand{\textteluguvowele}{LTL}[1]{\ltl@vowel{#1}{\tlvoe}}
\DeclareTextCommand{\texttelugue}{LTL}{\ltl@ivowel{\tlvoe}}
\DeclareTextCommand{\textteluguvowelee}{LTL}[1]{\ltl@vowel{#1}{\tlvoE}}
\DeclareTextCommand{\textteluguee}{LTL}{\ltl@ivowel{\tlvoE}}
\DeclareTextCommand{\textteluguvowelai}{LTL}[1]{\ltl@vowel{#1}{\tlvoy}}
\DeclareTextCommand{\textteluguai}{LTL}{\ltl@ivowel{\tlvoy}}
\DeclareTextCommand{\textteluguvowelo}{LTL}[1]{\ltl@vowel{#1}{\tlvoo}}
\DeclareTextCommand{\textteluguo}{LTL}{\ltl@ivowel{\tlvoo}}
\DeclareTextCommand{\textteluguvoweloo}{LTL}[1]{\ltl@vowel{#1}{\tlvoO}}
\DeclareTextCommand{\textteluguoo}{LTL}{\ltl@ivowel{\tlvoO}}
\DeclareTextCommand{\textteluguvowelau}{LTL}[1]{\ltl@vowel{#1}{\tlvoow}}
\DeclareTextCommand{\textteluguau}{LTL}{\ltl@ivowel{\tlvoow}}
\DeclareTextCommand{\textteluguzero}{LTL}{\ltl@ivowel{\char\dtzeroCODE}}
\DeclareTextCommand{\textteluguone}{LTL}{\ltl@ivowel{\char\dtoneCODE}}
\DeclareTextCommand{\texttelugutwo}{LTL}{\ltl@ivowel{\char\dttwoCODE}}
\DeclareTextCommand{\textteluguthree}{LTL}{\ltl@ivowel{\char\dtthreeCODE}}
\DeclareTextCommand{\texttelugufour}{LTL}{\ltl@ivowel{\char\dtfourCODE}}
\DeclareTextCommand{\texttelugufive}{LTL}{\ltl@ivowel{\char\dtfiveCODE}}
\DeclareTextCommand{\texttelugusix}{LTL}{\ltl@ivowel{\char\dtsixCODE}}
\DeclareTextCommand{\textteluguseven}{LTL}{\ltl@ivowel{\char\dtsevenCODE}}
\DeclareTextCommand{\texttelugueight}{LTL}{\ltl@ivowel{\char\dteightCODE}}
\DeclareTextCommand{\texttelugunine}{LTL}{\ltl@ivowel{\char\dtnineCODE}}
%%% Local Variables:
%%% mode: latex
%%% coding: utf-8
%%% TeX-master: "../test.tex"
%%% End:
%%% Local IspellDict: british
