%%% Unicode to TeX mapping, file uni-214.def, U+D600..U+D6FF, autogenerated by makeunidef.pl
\ifx\ProvidesFile\undefined\else
\ProvidesFile{uni-214.def}[2022/08/07 UCS: Unicode data U+D600..U+D6FF]%
\fi
\gdef\u@cjk@hangul#1#2#3#4{{\fontencoding{C61}\def\CJK@plane{#1#2}\selectfont\char"#3#4\relax}}%
\uc@dclc{54784}{cjkhangul}{\u@cjk@hangul1547}%
\uc@dclc{54785}{cjkhangul}{\u@cjk@hangul1548}%
\uc@dclc{54788}{cjkhangul}{\u@cjk@hangul1549}%
\uc@dclc{54792}{cjkhangul}{\u@cjk@hangul154A}%
\uc@dclc{54800}{cjkhangul}{\u@cjk@hangul154B}%
\uc@dclc{54801}{cjkhangul}{\u@cjk@hangul154C}%
\uc@dclc{54803}{cjkhangul}{\u@cjk@hangul154D}%
\uc@dclc{54804}{cjkhangul}{\u@cjk@hangul154E}%
\uc@dclc{54805}{cjkhangul}{\u@cjk@hangul154F}%
\uc@dclc{54812}{cjkhangul}{\u@cjk@hangul1550}%
\uc@dclc{54816}{cjkhangul}{\u@cjk@hangul1551}%
\uc@dclc{54820}{cjkhangul}{\u@cjk@hangul1552}%
\uc@dclc{54829}{cjkhangul}{\u@cjk@hangul1553}%
\uc@dclc{54840}{cjkhangul}{\u@cjk@hangul1554}%
\uc@dclc{54841}{cjkhangul}{\u@cjk@hangul1555}%
\uc@dclc{54844}{cjkhangul}{\u@cjk@hangul1556}%
\uc@dclc{54848}{cjkhangul}{\u@cjk@hangul1557}%
\uc@dclc{54853}{cjkhangul}{\u@cjk@hangul1558}%
\uc@dclc{54856}{cjkhangul}{\u@cjk@hangul1559}%
\uc@dclc{54857}{cjkhangul}{\u@cjk@hangul155A}%
\uc@dclc{54859}{cjkhangul}{\u@cjk@hangul155B}%
\uc@dclc{54861}{cjkhangul}{\u@cjk@hangul155C}%
\uc@dclc{54865}{cjkhangul}{\u@cjk@hangul155D}%
\uc@dclc{54868}{cjkhangul}{\u@cjk@hangul155E}%
\uc@dclc{54869}{cjkhangul}{\u@cjk@hangul155F}%
\uc@dclc{54872}{cjkhangul}{\u@cjk@hangul1560}%
\uc@dclc{54876}{cjkhangul}{\u@cjk@hangul1561}%
\uc@dclc{54887}{cjkhangul}{\u@cjk@hangul1562}%
\uc@dclc{54889}{cjkhangul}{\u@cjk@hangul1563}%
\uc@dclc{54896}{cjkhangul}{\u@cjk@hangul1564}%
\uc@dclc{54897}{cjkhangul}{\u@cjk@hangul1565}%
\uc@dclc{54900}{cjkhangul}{\u@cjk@hangul1566}%
\uc@dclc{54915}{cjkhangul}{\u@cjk@hangul1567}%
\uc@dclc{54917}{cjkhangul}{\u@cjk@hangul1568}%
\uc@dclc{54924}{cjkhangul}{\u@cjk@hangul1569}%
\uc@dclc{54925}{cjkhangul}{\u@cjk@hangul156A}%
\uc@dclc{54928}{cjkhangul}{\u@cjk@hangul156B}%
\uc@dclc{54932}{cjkhangul}{\u@cjk@hangul156C}%
\uc@dclc{54941}{cjkhangul}{\u@cjk@hangul156D}%
\uc@dclc{54943}{cjkhangul}{\u@cjk@hangul156E}%
\uc@dclc{54945}{cjkhangul}{\u@cjk@hangul156F}%
\uc@dclc{54952}{cjkhangul}{\u@cjk@hangul1570}%
\uc@dclc{54956}{cjkhangul}{\u@cjk@hangul1571}%
\uc@dclc{54960}{cjkhangul}{\u@cjk@hangul1572}%
\uc@dclc{54969}{cjkhangul}{\u@cjk@hangul1573}%
\uc@dclc{54971}{cjkhangul}{\u@cjk@hangul1574}%
\uc@dclc{54980}{cjkhangul}{\u@cjk@hangul1575}%
\uc@dclc{54981}{cjkhangul}{\u@cjk@hangul1576}%
\uc@dclc{54984}{cjkhangul}{\u@cjk@hangul1577}%
\uc@dclc{54988}{cjkhangul}{\u@cjk@hangul1578}%
\uc@dclc{54993}{cjkhangul}{\u@cjk@hangul1579}%
\uc@dclc{54996}{cjkhangul}{\u@cjk@hangul157A}%
\uc@dclc{54999}{cjkhangul}{\u@cjk@hangul157B}%
\uc@dclc{55001}{cjkhangul}{\u@cjk@hangul157C}%
\uc@dclc{55008}{cjkhangul}{\u@cjk@hangul157D}%
\uc@dclc{55012}{cjkhangul}{\u@cjk@hangul157E}%
\uc@dclc{55016}{cjkhangul}{\u@cjk@hangul157F}%
\uc@dclc{55024}{cjkhangul}{\u@cjk@hangul1580}%
\uc@dclc{55029}{cjkhangul}{\u@cjk@hangul1581}%
\uc@dclc{55036}{cjkhangul}{\u@cjk@hangul1582}%
\uc@dclc{55037}{cjkhangul}{\u@cjk@hangul1583}%
%%% Local Variables: 
%%% mode: latex
%%% coding: utf-8
%%% End: 
