%%
%% This is file `x-mac-roman.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% inputenx.dtx  (with options: `mac-roman')
%% 
%% This is a generated file.
%% 
%% Project: inputenx
%% Version: 2019/11/29 v1.12
%% 
%% Copyright (C)
%%   2006-2011 Heiko Oberdiek
%%   2016-2019 Oberdiek Package Support Group
%% 
%% This work may be distributed and/or modified under the
%% conditions of the LaTeX Project Public License, either
%% version 1.3c of this license or (at your option) any later
%% version. This version of this license is in
%%    https://www.latex-project.org/lppl/lppl-1-3c.txt
%% and the latest version of this license is in
%%    https://www.latex-project.org/lppl.txt
%% and version 1.3 or later is part of all distributions of
%% LaTeX version 2005/12/01 or later.
%% 
%% This work has the LPPL maintenance status "maintained".
%% 
%% The Current Maintainers of this work are
%% Heiko Oberdiek and the Oberdiek Package Support Group
%% https://github.com/ho-tex/inputenx/issues
%% 
%% 
%% This work consists of the main source file inputenx.dtx
%% and the derived files
%%    inputenx.sty, inputenx.pdf, inputenx.ins, inputenx.drv, ix-alias.def,
%%    ix-math.def, ix-name.def, ix-slot.def, ix-uc.def,
%%    ix-utf8enc.dfu, x-ascii.def, x-verbatim.def, x-atarist.def,
%%    x-iso-8859-1.def, x-iso-8859-2.def, x-iso-8859-3.def,
%%    x-iso-8859-4.def, x-iso-8859-5.def, x-iso-8859-8.def,
%%    x-iso-8859-9.def, x-iso-8859-10.def, x-iso-8859-13.def,
%%    x-iso-8859-14.def, x-iso-8859-15.def, x-iso-8859-16.def,
%%    x-cp437.def, x-cp850.def, x-cp852.def, x-cp855.def,
%%    x-cp858.def, x-cp865.def, x-cp866.def, x-cp1250.def,
%%    x-cp1251.def, x-cp1252.def, x-cp1255.def, x-cp1257.def,
%%    x-dec-mcs.def, x-koi8-r.def, x-mac-centeuro.def,
%%    x-mac-cyrillic.def, x-mac-roman.def, x-nextstep.def,
%%    inputenx-licrcmds.txt, inputenx-utf8enc.txt.
%% 
\ProvidesFile{x-mac-roman.def}%
  [2019/11/29 v1.12 Input encoding mac-roman (inputenx)]%
\edef\RestoreAtCatcode{\catcode64=\the\catcode64\relax}
\makeatletter
\ProvideTextCommandDefault{\textOmega}{%
  \ensuremath\Omega
}
\ProvideTextCommandDefault{\textacutedbl}{%
  \H{}%
}
\ProvideTextCommandDefault{\textapproxequal}{%
  \ensuremath\approx
}
\ProvideTextCommandDefault{\textasciiacute}{%
  \@tabacckludge'{}%
}
\ProvideTextCommandDefault{\textasciibreve}{%
  \u{}%
}
\ProvideTextCommandDefault{\textasciicaron}{%
  \v{}%
}
\ProvideTextCommandDefault{\textasciidieresis}{%
  \"{}%
}
\ProvideTextCommandDefault{\textasciimacron}{%
  \@tabacckludge={}%
}
\ProvideTextCommandDefault{\textcent}{%
  \TextSymbolUnavailable\textcent
}
\ProvideTextCommandDefault{\textdegree}{%
  \ensuremath{{^\circ}}%
}
\ProvideTextCommandDefault{\textdiv}{%
  \TextSymbolUnavailable\textdiv
}
\ProvideTextCommandDefault{\texteuro}{%
  \TextSymbolUnavailable\texteuro
}
\ProvideTextCommandDefault{\textflorin}{%
  \textit{f}%
}
\ProvideTextCommandDefault{\textfractionsolidus}{%
  /%
}
\ProvideTextCommandDefault{\textgreaterequal}{%
  \ensuremath\geq
}
\ProvideTextCommandDefault{\textincrement}{%
  \ensuremath\Delta
}
\ProvideTextCommandDefault{\textinfinity}{%
  \ensuremath\infty
}
\ProvideTextCommandDefault{\textintegral}{%
  \ensuremath\int
}
\ProvideTextCommandDefault{\textlessequal}{%
  \ensuremath\leq
}
\ProvideTextCommandDefault{\textlnot}{%
  \ensuremath\lnot
}
\ProvideTextCommandDefault{\textlozenge}{%
  \ensuremath\diamond
}
\ProvideTextCommandDefault{\textmu}{%
  \ensuremath\mu
}
\ProvideTextCommandDefault{\textnotequal}{%
  \ensuremath\neq
}
\ProvideTextCommandDefault{\textpartial}{%
  \ensuremath\partial
}
\ProvideTextCommandDefault{\textpi}{%
  \ensuremath\pi
}
\ProvideTextCommandDefault{\textpm}{%
  \ensuremath\pm
}
\ProvideTextCommandDefault{\textproduct}{%
  \ensuremath\Pi
}
\ProvideTextCommandDefault{\textsummation}{%
  \ensuremath\Sigma
}
\ProvideTextCommandDefault{\textsurd}{%
  \ensuremath\surd
}
\ProvideTextCommandDefault{\textyen}{%
  \TextSymbolUnavailable\textyen
}
\DeclareInputText{128}{\"A}
\DeclareInputText{129}{\r A}
\DeclareInputText{130}{\c C}
\DeclareInputText{131}{\@tabacckludge'E}
\DeclareInputText{132}{\~N}
\DeclareInputText{133}{\"O}
\DeclareInputText{134}{\"U}
\DeclareInputText{135}{\@tabacckludge'a}
\DeclareInputText{136}{\@tabacckludge`a}
\DeclareInputText{137}{\^a}
\DeclareInputText{138}{\"a}
\DeclareInputText{139}{\~a}
\DeclareInputText{140}{\r a}
\DeclareInputText{141}{\c c}
\DeclareInputText{142}{\@tabacckludge'e}
\DeclareInputText{143}{\@tabacckludge`e}
\DeclareInputText{144}{\^e}
\DeclareInputText{145}{\"e}
\DeclareInputText{146}{\@tabacckludge'\i}
\DeclareInputText{147}{\@tabacckludge`\i}
\DeclareInputText{148}{\^\i}
\DeclareInputText{149}{\"\i}
\DeclareInputText{150}{\~n}
\DeclareInputText{151}{\@tabacckludge'o}
\DeclareInputText{152}{\@tabacckludge`o}
\DeclareInputText{153}{\^o}
\DeclareInputText{154}{\"o}
\DeclareInputText{155}{\~o}
\DeclareInputText{156}{\@tabacckludge'u}
\DeclareInputText{157}{\@tabacckludge`u}
\DeclareInputText{158}{\^u}
\DeclareInputText{159}{\"u}
\DeclareInputText{160}{\textdagger}
\DeclareInputText{161}{\textdegree}
\DeclareInputText{162}{\textcent}
\DeclareInputText{163}{\textsterling}
\DeclareInputText{164}{\textsection}
\DeclareInputText{165}{\textbullet}
\DeclareInputText{166}{\textparagraph}
\DeclareInputText{167}{\ss}
\DeclareInputText{168}{\textregistered}
\DeclareInputText{169}{\textcopyright}
\DeclareInputText{170}{\texttrademark}
\DeclareInputText{171}{\textasciiacute}
\DeclareInputText{172}{\textasciidieresis}
\DeclareInputText{173}{\textnotequal}
\DeclareInputText{174}{\AE}
\DeclareInputText{175}{\O}
\DeclareInputText{176}{\textinfinity}
\DeclareInputText{177}{\textpm}
\DeclareInputText{178}{\textlessequal}
\DeclareInputText{179}{\textgreaterequal}
\DeclareInputText{180}{\textyen}
\DeclareInputText{181}{\textmu}
\DeclareInputText{182}{\textpartial}
\DeclareInputText{183}{\textsummation}
\DeclareInputText{184}{\textproduct}
\DeclareInputText{185}{\textpi}
\DeclareInputText{186}{\textintegral}
\DeclareInputText{187}{\textordfeminine}
\DeclareInputText{188}{\textordmasculine}
\DeclareInputText{189}{\textOmega}
\DeclareInputText{190}{\ae}
\DeclareInputText{191}{\o}
\DeclareInputText{192}{\textquestiondown}
\DeclareInputText{193}{\textexclamdown}
\DeclareInputText{194}{\textlnot}
\DeclareInputText{195}{\textsurd}
\DeclareInputText{196}{\textflorin}
\DeclareInputText{197}{\textapproxequal}
\DeclareInputText{198}{\textincrement}
\DeclareInputText{199}{\guillemotleft}
\DeclareInputText{200}{\guillemotright}
\DeclareInputText{201}{\textellipsis}
\DeclareInputText{202}{\nobreakspace}
\DeclareInputText{203}{\@tabacckludge`A}
\DeclareInputText{204}{\~A}
\DeclareInputText{205}{\~O}
\DeclareInputText{206}{\OE}
\DeclareInputText{207}{\oe}
\DeclareInputText{208}{\textendash}
\DeclareInputText{209}{\textemdash}
\DeclareInputText{210}{\textquotedblleft}
\DeclareInputText{211}{\textquotedblright}
\DeclareInputText{212}{\textquoteleft}
\DeclareInputText{213}{\textquoteright}
\DeclareInputText{214}{\textdiv}
\DeclareInputText{215}{\textlozenge}
\DeclareInputText{216}{\"y}
\DeclareInputText{217}{\"Y}
\DeclareInputText{218}{\textfractionsolidus}
\DeclareInputText{219}{\texteuro}
\DeclareInputText{220}{\guilsinglleft}
\DeclareInputText{221}{\guilsinglright}
\DeclareInputText{222}{fi}
\DeclareInputText{223}{fl}
\DeclareInputText{224}{\textdaggerdbl}
\DeclareInputText{225}{\textperiodcentered}
\DeclareInputText{226}{\quotesinglbase}
\DeclareInputText{227}{\quotedblbase}
\DeclareInputText{228}{\textperthousand}
\DeclareInputText{229}{\^A}
\DeclareInputText{230}{\^E}
\DeclareInputText{231}{\@tabacckludge'A}
\DeclareInputText{232}{\"E}
\DeclareInputText{233}{\@tabacckludge`E}
\DeclareInputText{234}{\@tabacckludge'I}
\DeclareInputText{235}{\^I}
\DeclareInputText{236}{\"I}
\DeclareInputText{237}{\@tabacckludge`I}
\DeclareInputText{238}{\@tabacckludge'O}
\DeclareInputText{239}{\^O}
\DeclareInputText{241}{\@tabacckludge`O}
\DeclareInputText{242}{\@tabacckludge'U}
\DeclareInputText{243}{\^U}
\DeclareInputText{244}{\@tabacckludge`U}
\DeclareInputText{245}{\i}
\DeclareInputText{246}{\textasciicircum}
\DeclareInputText{247}{\textasciitilde}
\DeclareInputText{248}{\textasciimacron}
\DeclareInputText{249}{\textasciibreve}
\DeclareInputText{250}{\.{}}
\DeclareInputText{251}{\r{}}
\DeclareInputText{252}{\c\ }
\DeclareInputText{253}{\textacutedbl}
\DeclareInputText{254}{\k{}}
\DeclareInputText{255}{\textasciicaron}
\RestoreAtCatcode
\ProvideTextCommandDefault{\textapplelogo}{%
  \TextSymbolUnavailable\textapplelogo
}
\DeclareInputText{240}{\textapplelogo}
\endinput
%%
%% End of file `x-mac-roman.def'.
