%%% Unicode to TeX mapping, file uni-171.def, U+AB00..U+ABFF, autogenerated by makeunidef.pl
\ifx\ProvidesFile\undefined\else
\ProvidesFile{uni-171.def}[2022/08/07 UCS: Unicode data U+AB00..U+ABFF]%
\fi
\uc@dclc{43870}{autogenerated}{\unicodesuper{\unichar{619}}}%
\uc@dclc{43881}{autogenerated}{\unicodesuper{\unichar{653}}}%
%%% Local Variables: 
%%% mode: latex
%%% coding: utf-8
%%% End: 
