////////////////////////////////////////////////////////////////////////////////
//
// (C) 2012, Alexander Grahn
//
// 3Dspintool.js
//
// version 20120301
//
////////////////////////////////////////////////////////////////////////////////
//
// 3D JavaScript to be used with media9.sty (option `add3Djscript')
//
// enables the Spin tool (also accessible via 3D toolbar or context menu)
// upon activation of the 3D scene; the scene then rotates around the upright
// axis while dragging with the mouse
//
// This work may be distributed and/or modified under the
// conditions of the LaTeX Project Public License.
// 
// The latest version of this license is in
//   http://mirrors.ctan.org/macros/latex/base/lppl.txt
// 
// This work has the LPPL maintenance status `maintained'.
// 
// The Current Maintainer of this work is A. Grahn.
//
////////////////////////////////////////////////////////////////////////////////

runtime.setCurrentTool(runtime.TOOL_NAME_SPIN);
