%%
%% This is file `mu/fithesis-english.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% english.dtx  (with options: `mu')
%% 
%% Copyright 1998--2024  Daniel Marek (DM), Jan Pavlovič (JP),
%%                       Petr Sojka (PS), Vít Starý Novotný (VN),
%%                       Tereza Vrabcová (TV)
%% http://www.fi.muni.cz/tech/unix/tex/fithesis.xhtml
%% Faculty of Informatics, Masaryk University (Brno, Czech Republic)
%% 
%% This work may be distributed and/or modified under the
%% conditions of the LaTeX Project Public License, either version
%% 1.3 of this license or (at your option) any later version.
%% The latest version of this license is available at
%% 
%%   http://www.latex-project.org/lppl.txt
%% 
%% and version 1.3 or later is part of all distributions of LaTeX
%% version 2005/12/01 or later.
%% 
%% This work has the LPPL maintenance status `maintained'.
%% 
%% The Current Maintainer of this work is Vít Starý Novotný (VN).
%% Send bug reports, requests for additions and questions
%% either to the fithesis discussion forum at
%% 
%%   http://is.muni.cz/auth/df/fithesis-sazba/
%% 
%% or to the e-mail address <witiko@mail.muni.cz>.
%% 
%% 
%% MODIFICATION ADVICE:
%% 
%% If you want to customize this file, it is best to make a copy of
%% the source file(s) from which it was produced.  Use a different
%% name for your copy(ies) and modify the copy(ies); this will ensure
%% that your modifications do not get overwritten when you install a
%% new release of the standard system.  You should also ensure that
%% your modified source file does not generate any modified file with
%% the same name as a standard file.
%% 
%% You will also need to produce your own, suitably named, .ins file to
%% control the generation of files from your source file; this file
%% should contain your own preambles for the files it generates, not
%% those in the standard .ins files.
%% 
%% The names of the source files used are shown above.
%% 
\ProvidesFile{fithesis/locale/mu/fithesis-english.def}[2017/07/09]
\gdef\thesis@english@universityName{Masaryk University}
\gdef\thesis@english@declaration{%
  Hereby I declare that this paper is my original authorial work,
  which I have worked out on my own. All sources, references, and
  literature used or excerpted during elaboration of this work are
  properly cited and listed in complete reference to the due source.}

\gdef\thesis@english@assignment{%
  \ifthesis@digital@
  \else
  \fi}
\gdef\thesis@english@assignment{%
  \ifthesis@blocks@assignment@hideIfDigital@
    \ifthesis@digital@
      This is where a copy of the official signed thesis assignment
      is located in the printed version of the document.
    \else
      Replace this page with a copy of the official signed thesis
      assignment.
    \fi
  \else
    Set the PDF document containing the official signed thesis
    assignment using the <<assignment>> key.
  \fi}

\gdef\thesis@english@bib@title{Bibliographic record}
\gdef\thesis@english@bib@pages{p}
\global\let\thesis@english@bib@author\thesis@english@authorTitle
\gdef\thesis@english@bib@thesisTitle{Title of Thesis}
\gdef\thesis@english@bib@advisor{Supervisor}
\gdef\thesis@english@bib@programme{Degree Programme}
\global\let\thesis@english@bib@field\thesis@english@fieldTitle
\gdef\thesis@english@bib@academicYear{Academic Year}
\gdef\thesis@english@bib@pages{Number of Pages}
\global\let\thesis@english@bib@keywords\thesis@english@keywordsTitle

\gdef\thesis@english@idTitle{UČO}
\endinput
%%
%% End of file `mu/fithesis-english.def'.
