%%
%% This is file `c61enc.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% ucs.dtx  (with options: `c61enc.def')
%% 
%% Copyright 2001 Dominique Unruh  <unruh@ut.ee>
%% Copyright 2013 Wolfgang Jeltsch <wolfgang@cs.ioc.ee>
%% Copyright 2022 David Carlisle https://github.com/LaTeX-Package-Repositories/ucs
%% 
%% This program is provided under the terms of the LaTeX Project Public License with some
%% modifications. See the file LICENSE for information.
%% 
\ProvidesFile{c61enc.def}[2001/10/11 Fontencoding C61 (KSC5601 hangul)]%
\DeclareFontEncoding{C61}{}{}%
\DeclareFontSubstitution{C61}{mj}{m}{n}%
\input{cenccmn.tex}%
\expandafter\let\csname C61/mj/m/n\endcsname\undefined
