%%
%% This is file `accsupp-dvipdfm.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% accsupp.dtx  (with options: `dvipdfm')
%% 
%% This is a generated file.
%% 
%% Project: accsupp
%% Version: 2019/12/05 v0.6
%% 
%% Copyright (C)
%%    2007, 2010 Heiko Oberdiek
%%    2016-2019 Oberdiek Package Support Group
%% 
%% This work may be distributed and/or modified under the
%% conditions of the LaTeX Project Public License, either
%% version 1.3c of this license or (at your option) any later
%% version. This version of this license is in
%%    https://www.latex-project.org/lppl/lppl-1-3c.txt
%% and the latest version of this license is in
%%    https://www.latex-project.org/lppl.txt
%% and version 1.3 or later is part of all distributions of
%% LaTeX version 2005/12/01 or later.
%% 
%% This work has the LPPL maintenance status "maintained".
%% 
%% The Current Maintainers of this work are
%% Heiko Oberdiek and the Oberdiek Package Support Group
%% https://github.com/ho-tex/accsupp/issues
%% 
%% 
%% This work consists of the main source file accsupp.dtx
%% and the derived files
%%    accsupp.sty, accsupp.pdf, accsupp.ins, accsupp.drv,
%%    accsupp-pdftex.def, accsupp-luatex.def, accsupp-dvipdfm.def,
%%    accsupp-dvips.def,
%%    accsupp-example1.tex, accsupp-example2.tex,
%%    accsupp-test1.tex.
%% 
\NeedsTeXFormat{LaTeX2e}
\ProvidesFile{accsupp-dvipdfm.def}%
  [2019/12/05 v0.6 accsupp driver for dvipdfm (HO)]%
\def\ACCSUPP@bdc{%
  \special{pdf:content \ACCSUPP@span BDC}%
}
\def\ACCSUPP@emc{%
  \special{pdf:content EMC}%
}
\endinput
%%
%% End of file `accsupp-dvipdfm.def'.
