%%
%% This is file `x-iso-8859-5.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% inputenx.dtx  (with options: `iso-8859-5')
%% 
%% This is a generated file.
%% 
%% Project: inputenx
%% Version: 2019/11/29 v1.12
%% 
%% Copyright (C)
%%   2006-2011 Heiko Oberdiek
%%   2016-2019 Oberdiek Package Support Group
%% 
%% This work may be distributed and/or modified under the
%% conditions of the LaTeX Project Public License, either
%% version 1.3c of this license or (at your option) any later
%% version. This version of this license is in
%%    https://www.latex-project.org/lppl/lppl-1-3c.txt
%% and the latest version of this license is in
%%    https://www.latex-project.org/lppl.txt
%% and version 1.3 or later is part of all distributions of
%% LaTeX version 2005/12/01 or later.
%% 
%% This work has the LPPL maintenance status "maintained".
%% 
%% The Current Maintainers of this work are
%% Heiko Oberdiek and the Oberdiek Package Support Group
%% https://github.com/ho-tex/inputenx/issues
%% 
%% 
%% This work consists of the main source file inputenx.dtx
%% and the derived files
%%    inputenx.sty, inputenx.pdf, inputenx.ins, inputenx.drv, ix-alias.def,
%%    ix-math.def, ix-name.def, ix-slot.def, ix-uc.def,
%%    ix-utf8enc.dfu, x-ascii.def, x-verbatim.def, x-atarist.def,
%%    x-iso-8859-1.def, x-iso-8859-2.def, x-iso-8859-3.def,
%%    x-iso-8859-4.def, x-iso-8859-5.def, x-iso-8859-8.def,
%%    x-iso-8859-9.def, x-iso-8859-10.def, x-iso-8859-13.def,
%%    x-iso-8859-14.def, x-iso-8859-15.def, x-iso-8859-16.def,
%%    x-cp437.def, x-cp850.def, x-cp852.def, x-cp855.def,
%%    x-cp858.def, x-cp865.def, x-cp866.def, x-cp1250.def,
%%    x-cp1251.def, x-cp1252.def, x-cp1255.def, x-cp1257.def,
%%    x-dec-mcs.def, x-koi8-r.def, x-mac-centeuro.def,
%%    x-mac-cyrillic.def, x-mac-roman.def, x-nextstep.def,
%%    inputenx-licrcmds.txt, inputenx-utf8enc.txt.
%% 
\ProvidesFile{x-iso-8859-5.def}%
  [2019/11/29 v1.12 Input encoding iso-8859-5 (inputenx)]%
\edef\RestoreAtCatcode{\catcode64=\the\catcode64\relax}
\makeatletter
\ProvideTextCommandDefault{\textnumero}{%
  N%
  \bgroup
    \check@mathfonts
    \fontsize\sf@size\z@
    \math@fontsfalse
    \selectfont
    \ooalign{%
      \raise0.5ex\hbox{o}%
      \crcr
      \hline
    }%
  \egroup
}
\DeclareInputText{160}{\nobreakspace}
\DeclareInputText{161}{\CYRYO}
\DeclareInputText{162}{\CYRDJE}
\DeclareInputText{163}{\@tabacckludge'\CYRG}
\DeclareInputText{164}{\CYRIE}
\DeclareInputText{165}{\CYRDZE}
\DeclareInputText{166}{\CYRII}
\DeclareInputText{167}{\CYRYI}
\DeclareInputText{168}{\CYRJE}
\DeclareInputText{169}{\CYRLJE}
\DeclareInputText{170}{\CYRNJE}
\DeclareInputText{171}{\CYRTSHE}
\DeclareInputText{172}{\@tabacckludge'\CYRK}
\DeclareInputText{173}{\-}
\DeclareInputText{174}{\CYRUSHRT}
\DeclareInputText{175}{\CYRDZHE}
\DeclareInputText{176}{\CYRA}
\DeclareInputText{177}{\CYRB}
\DeclareInputText{178}{\CYRV}
\DeclareInputText{179}{\CYRG}
\DeclareInputText{180}{\CYRD}
\DeclareInputText{181}{\CYRE}
\DeclareInputText{182}{\CYRZH}
\DeclareInputText{183}{\CYRZ}
\DeclareInputText{184}{\CYRI}
\DeclareInputText{185}{\CYRISHRT}
\DeclareInputText{186}{\CYRK}
\DeclareInputText{187}{\CYRL}
\DeclareInputText{188}{\CYRM}
\DeclareInputText{189}{\CYRN}
\DeclareInputText{190}{\CYRO}
\DeclareInputText{191}{\CYRP}
\DeclareInputText{192}{\CYRR}
\DeclareInputText{193}{\CYRS}
\DeclareInputText{194}{\CYRT}
\DeclareInputText{195}{\CYRU}
\DeclareInputText{196}{\CYRF}
\DeclareInputText{197}{\CYRH}
\DeclareInputText{198}{\CYRC}
\DeclareInputText{199}{\CYRCH}
\DeclareInputText{200}{\CYRSH}
\DeclareInputText{201}{\CYRSHCH}
\DeclareInputText{202}{\CYRHRDSN}
\DeclareInputText{203}{\CYRERY}
\DeclareInputText{204}{\CYRSFTSN}
\DeclareInputText{205}{\CYREREV}
\DeclareInputText{206}{\CYRYU}
\DeclareInputText{207}{\CYRYA}
\DeclareInputText{208}{\cyra}
\DeclareInputText{209}{\cyrb}
\DeclareInputText{210}{\cyrv}
\DeclareInputText{211}{\cyrg}
\DeclareInputText{212}{\cyrd}
\DeclareInputText{213}{\cyre}
\DeclareInputText{214}{\cyrzh}
\DeclareInputText{215}{\cyrz}
\DeclareInputText{216}{\cyri}
\DeclareInputText{217}{\cyrishrt}
\DeclareInputText{218}{\cyrk}
\DeclareInputText{219}{\cyrl}
\DeclareInputText{220}{\cyrm}
\DeclareInputText{221}{\cyrn}
\DeclareInputText{222}{\cyro}
\DeclareInputText{223}{\cyrp}
\DeclareInputText{224}{\cyrr}
\DeclareInputText{225}{\cyrs}
\DeclareInputText{226}{\cyrt}
\DeclareInputText{227}{\cyru}
\DeclareInputText{228}{\cyrf}
\DeclareInputText{229}{\cyrh}
\DeclareInputText{230}{\cyrc}
\DeclareInputText{231}{\cyrch}
\DeclareInputText{232}{\cyrsh}
\DeclareInputText{233}{\cyrshch}
\DeclareInputText{234}{\cyrhrdsn}
\DeclareInputText{235}{\cyrery}
\DeclareInputText{236}{\cyrsftsn}
\DeclareInputText{237}{\cyrerev}
\DeclareInputText{238}{\cyryu}
\DeclareInputText{239}{\cyrya}
\DeclareInputText{240}{\textnumero}
\DeclareInputText{241}{\cyryo}
\DeclareInputText{242}{\cyrdje}
\DeclareInputText{243}{\@tabacckludge'\cyrg}
\DeclareInputText{244}{\cyrie}
\DeclareInputText{245}{\cyrdze}
\DeclareInputText{246}{\cyrii}
\DeclareInputText{247}{\cyryi}
\DeclareInputText{248}{\cyrje}
\DeclareInputText{249}{\cyrlje}
\DeclareInputText{250}{\cyrnje}
\DeclareInputText{251}{\cyrtshe}
\DeclareInputText{252}{\@tabacckludge'\cyrk}
\DeclareInputText{253}{\textsection}
\DeclareInputText{254}{\cyrushrt}
\DeclareInputText{255}{\cyrdzhe}
\RestoreAtCatcode
\endinput
%%
%% End of file `x-iso-8859-5.def'.
