%%% Unicode to TeX mapping, file uni-3584.def, U+E0000..U+E00FF, autogenerated by makeunidef.pl
\ifx\ProvidesFile\undefined\else
\ProvidesFile{uni-3584.def}[2022/08/07 UCS: Unicode data U+E0000..U+E00FF]%
\fi
\gdef\uc@controlbox#1{{\fboxsep=1pt\fbox{\tabcolsep=0pt\ttfamily\tiny\begin{tabular}{c}#1\end{tabular}}}}%
\uc@dclc{917505}{ctrlglyphs}{\uc@controlbox{\ding{"D9}\\\ding{"2D}}}%
\global\let\uc@combining@prechar\@ne
\ifx\uc@tagtoks\undefined\newtoks\uc@tagtoks\fi
\gdef\uc@langtag{%
  \expandafter\uppercase\expandafter{\expandafter\uc@tagtoks\expandafter{\the\uc@tagtoks}}%
  \expandafter\ifx\expandafter\@nil\the\uc@tagtoks\@nil\uc@tagtoks{@empty}\fi
  \expandafter\ifx\csname language\the\uc@tagtoks\endcsname\relax
    \PackageError{ucs}{Unknown language tag '\the\uc@tagtoks' (\@backslashchar language\the\uc@tagtoks)}{%
      Define it via \@backslashchar newcommand\@backslashchar language\the\uc@tagtoks{...}.}%
  \else
    \csname language\the\uc@tagtoks\endcsname
  \fi}%
\gdef\uc@endtag{%
  \uc@tagtype%
  \uc@tagtoks{}\let\uc@tagtype\undefined%
  \let\uc@prechar\undefined}%
\gdef\uc@tag#1{%
  \uc@tagtoks\expandafter{\the\uc@tagtoks#1}}%
\gdef\uc@starttag#1{%
  \ifx\uc@prechar\undefined
    \def\uc@prechar##1{\ifnum##1<"E0020 \uc@endtag\fi\ifnum##1>"E007E \uc@endtag\fi}%
    \let\uc@tagtype#1%
  \else
    \PackageError{ucs}{\protect\uc@prechar\space already
      defined.}{Something is already using the \protect\uc@prechar
      mechanism. Tags can't be collected properly.}%
  \fi}%
{\lccode`\A`\{\relax\lccode`\B`\}\relax\lccode`\C`\~\lowercase{%
  \gdef\@leftbracechar{A}%
  \gdef\@rightbracechar{B}%
  \gdef\@tildechar{C}}}%
\uc@dclc{917505}{default}{\uc@starttag\uc@langtag}%
\uc@dclc{917536}{ctrlglyphs}{\uc@controlbox{\textvisiblespace\\\ding{"2D}}}%
\uc@dclc{917536}{default}{\uc@tag { }}%
\uc@dclc{917537}{ctrlglyphs}{\uc@controlbox{!\\\ding{"2D}}}%
\uc@dclc{917537}{default}{\uc@tag !}%
\uc@dclc{917538}{ctrlglyphs}{\uc@controlbox{"\\\ding{"2D}}}%
\uc@dclc{917538}{default}{\uc@tag "}%
\uc@dclc{917539}{ctrlglyphs}{\uc@controlbox{\#\\\ding{"2D}}}%
\uc@dclc{917539}{default}{\uc@tag {##}}%
\uc@dclc{917540}{ctrlglyphs}{\uc@controlbox{\$\\\ding{"2D}}}%
\uc@dclc{917540}{default}{\uc@tag $}%
\uc@dclc{917541}{ctrlglyphs}{\uc@controlbox{\%\\\ding{"2D}}}%
\uc@dclc{917541}{default}{\uc@tag \@percentchar}%
\uc@dclc{917542}{ctrlglyphs}{\uc@controlbox{\&\\\ding{"2D}}}%
\uc@dclc{917542}{default}{\uc@tag &}%
\uc@dclc{917543}{ctrlglyphs}{\uc@controlbox{\textquoteright\\\ding{"2D}}}%
\uc@dclc{917543}{default}{\uc@tag '}%
\uc@dclc{917544}{ctrlglyphs}{\uc@controlbox{(\\\ding{"2D}}}%
\uc@dclc{917544}{default}{\uc@tag (}%
\uc@dclc{917545}{ctrlglyphs}{\uc@controlbox{)\\\ding{"2D}}}%
\uc@dclc{917545}{default}{\uc@tag )}%
\uc@dclc{917546}{ctrlglyphs}{\uc@controlbox{*\\\ding{"2D}}}%
\uc@dclc{917546}{default}{\uc@tag *}%
\uc@dclc{917547}{ctrlglyphs}{\uc@controlbox{+\\\ding{"2D}}}%
\uc@dclc{917547}{default}{\uc@tag +}%
\uc@dclc{917548}{ctrlglyphs}{\uc@controlbox{,\\\ding{"2D}}}%
\uc@dclc{917548}{default}{\uc@tag ,}%
\uc@dclc{917549}{ctrlglyphs}{\uc@controlbox{-\\\ding{"2D}}}%
\uc@dclc{917549}{default}{\uc@tag -}%
\uc@dclc{917550}{ctrlglyphs}{\uc@controlbox{.\\\ding{"2D}}}%
\uc@dclc{917550}{default}{\uc@tag .}%
\uc@dclc{917551}{ctrlglyphs}{\uc@controlbox{/\\\ding{"2D}}}%
\uc@dclc{917551}{default}{\uc@tag /}%
\uc@dclc{917552}{ctrlglyphs}{\uc@controlbox{0\\\ding{"2D}}}%
\uc@dclc{917552}{default}{\uc@tag 0}%
\uc@dclc{917553}{ctrlglyphs}{\uc@controlbox{1\\\ding{"2D}}}%
\uc@dclc{917553}{default}{\uc@tag 1}%
\uc@dclc{917554}{ctrlglyphs}{\uc@controlbox{2\\\ding{"2D}}}%
\uc@dclc{917554}{default}{\uc@tag 2}%
\uc@dclc{917555}{ctrlglyphs}{\uc@controlbox{3\\\ding{"2D}}}%
\uc@dclc{917555}{default}{\uc@tag 3}%
\uc@dclc{917556}{ctrlglyphs}{\uc@controlbox{4\\\ding{"2D}}}%
\uc@dclc{917556}{default}{\uc@tag 4}%
\uc@dclc{917557}{ctrlglyphs}{\uc@controlbox{5\\\ding{"2D}}}%
\uc@dclc{917557}{default}{\uc@tag 5}%
\uc@dclc{917558}{ctrlglyphs}{\uc@controlbox{6\\\ding{"2D}}}%
\uc@dclc{917558}{default}{\uc@tag 6}%
\uc@dclc{917559}{ctrlglyphs}{\uc@controlbox{7\\\ding{"2D}}}%
\uc@dclc{917559}{default}{\uc@tag 7}%
\uc@dclc{917560}{ctrlglyphs}{\uc@controlbox{8\\\ding{"2D}}}%
\uc@dclc{917560}{default}{\uc@tag 8}%
\uc@dclc{917561}{ctrlglyphs}{\uc@controlbox{9\\\ding{"2D}}}%
\uc@dclc{917561}{default}{\uc@tag 9}%
\uc@dclc{917562}{ctrlglyphs}{\uc@controlbox{:\\\ding{"2D}}}%
\uc@dclc{917562}{default}{\uc@tag :}%
\uc@dclc{917563}{ctrlglyphs}{\uc@controlbox{;\\\ding{"2D}}}%
\uc@dclc{917563}{default}{\uc@tag ;}%
\uc@dclc{917564}{ctrlglyphs}{\uc@controlbox{<\\\ding{"2D}}}%
\uc@dclc{917564}{default}{\uc@tag <}%
\uc@dclc{917565}{ctrlglyphs}{\uc@controlbox{=\\\ding{"2D}}}%
\uc@dclc{917565}{default}{\uc@tag =}%
\uc@dclc{917566}{ctrlglyphs}{\uc@controlbox{>\\\ding{"2D}}}%
\uc@dclc{917566}{default}{\uc@tag >}%
\uc@dclc{917567}{ctrlglyphs}{\uc@controlbox{?\\\ding{"2D}}}%
\uc@dclc{917567}{default}{\uc@tag ?}%
\uc@dclc{917568}{ctrlglyphs}{\uc@controlbox{@\\\ding{"2D}}}%
\uc@dclc{917568}{default}{\uc@tag @}%
\uc@dclc{917569}{ctrlglyphs}{\uc@controlbox{A\\\ding{"2D}}}%
\uc@dclc{917569}{default}{\uc@tag A}%
\uc@dclc{917570}{ctrlglyphs}{\uc@controlbox{B\\\ding{"2D}}}%
\uc@dclc{917570}{default}{\uc@tag B}%
\uc@dclc{917571}{ctrlglyphs}{\uc@controlbox{C\\\ding{"2D}}}%
\uc@dclc{917571}{default}{\uc@tag C}%
\uc@dclc{917572}{ctrlglyphs}{\uc@controlbox{D\\\ding{"2D}}}%
\uc@dclc{917572}{default}{\uc@tag D}%
\uc@dclc{917573}{ctrlglyphs}{\uc@controlbox{E\\\ding{"2D}}}%
\uc@dclc{917573}{default}{\uc@tag E}%
\uc@dclc{917574}{ctrlglyphs}{\uc@controlbox{F\\\ding{"2D}}}%
\uc@dclc{917574}{default}{\uc@tag F}%
\uc@dclc{917575}{ctrlglyphs}{\uc@controlbox{G\\\ding{"2D}}}%
\uc@dclc{917575}{default}{\uc@tag G}%
\uc@dclc{917576}{ctrlglyphs}{\uc@controlbox{H\\\ding{"2D}}}%
\uc@dclc{917576}{default}{\uc@tag H}%
\uc@dclc{917577}{ctrlglyphs}{\uc@controlbox{I\\\ding{"2D}}}%
\uc@dclc{917577}{default}{\uc@tag I}%
\uc@dclc{917578}{ctrlglyphs}{\uc@controlbox{J\\\ding{"2D}}}%
\uc@dclc{917578}{default}{\uc@tag J}%
\uc@dclc{917579}{ctrlglyphs}{\uc@controlbox{K\\\ding{"2D}}}%
\uc@dclc{917579}{default}{\uc@tag K}%
\uc@dclc{917580}{ctrlglyphs}{\uc@controlbox{L\\\ding{"2D}}}%
\uc@dclc{917580}{default}{\uc@tag L}%
\uc@dclc{917581}{ctrlglyphs}{\uc@controlbox{M\\\ding{"2D}}}%
\uc@dclc{917581}{default}{\uc@tag M}%
\uc@dclc{917582}{ctrlglyphs}{\uc@controlbox{N\\\ding{"2D}}}%
\uc@dclc{917582}{default}{\uc@tag N}%
\uc@dclc{917583}{ctrlglyphs}{\uc@controlbox{O\\\ding{"2D}}}%
\uc@dclc{917583}{default}{\uc@tag O}%
\uc@dclc{917584}{ctrlglyphs}{\uc@controlbox{P\\\ding{"2D}}}%
\uc@dclc{917584}{default}{\uc@tag P}%
\uc@dclc{917585}{ctrlglyphs}{\uc@controlbox{Q\\\ding{"2D}}}%
\uc@dclc{917585}{default}{\uc@tag Q}%
\uc@dclc{917586}{ctrlglyphs}{\uc@controlbox{R\\\ding{"2D}}}%
\uc@dclc{917586}{default}{\uc@tag R}%
\uc@dclc{917587}{ctrlglyphs}{\uc@controlbox{S\\\ding{"2D}}}%
\uc@dclc{917587}{default}{\uc@tag S}%
\uc@dclc{917588}{ctrlglyphs}{\uc@controlbox{T\\\ding{"2D}}}%
\uc@dclc{917588}{default}{\uc@tag T}%
\uc@dclc{917589}{ctrlglyphs}{\uc@controlbox{U\\\ding{"2D}}}%
\uc@dclc{917589}{default}{\uc@tag U}%
\uc@dclc{917590}{ctrlglyphs}{\uc@controlbox{V\\\ding{"2D}}}%
\uc@dclc{917590}{default}{\uc@tag V}%
\uc@dclc{917591}{ctrlglyphs}{\uc@controlbox{W\\\ding{"2D}}}%
\uc@dclc{917591}{default}{\uc@tag W}%
\uc@dclc{917592}{ctrlglyphs}{\uc@controlbox{X\\\ding{"2D}}}%
\uc@dclc{917592}{default}{\uc@tag X}%
\uc@dclc{917593}{ctrlglyphs}{\uc@controlbox{Y\\\ding{"2D}}}%
\uc@dclc{917593}{default}{\uc@tag Y}%
\uc@dclc{917594}{ctrlglyphs}{\uc@controlbox{Z\\\ding{"2D}}}%
\uc@dclc{917594}{default}{\uc@tag Z}%
\uc@dclc{917595}{ctrlglyphs}{\uc@controlbox{[\\\ding{"2D}}}%
\uc@dclc{917595}{default}{\uc@tag [}%
\uc@dclc{917596}{ctrlglyphs}{\uc@controlbox{\textbackslash\\\ding{"2D}}}%
\uc@dclc{917596}{default}{\uc@tag \@backslashchar}%
\uc@dclc{917597}{ctrlglyphs}{\uc@controlbox{]\\\ding{"2D}}}%
\uc@dclc{917597}{default}{\uc@tag ]}%
\uc@dclc{917598}{ctrlglyphs}{\uc@controlbox{\textasciicircum\\\ding{"2D}}}%
\uc@dclc{917598}{default}{\uc@tag ^}%
\uc@dclc{917599}{ctrlglyphs}{\uc@controlbox{\textunderscore\\\ding{"2D}}}%
\uc@dclc{917599}{default}{\uc@tag _}%
\uc@dclc{917600}{ctrlglyphs}{\uc@controlbox{`\\\ding{"2D}}}%
\uc@dclc{917600}{default}{\uc@tag `}%
\uc@dclc{917601}{ctrlglyphs}{\uc@controlbox{a\\\ding{"2D}}}%
\uc@dclc{917601}{default}{\uc@tag a}%
\uc@dclc{917602}{ctrlglyphs}{\uc@controlbox{b\\\ding{"2D}}}%
\uc@dclc{917602}{default}{\uc@tag b}%
\uc@dclc{917603}{ctrlglyphs}{\uc@controlbox{c\\\ding{"2D}}}%
\uc@dclc{917603}{default}{\uc@tag c}%
\uc@dclc{917604}{ctrlglyphs}{\uc@controlbox{d\\\ding{"2D}}}%
\uc@dclc{917604}{default}{\uc@tag d}%
\uc@dclc{917605}{ctrlglyphs}{\uc@controlbox{e\\\ding{"2D}}}%
\uc@dclc{917605}{default}{\uc@tag e}%
\uc@dclc{917606}{ctrlglyphs}{\uc@controlbox{f\\\ding{"2D}}}%
\uc@dclc{917606}{default}{\uc@tag f}%
\uc@dclc{917607}{ctrlglyphs}{\uc@controlbox{g\\\ding{"2D}}}%
\uc@dclc{917607}{default}{\uc@tag g}%
\uc@dclc{917608}{ctrlglyphs}{\uc@controlbox{h\\\ding{"2D}}}%
\uc@dclc{917608}{default}{\uc@tag h}%
\uc@dclc{917609}{ctrlglyphs}{\uc@controlbox{i\\\ding{"2D}}}%
\uc@dclc{917609}{default}{\uc@tag i}%
\uc@dclc{917610}{ctrlglyphs}{\uc@controlbox{j\\\ding{"2D}}}%
\uc@dclc{917610}{default}{\uc@tag j}%
\uc@dclc{917611}{ctrlglyphs}{\uc@controlbox{k\\\ding{"2D}}}%
\uc@dclc{917611}{default}{\uc@tag k}%
\uc@dclc{917612}{ctrlglyphs}{\uc@controlbox{l\\\ding{"2D}}}%
\uc@dclc{917612}{default}{\uc@tag l}%
\uc@dclc{917613}{ctrlglyphs}{\uc@controlbox{m\\\ding{"2D}}}%
\uc@dclc{917613}{default}{\uc@tag m}%
\uc@dclc{917614}{ctrlglyphs}{\uc@controlbox{n\\\ding{"2D}}}%
\uc@dclc{917614}{default}{\uc@tag n}%
\uc@dclc{917615}{ctrlglyphs}{\uc@controlbox{o\\\ding{"2D}}}%
\uc@dclc{917615}{default}{\uc@tag o}%
\uc@dclc{917616}{ctrlglyphs}{\uc@controlbox{p\\\ding{"2D}}}%
\uc@dclc{917616}{default}{\uc@tag p}%
\uc@dclc{917617}{ctrlglyphs}{\uc@controlbox{q\\\ding{"2D}}}%
\uc@dclc{917617}{default}{\uc@tag q}%
\uc@dclc{917618}{ctrlglyphs}{\uc@controlbox{r\\\ding{"2D}}}%
\uc@dclc{917618}{default}{\uc@tag r}%
\uc@dclc{917619}{ctrlglyphs}{\uc@controlbox{s\\\ding{"2D}}}%
\uc@dclc{917619}{default}{\uc@tag s}%
\uc@dclc{917620}{ctrlglyphs}{\uc@controlbox{t\\\ding{"2D}}}%
\uc@dclc{917620}{default}{\uc@tag t}%
\uc@dclc{917621}{ctrlglyphs}{\uc@controlbox{u\\\ding{"2D}}}%
\uc@dclc{917621}{default}{\uc@tag u}%
\uc@dclc{917622}{ctrlglyphs}{\uc@controlbox{v\\\ding{"2D}}}%
\uc@dclc{917622}{default}{\uc@tag v}%
\uc@dclc{917623}{ctrlglyphs}{\uc@controlbox{w\\\ding{"2D}}}%
\uc@dclc{917623}{default}{\uc@tag w}%
\uc@dclc{917624}{ctrlglyphs}{\uc@controlbox{x\\\ding{"2D}}}%
\uc@dclc{917624}{default}{\uc@tag x}%
\uc@dclc{917625}{ctrlglyphs}{\uc@controlbox{y\\\ding{"2D}}}%
\uc@dclc{917625}{default}{\uc@tag y}%
\uc@dclc{917626}{ctrlglyphs}{\uc@controlbox{z\\\ding{"2D}}}%
\uc@dclc{917626}{default}{\uc@tag z}%
\uc@dclc{917627}{ctrlglyphs}{\uc@controlbox{\{\\\ding{"2D}}}%
\uc@dclc{917627}{default}{\uc@tag \@leftbracechar}%
\uc@dclc{917628}{ctrlglyphs}{\uc@controlbox{|\\\ding{"2D}}}%
\uc@dclc{917628}{default}{\uc@tag |}%
\uc@dclc{917629}{ctrlglyphs}{\uc@controlbox{\}\\\ding{"2D}}}%
\uc@dclc{917629}{default}{\uc@tag \@rightbracechar}%
\uc@dclc{917630}{ctrlglyphs}{\uc@controlbox{\textasciitilde\\\ding{"2D}}}%
\uc@dclc{917630}{default}{\uc@tag \@tildechar}%
\uc@dclc{917631}{ctrlglyphs}{\uc@controlbox{\ding{"36}\\\ding{"2D}}}%
\uc@dclc{917631}{default}{\uc@tagtoks{CANCEL}\ifx\uc@tagtype\undefined\uc@langtag\else\uc@tagtype\fi\uc@tagtoks{}\let\uc@tagtype\undefined\let\uc@prechar\undefined}%
%%% Local Variables: 
%%% mode: latex
%%% coding: utf-8
%%% End: 
