%!TEX encoding = UTF-8 Unicode
%
% Translation completed on 13/03/2022
\ProvidesFile{ecvro.def}[europecv Romanian definitions]
% Personal information
\def\ecv@infosectionkey{\ecv@utf{Informa{\c t}ii personale}}
\def\ecv@datekey{\ecv@utf{Actualizat la}}
\def\ecv@namekey{\ecv@utf{Nume~/ Prenume}}
\def\ecv@addresskey{\ecv@utf{Adresa}}
\def\ecv@telkey{\ecv@utf{Telefon}}
\def\ecv@mobilekey{\ecv@utf{Mobil}}
\def\ecv@faxkey{\ecv@utf{Fax}}
\def\ecv@officekey{\ecv@utf{Birou}}
\def\ecv@emailkey{\ecv@utf{E-mail}}
\def\ecv@professionalkey{\ecv@utf{E-mail profesional}}
\def\ecv@skypekey{\ecv@utf{Skype}}
\def\ecv@matrixriotkey{\ecv@utf{Matrix/Riot}}
\def\ecv@youtubekey{\ecv@utf{YouTube}}
\def\ecv@peckey{\ecv@utf{PEC}}
\def\ecv@homepagekey{\ecv@utf{Home page}}
\def\ecv@nationalitykey{\ecv@utf{Cet{\u a}{\c t}enia}}
\def\ecv@birthkey{\ecv@utf{Data na{\c s}terii}}
\def\ecv@genderkey{\ecv@utf{Sex}}
% Footer
\def\ecv@pagekey{\ecv@utf{Pag}}
\def\ecv@cvofkey{\ecv@utf{Curriculum vit\ae}}
% Language table
\def\ecv@mothertonguekey{\ecv@utf{Limba(i) matern{\u a}(e)}}
\def\ecv@assesskey{\ecv@utf{Autoevaluare}}
\def\ecv@levelkey{\ecv@utf{Nivel european}}
\def\ecv@understandkey{\ecv@utf{Comprehensiune}}
\def\ecv@speakkey{\ecv@utf{Vorbit}}
\def\ecv@writekey{\ecv@utf{Scris}}
\def\ecv@listenkey{\ecv@utf{Abilitati de ascultare}}
\def\ecv@readkey{\ecv@utf{Abilitati de citire}}
\def\ecv@interactkey{\ecv@utf{Interactiune}}
\def\ecv@productkey{\ecv@utf{Exprimare}}
\def\ecv@langfooterkey{\ecv@utf{Cadrului european de referin{\c t}{\u a} pentru limbi}}
\def\ecv@cefbasickey{\ecv@utf{Utilizator de baz{\u a}}}
\def\ecv@cefindepkey{\ecv@utf{Utilizator independent}}
\def\ecv@cefprofkey{\ecv@utf{Utilizator experimentat}}

\renewcommand*\ecvtitle{\ecv@utf{\Large\textbf{C\ecv@kern u\ecv@kern r\ecv@kern r\ecv@kern i\ecv@kern c\ecv@kern u\ecv@kern l\ecv@kern u\ecv@kern m \ecv@kern v\ecv@kern i\ecv@kern t\ecv@kern a\ecv@kern e}\\[5pt]
\Large\textbf{E\ecv@kern u\ecv@kern r\ecv@kern o\ecv@kern p\ecv@kern a\ecv@kern s\ecv@kern s}}}
