%%
%% This is file `basic.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% circ.dtx  (with options: `basic')
%% CIRC is a LaTeX package to typeset circuit and optics diagrams.
%% Copyright (C) 1997,1998,2003  Sebastian Tannert and Andreas Tille
%% 
%%   This program is free software; you can redistribute it and/or modify
%%   it under the terms of the GNU General Public License as published by
%%   the Free Software Foundation; either version 2 of the License, or
%%   (at your option) any later version.
%% 
%%   This program is distributed in the hope that it will be useful,
%%   but WITHOUT ANY WARRANTY; without even the implied warranty of
%%   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%%   GNU General Public License for more details.
%% 
%%   You should have received a copy of the GNU General Public License
%%   along with this program; if not, write to the Free Software
%%   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
%% 
%% For error reports concerning UNCHANGED versions of this file no
%% more than one year old, see CIRC.DVI after installation.
%% If installation fails search thru this file for 'bug'.
\ProvidesFile{basic.def}
\freecirc
\def\GND#1 {\setbox\*bbox=\hbox{\c*fnt\char254}%
  \check*min{\wd\*bbox}\check*max{\wd\*bbox}\put*box
  \store*XY{GND#1}\store*XY{GND#1:}\reset*ifs}
\def\gnd#1 {\setbox\*bbox=\hbox{\c*fnt\char253}%
  \check*min{\wd\*bbox}\check*max{\wd\*bbox}\put*box
  \store*XY{gnd#1}\store*XY{gnd#1:}\reset*ifs}
\def\junction#1 {\setbox\*bbox=\hbox{\c*fnt\char255}\check*{\wd\*bbox}\check*X
                 \put*box\store*XY{.#1:}\store*XY{junction#1:}%
                 \store*XY{junction#1}\store*XY{.#1}\reset*ifs}
\cdef         R     R     \c*fntw    0
\cdef         Rus   R     \c*fntw   24
\cdefviii     Rvar  R     \c*fntw    8          . S *
\cdefviii     Rusvar R    \c*fntw   32          . S *
\cdef         C     C     \c*fntw  128
\cdef         Cvar  C     \c*fntw  130
\cdefiv       Cel   C     \c*fntw  136          - +
\cdefiv       D     D     \c*fntd    0          K A
\cdefiv       ZD    D     \c*fntd    4          K A
\cdefiviv     LED   D     \c*fntd    8          K A
\cdefiv       Dcap  D     \c*fntd   16          K A
\cdefiv       whatI I     \c*fnt   248          d s
\cdefiv       U     U     \c*fnt    16          + -
\cdef       varU  U   \c*fnt  44
\cdef       varI  I   \c*fnt 46
\cdefiv       Uvar  U     \c*fnt    20          + -
\cdef         I     I     \c*fnt    12
\cdef         Ivar  I     \c*fnt    14
\cdef         V     U     {\def\add*cmds{\clr*acmds
                           \ac*{\symfont V}}\c*fnt}8
\cdef         A     I     {\def\add*cmds{\clr*acmds
                           \ac*{\symfont A}}\c*fnt}8
\cdefiv       L     L     \c*fnt     0          . *
\cdef         xtal  Q     \c*fnt     4
\cdef         La    La    \c*fnt     6
\cdef         GasLa {}   \c*fnt     40
\cdef         S     S     \c*fnt    24
\cdefviii     SW    S     \c*fnt    32          o s c
\cdefivNL     mconnection \c*fnt   232          o c
\cdefivNL     connection  \c*fnt   240          o c
\cdefivNL     fconnection \c*fnt   244          o c
\cdefiviv npnPH T \c*fntt 80 E C
\cdefviii     npnEC T     \c*fntt    0          E . C
\cdefviii     pnpEC T     \c*fntt    8          E . C
\cdefviii     npn   T     \c*fntt   16          E B C
\cdefviii     pnp   T     \c*fntt   24          E B C
\cdefviii     nfet  T     \c*fntt   32          S G D
\cdefviii     pfet  T     \c*fntt   40          S G D
\cdefviii     nvmos T     \c*fntt   48          S G D
\cdefviii     pvmos T     \c*fntt   56          S G D
\cdefviii     namos T     \c*fntt   64          S G D
\cdefviii     pamos T     \c*fntt   72          S G D
\protectcirc
\endinput
%%
%% End of file `basic.def'.
