% This file is part of the "lettre" package.
% This package is distributed under the terms of the LaTeX Project 
% Public License (LPPL) described in the file lppl.txt.
%
% Denis Mégevand - Observatoire de Genève.
%
% Ce fichier fait partie de la distribution du paquetage "lettre".
% Ce paquetage est distribué sous les termes de la licence publique 
% du projet LaTeX (LPPL) décrite dans le fichier lppl.txt.
%
%    ********************************
%    *     DEFINITIONS LOCALES      *
%    ********************************
%
\address{Nom\\Adresse}
\telephone{Numero de telephone}	%|\notelephone
\fax{Numero de telefax}		%|\nofax
\lieu{Lieu}			%|\nolieu
