%%
%% This is file `tagpdf-ns-mathml.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% tagpdf-data.dtx  (with options: `ns-mathml')
%% 
%% Copyright (C) 2019-2024 Ulrike Fischer
%% 
%% It may be distributed and/or modified under the conditions of
%% the LaTeX Project Public License (LPPL), either version 1.3c of
%% this license or (at your option) any later version.  The latest
%% version of this license is in the file:
%% 
%%    https://www.latex-project.org/lppl.txt
%% 
%% This file is part of the "tagpdf bundle" (The Work in LPPL)
%% and all files in that bundle must be distributed together.
%% 
%% File: tagpdf-data.dtx
%% \ProvidesExplFile {tagpdf-ns-mathml.def} {2025-03-05} {0.99o}
abs,abs,mathml,
and,and,mathml,
annotation,annotation,mathml,
apply,apply,mathml,
approx,approx,mathml,
arccos,arccos,mathml,
arccosh,arccosh,mathml,
arccot,arccot,mathml,
arccoth,arccoth,mathml,
arccsc,arccsc,mathml,
arccsch,arccsch,mathml,
arcsec,arcsec,mathml,
arcsech,arcsech,mathml,
arcsin,arcsin,mathml,
arcsinh,arcsinh,mathml,
arctan,arctan,mathml,
arctanh,arctanh,mathml,
arg,arg,mathml,
bind,bind,mathml,
bvar,bvar,mathml,
card,card,mathml,
cartesianproduct,cartesianproduct,mathml,
cbytes,cbytes,mathml,
ceiling,ceiling,mathml,
cerror,cerror,mathml,
ci,ci,mathml,
cn,cn,mathml,
codomain,codomain,mathml,
complexes,complexes,mathml,
compose,compose,mathml,
condition,condition,mathml,
conjugate,conjugate,mathml,
cos,cos,mathml,
cosh,cosh,mathml,
cot,cot,mathml,
coth,coth,mathml,
cs,cs,mathml,
csc,csc,mathml,
csch,csch,mathml,
csymbol,csymbol,mathml,
curl,curl,mathml,
declare,declare,mathml,
degree,degree,mathml,
determinant,determinant,mathml,
diff,diff,mathml,
divergence,divergence,mathml,
divide,divide,mathml,
domain,domain,mathml,
domainofapplication,domainofapplication,mathml,
emptyset,emptyset,mathml,
eq,eq,mathml,
equivalent,equivalent,mathml,
eulergamma,eulergamma,mathml,
exists,exists,mathml,
exp,exp,mathml,
exponentiale,exponentiale,mathml,
factorial,factorial,mathml,
factorof,factorof,mathml,
false,false,mathml,
floor,floor,mathml,
fn,fn,mathml,
forall,forall,mathml,
gcd,gcd,mathml,
geq,geq,mathml,
grad,grad,mathml,
gt,gt,mathml,
ident,ident,mathml,
image,image,mathml,
imaginary,imaginary,mathml,
imaginaryi,imaginaryi,mathml,
implies,implies,mathml,
in,in,mathml,
infinity,infinity,mathml,
int,int,mathml,
integers,integers,mathml,
intersect,intersect,mathml,
interval,interval,mathml,
inverse,inverse,mathml,
lambda,lambda,mathml,
laplacian,laplacian,mathml,
lcm,lcm,mathml,
leq,leq,mathml,
limit,limit,mathml,
ln,ln,mathml,
log,log,mathml,
logbase,logbase,mathml,
lowlimit,lowlimit,mathml,
lt,lt,mathml,
maction,maction,mathml,
maligngroup,maligngroup,mathml,
malignmark,malignmark,mathml,
math,math,mathml,
matrix,matrix,mathml,
matrixrow,matrixrow,mathml,
max,max,mathml,
mean,mean,mathml,
median,median,mathml,
menclose,menclose,mathml,
merror,merror,mathml,
mfenced,mfenced,mathml,
mfrac,mfrac,mathml,
mglyph,mglyph,mathml,
mi,mi,mathml,
min,min,mathml,
minus,minus,mathml,
mlabeledtr,mlabeledtr,mathml,
mlongdiv,mlongdiv,mathml,
mmultiscripts,mmultiscripts,mathml,
mn,mn,mathml,
mo,mo,mathml,
mode,mode,mathml,
moment,moment,mathml,
momentabout,momentabout,mathml,
mover,mover,mathml,
mpadded,mpadded,mathml,
mphantom,mphantom,mathml,
mprescripts,mprescripts,mathml,
mroot,mroot,mathml,
mrow,mrow,mathml,
ms,ms,mathml,
mscarries,mscarries,mathml,
mscarry,mscarry,mathml,
msgroup,msgroup,mathml,
msline,msline,mathml,
mspace,mspace,mathml,
msqrt,msqrt,mathml,
msrow,msrow,mathml,
mstack,mstack,mathml,
mstyle,mstyle,mathml,
msub,msub,mathml,
msubsup,msubsup,mathml,
msup,msup,mathml,
mtable,mtable,mathml,
mtd,mtd,mathml,
mtext,mtext,mathml,
mtr,mtr,mathml,
munder,munder,mathml,
munderover,munderover,mathml,
naturalnumbers,naturalnumbers,mathml,
neq,neq,mathml,
none,none,mathml,
not,not,mathml,
notanumber,notanumber,mathml,
notin,notin,mathml,
notprsubset,notprsubset,mathml,
notsubset,notsubset,mathml,
or,or,mathml,
otherwise,otherwise,mathml,
outerproduct,outerproduct,mathml,
partialdiff,partialdiff,mathml,
pi,pi,mathml,
piece,piece,mathml,
piecewise,piecewise,mathml,
plus,plus,mathml,
power,power,mathml,
primes,primes,mathml,
product,product,mathml,
prsubset,prsubset,mathml,
quotient,quotient,mathml,
rationals,rationals,mathml,
real,real,mathml,
reals,reals,mathml,
reln,reln,mathml,
rem,rem,mathml,
root,root,mathml,
scalarproduct,scalarproduct,mathml,
sdev,sdev,mathml,
sec,sec,mathml,
sech,sech,mathml,
selector,selector,mathml,
semantics,semantics,mathml,
sep,sep,mathml,
set,set,mathml,
setdiff,setdiff,mathml,
share,share,mathml,
sin,sin,mathml,
sinh,sinh,mathml,
subset,subset,mathml,
sum,sum,mathml,
tan,tan,mathml,
tanh,tanh,mathml,
tendsto,tendsto,mathml,
times,times,mathml,
transpose,transpose,mathml,
true,true,mathml,
union,union,mathml,
uplimit,uplimit,mathml,
variance,variance,mathml,
vector,vector,mathml,
vectorproduct,vectorproduct,mathml,
xor,xor,mathml,
%% 
%%
%% End of file `tagpdf-ns-mathml.def'.
