%%% Unicode to TeX mapping, file uni-760.def, U+2F800..U+2F8FF, autogenerated by makeunidef.pl
\ifx\ProvidesFile\undefined\else
\ProvidesFile{uni-760.def}[2022/08/07 UCS: Unicode data U+2F800..U+2F8FF]%
\fi
\uc@dclc{194560}{autogenerated}{\unichar{20029}}%
\uc@dclc{194561}{autogenerated}{\unichar{20024}}%
\uc@dclc{194564}{autogenerated}{\unichar{20320}}%
\uc@dclc{194565}{autogenerated}{\unichar{20398}}%
\uc@dclc{194566}{autogenerated}{\unichar{20411}}%
\uc@dclc{194568}{autogenerated}{\unichar{20602}}%
\uc@dclc{194569}{autogenerated}{\unichar{20633}}%
\uc@dclc{194570}{autogenerated}{\unichar{20711}}%
\uc@dclc{194571}{autogenerated}{\unichar{20687}}%
\uc@dclc{194574}{autogenerated}{\unichar{20813}}%
\uc@dclc{194575}{autogenerated}{\unichar{20820}}%
\uc@dclc{194577}{autogenerated}{\unichar{20855}}%
\uc@dclc{194580}{autogenerated}{\unichar{20839}}%
\uc@dclc{194581}{autogenerated}{\unichar{20877}}%
\uc@dclc{194583}{autogenerated}{\unichar{20887}}%
\uc@dclc{194584}{autogenerated}{\unichar{20900}}%
\uc@dclc{194586}{autogenerated}{\unichar{20908}}%
\uc@dclc{194587}{autogenerated}{\unichar{20917}}%
\uc@dclc{194589}{autogenerated}{\unichar{20981}}%
\uc@dclc{194590}{autogenerated}{\unichar{20995}}%
\uc@dclc{194592}{autogenerated}{\unichar{21051}}%
\uc@dclc{194593}{autogenerated}{\unichar{21062}}%
\uc@dclc{194594}{autogenerated}{\unichar{21106}}%
\uc@dclc{194595}{autogenerated}{\unichar{21111}}%
\uc@dclc{194597}{autogenerated}{\unichar{21191}}%
\uc@dclc{194598}{autogenerated}{\unichar{21193}}%
\uc@dclc{194599}{autogenerated}{\unichar{21220}}%
\uc@dclc{194600}{autogenerated}{\unichar{21242}}%
\uc@dclc{194601}{autogenerated}{\unichar{21253}}%
\uc@dclc{194602}{autogenerated}{\unichar{21254}}%
\uc@dclc{194603}{autogenerated}{\unichar{21271}}%
\uc@dclc{194604}{autogenerated}{\unichar{21321}}%
\uc@dclc{194605}{autogenerated}{\unichar{21329}}%
\uc@dclc{194606}{autogenerated}{\unichar{21338}}%
\uc@dclc{194607}{autogenerated}{\unichar{21363}}%
\uc@dclc{194609}{autogenerated}{\unichar{21375}}%
\uc@dclc{194610}{autogenerated}{\unichar{21375}}%
\uc@dclc{194611}{autogenerated}{\unichar{21375}}%
\uc@dclc{194613}{autogenerated}{\unichar{28784}}%
\uc@dclc{194614}{autogenerated}{\unichar{21450}}%
\uc@dclc{194615}{autogenerated}{\unichar{21471}}%
\uc@dclc{194617}{autogenerated}{\unichar{21483}}%
\uc@dclc{194618}{autogenerated}{\unichar{21489}}%
\uc@dclc{194619}{autogenerated}{\unichar{21510}}%
\uc@dclc{194621}{autogenerated}{\unichar{21560}}%
\uc@dclc{194622}{autogenerated}{\unichar{21576}}%
\uc@dclc{194623}{autogenerated}{\unichar{21608}}%
\uc@dclc{194624}{autogenerated}{\unichar{21666}}%
\uc@dclc{194626}{autogenerated}{\unichar{21776}}%
\uc@dclc{194627}{autogenerated}{\unichar{21843}}%
\uc@dclc{194628}{autogenerated}{\unichar{21859}}%
\uc@dclc{194629}{autogenerated}{\unichar{21892}}%
\uc@dclc{194630}{autogenerated}{\unichar{21892}}%
\uc@dclc{194631}{autogenerated}{\unichar{21913}}%
\uc@dclc{194632}{autogenerated}{\unichar{21931}}%
\uc@dclc{194633}{autogenerated}{\unichar{21939}}%
\uc@dclc{194634}{autogenerated}{\unichar{21954}}%
\uc@dclc{194635}{autogenerated}{\unichar{22294}}%
\uc@dclc{194636}{autogenerated}{\unichar{22022}}%
\uc@dclc{194639}{autogenerated}{\unichar{22132}}%
\uc@dclc{194640}{autogenerated}{\unichar{20999}}%
\uc@dclc{194641}{autogenerated}{\unichar{22766}}%
\uc@dclc{194642}{autogenerated}{\unichar{22478}}%
\uc@dclc{194643}{autogenerated}{\unichar{22516}}%
\uc@dclc{194644}{autogenerated}{\unichar{22541}}%
\uc@dclc{194645}{autogenerated}{\unichar{22411}}%
\uc@dclc{194646}{autogenerated}{\unichar{22578}}%
\uc@dclc{194647}{autogenerated}{\unichar{22577}}%
\uc@dclc{194648}{autogenerated}{\unichar{22700}}%
\uc@dclc{194650}{autogenerated}{\unichar{22770}}%
\uc@dclc{194651}{autogenerated}{\unichar{22775}}%
\uc@dclc{194652}{autogenerated}{\unichar{22790}}%
\uc@dclc{194653}{autogenerated}{\unichar{22810}}%
\uc@dclc{194654}{autogenerated}{\unichar{22818}}%
\uc@dclc{194655}{autogenerated}{\unichar{22882}}%
\uc@dclc{194658}{autogenerated}{\unichar{23020}}%
\uc@dclc{194659}{autogenerated}{\unichar{23067}}%
\uc@dclc{194661}{autogenerated}{\unichar{23000}}%
\uc@dclc{194662}{autogenerated}{\unichar{23142}}%
\uc@dclc{194665}{autogenerated}{\unichar{23304}}%
\uc@dclc{194666}{autogenerated}{\unichar{23358}}%
\uc@dclc{194667}{autogenerated}{\unichar{23358}}%
\uc@dclc{194669}{autogenerated}{\unichar{23491}}%
\uc@dclc{194670}{autogenerated}{\unichar{23512}}%
\uc@dclc{194671}{autogenerated}{\unichar{23527}}%
\uc@dclc{194672}{autogenerated}{\unichar{23539}}%
\uc@dclc{194674}{autogenerated}{\unichar{23551}}%
\uc@dclc{194675}{autogenerated}{\unichar{23558}}%
\uc@dclc{194676}{autogenerated}{\unichar{24403}}%
\uc@dclc{194677}{autogenerated}{\unichar{23586}}%
\uc@dclc{194679}{autogenerated}{\unichar{23648}}%
\uc@dclc{194680}{autogenerated}{\unichar{23662}}%
\uc@dclc{194682}{autogenerated}{\unichar{23693}}%
\uc@dclc{194684}{autogenerated}{\unichar{23875}}%
\uc@dclc{194687}{autogenerated}{\unichar{23915}}%
\uc@dclc{194688}{autogenerated}{\unichar{23932}}%
\uc@dclc{194689}{autogenerated}{\unichar{24033}}%
\uc@dclc{194690}{autogenerated}{\unichar{24034}}%
\uc@dclc{194692}{autogenerated}{\unichar{24061}}%
\uc@dclc{194693}{autogenerated}{\unichar{24104}}%
\uc@dclc{194694}{autogenerated}{\unichar{24125}}%
\uc@dclc{194695}{autogenerated}{\unichar{24169}}%
\uc@dclc{194699}{autogenerated}{\unichar{24240}}%
\uc@dclc{194700}{autogenerated}{\unichar{24243}}%
\uc@dclc{194701}{autogenerated}{\unichar{24246}}%
\uc@dclc{194702}{autogenerated}{\unichar{24266}}%
\uc@dclc{194704}{autogenerated}{\unichar{24318}}%
\uc@dclc{194707}{autogenerated}{\unichar{33281}}%
\uc@dclc{194708}{autogenerated}{\unichar{24354}}%
\uc@dclc{194709}{autogenerated}{\unichar{24354}}%
\uc@dclc{194713}{autogenerated}{\unichar{24418}}%
\uc@dclc{194714}{autogenerated}{\unichar{24427}}%
\uc@dclc{194717}{autogenerated}{\unichar{24525}}%
\uc@dclc{194718}{autogenerated}{\unichar{24535}}%
\uc@dclc{194720}{autogenerated}{\unichar{24705}}%
\uc@dclc{194723}{autogenerated}{\unichar{24724}}%
\uc@dclc{194725}{autogenerated}{\unichar{24775}}%
\uc@dclc{194726}{autogenerated}{\unichar{24904}}%
\uc@dclc{194727}{autogenerated}{\unichar{24908}}%
\uc@dclc{194728}{autogenerated}{\unichar{24910}}%
\uc@dclc{194729}{autogenerated}{\unichar{24908}}%
\uc@dclc{194730}{autogenerated}{\unichar{24954}}%
\uc@dclc{194731}{autogenerated}{\unichar{24974}}%
\uc@dclc{194732}{autogenerated}{\unichar{25010}}%
\uc@dclc{194733}{autogenerated}{\unichar{24996}}%
\uc@dclc{194734}{autogenerated}{\unichar{25007}}%
\uc@dclc{194735}{autogenerated}{\unichar{25054}}%
\uc@dclc{194736}{autogenerated}{\unichar{25074}}%
\uc@dclc{194737}{autogenerated}{\unichar{25078}}%
\uc@dclc{194738}{autogenerated}{\unichar{25104}}%
\uc@dclc{194739}{autogenerated}{\unichar{25115}}%
\uc@dclc{194741}{autogenerated}{\unichar{25265}}%
\uc@dclc{194742}{autogenerated}{\unichar{25300}}%
\uc@dclc{194743}{autogenerated}{\unichar{25424}}%
\uc@dclc{194745}{autogenerated}{\unichar{25405}}%
\uc@dclc{194746}{autogenerated}{\unichar{25340}}%
\uc@dclc{194747}{autogenerated}{\unichar{25448}}%
\uc@dclc{194748}{autogenerated}{\unichar{25475}}%
\uc@dclc{194749}{autogenerated}{\unichar{25572}}%
\uc@dclc{194751}{autogenerated}{\unichar{25634}}%
\uc@dclc{194752}{autogenerated}{\unichar{25541}}%
\uc@dclc{194753}{autogenerated}{\unichar{25513}}%
\uc@dclc{194755}{autogenerated}{\unichar{25705}}%
\uc@dclc{194757}{autogenerated}{\unichar{25757}}%
\uc@dclc{194758}{autogenerated}{\unichar{25719}}%
\uc@dclc{194760}{autogenerated}{\unichar{25935}}%
\uc@dclc{194761}{autogenerated}{\unichar{25964}}%
\uc@dclc{194764}{autogenerated}{\unichar{26360}}%
\uc@dclc{194765}{autogenerated}{\unichar{26185}}%
\uc@dclc{194767}{autogenerated}{\unichar{26257}}%
\uc@dclc{194770}{autogenerated}{\unichar{20882}}%
\uc@dclc{194771}{autogenerated}{\unichar{20885}}%
\uc@dclc{194772}{autogenerated}{\unichar{26368}}%
\uc@dclc{194774}{autogenerated}{\unichar{32941}}%
\uc@dclc{194776}{autogenerated}{\unichar{26391}}%
\uc@dclc{194777}{autogenerated}{\unichar{26395}}%
\uc@dclc{194778}{autogenerated}{\unichar{26401}}%
\uc@dclc{194779}{autogenerated}{\unichar{26462}}%
\uc@dclc{194780}{autogenerated}{\unichar{26451}}%
\uc@dclc{194783}{autogenerated}{\unichar{26618}}%
\uc@dclc{194784}{autogenerated}{\unichar{26501}}%
\uc@dclc{194786}{autogenerated}{\unichar{26757}}%
\uc@dclc{194789}{autogenerated}{\unichar{26655}}%
\uc@dclc{194790}{autogenerated}{\unichar{26900}}%
\uc@dclc{194792}{autogenerated}{\unichar{26946}}%
\uc@dclc{194793}{autogenerated}{\unichar{27043}}%
\uc@dclc{194795}{autogenerated}{\unichar{27304}}%
\uc@dclc{194797}{autogenerated}{\unichar{27355}}%
\uc@dclc{194799}{autogenerated}{\unichar{27425}}%
\uc@dclc{194801}{autogenerated}{\unichar{27476}}%
\uc@dclc{194803}{autogenerated}{\unichar{27506}}%
\uc@dclc{194804}{autogenerated}{\unichar{27551}}%
\uc@dclc{194805}{autogenerated}{\unichar{27578}}%
\uc@dclc{194806}{autogenerated}{\unichar{27579}}%
\uc@dclc{194810}{autogenerated}{\unichar{27726}}%
\uc@dclc{194812}{autogenerated}{\unichar{27839}}%
\uc@dclc{194813}{autogenerated}{\unichar{27853}}%
\uc@dclc{194814}{autogenerated}{\unichar{27751}}%
\uc@dclc{194815}{autogenerated}{\unichar{27926}}%
%%% Local Variables: 
%%% mode: latex
%%% coding: utf-8
%%% End: 
