%%% Unicode to TeX mapping, file uni-24.def, U+1800..U+18FF, autogenerated by makeunidef.pl
\ifx\ProvidesFile\undefined\else
\ProvidesFile{uni-24.def}[2022/08/07 UCS: Unicode data U+1800..U+18FF]%
\fi
\uc@dclc{6145}{default}{\textmongolianellipsis}%
\uc@dclc{6146}{default}{\textmongoliancomma}%
\uc@dclc{6147}{default}{\textmongolianfullstop}%
\uc@dclc{6148}{default}{\textmongoliancolon}%
\uc@dclc{6149}{default}{\textmongolianfourdots}%
\uc@dclc{6152}{default}{\textmongolianmanchucomma}%
\uc@dclc{6153}{default}{\textmongolianmanchufullstop}%
\uc@dclc{6154}{default}{\textmongoliannirugu}%
\uc@dclc{6155}{default}{\textmongolianfreevariationselectorone}%
\uc@dclc{6156}{default}{\textmongolianfreevariationselectortwo}%
\uc@dclc{6158}{default}{\textmongolianvowelseparator}%
\uc@dclc{6160}{default}{\textmongolianzero}%
\uc@dclc{6161}{default}{\textmongolianone}%
\uc@dclc{6162}{default}{\textmongoliantwo}%
\uc@dclc{6163}{default}{\textmongolianthree}%
\uc@dclc{6164}{default}{\textmongolianfour}%
\uc@dclc{6165}{default}{\textmongolianfive}%
\uc@dclc{6166}{default}{\textmongoliansix}%
\uc@dclc{6167}{default}{\textmongolianseven}%
\uc@dclc{6168}{default}{\textmongolianeight}%
\uc@dclc{6169}{default}{\textmongoliannine}%
\uc@dclc{6176}{default}{\textmongoliana}%
\uc@dclc{6177}{default}{\textmongoliane}%
\uc@dclc{6178}{default}{\textmongoliani}%
\uc@dclc{6179}{default}{\textmongoliano}%
\uc@dclc{6180}{default}{\textmongolianu}%
\uc@dclc{6184}{default}{\textmongolianna}%
\uc@dclc{6185}{default}{\textmongolianang}%
\uc@dclc{6186}{default}{\textmongolianba}%
\uc@dclc{6187}{default}{\textmongolianpa}%
\uc@dclc{6188}{default}{\textmongolianqa}%
\uc@dclc{6189}{default}{\textmongolianga}%
\uc@dclc{6190}{default}{\textmongolianma}%
\uc@dclc{6191}{default}{\textmongolianla}%
\uc@dclc{6192}{default}{\textmongoliansa}%
\uc@dclc{6193}{default}{\textmongoliansha}%
\uc@dclc{6194}{default}{\textmongolianta}%
\uc@dclc{6195}{default}{\textmongolianda}%
\uc@dclc{6196}{default}{\textmongoliancha}%
\uc@dclc{6197}{default}{\textmongolianja}%
\uc@dclc{6198}{default}{\textmongolianya}%
\uc@dclc{6199}{default}{\textmongolianra}%
\uc@dclc{6200}{default}{\textmongolianwa}%
\uc@dclc{6201}{default}{\textmongolianfa}%
\uc@dclc{6202}{default}{\textmongolianka}%
\uc@dclc{6203}{default}{\textmongoliankha}%
\uc@dclc{6204}{default}{\textmongoliantsa}%
\uc@dclc{6205}{default}{\textmongolianza}%
\uc@dclc{6206}{default}{\textmongolianhaa}%
\uc@dclc{6207}{default}{\textmongolianzra}%
\uc@dclc{6208}{default}{\textmongolianlha}%
\uc@dclc{6209}{default}{\textmongolianzhi}%
\uc@dclc{6210}{default}{\textmongolianchi}%
\uc@dclc{6237}{default}{\textmongoliansibee}%
\uc@dclc{6240}{default}{\textmongoliansibeue}%
\uc@dclc{6241}{default}{\textmongoliansibeu}%
\uc@dclc{6242}{default}{\textmongoliansibeang}%
\uc@dclc{6244}{default}{\textmongoliansibega}%
\uc@dclc{6245}{default}{\textmongoliansibeha}%
\uc@dclc{6246}{default}{\textmongoliansibepa}%
\uc@dclc{6247}{default}{\textmongoliansibesha}%
\uc@dclc{6248}{default}{\textmongoliansibeta}%
\uc@dclc{6249}{default}{\textmongoliansibeda}%
\uc@dclc{6252}{default}{\textmongoliansibegaa}%
\uc@dclc{6253}{default}{\textmongoliansibehaa}%
\uc@dclc{6254}{default}{\textmongoliansibetsa}%
\uc@dclc{6255}{default}{\textmongoliansibeza}%
\uc@dclc{6256}{default}{\textmongoliansiberaa}%
\uc@dclc{6257}{default}{\textmongoliansibecha}%
\uc@dclc{6260}{default}{\textmongolianmanchuka}%
\uc@dclc{6261}{default}{\textmongolianmanchura}%
\uc@dclc{6262}{default}{\textmongolianmanchufa}%
\uc@dclc{6263}{default}{\textmongolianmanchuzha}%
\uc@dclc{6272}{default}{\textmongolianaligalianusvaraone}%
\uc@dclc{6299}{default}{\textmongolianmanchualigalinga}%
\uc@dclc{6300}{default}{\textmongolianmanchualigalica}%
\uc@dclc{6308}{default}{\textmongolianmanchualigalizha}%
\uc@dclc{6309}{default}{\textmongolianmanchualigaliza}%
%%% Local Variables: 
%%% mode: latex
%%% coding: utf-8
%%% End: 
