%%% Unicode to TeX mapping, file uni-507.def, U+1FB00..U+1FBFF, autogenerated by makeunidef.pl
\ifx\ProvidesFile\undefined\else
\ProvidesFile{uni-507.def}[2022/08/07 UCS: Unicode data U+1FB00..U+1FBFF]%
\fi
\uc@dclc{130032}{autogenerated}{\unichar{48}}%
\uc@dclc{130033}{autogenerated}{\unichar{49}}%
\uc@dclc{130034}{autogenerated}{\unichar{50}}%
\uc@dclc{130035}{autogenerated}{\unichar{51}}%
\uc@dclc{130036}{autogenerated}{\unichar{52}}%
\uc@dclc{130037}{autogenerated}{\unichar{53}}%
\uc@dclc{130038}{autogenerated}{\unichar{54}}%
\uc@dclc{130039}{autogenerated}{\unichar{55}}%
\uc@dclc{130040}{autogenerated}{\unichar{56}}%
\uc@dclc{130041}{autogenerated}{\unichar{57}}%
%%% Local Variables: 
%%% mode: latex
%%% coding: utf-8
%%% End: 
