%%
%% This is file `ix-alias.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% inputenx.dtx  (with options: `alias')
%% 
%% This is a generated file.
%% 
%% Project: inputenx
%% Version: 2019/11/29 v1.12
%% 
%% Copyright (C)
%%   2006-2011 Heiko Oberdiek
%%   2016-2019 Oberdiek Package Support Group
%% 
%% This work may be distributed and/or modified under the
%% conditions of the LaTeX Project Public License, either
%% version 1.3c of this license or (at your option) any later
%% version. This version of this license is in
%%    https://www.latex-project.org/lppl/lppl-1-3c.txt
%% and the latest version of this license is in
%%    https://www.latex-project.org/lppl.txt
%% and version 1.3 or later is part of all distributions of
%% LaTeX version 2005/12/01 or later.
%% 
%% This work has the LPPL maintenance status "maintained".
%% 
%% The Current Maintainers of this work are
%% Heiko Oberdiek and the Oberdiek Package Support Group
%% https://github.com/ho-tex/inputenx/issues
%% 
%% 
%% This work consists of the main source file inputenx.dtx
%% and the derived files
%%    inputenx.sty, inputenx.pdf, inputenx.ins, inputenx.drv, ix-alias.def,
%%    ix-math.def, ix-name.def, ix-slot.def, ix-uc.def,
%%    ix-utf8enc.dfu, x-ascii.def, x-verbatim.def, x-atarist.def,
%%    x-iso-8859-1.def, x-iso-8859-2.def, x-iso-8859-3.def,
%%    x-iso-8859-4.def, x-iso-8859-5.def, x-iso-8859-8.def,
%%    x-iso-8859-9.def, x-iso-8859-10.def, x-iso-8859-13.def,
%%    x-iso-8859-14.def, x-iso-8859-15.def, x-iso-8859-16.def,
%%    x-cp437.def, x-cp850.def, x-cp852.def, x-cp855.def,
%%    x-cp858.def, x-cp865.def, x-cp866.def, x-cp1250.def,
%%    x-cp1251.def, x-cp1252.def, x-cp1255.def, x-cp1257.def,
%%    x-dec-mcs.def, x-koi8-r.def, x-mac-centeuro.def,
%%    x-mac-cyrillic.def, x-mac-roman.def, x-nextstep.def,
%%    inputenx-licrcmds.txt, inputenx-utf8enc.txt.
%% 
\ProvidesFile{ix-alias.def}[2019/11/29 v1.12 Alias list (inputenx)]
\InputenxAlias{ascii}{x-ascii}
\InputenxAlias{atarist}{x-atarist}
\InputenxAlias{iso-8859-1}{x-iso-8859-1}
\InputenxAlias{iso-8859-2}{x-iso-8859-2}
\InputenxAlias{iso-8859-3}{x-iso-8859-3}
\InputenxAlias{iso-8859-4}{x-iso-8859-4}
\InputenxAlias{iso-8859-5}{x-iso-8859-5}
\InputenxAlias{iso-8859-8}{x-iso-8859-8}
\InputenxAlias{iso-8859-9}{x-iso-8859-9}
\InputenxAlias{iso-8859-10}{x-iso-8859-10}
\InputenxAlias{iso-8859-13}{x-iso-8859-13}
\InputenxAlias{iso-8859-14}{x-iso-8859-14}
\InputenxAlias{iso-8859-15}{x-iso-8859-15}
\InputenxAlias{iso-8859-16}{x-iso-8859-16}
\InputenxAlias{cp437}{x-cp437}
\InputenxAlias{cp850}{x-cp850}
\InputenxAlias{cp852}{x-cp852}
\InputenxAlias{cp855}{x-cp855}
\InputenxAlias{cp858}{x-cp858}
\InputenxAlias{cp865}{x-cp865}
\InputenxAlias{cp866}{x-cp866}
\InputenxAlias{cp1250}{x-cp1250}
\InputenxAlias{cp1251}{x-cp1251}
\InputenxAlias{cp1252}{x-cp1252}
\InputenxAlias{cp1255}{x-cp1255}
\InputenxAlias{cp1257}{x-cp1257}
\InputenxAlias{dec-mcs}{x-dec-mcs}
\InputenxAlias{koi8-r}{x-koi8-r}
\InputenxAlias{mac-centeuro}{x-mac-centeuro}
\InputenxAlias{mac-cyrillic}{x-mac-cyrillic}
\InputenxAlias{mac-roman}{x-mac-roman}
\InputenxAlias{nextstep}{x-nextstep}
\InputenxAlias{ansinew}{x-cp1252}
\InputenxAlias{applemac}{x-mac-roman}
\InputenxAlias{ascii-print}{x-ascii}
\InputenxAlias{ascii-printable}{x-ascii}
\InputenxAlias{atari}{x-atarist}
\InputenxAlias{clean7bit}{x-ascii}
\InputenxAlias{cp437de}{x-cp437}
\InputenxAlias{decmulti}{x-dec-mcs}
\InputenxAlias{iso88595}{x-iso-8859-5}
\InputenxAlias{latin1}{x-iso-8859-1}
\InputenxAlias{latin10}{x-iso-8859-16}
\InputenxAlias{latin2}{x-iso-8859-2}
\InputenxAlias{latin3}{x-iso-8859-3}
\InputenxAlias{latin4}{x-iso-8859-4}
\InputenxAlias{latin5}{x-iso-8859-9}
\InputenxAlias{latin6}{x-iso-8859-10}
\InputenxAlias{latin7}{x-iso-8859-13}
\InputenxAlias{latin8}{x-iso-8859-14}
\InputenxAlias{latin9}{x-iso-8859-15}
\InputenxAlias{mac-ce}{x-mac-centeuro}
\InputenxAlias{mac-ukrainian}{x-mac-cyrillic}
\InputenxAlias{macce}{x-mac-centeuro}
\InputenxAlias{maccyr}{x-mac-cyrillic}
\InputenxAlias{macukr}{x-mac-cyrillic}
\InputenxAlias{next}{x-nextstep}
\InputenxAlias{us-ascii}{x-ascii}
\InputenxAlias{verbatim}{x-verbatim}
\endinput
%%
%% End of file `ix-alias.def'.
