%%
%% This is file `tcidvi.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% drivers.dtx  (with options: `tcidvi,color4,nops')
%% 
%% drivers.dtx Copyright (C) 1994      David Carlisle Sebastian Rahtz
%%             Copyright (C) 1995 1996 1997 1998 1999 David Carlisle
%%             Copyright (C) 2000-2025 LaTeX Project
%% The LaTeX Project and any individual authors listed elsewhere
%% in this file.
%%
%% This file is part of the Standard LaTeX `Graphics Bundle'.
%% It may be distributed under the terms of the LaTeX Project Public
%% License, as described in lppl.txt in the base LaTeX distribution.
%% Either version 1.3 or, at your option, any later version.
%%
\ProvidesFile{tcidvi.def}
        [2016/06/17 v3.0m Driver-dependent file (DPC,SPQR)]
\def\c@lor@arg#1{%
  \dimen@#1\p@
  \ifdim\dimen@<\z@\dimen@\maxdimen\fi
  \ifdim\dimen@>\p@
    \PackageError{color}{Argument `#1' not in range [0,1]}\@ehd
  \fi}
\def\color@gray#1#2{%
  \c@lor@arg{#2}%
  \c@lor@rgb@RGB\@tempa
  \edef#1{\@tempa\@tempa\@tempa}%
  }
\def\color@cmyk#1#2{\c@lor@@cmyk#2\@@#1}
\def\c@lor@@cmyk#1,#2,#3,#4\@@#5{%
  \c@lor@arg{#4}%
    \dimen@ii#4\p@
  \c@lor@arg{#1}%
  \c@lor@cmyk@RGB\@tempa
  \c@lor@arg{#2}%
  \c@lor@cmyk@RGB\@tempb
  \c@lor@arg{#3}%
  \c@lor@cmyk@RGB\@tempc
  \edef#5{\@tempa\@tempb\@tempc}%
  }
\def\c@lor@cmyk@RGB#1{%
  \advance\dimen@-\p@
  \advance\dimen@\dimen@ii
  \dimen@-\@cclv\dimen@
  \divide\dimen@\p@
  \count@\ifdim\dimen@<\z@\z@\else\dimen@\fi
  \edef#1{\the\count@\space}}
\def\color@rgb#1#2{\c@lor@@rgb#2\@@#1}
\def\c@lor@@rgb#1,#2,#3\@@#4{%
  \c@lor@arg{#1}%
  \c@lor@rgb@RGB\@tempa
  \c@lor@arg{#2}%
  \c@lor@rgb@RGB\@tempb
  \c@lor@arg{#3}%
  \c@lor@rgb@RGB\@tempc
  \edef#4{\@tempa\@tempb\@tempc}%
  }
\def\c@lor@rgb@RGB#1{%
  \dimen@\@cclv\dimen@
  \count@\dimen@
  \divide\count@\p@
  \edef#1{\the\count@\space}}
\def\color@RGB#1#2{\c@lor@@RGB#2\@@#1}
\def\c@lor@@RGB#1,#2,#3\@@#4{%
  \edef#4{#1 #2 #3}%
  }
\def\color@named#1#2{\c@lor@@named#2,,\@@#1}
\def\c@lor@@named#1,#2,#3\@@#4{%
  \@ifundefined{col@#1}%
    {\PackageError{color}{Undefined color `#1'}\@ehd}%
  {\edef#4{\csname col@#1\endcsname}}%
  }
\def\c@lor@to@ps#1#2 #3 #4\@@{%
  #1#2 255 div #3 255 div #4 255 div setrgbcolor}
\def\current@color{0 0 0}
\def\set@color{%
  \special{textcolor: \current@color}\aftergroup\reset@color}
\def\reset@color{\special{textcolor: \current@color}}
\def\set@page@color{%
  \c@lor@special\sixt@@n{background color ignored: \current@color}}
\def\define@color@named#1#2{%
  \expandafter\edef\csname col@#1\endcsname{#2}}
\AtBeginDocument{\def\color@block#1#2#3{%
  {\rlap{\ifcolors@
      \@defaultunits\count@\current@color\@nnil
      \dimen@\count@\p@
      \divide\dimen@\@cclv
      \dimen@ii#2%
      \advance\dimen@ii#3%
      \lower#3\hbox{%
      \special{language "Scientific Word";%
               type "greybox";%
               greyscale \strip@pt\dimen@;%
               height \the\dimen@ii;%
               width \the#1;%
               depth 0pt;}}%
           \fi}}}}
\def\Ginclude@eps#1{%
 \message{<#1>}%
 \raise\Gin@req@height\hbox{%
  \ifx\Gin@ollx\@undefined
  \else
    \@tempdimb \Gin@ourx bp%
    \advance\@tempdimb-\Gin@ollx bp%
    \@tempdima\Gin@llx bp%
    \advance\@tempdima-\Gin@ollx bp%
    \Gscale@div\TCI@cropleft\@tempdima\@tempdimb
    \@tempdima\Gin@urx bp%
    \advance\@tempdima-\Gin@ollx bp%
    \Gscale@div\TCI@cropright\@tempdima\@tempdimb
    \@tempdimb \Gin@oury bp%
    \advance\@tempdimb-\Gin@olly bp%
    \@tempdima\Gin@lly bp%
    \advance\@tempdima-\Gin@olly bp%
    \Gscale@div\TCI@cropbottom\@tempdima\@tempdimb
    \@tempdima\Gin@ury bp%
    \advance\@tempdima-\Gin@olly bp%
    \Gscale@div\TCI@croptop\@tempdima\@tempdimb
  \fi
    \special{%
      language \TCI@language;%
      type \TCI@type;%
      valid_file \TCI@validfile;%
      width \the\Gin@req@width;%
      height \the\Gin@req@height;%
      depth 0pt;%
      original-width \the\Gin@nat@width;%
      original-height \the\Gin@nat@height;%
      cropleft "\TCI@cropleft";%
      croptop "\TCI@croptop";%
      cropright "\TCI@cropright";%
      cropbottom "\TCI@cropbottom";%
      filename '#1';%
      \ifx\TCI@temp\@empty\else tempfilename \TCI@temp;\fi
      }}}
\def\TCI@language{"Scientific Word"}
\def\TCI@type{"GRAPHIC"}
\def\TCI@validfile{'F'}
\def\TCI@cropleft{0}
\def\TCI@croptop{1}
\def\TCI@cropright{1}
\def\TCI@cropbottom{0}
\let\TCI@temp\@empty
\let\Ginclude@bmp\Ginclude@eps
\def\Gin@extensions{}
\@namedef{Gin@rule@.ps}#1{{eps}{.ps}{#1}}
\@namedef{Gin@rule@.eps}#1{{eps}{.eps}{#1}}
\@namedef{Gin@rule@.PS}#1{{eps}{.PS}{#1}}
\@namedef{Gin@rule@.EPS}#1{{eps}{.EPS}{#1}}
\@namedef{Gin@rule@*}#1{{bmp}{\Gin@ext}{#1}}
\def\Gin@PS@raw#1{}
\def\Gin@PS@restored#1{}
\def\Gin@PS@literal@header#1{}
\def\Gin@PS@file@header#1{}
\endinput
%%
%% End of file `tcidvi.def'.
