%%% Unicode to TeX mapping, file uni-176.def, U+B000..U+B0FF, autogenerated by makeunidef.pl
\ifx\ProvidesFile\undefined\else
\ProvidesFile{uni-176.def}[2022/08/07 UCS: Unicode data U+B000..U+B0FF]%
\fi
\gdef\u@cjk@hangul#1#2#3#4{{\fontencoding{C61}\def\CJK@plane{#1#2}\selectfont\char"#3#4\relax}}%
\uc@dclc{45056}{cjkhangul}{\u@cjk@hangul0788}%
\uc@dclc{45057}{cjkhangul}{\u@cjk@hangul0789}%
\uc@dclc{45060}{cjkhangul}{\u@cjk@hangul078A}%
\uc@dclc{45068}{cjkhangul}{\u@cjk@hangul078B}%
\uc@dclc{45072}{cjkhangul}{\u@cjk@hangul078C}%
\uc@dclc{45076}{cjkhangul}{\u@cjk@hangul078D}%
\uc@dclc{45084}{cjkhangul}{\u@cjk@hangul078E}%
\uc@dclc{45085}{cjkhangul}{\u@cjk@hangul078F}%
\uc@dclc{45096}{cjkhangul}{\u@cjk@hangul0790}%
\uc@dclc{45124}{cjkhangul}{\u@cjk@hangul0791}%
\uc@dclc{45125}{cjkhangul}{\u@cjk@hangul0792}%
\uc@dclc{45128}{cjkhangul}{\u@cjk@hangul0793}%
\uc@dclc{45130}{cjkhangul}{\u@cjk@hangul0794}%
\uc@dclc{45132}{cjkhangul}{\u@cjk@hangul0795}%
\uc@dclc{45134}{cjkhangul}{\u@cjk@hangul0796}%
\uc@dclc{45139}{cjkhangul}{\u@cjk@hangul0797}%
\uc@dclc{45140}{cjkhangul}{\u@cjk@hangul0798}%
\uc@dclc{45141}{cjkhangul}{\u@cjk@hangul0799}%
\uc@dclc{45143}{cjkhangul}{\u@cjk@hangul079A}%
\uc@dclc{45145}{cjkhangul}{\u@cjk@hangul079B}%
\uc@dclc{45149}{cjkhangul}{\u@cjk@hangul079C}%
\uc@dclc{45180}{cjkhangul}{\u@cjk@hangul079D}%
\uc@dclc{45181}{cjkhangul}{\u@cjk@hangul079E}%
\uc@dclc{45184}{cjkhangul}{\u@cjk@hangul079F}%
\uc@dclc{45188}{cjkhangul}{\u@cjk@hangul07A0}%
\uc@dclc{45196}{cjkhangul}{\u@cjk@hangul07A1}%
\uc@dclc{45197}{cjkhangul}{\u@cjk@hangul07A2}%
\uc@dclc{45199}{cjkhangul}{\u@cjk@hangul07A3}%
\uc@dclc{45201}{cjkhangul}{\u@cjk@hangul07A4}%
\uc@dclc{45208}{cjkhangul}{\u@cjk@hangul07A5}%
\uc@dclc{45209}{cjkhangul}{\u@cjk@hangul07A6}%
\uc@dclc{45210}{cjkhangul}{\u@cjk@hangul07A7}%
\uc@dclc{45212}{cjkhangul}{\u@cjk@hangul07A8}%
\uc@dclc{45215}{cjkhangul}{\u@cjk@hangul07A9}%
\uc@dclc{45216}{cjkhangul}{\u@cjk@hangul07AA}%
\uc@dclc{45217}{cjkhangul}{\u@cjk@hangul07AB}%
\uc@dclc{45218}{cjkhangul}{\u@cjk@hangul07AC}%
\uc@dclc{45224}{cjkhangul}{\u@cjk@hangul07AD}%
\uc@dclc{45225}{cjkhangul}{\u@cjk@hangul07AE}%
\uc@dclc{45227}{cjkhangul}{\u@cjk@hangul07AF}%
\uc@dclc{45228}{cjkhangul}{\u@cjk@hangul07B0}%
\uc@dclc{45229}{cjkhangul}{\u@cjk@hangul07B1}%
\uc@dclc{45230}{cjkhangul}{\u@cjk@hangul07B2}%
\uc@dclc{45231}{cjkhangul}{\u@cjk@hangul07B3}%
\uc@dclc{45233}{cjkhangul}{\u@cjk@hangul07B4}%
\uc@dclc{45235}{cjkhangul}{\u@cjk@hangul07B5}%
\uc@dclc{45236}{cjkhangul}{\u@cjk@hangul07B6}%
\uc@dclc{45237}{cjkhangul}{\u@cjk@hangul07B7}%
\uc@dclc{45240}{cjkhangul}{\u@cjk@hangul07B8}%
\uc@dclc{45244}{cjkhangul}{\u@cjk@hangul07B9}%
\uc@dclc{45252}{cjkhangul}{\u@cjk@hangul07BA}%
\uc@dclc{45253}{cjkhangul}{\u@cjk@hangul07BB}%
\uc@dclc{45255}{cjkhangul}{\u@cjk@hangul07BC}%
\uc@dclc{45256}{cjkhangul}{\u@cjk@hangul07BD}%
\uc@dclc{45257}{cjkhangul}{\u@cjk@hangul07BE}%
\uc@dclc{45264}{cjkhangul}{\u@cjk@hangul07BF}%
\uc@dclc{45265}{cjkhangul}{\u@cjk@hangul07C0}%
\uc@dclc{45268}{cjkhangul}{\u@cjk@hangul07C1}%
\uc@dclc{45272}{cjkhangul}{\u@cjk@hangul07C2}%
\uc@dclc{45280}{cjkhangul}{\u@cjk@hangul07C3}%
\uc@dclc{45285}{cjkhangul}{\u@cjk@hangul07C4}%
%%% Local Variables: 
%%% mode: latex
%%% coding: utf-8
%%% End: 
