%%% Unicode to TeX mapping, file uni-210.def, U+D200..U+D2FF, autogenerated by makeunidef.pl
\ifx\ProvidesFile\undefined\else
\ProvidesFile{uni-210.def}[2022/08/07 UCS: Unicode data U+D200..U+D2FF]%
\fi
\gdef\u@cjk@hangul#1#2#3#4{{\fontencoding{C61}\def\CJK@plane{#1#2}\selectfont\char"#3#4\relax}}%
\uc@dclc{53767}{cjkhangul}{\u@cjk@hangul1489}%
\uc@dclc{53769}{cjkhangul}{\u@cjk@hangul148A}%
\uc@dclc{53776}{cjkhangul}{\u@cjk@hangul148B}%
\uc@dclc{53804}{cjkhangul}{\u@cjk@hangul148C}%
\uc@dclc{53805}{cjkhangul}{\u@cjk@hangul148D}%
\uc@dclc{53808}{cjkhangul}{\u@cjk@hangul148E}%
\uc@dclc{53812}{cjkhangul}{\u@cjk@hangul148F}%
\uc@dclc{53820}{cjkhangul}{\u@cjk@hangul1490}%
\uc@dclc{53821}{cjkhangul}{\u@cjk@hangul1491}%
\uc@dclc{53823}{cjkhangul}{\u@cjk@hangul1492}%
\uc@dclc{53825}{cjkhangul}{\u@cjk@hangul1493}%
\uc@dclc{53832}{cjkhangul}{\u@cjk@hangul1494}%
\uc@dclc{53852}{cjkhangul}{\u@cjk@hangul1495}%
\uc@dclc{53860}{cjkhangul}{\u@cjk@hangul1496}%
\uc@dclc{53888}{cjkhangul}{\u@cjk@hangul1497}%
\uc@dclc{53889}{cjkhangul}{\u@cjk@hangul1498}%
\uc@dclc{53892}{cjkhangul}{\u@cjk@hangul1499}%
\uc@dclc{53896}{cjkhangul}{\u@cjk@hangul149A}%
\uc@dclc{53904}{cjkhangul}{\u@cjk@hangul149B}%
\uc@dclc{53905}{cjkhangul}{\u@cjk@hangul149C}%
\uc@dclc{53909}{cjkhangul}{\u@cjk@hangul149D}%
\uc@dclc{53916}{cjkhangul}{\u@cjk@hangul149E}%
\uc@dclc{53920}{cjkhangul}{\u@cjk@hangul149F}%
\uc@dclc{53924}{cjkhangul}{\u@cjk@hangul14A0}%
\uc@dclc{53932}{cjkhangul}{\u@cjk@hangul14A1}%
\uc@dclc{53937}{cjkhangul}{\u@cjk@hangul14A2}%
\uc@dclc{53944}{cjkhangul}{\u@cjk@hangul14A3}%
\uc@dclc{53945}{cjkhangul}{\u@cjk@hangul14A4}%
\uc@dclc{53948}{cjkhangul}{\u@cjk@hangul14A5}%
\uc@dclc{53951}{cjkhangul}{\u@cjk@hangul14A6}%
\uc@dclc{53952}{cjkhangul}{\u@cjk@hangul14A7}%
\uc@dclc{53954}{cjkhangul}{\u@cjk@hangul14A8}%
\uc@dclc{53960}{cjkhangul}{\u@cjk@hangul14A9}%
\uc@dclc{53961}{cjkhangul}{\u@cjk@hangul14AA}%
\uc@dclc{53963}{cjkhangul}{\u@cjk@hangul14AB}%
\uc@dclc{53972}{cjkhangul}{\u@cjk@hangul14AC}%
\uc@dclc{53976}{cjkhangul}{\u@cjk@hangul14AD}%
\uc@dclc{53980}{cjkhangul}{\u@cjk@hangul14AE}%
\uc@dclc{53988}{cjkhangul}{\u@cjk@hangul14AF}%
\uc@dclc{53989}{cjkhangul}{\u@cjk@hangul14B0}%
\uc@dclc{54000}{cjkhangul}{\u@cjk@hangul14B1}%
\uc@dclc{54001}{cjkhangul}{\u@cjk@hangul14B2}%
\uc@dclc{54004}{cjkhangul}{\u@cjk@hangul14B3}%
\uc@dclc{54008}{cjkhangul}{\u@cjk@hangul14B4}%
%%% Local Variables: 
%%% mode: latex
%%% coding: utf-8
%%% End: 
