%!TEX encoding = UTF-8 Unicode
%
% Translation completed, 01/03/2020
\ProvidesFile{ecvlt.def}[europecv Lithuanian definitions]
% Personal information
\def\ecv@infosectionkey{\ecv@utf{Asmenin{\.e} informacija}}
\def\ecv@datekey{\ecv@utf{Atnaujinta}}
\def\ecv@namekey{\ecv@utf{Vardas~(-ai)~/ Pavard{\.e}~(-s)}}
\def\ecv@addresskey{\ecv@utf{Adresas~(-ai)}}
\def\ecv@telkey{\ecv@utf{Telefonas~(-ai)}}
\def\ecv@faxkey{\ecv@utf{Fax}}
\def\ecv@mobilekey{\ecv@utf{Mobilus}}
\def\ecv@officekey{\ecv@utf{Biuras}}
\def\ecv@emailkey{\ecv@utf{El. pa{\v s}tas~(-ai)}}
\def\ecv@professionalkey{\ecv@utf{Profesionalus el. Paštas}}
\def\ecv@skypekey{\ecv@utf{Skype}}
\def\ecv@matrixriotkey{\ecv@utf{Matrix/Riot}}
\def\ecv@youtubekey{\ecv@utf{YouTube}}
\def\ecv@peckey{\ecv@utf{PEC}}
\def\ecv@homepagekey{\ecv@utf{Pagrindinis puslapis}}
\def\ecv@nationalitykey{\ecv@utf{Pilietyb{\.e}}}
\def\ecv@birthkey{\ecv@utf{Gimimo data}}
\def\ecv@genderkey{\ecv@utf{Lytis}}
% Footer
\def\ecv@pagekey{\ecv@utf{Puslapis}}
\def\ecv@cvofkey{\ecv@utf{Gyvenimo apra{\v s}ymas}}
% Language table
\def\ecv@mothertonguekey{\ecv@utf{Gimtoji kalba~(-os)}}
\def\ecv@assesskey{\ecv@utf{{\k I}sivertinimas}}
\def\ecv@levelkey{\ecv@utf{Europos lygis}}
\def\ecv@understandkey{\ecv@utf{Supratimas}}
\def\ecv@speakkey{\ecv@utf{Kalb{\.e}jimas}}
\def\ecv@writekey{\ecv@utf{Ra{\v s}ymas}}
\def\ecv@listenkey{\ecv@utf{Klausymas}}
\def\ecv@readkey{\ecv@utf{Skaitymas}}
\def\ecv@interactkey{\ecv@utf{Bendravimas {\v z}od{\v z}iu}}
\def\ecv@productkey{\ecv@utf{Informacijos pateikimas {\v z}od{\v z}iu}}
\def\ecv@langfooterkey{\ecv@utf{Bendrieji kalb{\k u} metmenys Europoje}}
\def\ecv@cefbasickey{\ecv@utf{Pradedantis vartotojas}}
\def\ecv@cefindepkey{\ecv@utf{Pa{\v z}eng{\k e}s vartotojas}}
\def\ecv@cefprofkey{\ecv@utf{{\k I}gud{\k e}s vartotojas}}

\renewcommand*{\ecvbranding}{\ecv@utf{\Large\textbf{E\ecv@kern u\ecv@kern
r\ecv@kern o\ecv@kern p\ecv@kern a\ecv@kern s\ecv@kern s}\\[5pt]}}
\renewcommand*\ecvtitle{\ecvbranding\ecv@utf{
\Large\textbf{G\ecv@kern y\ecv@kern v\ecv@kern e\ecv@kern
n\ecv@kern i\ecv@kern m\ecv@kern o \ecv@kern \ecv@kern a\ecv@kern p\ecv@kern
r\ecv@kern a\ecv@kern {\v s}\ecv@kern y\ecv@kern m\ecv@kern a\ecv@kern s}}}
