%%
%% This is file `t1renc.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% t1renc.dtx  (with options: `encoding')
%% 
%% IMPORTANT NOTICE:
%% 
%% For the copyright see the source file.
%% 
%% Any modified versions of this file must be renamed
%% with new filenames distinct from t1renc.def.
%% 
%% For distribution of the original source see the terms
%% for copying and modification in the file t1renc.dtx.
%% 
%% This generated file may be distributed as long as the
%% original source files, as listed above, are part of the
%% same distribution. (The sources need not necessarily be
%% in the same archive or directory.)
%% \CheckSum{474}
\ProvidesFile{t1renc.def}
   [1998/12/17 Relaxed TeX latin text encoding, version 1.00 (beta)]
\@ifundefined{RE@text@variable}{%
   \PackageError{T1R encoding}{%
      The definition of the T1R encoding requires that\MessageBreak
      the `relenc' package is loaded first}%
   {The T1R encoding cannot be defined.\MessageBreak
      If you continue, you will most likely face further errors.%
      \MessageBreak The best option is to type `x' and fix your
      manuscript.}%
   \endinput
}{}
\DeclareFontEncoding{T1R}{}{}
\DeclareFontSubstitution{T1R}{zcm}{m}{n}
\SetEncodingSearchPath{T1R}{
   {\cf@encoding/\f@family/\f@series/\f@shape}
   {\cf@encoding/\f@family/?/\f@shape}
   {\cf@encoding/\f@family/?/?}
   {\cf@encoding/?/?/?}
   {\RE@convert@nfss{T1}}
   {\RE@convert@nfss{?}}
}
\DeclareTextAccent{\`}{T1R}{0}
\DeclareTextAccent{\'}{T1R}{1}
\DeclareTextAccent{\^}{T1R}{2}
\DeclareTextAccent{\~}{T1R}{3}
\DeclareTextAccent{\"}{T1R}{4}
\DeclareTextVariableAccent{\H}{T1R}{5}
\DeclareTextAccent{\r}{T1R}{6}
\DeclareTextVariableAccent{\v}{T1R}{7}
\DeclareTextVariableAccent{\u}{T1R}{8}
\DeclareTextAccent{\=}{T1R}{9}
\DeclareTextVariableAccent{\.}{T1R}{10}
\DeclareTextCommand{\b}{T1R}[1]
   {{\o@lign{\relax#1\crcr\hidewidth\sh@ft{29}%
     \vbox to.2ex{\hbox{\char9}\vss}\hidewidth}}}
\DeclareTextVariableCommand{\c}{T1R}[1]
   {\setbox\z@\hbox{#1}\ifdim\ht\z@=1ex\accent11 #1%
     \else{\ooalign{\hidewidth\char11\hidewidth
        \crcr\unhbox\z@}}\fi}
\DeclareTextCommand{\d}{T1R}[1]
   {{\o@lign{\relax#1\crcr\hidewidth\sh@ft{10}.\hidewidth}}}
\DeclareTextVariableCommand{\k}{T1R}[1]
   {\oalign{\null#1\crcr\hidewidth\char12}}
\DeclareTextSymbol{\AE}{T1R}{198}
\DeclareTextSymbol{\DH}{T1R}{208}
\DeclareTextSymbol{\DJ}{T1R}{208}
\DeclareTextVariableSymbol{\L}{T1R}{138}
\DeclareTextVariableSymbol{\NG}{T1R}{141}
\DeclareTextSymbol{\OE}{T1R}{215}
\DeclareTextSymbol{\O}{T1R}{216}
\DeclareTextVariableSymbol{\SS}{T1R}{223}
\DeclareTextSymbol{\TH}{T1R}{222}
\DeclareTextSymbol{\ae}{T1R}{230}
\DeclareTextSymbol{\dh}{T1R}{240}
\DeclareTextVariableSymbol{\dj}{T1R}{158}
\DeclareTextSymbol{\guillemotleft}{T1R}{19}
\DeclareTextSymbol{\guillemotright}{T1R}{20}
\DeclareTextSymbol{\guilsinglleft}{T1R}{14}
\DeclareTextSymbol{\guilsinglright}{T1R}{15}
\DeclareTextSymbol{\i}{T1R}{25}
\DeclareTextSymbol{\j}{T1R}{26}
\DeclareTextVariableSymbol{\l}{T1R}{170}
\DeclareTextVariableSymbol{\ng}{T1R}{173}
\DeclareTextSymbol{\oe}{T1R}{247}
\DeclareTextSymbol{\o}{T1R}{248}
\DeclareTextSymbol{\quotedblbase}{T1R}{18}
\DeclareTextSymbol{\quotesinglbase}{T1R}{13}
\DeclareTextSymbol{\ss}{T1R}{255}
\DeclareTextSymbol{\textasciicircum}{T1R}{`\^}
\DeclareTextSymbol{\textasciitilde}{T1R}{`\~}
\DeclareTextSymbol{\textbackslash}{T1R}{`\\}
\DeclareTextSymbol{\textbar}{T1R}{`\|}
\DeclareTextSymbol{\textbraceleft}{T1R}{`\{}
\DeclareTextSymbol{\textbraceright}{T1R}{`\}}
\DeclareTextSymbol{\textcompwordmark}{T1R}{23}
\DeclareTextSymbol{\textdollar}{T1R}{`\$}
\DeclareTextSymbol{\textemdash}{T1R}{22}
\DeclareTextSymbol{\textendash}{T1R}{21}
\DeclareTextVariableSymbol{\textexclamdown}{T1R}{189}
\DeclareTextSymbol{\textgreater}{T1R}{`\>}
\DeclareTextSymbol{\textless}{T1R}{`\<}
\DeclareTextCommand{\textperthousand}{T1R}{\%\char 24 }
\DeclareTextCommand{\textpertenthousand}{T1R}{\%\char 24\char 24 }
\DeclareTextVariableSymbol{\textquestiondown}{T1R}{190}
\DeclareTextSymbol{\textquotedblleft}{T1R}{16}
\DeclareTextSymbol{\textquotedblright}{T1R}{17}
\DeclareTextSymbol{\textquotedbl}{T1R}{`\"}
\DeclareTextSymbol{\textquoteleft}{T1R}{`\`}
\DeclareTextSymbol{\textquoteright}{T1R}{`\'}
\DeclareTextVariableSymbol{\textsection}{T1R}{159}
\DeclareTextVariableSymbol{\textsterling}{T1R}{191}
\DeclareTextSymbol{\textunderscore}{T1R}{95}
\DeclareTextSymbol{\textvisiblespace}{T1R}{32}
\DeclareTextSymbol{\th}{T1R}{254}
\DefineTextVariantComposition{\.}{T1R}{}{}{}{i}{`\i}
\DefineTextVariantComposition{\u}{T1R}{}{}{}{A}{128}
\DefineTextVariantComposition{\k}{T1R}{}{}{}{A}{129}
\DeclareVariableTextComposition{\'}{T1R}{C}
\DefineTextVariantComposition{\v}{T1R}{}{}{}{C}{131}
\DefineTextVariantComposition{\v}{T1R}{}{}{}{D}{132}
\DefineTextVariantComposition{\v}{T1R}{}{}{}{E}{133}
\DefineTextVariantComposition{\k}{T1R}{}{}{}{E}{134}
\DefineTextVariantComposition{\u}{T1R}{}{}{}{G}{135}
\DeclareVariableTextComposition{\'}{T1R}{L}
\DefineTextVariantComposition{\v}{T1R}{}{}{}{L}{137}
\DeclareVariableTextComposition{\'}{T1R}{N}
\DefineTextVariantComposition{\v}{T1R}{}{}{}{N}{140}
\DefineTextVariantComposition{\H}{T1R}{}{}{}{O}{142}
\DeclareVariableTextComposition{\'}{T1R}{R}
\DefineTextVariantComposition{\v}{T1R}{}{}{}{R}{144}
\DeclareVariableTextComposition{\'}{T1R}{S}
\DefineTextVariantComposition{\v}{T1R}{}{}{}{S}{146}
\DeclareVariableTextComposition{\c}{T1R}{S}
\DefineTextVariantComposition{\v}{T1R}{}{}{}{T}{148}
\DeclareVariableTextComposition{\c}{T1R}{T}
\DefineTextVariantComposition{\H}{T1R}{}{}{}{U}{150}
\DeclareVariableTextComposition{\r}{T1R}{U}
\DeclareVariableTextComposition{\"}{T1R}{Y}
\DeclareVariableTextComposition{\'}{T1R}{Z}
\DefineTextVariantComposition{\v}{T1R}{}{}{}{Z}{154}
\DefineTextVariantComposition{\.}{T1R}{}{}{}{Z}{155}
\DefineTextVariantComposition{\.}{T1R}{}{}{}{I}{157}
\DefineTextVariantComposition{\u}{T1R}{}{}{}{a}{160}
\DefineTextVariantComposition{\k}{T1R}{}{}{}{a}{161}
\DeclareVariableTextComposition{\'}{T1R}{c}
\DefineTextVariantComposition{\v}{T1R}{}{}{}{c}{163}
\DefineTextVariantComposition{\v}{T1R}{}{}{}{d}{164}
\DefineTextVariantComposition{\v}{T1R}{}{}{}{e}{165}
\DefineTextVariantComposition{\k}{T1R}{}{}{}{e}{166}
\DefineTextVariantComposition{\u}{T1R}{}{}{}{g}{167}
\DeclareVariableTextComposition{\'}{T1R}{l}
\DefineTextVariantComposition{\v}{T1R}{}{}{}{l}{169}
\DeclareVariableTextComposition{\'}{T1R}{n}
\DefineTextVariantComposition{\v}{T1R}{}{}{}{n}{172}
\DefineTextVariantComposition{\H}{T1R}{}{}{}{o}{174}
\DeclareVariableTextComposition{\'}{T1R}{r}
\DefineTextVariantComposition{\v}{T1R}{}{}{}{r}{176}
\DeclareVariableTextComposition{\'}{T1R}{s}
\DefineTextVariantComposition{\v}{T1R}{}{}{}{s}{178}
\DeclareVariableTextComposition{\c}{T1R}{s}
\DefineTextVariantComposition{\v}{T1R}{}{}{}{t}{180}
\DeclareVariableTextComposition{\c}{T1R}{t}
\DefineTextVariantComposition{\H}{T1R}{}{}{}{u}{182}
\DeclareVariableTextComposition{\r}{T1R}{u}
\DeclareVariableTextComposition{\"}{T1R}{y}
\DeclareVariableTextComposition{\'}{T1R}{z}
\DefineTextVariantComposition{\v}{T1R}{}{}{}{z}{186}
\DefineTextVariantComposition{\.}{T1R}{}{}{}{z}{187}
\DeclareTextComposite{\`}{T1R}{A}{192}
\DeclareTextComposite{\'}{T1R}{A}{193}
\DeclareTextComposite{\^}{T1R}{A}{194}
\DeclareTextComposite{\~}{T1R}{A}{195}
\DeclareTextComposite{\"}{T1R}{A}{196}
\DeclareTextComposite{\r}{T1R}{A}{197}
\DeclareTextComposite{\c}{T1R}{C}{199}
\DeclareTextComposite{\`}{T1R}{E}{200}
\DeclareTextComposite{\'}{T1R}{E}{201}
\DeclareTextComposite{\^}{T1R}{E}{202}
\DeclareTextComposite{\"}{T1R}{E}{203}
\DeclareTextComposite{\`}{T1R}{I}{204}
\DeclareTextComposite{\'}{T1R}{I}{205}
\DeclareTextComposite{\^}{T1R}{I}{206}
\DeclareTextComposite{\"}{T1R}{I}{207}
\DeclareTextComposite{\~}{T1R}{N}{209}
\DeclareTextComposite{\`}{T1R}{O}{210}
\DeclareTextComposite{\'}{T1R}{O}{211}
\DeclareTextComposite{\^}{T1R}{O}{212}
\DeclareTextComposite{\~}{T1R}{O}{213}
\DeclareTextComposite{\"}{T1R}{O}{214}
\DeclareTextComposite{\`}{T1R}{U}{217}
\DeclareTextComposite{\'}{T1R}{U}{218}
\DeclareTextComposite{\^}{T1R}{U}{219}
\DeclareTextComposite{\"}{T1R}{U}{220}
\DeclareTextComposite{\'}{T1R}{Y}{221}
\DeclareTextComposite{\`}{T1R}{a}{224}
\DeclareTextComposite{\'}{T1R}{a}{225}
\DeclareTextComposite{\^}{T1R}{a}{226}
\DeclareTextComposite{\~}{T1R}{a}{227}
\DeclareTextComposite{\"}{T1R}{a}{228}
\DeclareTextComposite{\r}{T1R}{a}{229}
\DeclareTextComposite{\c}{T1R}{c}{231}
\DeclareTextComposite{\`}{T1R}{e}{232}
\DeclareTextComposite{\'}{T1R}{e}{233}
\DeclareTextComposite{\^}{T1R}{e}{234}
\DeclareTextComposite{\"}{T1R}{e}{235}
\DeclareTextComposite{\`}{T1R}{i}{236}
\DeclareTextComposite{\`}{T1R}{\i}{236}
\DeclareTextComposite{\'}{T1R}{i}{237}
\DeclareTextComposite{\'}{T1R}{\i}{237}
\DeclareTextComposite{\^}{T1R}{i}{238}
\DeclareTextComposite{\^}{T1R}{\i}{238}
\DeclareTextComposite{\"}{T1R}{i}{239}
\DeclareTextComposite{\"}{T1R}{\i}{239}
\DeclareTextComposite{\~}{T1R}{n}{241}
\DeclareTextComposite{\`}{T1R}{o}{242}
\DeclareTextComposite{\'}{T1R}{o}{243}
\DeclareTextComposite{\^}{T1R}{o}{244}
\DeclareTextComposite{\~}{T1R}{o}{245}
\DeclareTextComposite{\"}{T1R}{o}{246}
\DeclareTextComposite{\`}{T1R}{u}{249}
\DeclareTextComposite{\'}{T1R}{u}{250}
\DeclareTextComposite{\^}{T1R}{u}{251}
\DeclareTextComposite{\"}{T1R}{u}{252}
\DeclareTextComposite{\'}{T1R}{y}{253}
\endinput
%%
%% End of file `t1renc.def'.
