%%
%% This is file `t2denc.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% ucs.dtx  (with options: `t2denc.def')
%% 
%% Copyright 2001 Dominique Unruh  <unruh@ut.ee>
%% Copyright 2013 Wolfgang Jeltsch <wolfgang@cs.ioc.ee>
%% Copyright 2022 David Carlisle https://github.com/LaTeX-Package-Repositories/ucs
%% 
%% This program is provided under the terms of the LaTeX Project Public License with some
%% modifications. See the file LICENSE for information.
%% 
\NeedsTeXFormat{LaTeX2e}[1998/12/01]%
\ProvidesFile{t2denc.def}[Experimental T2D]%
\DeclareFontEncoding{T2D}{}{}%
\DeclareFontSubstitution{\LastDeclaredEncoding}{cmr}{m}{n}%
\DeclareTextSymbol\CYRA\LastDeclaredEncoding{"C0}%
\DeclareTextSymbol\cyra\LastDeclaredEncoding{"E0}%
\DeclareTextSymbol\CYRB\LastDeclaredEncoding{"C1}%
\DeclareTextSymbol\cyrb\LastDeclaredEncoding{"E1}%
\DeclareTextSymbol\CYRV\LastDeclaredEncoding{"C2}%
\DeclareTextSymbol\cyrv\LastDeclaredEncoding{"E2}%
\DeclareTextSymbol\CYRG\LastDeclaredEncoding{"C3}%
\DeclareTextSymbol\cyrg\LastDeclaredEncoding{"E3}%
\DeclareTextSymbol\CYRD\LastDeclaredEncoding{"C4}%
\DeclareTextSymbol\cyrd\LastDeclaredEncoding{"E4}%
\DeclareTextSymbol\CYRE\LastDeclaredEncoding{"C5}%
\DeclareTextSymbol\cyre\LastDeclaredEncoding{"E5}%
\DeclareTextSymbol\CYRZH\LastDeclaredEncoding{"C6}%
\DeclareTextSymbol\cyrzh\LastDeclaredEncoding{"E6}%
\DeclareTextSymbol\CYRZ\LastDeclaredEncoding{"C7}%
\DeclareTextSymbol\cyrz\LastDeclaredEncoding{"E7}%
\DeclareTextSymbol\CYRI\LastDeclaredEncoding{"C8}%
\DeclareTextSymbol\cyri\LastDeclaredEncoding{"E8}%
\DeclareTextSymbol\CYRISHRT\LastDeclaredEncoding{"C9}%
\DeclareTextSymbol\cyrishrt\LastDeclaredEncoding{"E9}%
\DeclareTextSymbol\CYRK\LastDeclaredEncoding{"CA}%
\DeclareTextSymbol\cyrk\LastDeclaredEncoding{"EA}%
\DeclareTextSymbol\CYRL\LastDeclaredEncoding{"CB}%
\DeclareTextSymbol\cyrl\LastDeclaredEncoding{"EB}%
\DeclareTextSymbol\CYRM\LastDeclaredEncoding{"CC}%
\DeclareTextSymbol\cyrm\LastDeclaredEncoding{"EC}%
\DeclareTextSymbol\CYRN\LastDeclaredEncoding{"CD}%
\DeclareTextSymbol\cyrn\LastDeclaredEncoding{"ED}%
\DeclareTextSymbol\CYRO\LastDeclaredEncoding{"CE}%
\DeclareTextSymbol\cyro\LastDeclaredEncoding{"EE}%
\DeclareTextSymbol\CYRP\LastDeclaredEncoding{"CF}%
\DeclareTextSymbol\cyrp\LastDeclaredEncoding{"EF}%
\DeclareTextSymbol\CYRR\LastDeclaredEncoding{"D0}%
\DeclareTextSymbol\cyrr\LastDeclaredEncoding{"F0}%
\DeclareTextSymbol\CYRS\LastDeclaredEncoding{"D1}%
\DeclareTextSymbol\cyrs\LastDeclaredEncoding{"F1}%
\DeclareTextSymbol\CYRT\LastDeclaredEncoding{"D2}%
\DeclareTextSymbol\cyrt\LastDeclaredEncoding{"F2}%
\DeclareTextSymbol\CYRU\LastDeclaredEncoding{"D3}%
\DeclareTextSymbol\cyru\LastDeclaredEncoding{"F3}%
\DeclareTextSymbol\CYRF\LastDeclaredEncoding{"D4}%
\DeclareTextSymbol\cyrf\LastDeclaredEncoding{"F4}%
\DeclareTextSymbol\CYRH\LastDeclaredEncoding{"D5}%
\DeclareTextSymbol\cyrh\LastDeclaredEncoding{"F5}%
\DeclareTextSymbol\CYRC\LastDeclaredEncoding{"D6}%
\DeclareTextSymbol\cyrc\LastDeclaredEncoding{"F6}%
\DeclareTextSymbol\CYRCH\LastDeclaredEncoding{"D7}%
\DeclareTextSymbol\cyrch\LastDeclaredEncoding{"F7}%
\DeclareTextSymbol\CYRSH\LastDeclaredEncoding{"D8}%
\DeclareTextSymbol\cyrsh\LastDeclaredEncoding{"F8}%
\DeclareTextSymbol\CYRSHCH\LastDeclaredEncoding{"D9}%
\DeclareTextSymbol\cyrshch\LastDeclaredEncoding{"F9}%
\DeclareTextSymbol\CYRHRDSN\LastDeclaredEncoding{"DA}%
\DeclareTextSymbol\cyrhrdsn\LastDeclaredEncoding{"FA}%
\DeclareTextSymbol\CYRERY\LastDeclaredEncoding{"DB}%
\DeclareTextSymbol\cyrery\LastDeclaredEncoding{"FB}%
\DeclareTextSymbol\CYRSFTSN\LastDeclaredEncoding{"DC}%
\DeclareTextSymbol\cyrsftsn\LastDeclaredEncoding{"FC}%
\DeclareTextSymbol\CYREREV\LastDeclaredEncoding{"DD}%
\DeclareTextSymbol\cyrerev\LastDeclaredEncoding{"FD}%
\DeclareTextSymbol\CYRYU\LastDeclaredEncoding{"DE}%
\DeclareTextSymbol\cyryu\LastDeclaredEncoding{"FE}%
\DeclareTextSymbol\CYRYA\LastDeclaredEncoding{"DF}%
\DeclareTextSymbol\cyrya\LastDeclaredEncoding{"FF}%
\DeclareTextSymbol\CYRYO\LastDeclaredEncoding{"9C}%
\DeclareTextSymbol\cyryo\LastDeclaredEncoding{"BC}%
\DeclareTextSymbol\CYRDZE\LastDeclaredEncoding{"8F}%
\DeclareTextSymbol\cyrdze\LastDeclaredEncoding{"AF}%
\DeclareTextSymbol\CYRYAT\LastDeclaredEncoding{"93}%
\DeclareTextSymbol\cyryat\LastDeclaredEncoding{"B3}%
\DeclareTextSymbol\CYRBYUS\LastDeclaredEncoding{"97}%
\DeclareTextSymbol\cyrbyus\LastDeclaredEncoding{"B7}%
\DeclareTextSymbol\CYRIZH\LastDeclaredEncoding{"8A}%
\DeclareTextSymbol\cyrizh\LastDeclaredEncoding{"AA}%
\DeclareTextSymbol\CYRIE\LastDeclaredEncoding{"99}%
\DeclareTextSymbol\cyrie\LastDeclaredEncoding{"B9}%
\DeclareTextSymbol\CYREPS\LastDeclaredEncoding{"9B}%
\DeclareTextSymbol\cyreps\LastDeclaredEncoding{"BB}%
\DeclareTextSymbol\CYRAZ\LastDeclaredEncoding{"80}%
\DeclareTextSymbol\cyraz\LastDeclaredEncoding{"A0}%
\DeclareTextSymbol\CYRIAZ\LastDeclaredEncoding{"81}%
\DeclareTextSymbol\cyriaz\LastDeclaredEncoding{"A1}%
\DeclareTextSymbol\CYRLYUS\LastDeclaredEncoding{"82}%
\DeclareTextSymbol\cyrlyus\LastDeclaredEncoding{"A2}%
\DeclareTextSymbol\CYRIOTLYUS\LastDeclaredEncoding{"83}%
\DeclareTextSymbol\cyriotlyus\LastDeclaredEncoding{"A3}%
\DeclareTextSymbol\CYRGERV\LastDeclaredEncoding{"84}%
\DeclareTextSymbol\cyrgerv\LastDeclaredEncoding{"A4}%
\DeclareTextSymbol\CYRZEMLA\LastDeclaredEncoding{"86}%
\DeclareTextSymbol\cyrzemla\LastDeclaredEncoding{"A6}%
\DeclareTextSymbol\CYRKSI\LastDeclaredEncoding{"87}%
\DeclareTextSymbol\cyrksi\LastDeclaredEncoding{"A7}%
\DeclareTextSymbol\CYRVARIZHE\LastDeclaredEncoding{"88}%
\DeclareTextSymbol\cyrvarizhe\LastDeclaredEncoding{"A8}%
\DeclareTextSymbol\CYRIZHE\LastDeclaredEncoding{"89}%
\DeclareTextSymbol\cyrizhe\LastDeclaredEncoding{"A9}%
\DeclareTextSymbol\CYROMGA\LastDeclaredEncoding{"8B}%
\DeclareTextSymbol\cyromga\LastDeclaredEncoding{"AB}%
\DeclareTextSymbol\CYROMRND\LastDeclaredEncoding{"8C}%
\DeclareTextSymbol\cyromrnd\LastDeclaredEncoding{"AC}%
\DeclareTextSymbol\CYROT\LastDeclaredEncoding{"8D}%
\DeclareTextSymbol\cyrot\LastDeclaredEncoding{"AD}%
\DeclareTextSymbol\CYROMTLO\LastDeclaredEncoding{"8E}%
\DeclareTextSymbol\cyromtlo\LastDeclaredEncoding{"AE}%
\DeclareTextSymbol\CYRFITA\LastDeclaredEncoding{"90}%
\DeclareTextSymbol\cyrfita\LastDeclaredEncoding{"B0}%
\DeclareTextSymbol\CYRKOPPA\LastDeclaredEncoding{"91}%
\DeclareTextSymbol\cyrkoppa\LastDeclaredEncoding{"B1}%
\DeclareTextSymbol\CYRUK\LastDeclaredEncoding{"92}%
\DeclareTextSymbol\cyruk\LastDeclaredEncoding{"B2}%
\DeclareTextSymbol\CYRCHERV\LastDeclaredEncoding{"94}%
\DeclareTextSymbol\cyrcherv\LastDeclaredEncoding{"B4}%
\DeclareTextSymbol\CYRPSI\LastDeclaredEncoding{"95}%
\DeclareTextSymbol\cyrpsi\LastDeclaredEncoding{"B5}%
\DeclareTextSymbol\CYRSHTA\LastDeclaredEncoding{"96}%
\DeclareTextSymbol\cyrshta\LastDeclaredEncoding{"B6}%
\DeclareTextSymbol\CYRIOTBYUS\LastDeclaredEncoding{"98}%
\DeclareTextSymbol\cyriotbyus\LastDeclaredEncoding{"B8}%
\DeclareTextSymbol\CYRIOTEST\LastDeclaredEncoding{"9A}%
\DeclareTextSymbol\cyriotest\LastDeclaredEncoding{"BA}%
\DeclareTextSymbol\CYRNARROWE\LastDeclaredEncoding{"9B}%
\DeclareTextSymbol\cyrnarrowe\LastDeclaredEncoding{"BB}%
\DeclareTextAccent\`\LastDeclaredEncoding{"00}%
\DeclareTextAccent\'\LastDeclaredEncoding{"01}%
\DeclareTextAccent\^\LastDeclaredEncoding{"02}%
\DeclareTextAccent\~\LastDeclaredEncoding{"03}%
\DeclareTextAccent\"\LastDeclaredEncoding{"04}%
\DeclareTextAccent\H\LastDeclaredEncoding{"05}%
\DeclareTextAccent\r\LastDeclaredEncoding{"06}%
\DeclareTextAccent\v\LastDeclaredEncoding{"07}%
\DeclareTextAccent\u\LastDeclaredEncoding{"08}%
\DeclareTextAccent\=\LastDeclaredEncoding{"09}%
\DeclareTextAccent\.\LastDeclaredEncoding{"0A}%
\DeclareTextSymbol\cyrlangle\LastDeclaredEncoding{"0E}%
\DeclareTextSymbol\cyrrangle\LastDeclaredEncoding{"0F}%
\DeclareTextAccent\F\LastDeclaredEncoding{"12}%
\DeclareTextAccent\C\LastDeclaredEncoding{"13}%
\DeclareTextAccent\U\LastDeclaredEncoding{"14}%
\DeclareTextSymbol\cyrdash\LastDeclaredEncoding{"16}%
\DeclareTextSymbol\perthousand\LastDeclaredEncoding{"18}%
\DeclareTextSymbol\i\LastDeclaredEncoding{"19}%
\DeclareTextSymbol\j\LastDeclaredEncoding{"1A}%
\DeclareTextSymbol\CYRNo\LastDeclaredEncoding{"9D}%
\DeclareTextSymbol\textsection\LastDeclaredEncoding{"9F}%
\DeclareTextSymbol\quotedblbase\LastDeclaredEncoding{"BD}%
\DeclareTextSymbol\guillemotleft\LastDeclaredEncoding{"BE}%
\DeclareTextSymbol\guillemotright\LastDeclaredEncoding{"BF}%
\DeclareTextAccent\CYRtitlo\LastDeclaredEncoding{"0B}%
\DeclareTextAccent\CYRpalatal\LastDeclaredEncoding{"0C}%
\DeclareTextAccent\CYRpaerok\LastDeclaredEncoding{"0D}%
\DeclareTextAccent\CYRkamora\LastDeclaredEncoding{"17}%
\DeclareTextAccent\CYRpsili\LastDeclaredEncoding{"1B}%
\DeclareTextAccent\CYRdasia\LastDeclaredEncoding{"1C}%
\DeclareTextAccent\CYRzvat\LastDeclaredEncoding{"1D}%
\DeclareTextAccent\CYRpneuac\LastDeclaredEncoding{"1E}%
\DeclareTextAccent\CYRpneugrav\LastDeclaredEncoding{"1F}%
\DeclareTextAccent\CYRthousands\LastDeclaredEncoding{"9E}%
\DeclareTextSymbol\CYRNASH\LastDeclaredEncoding{"85}%
\DeclareTextSymbol\cyrnash\LastDeclaredEncoding{"A5}%
