%%% Unicode to TeX mapping, file uni-203.def, U+CB00..U+CBFF, autogenerated by makeunidef.pl
\ifx\ProvidesFile\undefined\else
\ProvidesFile{uni-203.def}[2022/08/07 UCS: Unicode data U+CB00..U+CBFF]%
\fi
\gdef\u@cjk@hangul#1#2#3#4{{\fontencoding{C61}\def\CJK@plane{#1#2}\selectfont\char"#3#4\relax}}%
\uc@dclc{51976}{cjkhangul}{\u@cjk@hangul1354}%
\uc@dclc{51984}{cjkhangul}{\u@cjk@hangul1355}%
\uc@dclc{51988}{cjkhangul}{\u@cjk@hangul1356}%
\uc@dclc{51992}{cjkhangul}{\u@cjk@hangul1357}%
\uc@dclc{52000}{cjkhangul}{\u@cjk@hangul1358}%
\uc@dclc{52001}{cjkhangul}{\u@cjk@hangul1359}%
\uc@dclc{52033}{cjkhangul}{\u@cjk@hangul135A}%
\uc@dclc{52040}{cjkhangul}{\u@cjk@hangul135B}%
\uc@dclc{52041}{cjkhangul}{\u@cjk@hangul135C}%
\uc@dclc{52044}{cjkhangul}{\u@cjk@hangul135D}%
\uc@dclc{52048}{cjkhangul}{\u@cjk@hangul135E}%
\uc@dclc{52056}{cjkhangul}{\u@cjk@hangul135F}%
\uc@dclc{52057}{cjkhangul}{\u@cjk@hangul1360}%
\uc@dclc{52061}{cjkhangul}{\u@cjk@hangul1361}%
\uc@dclc{52068}{cjkhangul}{\u@cjk@hangul1362}%
\uc@dclc{52088}{cjkhangul}{\u@cjk@hangul1363}%
\uc@dclc{52089}{cjkhangul}{\u@cjk@hangul1364}%
\uc@dclc{52124}{cjkhangul}{\u@cjk@hangul1365}%
\uc@dclc{52152}{cjkhangul}{\u@cjk@hangul1366}%
\uc@dclc{52180}{cjkhangul}{\u@cjk@hangul1367}%
\uc@dclc{52196}{cjkhangul}{\u@cjk@hangul1368}%
\uc@dclc{52199}{cjkhangul}{\u@cjk@hangul1369}%
\uc@dclc{52201}{cjkhangul}{\u@cjk@hangul136A}%
%%% Local Variables: 
%%% mode: latex
%%% coding: utf-8
%%% End: 
