%%% Unicode to TeX mapping, file uni-9.def, U+0900..U+09FF, autogenerated by makeunidef.pl
\ifx\ProvidesFile\undefined\else
\ProvidesFile{uni-9.def}[2022/08/07 UCS: Unicode data U+0900..U+09FF]%
\fi
\uc@dclc{2305}{default}{\uc@cmb\textdevanagaricandrabindu{#1}}%
\uc@dclc{2306}{default}{\uc@cmb\textdevanagarianusvara{#1}}%
\uc@dclc{2307}{default}{\uc@cmb\textdevanagarivisarga{#1}}%
\uc@dclc{2309}{default}{\textdevanagaria}%
\uc@dclc{2310}{default}{\textdevanagariaa}%
\uc@dclc{2311}{default}{\textdevanagarii}%
\uc@dclc{2312}{default}{\textdevanagariii}%
\uc@dclc{2313}{default}{\textdevanagariu}%
\uc@dclc{2314}{default}{\textdevanagariuu}%
\uc@dclc{2315}{default}{\textdevanagarivocalicr}%
\uc@dclc{2316}{default}{\textdevanagarivocalicl}%
\uc@dclc{2317}{default}{\textdevanagaricandrae}%
\uc@dclc{2318}{default}{\textdevanagarishorte}%
\uc@dclc{2319}{default}{\textdevanagarie}%
\uc@dclc{2320}{default}{\textdevanagariai}%
\uc@dclc{2321}{default}{\textdevanagaricandrao}%
\uc@dclc{2322}{default}{\textdevanagarishorto}%
\uc@dclc{2323}{default}{\textdevanagario}%
\uc@dclc{2324}{default}{\textdevanagariau}%
\uc@dclc{2325}{default}{\textdevanagarika}%
\uc@dclc{2326}{default}{\textdevanagarikha}%
\uc@dclc{2327}{default}{\textdevanagariga}%
\uc@dclc{2328}{default}{\textdevanagarigha}%
\uc@dclc{2329}{default}{\textdevanagaringa}%
\uc@dclc{2330}{default}{\textdevanagarica}%
\uc@dclc{2331}{default}{\textdevanagaricha}%
\uc@dclc{2332}{default}{\textdevanagarija}%
\uc@dclc{2333}{default}{\textdevanagarijha}%
\uc@dclc{2334}{default}{\textdevanagarinya}%
\uc@dclc{2335}{default}{\textdevanagaritta}%
\uc@dclc{2336}{default}{\textdevanagarittha}%
\uc@dclc{2337}{default}{\textdevanagaridda}%
\uc@dclc{2338}{default}{\textdevanagariddha}%
\uc@dclc{2339}{default}{\textdevanagarinna}%
\uc@dclc{2340}{default}{\textdevanagarita}%
\uc@dclc{2341}{default}{\textdevanagaritha}%
\uc@dclc{2342}{default}{\textdevanagarida}%
\uc@dclc{2343}{default}{\textdevanagaridha}%
\uc@dclc{2344}{default}{\textdevanagarina}%
\uc@dclc{2345}{default}{\textdevanagarinnna}%
\uc@dclc{2346}{default}{\textdevanagaripa}%
\uc@dclc{2347}{default}{\textdevanagaripha}%
\uc@dclc{2348}{default}{\textdevanagariba}%
\uc@dclc{2349}{default}{\textdevanagaribha}%
\uc@dclc{2350}{default}{\textdevanagarima}%
\uc@dclc{2351}{default}{\textdevanagariya}%
\uc@dclc{2352}{default}{\textdevanagarira}%
\uc@dclc{2353}{default}{\textdevanagarirra}%
\uc@dclc{2354}{default}{\textdevanagarila}%
\uc@dclc{2355}{default}{\textdevanagarilla}%
\uc@dclc{2356}{default}{\textdevanagarillla}%
\uc@dclc{2357}{default}{\textdevanagariva}%
\uc@dclc{2358}{default}{\textdevanagarisha}%
\uc@dclc{2359}{default}{\textdevanagarissa}%
\uc@dclc{2360}{default}{\textdevanagarisa}%
\uc@dclc{2361}{default}{\textdevanagariha}%
\uc@dclc{2364}{default}{\uc@cmb\textdevanagarinukta{#1}}%
\uc@dclc{2365}{default}{\textdevanagariavagraha}%
\uc@dclc{2366}{default}{\uc@cmb\textdevanagarivowelaa{#1}}%
\uc@dclc{2367}{default}{\uc@cmb\textdevanagarivoweli{#1}}%
\uc@dclc{2368}{default}{\uc@cmb\textdevanagarivowelii{#1}}%
\uc@dclc{2369}{default}{\uc@cmb\textdevanagarivowelu{#1}}%
\uc@dclc{2370}{default}{\uc@cmb\textdevanagarivoweluu{#1}}%
\uc@dclc{2371}{default}{\uc@cmb\textdevanagarivowelvocalicr{#1}}%
\uc@dclc{2372}{default}{\uc@cmb\textdevanagarivowelvocalicrr{#1}}%
\uc@dclc{2373}{default}{\uc@cmb\textdevanagarivowelcandrae{#1}}%
\uc@dclc{2374}{default}{\uc@cmb\textdevanagarivowelshorte{#1}}%
\uc@dclc{2375}{default}{\uc@cmb\textdevanagarivowele{#1}}%
\uc@dclc{2376}{default}{\uc@cmb\textdevanagarivowelai{#1}}%
\uc@dclc{2377}{default}{\uc@cmb\textdevanagarivowelcandrao{#1}}%
\uc@dclc{2378}{default}{\uc@cmb\textdevanagarivowelshorto{#1}}%
\uc@dclc{2379}{default}{\uc@cmb\textdevanagarivowelo{#1}}%
\uc@dclc{2380}{default}{\uc@cmb\textdevanagarivowelau{#1}}%
\uc@dclc{2381}{default}{\uc@cmb\textdevanagarivirama{#1}}%
\uc@dclc{2384}{default}{\textdevanagariom}%
\uc@dclc{2385}{default}{\uc@cmb\textdevanagariudatta{#1}}%
\uc@dclc{2386}{default}{\uc@cmb\textdevanagarianudatta{#1}}%
\uc@dclc{2387}{default}{\uc@cmb\@tabacckludge`{#1}}%
\uc@dclc{2388}{default}{\uc@cmb\@tabacckludge'{#1}}%
\uc@dclc{2392}{default}{\textdevanagariqa}%
\uc@dclc{2393}{default}{\textdevanagarikhha}%
\uc@dclc{2394}{default}{\textdevanagarighha}%
\uc@dclc{2395}{default}{\textdevanagariza}%
\uc@dclc{2396}{default}{\textdevanagaridddha}%
\uc@dclc{2397}{default}{\textdevanagarirha}%
\uc@dclc{2398}{default}{\textdevanagarifa}%
\uc@dclc{2399}{default}{\textdevanagariyya}%
\uc@dclc{2400}{default}{\textdevanagarivocalicrr}%
\uc@dclc{2401}{default}{\textdevanagarivocalicll}%
\uc@dclc{2402}{default}{\uc@cmb\textdevanagarivowelvocalicl{#1}}%
\uc@dclc{2403}{default}{\uc@cmb\textdevanagarivowelvocalicll{#1}}%
\uc@dclc{2404}{default}{\textdevanagaridanda}%
\uc@dclc{2405}{default}{\textdevanagaridoubledanda}%
\uc@dclc{2406}{default}{\textdevanagarizero}%
\uc@dclc{2407}{default}{\textdevanagarione}%
\uc@dclc{2408}{default}{\textdevanagaritwo}%
\uc@dclc{2409}{default}{\textdevanagarithree}%
\uc@dclc{2410}{default}{\textdevanagarifour}%
\uc@dclc{2411}{default}{\textdevanagarifive}%
\uc@dclc{2412}{default}{\textdevanagarisix}%
\uc@dclc{2413}{default}{\textdevanagariseven}%
\uc@dclc{2414}{default}{\textdevanagarieight}%
\uc@dclc{2415}{default}{\textdevanagarinine}%
\uc@dclc{2416}{default}{\textdevanagariabbreviation}%
%%% Local Variables: 
%%% mode: latex
%%% coding: utf-8
%%% End: 
