%!TEX encoding = UTF-8 Unicode
%
%
\ProvidesFile{europasscv_sl.def}[europasscv Slovenian definitions]
% Personal information
\def\ecv@infosectionkey{\ecv@utf{Osebni podatki}}
\def\ecv@namekey{\ecv@utf{Ime~/ Priimek}}
\def\ecv@addresskey{\ecv@utf{Naslov}}
\def\ecv@telkey{\ecv@utf{Telefon}}
\def\ecv@mobilekey{\ecv@utf{Prenosni telefon}}
\def\ecv@faxkey{\ecv@utf{Telefaks}}
\def\ecv@emailkey{\ecv@utf{E-po{\v s}ta}}
\def\ecv@nationalitykey{\ecv@utf{Dr{\v z}avljanstvo}}
\def\ecv@birthkey{\ecv@utf{Datum rojstva}}
\def\ecv@genderkey{\ecv@utf{Spol}}
% Footer
\def\ecv@pagekey{\ecv@utf{Stran}}
\def\ecv@cvofkey{\ecv@utf{{\v Z}ivljenjepis}}
% Language table
\def\ecv@mothertonguekey{\ecv@utf{Materni jezik}}
\def\ecv@otherlanguageskey{\ecv@utf{Tuji jeziki}}
\def\ecv@assesskey{\ecv@utf{Samovrednotenje}}
\def\ecv@levelkey{\ecv@utf{Evropska raven}}
\def\ecv@understandkey{\ecv@utf{RAZUMEVANJE}}
\def\ecv@speakkey{\ecv@utf{GOVORJENJE}}
\def\ecv@writekey{\ecv@utf{PISANJE}}
\def\ecv@listenkey{\ecv@utf{Slu{\v s}no razumevanje}}
\def\ecv@readkey{\ecv@utf{Bralno razumevanje}}
\def\ecv@interactkey{\ecv@utf{Govorno sporazumevanje}}
\def\ecv@productkey{\ecv@utf{Govorno sporo{\v c}anje}}
\def\ecv@langshortdesckey{\ecv@utf{Stopnja: A1/A2: Osnovni uporabnik -- B1/B2: Samostojni uporabnik -- C1/C2: Usposobljeni uporabnik}}
\def\ecv@langfooterkey{\ecv@utf{Skupni evropski jezikovni okvir}}
\def\ecv@langlinkkey{\ecv@utf{https://europass.cedefop.europa.eu/sl/resources/european-language-levels-cefr}}
\def\ecv@cefbasickey{\ecv@utf{Osnovni uporabnik}}
\def\ecv@cefindepkey{\ecv@utf{Samostojni uporabnik}}
\def\ecv@cefprofkey{\ecv@utf{Usposobljeni uporabnik}}
\def\ecv@europeanunionkey{\ecv@utf{Evropska unija}}
% Digital competences self-assessment grid
\def\ecv@digitalcompetenceskey{\ecv@utf{Digitalne kompetence}}
\def\ecv@informationprocessingkey{\ecv@utf{Obdelava informacij}}
\def\ecv@communicationkey{\ecv@utf{Komunikacija}}
\def\ecv@contentcreationkey{\ecv@utf{Ustvarjanje\\ vsebin}}
\def\ecv@safetykey{\ecv@utf{Varnost}}
\def\ecv@problensolvingkey{\ecv@utf{Re{\v s}evanje problemov}}
\def\ecv@digcompfooterkey{\ecv@utf{Digitalne kompetence - Samoocenjevalna lestvica}}
\def\ecv@digcomplinkkey{\ecv@utf{https://europass.cedefop.europa.eu/sl/resources/digital-competences}}
\def\ecv@dcbasickey{\ecv@utf{Osnovni uporabnik}}
\def\ecv@dcindepkey{\ecv@utf{Samostojni uporabnik}}
\def\ecv@dcprofkey{\ecv@utf{Usposobljeni uporabnik}}

% Width of language columns
\def\ecv@langcola{0.15}
\def\ecv@langcolb{0.15}
\def\ecv@langcolc{0.25}
\def\ecv@langcold{0.25}
\def\ecv@langcole{0.2}

